(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1064029,      24697]
NotebookOptionsPosition[   1024386,      23997]
NotebookOutlinePosition[   1025414,      24028]
CellTagsIndexPosition[   1025371,      24025]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Estimation of System Properties", "Title",ExpressionUUID->"4cc34c80-8806-4723-afae-8aad8dfaee4b"],

Cell["\<\
Experimental Data and Estimations for Setups of GEMC Simulations
& Comparison with its Results\
\>", "Subtitle",ExpressionUUID->"d0f29692-bbf9-4505-bd33-b38cefc5770d"],

Cell["\<\
This notebook is - in contrast to the others - intentionally based on the \
*.nb format.
Thereby the results are saved if the notebook is closed and can be \
re-examined any-time, for example when simulation results are investigated \
for plausibility.
It is recommended to execute entire sections or subsections, to ensure all \
necessary code is executed. \
\>", "Abstract",ExpressionUUID->"3eb46d30-9946-41f7-8b86-4c9558d9a50d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}], "\n", 
 RowBox[{"Get", "[", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{"\"\<pkg\>\"", ",", "\"\<PropertyPackage.wl\>\""}], "}"}], "]"}], 
  "]"}], "\n", 
 RowBox[{"Get", "[", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{"\"\<pkg\>\"", ",", "\"\<ForceFieldOPLS.wl\>\""}], "}"}], "]"}], 
  "]"}], "\n", 
 RowBox[{"Get", "[", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{"\"\<pkg\>\"", ",", "\"\<ChemicalThermoPackage.wl\>\""}], "}"}], 
   "]"}], "]"}]}], "Code",
 InitializationCell->True,
 CellLabel->"In[1]:=",ExpressionUUID->"eb8e52dc-3683-4c37-83ed-9994e71f8b90"],

Cell[CellGroupData[{

Cell["Pure Component", "Chapter",ExpressionUUID->"40be499d-edf5-4286-a365-4a28f3485f9b"],

Cell[CellGroupData[{

Cell["Component Name and Label", "Section",ExpressionUUID->"0b5c408b-e640-4b43-b45b-143a61cb01ba"],

Cell["\<\
Enter the name of the component and the OPLS-label.
The check will tell if they are present in the packages and additional \
information can be extracted.
Critical point data and Antoine parameter will be extracted from the \
\[OpenCurlyQuote]physicalPropertyData\[CloseCurlyQuote].
The LJ parameters will be extracted from \[OpenCurlyQuote]oplsNonBonded\
\[CloseCurlyQuote].\
\>", "Text",ExpressionUUID->"65aa9bbe-68f8-49e7-8516-6625826560b7"],

Cell[CellGroupData[{

Cell["Check-Function", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"cc4a6757-31b6-41ff-b742-747ef4f35b42"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CheckPureInput", "::", "usage"}], " ", "=", " ", 
   "\"\<CheckPureInput[] -> Checks if the variables 'component' and 'labelLj' \
are valid keys in 'physicalPropertyData' and 'oplsNonBonded'.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"CheckPureInput", "[", "]"}], " ", ":=", " ", 
  RowBox[{"(", "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"KeyExistsQ", "[", 
       RowBox[{"physicalPropertyData", ",", "component"}], "]"}], ",", 
      RowBox[{
      "Print", "[", "\"\<Component was found in 'physicalPropertyData'\>\"", 
       "]"}], ",", 
      RowBox[{
       RowBox[{
       "Print", "[", 
        "\"\<Component was NOT found in 'physicalPropertyData'\>\"", "]"}], 
       ";", 
       RowBox[{"Beep", "[", "]"}], ";"}]}], "]"}], ";", "\n", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"KeyExistsQ", "[", 
       RowBox[{"oplsNonBonded", ",", "labelLj"}], "]"}], ",", 
      RowBox[{
      "Print", "[", "\"\<Label was found in 'oplsNonBonded'\>\"", "]"}], ",", 
      RowBox[{
       RowBox[{
       "Print", "[", "\"\<Label was NOT found in 'oplsNonBonded'\>\"", "]"}], 
       ";", 
       RowBox[{"Beep", "[", "]"}], ";"}]}], "]"}], ";"}], "\n", 
   ")"}]}]}], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[5]:=",ExpressionUUID->"6c59b5ec-04ee-4917-953f-47d77a4489b2"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"component", "=", "\"\<Argon\>\""}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "name", " ", "of", " ", "the", " ", "component", " ", "in", " ", "the", 
     " ", "Property"}], "-", "Package"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"labelLj", " ", "=", " ", "\"\<Ar,Tan\>\""}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"name", " ", "of", " ", "the", " ", "OPLS"}], "-", 
    RowBox[{"label", " ", "in", " ", "the", " ", "ForceFieldOPLS"}], "-", 
    "Package"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"CheckPureInput", "[", "]"}]}], "Input",
 Background->RGBColor[1, 1, 0],
 CellLabel->"In[7]:=",ExpressionUUID->"96f54c96-010b-43c8-89b4-16419dcb7d52"],

Cell[CellGroupData[{

Cell[BoxData["\<\"Component was found in 'physicalPropertyData'\"\>"], "Print",
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"ca5e31de-fd2b-4ac9-b4b9-fd7732e5aac2"],

Cell[BoxData["\<\"Label was found in 'oplsNonBonded'\"\>"], "Print",
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"c05ec7f2-27a7-45b9-9aea-0ebf54021d5b"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Experimental and Physical Property Data", "Section",ExpressionUUID->"7fa950cc-0aab-40d2-8d23-235c5b00985b"],

Cell["\<\
In this section, experimental data can be entered and compared to the Antoine \
equation and Thol2016 EoS.
It will also be available in further sections. Be sure to update this section \
for your investigated component.\
\>", "Text",ExpressionUUID->"4a5478a5-88a9-4252-b855-fcf53dfa9cbf"],

Cell[CellGroupData[{

Cell["Experimental Data", "Subsection",ExpressionUUID->"03cf1172-7266-44a1-b482-895fc8516f20"],

Cell["\<\
literature references:
Argon ...\tCRC Handbook,99th Ed.,2019-2019
Ethane ...\tHorstmann S., et.al., GPA Research Rep., Rep.No. RR-203, 1-127, \
2010
\t\tCRC Handbook, 99th Ed., 6-125 - 6-127\
\>", "Text",ExpressionUUID->"a7cc6462-2c07-4996-b378-e60d6c034d51"],

Cell[TextData[{
 StyleBox["saturation densities:\trhoSatExp = {T[K], ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Rho]", "Vap"], TraditionalForm]],
  FontWeight->"Bold",ExpressionUUID->"ebb2c81b-026c-4a98-9349-0bea4f9a88a9"],
 StyleBox["[mol/dm\.b3], ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Rho]", "Liq"], TraditionalForm]],
  FontWeight->"Bold",ExpressionUUID->"b2320075-4d80-4a8d-b6f6-d6923d2488ed"],
 StyleBox["[mol/dm\.b3]}\nsaturation pressure:\tpSatExp = {T[K], P[bar]}",
  FontWeight->"Bold"]
}], "Text",ExpressionUUID->"5b40000c-8b99-4f86-aec4-0e29e2faff04"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"rhoSatExp", "=", 
    RowBox[{"<|", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\"\<Argon\>\"", "->", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"83.81", ",", "0.102", ",", "35.471"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"90.", ",", "0.186", ",", "34.52"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"100.", ",", "0.422", ",", "32.893"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"110.", ",", "0.833", ",", "31.1150"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"120.", ",", "1.505", ",", "29.113"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"130.", ",", "2.593", ",", "26.735"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"140.", ",", "4.478", ",", "23.623"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"150.", ",", "9.875", ",", "17.032"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"150.69", ",", "13.407", ",", "13.407"}], "}"}]}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<Ethane\>\"", "->", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"245.00", ",", "0.715", ",", "15.0283"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"262.53", ",", "1.19721", ",", "14.0805"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"278.61", ",", "1.95544", ",", "12.8168"}], "}"}]}], 
        "}"}]}]}], "\[IndentingNewLine]", "|>"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pSatExp", " ", "=", " ", 
   RowBox[{"<|", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\"\<Argon\>\"", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"83.806", ",", "0.68891"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"88.806", ",", "1.1842"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"93.806", ",", "1.9146"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"98.806", ",", "2.9414"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"103.81", ",", "4.33"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"108.81", ",", "6.1474"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"113.81", ",", "8.4634"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"118.81", ",", "11.349"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"123.81", ",", "14.877"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"128.81", ",", "19.125"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"133.81", ",", "24.174"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"138.81", ",", "30.118"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"143.81", ",", "37.071"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"148.81", ",", "45.197"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\"\<Ethane\>\"", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"120.", ",", "0.004"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"140.", ",", "0.038"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"160.", ",", "0.215"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"180.", ",", "0.787"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"200.", ",", "2.17"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"220.", ",", "4.92"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"240.", ",", "9.67"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"260.", ",", "17.12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"280.", ",", "28.06"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"300.", ",", "43.55"}], "}"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "|>"}]}], ";"}]}], "Code",
 InitializationCell->False,
 CellLabel->"In[10]:=",ExpressionUUID->"e2b5119c-03c0-4952-8b46-79d43339e8be"]
}, Closed]],

Cell[CellGroupData[{

Cell["Extract LJ Parameters", "Subsection",ExpressionUUID->"81da45b4-f0af-420c-8e8b-1cc1d169c0ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"obtain", " ", "LJ", " ", "parameters"}], "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Sigma]", 
       RowBox[{"(*", 
        RowBox[{"[", "\[Angstrom]", "]"}], "*)"}], ",", "\[Epsilon]"}], 
      RowBox[{"(*", 
       RowBox[{"[", 
        RowBox[{"kcal", " ", 
         RowBox[{"mol", "^", 
          RowBox[{"-", "1"}]}]}], "]"}], "*)"}], "}"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"oplsNonBonded", "[", "labelLj", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3"}], "}"}], "]"}], "]"}]}], ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "conversion", " ", "factors", " ", "for", " ", "T", " ", "from", " ", 
      "K"}], " ", ">", " ", 
     RowBox[{"reduced", " ", "Lj", " ", "Units"}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"tLjRedFac", " ", "=", "  ", 
     RowBox[{"1", " ", 
      RowBox[{"(*", "K", "*)"}], "/", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{"(*", 
         RowBox[{"kcal", " ", "/", "mol"}], "*)"}], " ", "*", 
        RowBox[{
         RowBox[{"4184", " ", 
          RowBox[{"(*", 
           RowBox[{"J", " ", "/", "mol"}], "*)"}], " ", "/", "nAvogadro"}], 
         "  ", 
         RowBox[{"(*", 
          RowBox[{"J", " ", "/", "1"}], "*)"}], " ", "/", "kB"}]}], " ", 
       RowBox[{"(*", "1", "*)"}], ")"}]}]}], " ", 
    RowBox[{"(*", 
     SuperscriptBox["t", "*"], "*)"}], " ", ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{"conversion", " ", "factors", " ", "for", " ", "rho", 
     RowBox[{"(", "T", ")"}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"rhoLjRedFac", " ", "=", " ", 
     RowBox[{"1", " ", 
      RowBox[{"(*", 
       RowBox[{"mol", "/", 
        SuperscriptBox["dm", "3"]}], "*)"}], " ", "*", "nAvogadro", " ", 
      RowBox[{"(*", 
       RowBox[{"1", "/", 
        SuperscriptBox["dm", "3"]}], "*)"}], " ", "*", 
      RowBox[{"10", "^", 
       RowBox[{"(", 
        RowBox[{"-", "27"}], ")"}]}], " ", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"1", "/", 
         SuperscriptBox["A", "3"]}], ")"}], "*)"}], " ", "*", 
      RowBox[{"\[Sigma]", "^", "3"}]}]}], " ", 
    RowBox[{"(*", "1", "*)"}], ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{"conversion", " ", "factors", " ", "for", " ", "rho", 
     RowBox[{"(", "T", ")"}], " ", "and", " ", "p", 
     RowBox[{"(", "T", ")"}], " ", "data"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"pLjRedFac", " ", "=", " ", 
     RowBox[{"1", " ", 
      RowBox[{"(*", "bar", "*)"}], " ", "*", 
      SuperscriptBox["10", "5"], " ", 
      RowBox[{"(*", "Pa", "*)"}], "  ", "*", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Sigma]", " ", 
          RowBox[{"(*", "A", "*)"}], " ", "*", " ", 
          SuperscriptBox["10", 
           RowBox[{"-", "10"}]]}], " ", 
         RowBox[{"(*", "m", "*)"}], ")"}], "^", "3"}], " ", 
       RowBox[{"(*", 
        SuperscriptBox["m", "3"], "*)"}], " ", "/", " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"(*", 
          RowBox[{"kcal", " ", "/", "mol"}], "*)"}], " ", "*", 
         RowBox[{"4184", " ", 
          RowBox[{"(*", 
           RowBox[{"J", " ", "/", "mol"}], "*)"}], " ", "/", "nAvogadro"}]}], 
        "  ", 
        RowBox[{"(*", 
         RowBox[{"J", " ", "/", "1"}], "*)"}], ")"}]}]}]}], ";"}]}]}]], "Code",
 InitializationCell->False,
 CellLabel->"In[12]:=",ExpressionUUID->"970d64b2-42db-45af-ab06-05d8d3f96b04"]
}, Closed]],

Cell[CellGroupData[{

Cell["Compare Experimental Data with Antoine ", "Subsection",ExpressionUUID->"91bd02bf-33ef-47dc-ab27-f3d8bb01a5ae"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"KeyExistsQ", "[", 
     RowBox[{"physicalPropertyData", ",", "component"}], "]"}], " ", "&&", 
    " ", 
    RowBox[{"KeyExistsQ", "[", 
     RowBox[{
      RowBox[{"physicalPropertyData", "[", "component", "]"}], ",", 
      "\"\<antoineParameters\>\""}], "]"}], " ", "&&", " ", 
    RowBox[{"KeyExistsQ", "[", 
     RowBox[{"pSatExp", ",", "component"}], "]"}]}], ",", "\n", "\t", 
   RowBox[{"Show", "[", 
    RowBox[{"{", "\n", "\t\t", 
     RowBox[{
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"pAntoine", "[", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"physicalPropertyData", "[", 
             RowBox[{
             "component", ",", "\"\<antoineParameters\>\"", ",", "1", ",", 
              " ", "#"}], "]"}], "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{"\"\<A\>\"", ",", "\"\<B\>\"", ",", "\"\<C\>\""}], 
            "}"}]}], ",", "\"\<log10\>\""}], "]"}], "\n", "\t\t\t", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"Min", "[", 
           RowBox[{"pSatExp", "\[LeftDoubleBracket]", 
            RowBox[{"component", ",", "All", ",", "1"}], 
            "\[RightDoubleBracket]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"physicalPropertyData", "[", 
            RowBox[{"component", ",", "\"\<tCrit\>\""}], "]"}], "+", "10"}]}],
          "}"}], "\n", "\t\t\t", ",", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"{", "\"\<Antoine\>\"", "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "component"}], ",", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
          "\"\<T [K]\>\"", ",", 
           "\"\<\!\(\*SuperscriptBox[SubscriptBox[\(P\), \(i\)], \(s\)]\) \
[bar]\>\""}], "}"}]}]}], "\n", "\t\t", "]"}], ",", "\n", "\t\t", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"pSatExp", "[", 
         RowBox[{"[", "component", "]"}], "]"}], ",", 
        RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}], ",", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"{", "\"\<Experimental\>\"", "}"}]}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Red", "}"}]}]}], "]"}], ",", "\n", "\t\t", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"physicalPropertyData", "[", 
            RowBox[{"component", ",", "\"\<tCrit\>\""}], "]"}], ",", 
           RowBox[{"physicalPropertyData", "[", 
            RowBox[{"component", ",", "\"\<pCrit\>\""}], "]"}]}], "}"}], 
         "}"}], ",", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"{", "\"\<Critical point\>\"", "}"}]}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", "Green", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
     "\t", "}"}], "]"}], ",", "\n", "\t", 
   RowBox[{"Print", "@", 
    RowBox[{"Style", "[", 
     RowBox[{
     "\"\<No Antoine parameter or experimental data are available!\>\"", ",", 
      "Bold", ",", "14"}], "]"}]}]}], "\n", "]"}]], "Code",
 InitializationCell->False,
 CellLabel->"In[16]:=",ExpressionUUID->"70ff5398-64cd-408e-b69f-3e082f351e44"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{{}, {}, 
        TagBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwVx3k4lAkAx/GZqfHQaJBy1DiSROlQ2snx9P4U1jHv2NWMjKsx86pEj6fs
NtKTO6RrtaWmcku0tn06diWVjBxrlcVKzixjMHmSWta0lm3/+D7f57NaEuMf
waDRaOTn/r+jf27G5Y8CLH545uQ8W0XM8IOjTKYFkAm1CsXmKqLS19Tv+owA
L/yNV/62UUU4e1w2KtQIUDBhYVrFUxFuO87drFgQgBPbk6/JUhF885N1dSwh
Et8+PK6nM0pEqkMWptYIsaS4s7aYNUbkpXBkfIEQfsWb/lm5QU0cSrKyXf9E
COMRunei+ySRuSCaWWYRgA5m8zFm4AfC3zTLRD8xANHLmxQjwmkigeY2t3k0
AJfg6+I0N0vMHbT7N8RrL/6+72l/rWWO6M27WlNxdy/4t7mJoQ9oOBBDe6Vv
GogOpP5wwWkRPGrlOinHA6Gb7+8828ZE2mDV/IqhQLxTS36sVmtjRTLLoHK3
CAGOdtUxRrrY81goiy4W4ZxkMLomTg8fntvku7OCcKsoY3dDtQGUfDulXXQQ
vnnX03m11hDc0ntqh84glNGujdmuNgL3qqMH3zUYlfU8pajUBKdZY49lN4Kh
bOFy3DaugivPaqZucQgaPdqezJqZw419nme2PwRU93wiK8MSZblJlLw1BAMy
cdJ+ZytUN0b9bscNxdA2UcEAwxqWsZmixiuhaLvYuk7cuBajbzeUZNDCIG+y
bG9rXQeaiqYrlIRhgGX7R1S7HerjXzZ+oQjD0QJ6ZIRqAyb6rDxc1u9D46na
klHPTYh4VvaGd2Yfmtw4RAR/C3DkZ5fkv/YhmlXayy52ABXWP63cKAY0gooS
xja0PY/r0wsT48J7rRyzIEdMZnet4V0Uoyg1sr3pzXb8YtGqYdeJoVmdEDMY
zEXHJ4Wm94MYmXRrU82bHSh0jQ96ZBMO3hFr7/wcZ5gQzd4We8Oh0/0t7SRc
gbJ++eUz4ViamvbwgOVOGLSfjrv4OBwOTGJ56xSBHd5bk+UT4Qh0OmbpMALo
r8tT37WUwIx+/Vb5Ozdk1xcNffW1BNlmN5sNJ3dB0XzIhZ4uwTF1m+Ig2x0+
ZpufVldJcCP3oDtnqwdObDnbOjcugcyHuNvm44nQ2xVufuZSEEavtHPSvsSY
MmKXrZ8UozTjysB7Xvg1etVhVqIU3vvLT8cOeSM4+NLswj0p4tcrukq3+yJn
SemyE8NSlDXWyHrieYi7/eDsHqUUCbLxS/IkHkQ+dVr2I1I0cd4HitJ54GQN
fupTSXHc7HxnTzYPhTqrhneqpdh04M+CkTIeKrS/u8+YkqL4XErCyi4eFFrx
gqx5KTrsnH3ojiRKSjNfShakeOY0THQ6kTjlecXLhUaBGeXYV06Q8Ep/4DpB
pzDEadIW+pJ4wZy05jMpSBpSHO5LSLxeTE0b6FKIzPyp5nw2iUclR2PUnz2U
wLA4fIXEdffkccVSCq+PDFrzckmEpeX1x+pRYNdvt9YtJ6Fc1F3fuYxCP8Ng
6vtnJBqKR4k7hhSsW9LTZA0kbu2eqUpfTuGjf9zT4BYSh1IN73CNKHR3Nay1
eU3Cd42Vrb4xhfr3Fnt0B0jY120pGvvst3MTNh+HSbClBKfWhIKAaV/YM05i
ksHPkZtSMDborVVMkvgPZukkLg==
           "]]}, 
         Annotation[#, "Charting`Private`Tag$46747#1"]& ]}}, {}}, {{}, {{{
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{{
                 GrayLevel[1], 
                 DiskBox[{0, 0}, 
                  Offset[{3, 3}]]}, 
                AbsoluteThickness[1.5], 
                Dashing[{}], 
                CircleBox[{0, 0}, 
                 Offset[{3, 3}]]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[1, 0, 0]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Scaled[9.75]], {{{83.806, 0.68891}}, {{88.806, 1.1842}}, {{93.806, 
          1.9146}}, {{98.806, 2.9414}}, {{103.81, 4.33}}, {{108.81, 
          6.1474}}, {{113.81, 8.4634}}, {{118.81, 11.349}}, {{123.81, 
          14.877}}, {{128.81, 19.125}}, {{133.81, 24.174}}, {{138.81, 
          30.118}}, {{143.81, 37.071}}, {{148.81, 
          45.197}}}]}}}, {{}, {}}}, {{}, {{{
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         PointBox[{{150.8, 48.7373}, {150.8, 48.7373}}]}}}, {{}, {}}}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {83.80600000000018, 0}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox[
        TagBox["\"T [K]\"", HoldForm], TraditionalForm], 
       FormBox[
        TagBox[
        "\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \\(i\\)], \
\\(s\\)]\\) [bar]\"", HoldForm], TraditionalForm]}, AxesOrigin -> {83.806, 0},
      DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"Argon\"", TraditionalForm], 
     PlotRange -> {{83.806, 160.8}, {0., 59.87313101956004}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"Antoine\""}, "LineLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Experimental\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Critical point\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 1, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellLabel->"Out[16]=",ExpressionUUID->"d0205640-9141-4bb2-8e07-cbcbb71b124a"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Does the component behave like a Lennard-Jones fluid?", "Subsection",ExpressionUUID->"bd3a149d-31f5-4059-b4af-edecf198209f"],

Cell[TextData[{
 "The experimental data is compared to the prediction of the Thol2016 EoS for \
LJ-fluids in reduced units.\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["T", "red"], "=", 
    RowBox[{"T", "/", 
     SubscriptBox["T", "C"]}]}], TraditionalForm]],ExpressionUUID->
  "05079ee5-c130-46c0-8105-02111c106adf"],
 "\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Rho]", "red"], "=", 
   RowBox[{"\[Rho]", "/", 
    SubscriptBox["\[Rho]", "C"]}]}]],
  CellChangeTimes->{{3.854793674201311*^9, 3.854793700148117*^9}, {
   3.854793731075485*^9, 3.8547937778787355`*^9}, {3.8547938112990923`*^9, 
   3.8547938991252627`*^9}, {3.8547939428119392`*^9, 
   3.8547939446960764`*^9}, {3.854794029794876*^9, 3.85479403126866*^9}},
  ExpressionUUID->"6c470c09-7d63-4350-bec9-36f3b927bb1a"],
 "\nThe experimental data is reduced using the critical point from the \
\[OpenCurlyDoubleQuote]physicalPropertyData\[CloseCurlyDoubleQuote]."
}], "Text",ExpressionUUID->"508de601-a947-4dcb-9ade-c403a078a626"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"KeyExistsQ", "[", 
     RowBox[{"physicalPropertyData", ",", "component"}], "]"}], " ", "&&", 
    " ", 
    RowBox[{"AllTrue", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"KeyExistsQ", "[", 
          RowBox[{
           RowBox[{"physicalPropertyData", "[", "component", "]"}], ",", 
           "#"}], "]"}], "&"}], "/@", 
        RowBox[{"{", 
         RowBox[{"\"\<vCrit\>\"", ",", "\"\<tCrit\>\""}], "}"}]}], ")"}], ",",
       "TrueQ"}], "]"}]}], ",", "\n", "\t", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tCrit", ",", "vCrit"}], "}"}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"tCrit", " ", "=", " ", 
       RowBox[{"physicalPropertyData", "[", 
        RowBox[{"component", ",", "\"\<tCrit\>\""}], "]"}]}], ";", "\n", "\t", 
      RowBox[{"vCrit", " ", "=", " ", 
       RowBox[{"physicalPropertyData", "[", 
        RowBox[{"component", ",", "\"\<vCrit\>\""}], "]"}]}], ";", "\n", "\t", 
      RowBox[{"Show", "[", "\n", "\t\t", 
       RowBox[{
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Rho]SatLiqRedLJ", "[", "tRed", "]"}], ",", 
            RowBox[{"\[Rho]SatVapRedLJ", "[", "tRed", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"tRed", ",", "0.5", ",", "1."}], "}"}], "\n", "\t\t\t", 
          RowBox[{"(*", 
           RowBox[{",", 
            RowBox[{
            "PlotLabel", "\[Rule]", " ", 
             "\"\<Reduced Density at Saturation\>\""}]}], "*)"}], "\n", 
          "\t\t\t", ",", 
          RowBox[{"Frame", "\[Rule]", "True"}], ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"#", ",", " ", "14"}], "]"}], "&"}], "/@", 
             RowBox[{"{", " ", 
              RowBox[{
              "\"\<\!\(\*SubscriptBox[\(T\), \(red\)]\) [1]\>\"", ",", " ", 
               "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(red\)]\) [1]\>\""}], 
              "}"}]}], ")"}]}], "\n", "\t\t\t", ",", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Saturated Liquid, Thol 2016 LJ-Fluid EOS\>\"", ",", 
             "\"\<Saturated Vapor, Thol 2016 LJ-Fluid EOS\>\""}], "}"}]}], 
          "\n", "\t\t\t", ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0.5", ",", " ", "1.05"}], "}"}], ",", " ", 
             "Automatic"}], "}"}]}]}], "\n", "\t\t", "]"}], ",", "\n", "\t\t", 
        RowBox[{"ListPlot", "[", 
         RowBox[{
          RowBox[{"{", "\n", "\t\t\t\t", 
           RowBox[{
            RowBox[{"Transpose", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"rhoSatExp", "\[LeftDoubleBracket]", 
                 RowBox[{"component", ",", "All", ",", "1"}], 
                 "\[RightDoubleBracket]"}], "/", "tCrit"}], ",", 
               RowBox[{
                RowBox[{"rhoSatExp", "\[LeftDoubleBracket]", 
                 RowBox[{"component", ",", "All", ",", "3"}], 
                 "\[RightDoubleBracket]"}], "*", "vCrit"}]}], "}"}], "]"}], 
            ",", "\n", "\t\t\t\t", 
            RowBox[{"Transpose", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"rhoSatExp", "\[LeftDoubleBracket]", 
                 RowBox[{"component", ",", "All", ",", "1"}], 
                 "\[RightDoubleBracket]"}], "/", "tCrit"}], ",", 
               RowBox[{
                RowBox[{"rhoSatExp", "\[LeftDoubleBracket]", 
                 RowBox[{"component", ",", "All", ",", "2"}], 
                 "\[RightDoubleBracket]"}], "*", "vCrit"}]}], "}"}], "]"}]}], 
           "\n", "\t\t\t", "}"}], ",", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Saturated Liquid, Experimental\>\"", ",", 
             "\"\<Saturated Vapor, Experimental\>\""}], "}"}]}], "\n", 
          "\t\t\t", ",", 
          RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}]}], "\n", 
         "\t\t", "]"}], ",", "\n", "\t\t", 
        RowBox[{"ListPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1.", ",", "1."}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}], ",", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"{", "\"\<Critical point\>\"", "}"}]}]}], "]"}]}], "\n", 
       "\t", "]"}]}]}], "]"}], ",", "\n", "\t", 
   RowBox[{"Print", "@", 
    RowBox[{"Style", "[", 
     RowBox[{
     "\"\<No critical point data available!\>\"", ",", "Bold", ",", "14"}], 
     "]"}]}]}], "\n", "]"}]], "Code",
 InitializationCell->False,
 CellLabel->"In[17]:=",ExpressionUUID->"4f4ab980-1b66-48c9-be9b-4fcbd56d55a7"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{{}, {}, 
        TagBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwVkHs0FPgDxeeNSUtC+fVwerC2EpW29HC/5Cc2j7KVktD0S8l6FJWtSIxG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           "]]}, Annotation[#, "Charting`Private`Tag$47469#1"]& ], 
        TagBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwVVHs0FfgW9swjGhlvzZWGEgkrPajx4bp6iqzpCoWhoms6FCEK5YgeHpMM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           "]]}, 
         Annotation[#, "Charting`Private`Tag$47469#2"]& ]}}, {}}, {{}, {{{
         Directive[
          PointSize[0.012833333333333334`], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{{
                 GrayLevel[1], 
                 DiskBox[{0, 0}, 
                  Offset[{3, 3}]]}, 
                AbsoluteThickness[1.5], 
                Dashing[{}], 
                CircleBox[{0, 0}, 
                 Offset[{3, 3}]]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  RGBColor[0.368417, 0.506779, 0.709798], 
                  AbsoluteThickness[1.6]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Scaled[9.75]], {{{0.5557692307692307, 2.6567778999999994`}}, {{
          0.5968169761273209, 2.585548}}, {{0.663129973474801, 
          2.4636856999999996`}}, {{0.7294429708222812, 2.3305135}}, {{
          0.7957559681697612, 2.1805637}}, {{0.8620689655172413, 
          2.0024515}}, {{0.9283819628647214, 1.7693626999999998`}}, {{
          0.9946949602122015, 1.2756968}}, {{0.9992705570291777, 
          1.0041843}}}]}, {
         Directive[
          PointSize[0.012833333333333334`], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{{
                 GrayLevel[1], 
                 PolygonBox[
                  NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                AbsoluteThickness[1.5], 
                Dashing[{}], 
                JoinedCurveBox[
                 NCache[
                  Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                  Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  RGBColor[0.880722, 0.611041, 0.142051], 
                  AbsoluteThickness[1.6]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Scaled[9.75]], {{{0.5557692307692307, 0.007639799999999999}}, {{
          0.5968169761273209, 0.013931399999999998`}}, {{0.663129973474801, 
          0.0316078}}, {{0.7294429708222812, 0.062391699999999994`}}, {{
          0.7957559681697612, 0.11272449999999998`}}, {{0.8620689655172413, 
          0.1942157}}, {{0.9283819628647214, 0.3354022}}, {{
          0.9946949602122015, 0.7396375}}, {{0.9992705570291777, 
          1.0041843}}}]}}}, {{}, {}}}, {{}, {{{
         Directive[
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          PointSize[0.015]], 
         PointBox[{{1., 1.}, {2., 1.}}]}}}, {{}, {}}}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0.5000000000000011, 0}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{0, 0}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0.5, 0}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         TagBox[
          StyleBox[
          "\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(red\\)]\\) [1]\"", 14, 
           StripOnInput -> False], HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
          StyleBox[
          "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(red\\)]\\) [1]\"", 14, 
           StripOnInput -> False], HoldForm], TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0.5, 1.05}, {0., 2.7727357165776034`}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{Automatic, Automatic}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{
          "\"Saturated Liquid, Thol 2016 LJ-Fluid EOS\"", 
           "\"Saturated Vapor, Thol 2016 LJ-Fluid EOS\""}, "LineLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{
          "\"Saturated Liquid, Experimental\"", 
           "\"Saturated Vapor, Experimental\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], ",", "9.75`"}],
                     "}"}]}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "False"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Critical point\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    PointSize[0.54]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    PointSize[0.54]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"PointSize", "[", "0.015`", "]"}]}], "]"}], "}"}],
                ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellLabel->"Out[17]=",ExpressionUUID->"cd7f2a09-9ef2-431e-a63a-ecc6d9550fc8"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulation point proposal, based on Thol2016 EoS", "Section",ExpressionUUID->"a293ef4b-084b-49b7-bd48-e86c986c3af2"],

Cell[TextData[{
 "The EoS by Thol uses LJ-reduced units for temperature, pressure and density \
which are denoted with an uppercase Asterisk.\n\t",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    SuperscriptBox["T", "*"], "=", 
    FractionBox[
     RowBox[{"T", "*", 
      SubscriptBox["k", "B"]}], "\[CurlyEpsilon]"]}],
   FontWeight->"Plain"]],ExpressionUUID->
  "c4a6ac08-cec0-4210-8372-3f853153b749"],
 "\t\t",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    SuperscriptBox["P", "*"], "=", 
    FractionBox[
     RowBox[{"P", "*", 
      SuperscriptBox["\[Sigma]", "3"]}], "\[CurlyEpsilon]"]}],
   FontWeight->"Plain"]],
  CellChangeTimes->{{3.8548714809019413`*^9, 3.8548715004006968`*^9}},
  ExpressionUUID->"99165c67-7f38-43ad-9428-b851ffed0d14"],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    SuperscriptBox["\[Rho]", "*"],
    FontWeight->"Plain"], 
   StyleBox["=",
    FontWeight->"Plain"], 
   RowBox[{
    StyleBox["\[Rho]",
     FontWeight->"Plain"], 
    StyleBox["*",
     FontWeight->"Plain"], 
    SuperscriptBox["\[Sigma]", "3"]}]}]],
  CellChangeTimes->{{3.8548714809019413`*^9, 3.8548715004006968`*^9}},
  ExpressionUUID->"d827e814-f69d-43da-8ede-e977b8d40d4e"]
}], "Text",ExpressionUUID->"5ccd3c69-054c-4943-9686-0c0265dc59e1"],

Cell[CellGroupData[{

Cell["State Definition", "Subsection",ExpressionUUID->"6aaffb1f-8280-4895-a800-06cd2f6db86d"],

Cell["\<\
Choose the temperature between the boiling temperature and the critical \
temperature of the LJ-fluid\
\>", "Text",ExpressionUUID->"3fb46bd8-ee56-4fb3-9b4b-85fd9c9e09a5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*SubscriptBox[\(T\), \(boil\)]\)\>\"", ",", 
       RowBox[{"0.5", "*", 
        RowBox[{"tCritLJ", "/", "tLjRedFac"}]}], ",", "\"\<K\>\""}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*SubscriptBox[\(T\), \(C\)]\)\>\"", ",", 
       RowBox[{"1.0", "*", 
        RowBox[{"tCritLJ", "/", "tLjRedFac"}]}], ",", "\"\<K\>\""}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}], ",", 
   RowBox[{"Spacings", "->", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "]"}]], "Code",
 InitializationCell->False,
 CellLabel->"In[28]:=",ExpressionUUID->"e7fb6f4f-2b2b-406a-9cf0-90305525d25e"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\\!\\(\\*SubscriptBox[\\(T\\), \\(boil\\)]\\)\"\>", 
     "77.0814`", "\<\"K\"\>"},
    {"\<\"\\!\\(\\*SubscriptBox[\\(T\\), \\(C\\)]\\)\"\>", 
     "154.1628`", "\<\"K\"\>"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[28]=",ExpressionUUID->"f8091540-888c-49b0-b7df-17998230769d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tSim", " ", "=", " ", "115"}], ";"}], " ", 
  RowBox[{"(*", "K", "*)"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Input", " ", "in", " ", "LJ"}], "-", 
    RowBox[{"reduced", " ", 
     RowBox[{"units", ":", "  ", 
      RowBox[{"1.0", " ", 
       RowBox[{"(*", "1", "*)"}], "/", " ", "tLjRedFac"}]}]}]}], " ", 
   RowBox[{"(*", "K", "*)"}], " ", "*)"}]}]], "Input",
 Background->RGBColor[1, 1, 0],
 CellLabel->"In[29]:=",ExpressionUUID->"4d5c4b5a-a356-41a9-b16a-d2028988e8c5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation and Visualization", "Subsection",ExpressionUUID->"a0999732-1fe2-48df-8744-b436189cf74c"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"c236e83b-e78d-4219-a601-4b19b5fce01d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tSimRed", " ", "=", " ", 
   RowBox[{"tSim", " ", "*", 
    RowBox[{"tLjRedFac", "/", "tCritLJ"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"pSatSim", " ", "=", " ", 
   RowBox[{
    RowBox[{"pSatRedLJ", "[", "tSimRed", "]"}], "*", 
    RowBox[{"pCritLJ", "/", "pLjRedFac"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"rhoLSim", " ", "=", " ", 
    RowBox[{
     RowBox[{"\[Rho]SatLiqRedLJ", "[", "tSimRed", "]"}], "*", 
     RowBox[{"\[Rho]CritLJ", "/", "rhoLjRedFac"}]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"mol", "/", 
    SuperscriptBox["dm", "3"]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rhoVSim", " ", "=", " ", 
    RowBox[{
     RowBox[{"\[Rho]SatVapRedLJ", "[", "tSimRed", "]"}], "*", 
     RowBox[{"\[Rho]CritLJ", "/", "rhoLjRedFac"}]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"mol", "/", 
    SuperscriptBox["dm", "3"]}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ResultsPlotPureThol2016", "[", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"Print", "@", 
       RowBox[{"Show", "[", "\n", "\t\t", 
        RowBox[{
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"{", "\n", "\t\t\t\t", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Rho]SatLiqRedLJ", "[", 
               RowBox[{
                RowBox[{"tRed", "/", "tCritLJ"}], "*", "tLjRedFac"}], "]"}], 
              "*", 
              RowBox[{"\[Rho]CritLJ", "/", "rhoLjRedFac"}]}], ",", "\n", 
             "\t\t\t\t", 
             RowBox[{
              RowBox[{"\[Rho]SatVapRedLJ", "[", 
               RowBox[{
                RowBox[{"tRed", "/", "tCritLJ"}], "*", "tLjRedFac"}], "]"}], 
              "*", 
              RowBox[{"\[Rho]CritLJ", "/", "rhoLjRedFac"}]}]}], "\n", 
            "\t\t\t", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"tRed", ",", 
             RowBox[{"0.5", "*", 
              RowBox[{"tCritLJ", "/", "tLjRedFac"}]}], ",", 
             RowBox[{"1.", "*", 
              RowBox[{"tCritLJ", "/", "tLjRedFac"}]}]}], "}"}], "\n", 
           "\t\t\t", 
           RowBox[{"(*", 
            RowBox[{",", 
             RowBox[{
             "PlotLabel", "\[Rule]", " ", 
              "\"\<Reduced Density at Saturation\>\""}]}], "*)"}], "\n", 
           "\t\t\t", ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Style", "[", 
                RowBox[{"#", ",", " ", "14"}], "]"}], "&"}], "/@", 
              RowBox[{"{", " ", 
               RowBox[{
               "\"\<T / K\>\"", ",", " ", 
                "\"\<\[Rho] / mol \!\(\*SuperscriptBox[\(dm\), \
\(-3\)]\)\>\""}], "}"}]}], ")"}]}], "\n", "\t\t\t", ",", 
           RowBox[{"PlotLegends", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
             "\"\<Saturated Liquid, Thol 2016 EOS\>\"", ",", 
              "\"\<Saturated Vapor, Thol 2016 EOS\>\""}], "}"}]}], "\n", 
           "\t\t\t", ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0.5", ",", " ", "1.05"}], "}"}], "*", 
               RowBox[{"tCritLJ", "/", "tLjRedFac"}]}], ",", " ", 
              "Automatic"}], "}"}]}]}], "\n", "\t\t", "]"}], ",", "\n", 
         "\t\t", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"rhoSatExp", "\[LeftDoubleBracket]", 
              RowBox[{"component", ",", "All", ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "3"}], "}"}]}], "\[RightDoubleBracket]"}], 
             ",", 
             RowBox[{"rhoSatExp", "[", 
              RowBox[{"[", 
               RowBox[{"component", ",", "All", ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}]}], "}"}], 
           "\n", "\t\t\t", ",", 
           RowBox[{"PlotLegends", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
             "\"\<Saturated Liquid, Experimental\>\"", ",", 
              "\"\<Saturated Vapor, Experimental\>\""}], "}"}]}], "\n", 
           "\t\t\t", ",", 
           RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}]}], "\n", 
          "\t\t", "]"}], ",", "\n", "\t\t", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"tSim", ",", "rhoLSim"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"tSim", ",", "rhoVSim"}], "}"}]}], "}"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", "Red", "}"}]}], ",", 
           RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}], ",", 
           RowBox[{"PlotLegends", "\[Rule]", 
            RowBox[{"{", "\"\<Simulation\>\"", "}"}]}]}], "]"}], ",", "\n", 
         "\t\t", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"tCritLJ", "/", "tLjRedFac"}], ",", 
              RowBox[{"\[Rho]CritLJ", "/", "rhoLjRedFac"}]}], "}"}], "}"}], 
           ",", 
           RowBox[{"PlotLegends", "\[Rule]", 
            RowBox[{"{", "\"\<Critical point\>\"", "}"}]}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", "Green", "}"}]}]}], "]"}]}], "\n", "\t", "]"}]}], 
      ";", "\n", "\t", 
      RowBox[{"Highlighted", "@", 
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<Simulation @T=\>\"", "<>", 
           RowBox[{"ToString", "@", "tSim"}], "<>", 
           "\"\<K : \!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\) = \>\""}], ",", 
          RowBox[{"Round", "[", 
           RowBox[{"rhoLSim", ",", "0.00001"}], "]"}], ",", 
          "\"\< mol \!\(\*SuperscriptBox[\(dm\), \(-3\)]\), \
\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\) = \>\"", ",", 
          RowBox[{"Round", "[", 
           RowBox[{"rhoVSim", ",", "0.00001"}], "]"}], ",", 
          "\"\< mol \!\(\*SuperscriptBox[\(dm\), \(-3\)]\)\>\""}], "}"}], 
        "]"}]}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]}], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[30]:=",ExpressionUUID->"c144d3f3-68ac-4f9f-a97e-a72b2fb9ffba"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResultsPlotPureThol2016", "[", "]"}]], "Code",
 CellLabel->"In[35]:=",ExpressionUUID->"4ab698b3-a25b-4473-9f11-f0d7fdd1d0ab"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{{}, {}, 
        TagBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV0Hk41IkfB3BqoqREQodr8ytRYy7HON8zPx0zcu2IyT3f7yqltHg8G4ZQ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           "]]}, Annotation[#, "Charting`Private`Tag$48042#1"]& ], 
        TagBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwVj3k4lAsbxoniFGEsjYwxY4akqCSS8t5UQik1tuzzviFpo9TX2CdpObLV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           "]]}, 
         Annotation[#, "Charting`Private`Tag$48042#2"]& ]}}, {}}, {{}, {{{
         Directive[
          PointSize[0.012833333333333334`], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{{
                 GrayLevel[1], 
                 DiskBox[{0, 0}, 
                  Offset[{3, 3}]]}, 
                AbsoluteThickness[1.5], 
                Dashing[{}], 
                CircleBox[{0, 0}, 
                 Offset[{3, 3}]]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  RGBColor[0.368417, 0.506779, 0.709798], 
                  AbsoluteThickness[1.6]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Scaled[9.75]], {{{83.81, 35.471}}, {{90., 34.52}}, {{100., 
          32.893}}, {{110., 31.115}}, {{120., 29.113}}, {{130., 26.735}}, {{
          140., 23.623}}, {{150., 17.032}}, {{150.69, 13.407}}}]}, {
         Directive[
          PointSize[0.012833333333333334`], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{{
                 GrayLevel[1], 
                 PolygonBox[
                  NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                AbsoluteThickness[1.5], 
                Dashing[{}], 
                JoinedCurveBox[
                 NCache[
                  Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                  Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  RGBColor[0.880722, 0.611041, 0.142051], 
                  AbsoluteThickness[1.6]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Scaled[9.75]], {{{83.81, 0.102}}, {{90., 0.186}}, {{100., 
          0.422}}, {{110., 0.833}}, {{120., 1.505}}, {{130., 2.593}}, {{140., 
          4.478}}, {{150., 9.875}}, {{150.69, 
          13.407}}}]}}}, {{}, {}}}, {{}, {{{
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{{
                 GrayLevel[1], 
                 DiskBox[{0, 0}, 
                  Offset[{3, 3}]]}, 
                AbsoluteThickness[1.5], 
                Dashing[{}], 
                CircleBox[{0, 0}, 
                 Offset[{3, 3}]]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[1, 0, 0]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Scaled[9.75]], {{{115., 30.12948608118392}}, {{115., 
          1.1288264948653954`}}}]}}}, {{}, {}}}, {{}, {{{
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         PointBox[{{154.1628, 13.152693651696554`}, {154.1628, 
          13.152693651696554`}}]}}}, {{}, {}}}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {77.08140000000017, 0}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{0, 0}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {77.0814, 0}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         TagBox[
          StyleBox[
          "\"\[Rho] / mol \\!\\(\\*SuperscriptBox[\\(dm\\), \\(-3\\)]\\)\"", 
           14, StripOnInput -> False], HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
          StyleBox["\"T / K\"", 14, StripOnInput -> False], HoldForm], 
         TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{77.0814, 161.87094000000002`}, {0., 36.46894345726254}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{Automatic, Automatic}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{
          "\"Saturated Liquid, Thol 2016 EOS\"", 
           "\"Saturated Vapor, Thol 2016 EOS\""}, "LineLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{
          "\"Saturated Liquid, Experimental\"", 
           "\"Saturated Vapor, Experimental\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], ",", "9.75`"}],
                     "}"}]}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "False"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Simulation\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Critical point\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 1, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Print",
 CellLabel->
  "During evaluation of \
In[35]:=",ExpressionUUID->"fcde49e1-1190-48b2-8449-67a9887b631f"],

Cell[BoxData[
 TemplateBox[{
   TemplateBox[{
    "\"Simulation @T=115K : \\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\) = \
\"", "30.129490000000004`", 
     "\" mol \\!\\(\\*SuperscriptBox[\\(dm\\), \\(-3\\)]\\), \
\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\) = \"", "1.12883`", 
     "\" mol \\!\\(\\*SuperscriptBox[\\(dm\\), \\(-3\\)]\\)\""}, 
    "RowDefault"], FrameStyle -> None},
  "Highlighted"]], "Output",
 CellLabel->"Out[35]=",ExpressionUUID->"bd936ef3-d263-4a8d-9a0b-982dcc85b644"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Simulation Setup for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["n",
      FontSlant->"Plain"], 
     StyleBox["V",
      FontSlant->"Plain"]], "=", 
    SubscriptBox[
     StyleBox["n",
      FontSlant->"Plain"], 
     StyleBox["L",
      FontSlant->"Plain"]]}], TraditionalForm]],ExpressionUUID->
  "79e6a713-9c94-4306-a5b0-82b8c7b90f85"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["L",
      FontSlant->"Plain"], 
     StyleBox["V",
      FontSlant->"Plain"]], "=", 
    SubscriptBox[
     StyleBox["L",
      FontSlant->"Plain"], 
     StyleBox["L",
      FontSlant->"Plain"]]}], TraditionalForm]],ExpressionUUID->
  "5e222eb0-996a-4175-81c8-93801736d609"],
 " ( ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1.20", "<", 
    SuperscriptBox[
     StyleBox["T",
      FontSlant->"Plain"], "*"], "<=", "1.30"}], TraditionalForm]],
  ExpressionUUID->"1d6a1424-8e23-42c0-9d42-4e634d1e18a2"],
 " )"
}], "Subsection",ExpressionUUID->"0f9d22e3-5f17-42c6-a6c2-8fc1200b89eb"],

Cell["\<\
The following simulation setup is calculated under the assumption that the \
result of the Thol2016 EoS is the final value of the densities.
We assume a final distribution of the molecules where 40% of the total \
molecules is in the vapor phase and 60% of the total molecules are in the \
liquid phase.
We calculate the theoretical total volume of this simulation setup and use it \
for a setup with equal amounts of molecules in each box as well as the same \
initial density.\
\>", "Text",ExpressionUUID->"9c76cdd9-333c-4a15-a47f-4717bebc1821"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"e90744d5-5008-4130-8d98-f690e0ae0af7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ResultsGridPureEqRhoThol2016", "[", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"V1", ",", "V2", ",", "rhoSim"}], "}"}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"V1", " ", "=", " ", 
       RowBox[{
        RowBox[{"1", "/", "rhoVSim"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"dm", "^", "3"}], "/", "mol"}], "*)"}], "*", " ", 
        RowBox[{
         RowBox[{"10", "^", "27"}], " ", "/", "nAvogadro"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"A", "^", "3"}], "/", "N"}], "*)"}], " ", "*", " ", 
        "0.4"}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"A", "^", "3"}], "*)"}], ";", "\n", "\t", 
      RowBox[{"V2", " ", "=", " ", 
       RowBox[{
        RowBox[{"1", "/", "rhoLSim"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"dm", "^", "3"}], "/", "mol"}], "*)"}], "*", " ", 
        RowBox[{
         RowBox[{"10", "^", "27"}], " ", "/", "nAvogadro"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"A", "^", "3"}], "/", "N"}], "*)"}], " ", "*", " ", 
        "0.6"}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"A", "^", "3"}], "*)"}], ";", "\n", "\t", 
      RowBox[{"rhoSim", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"V1", "+", "V2"}], ")"}]}], 
         RowBox[{"(*", 
          RowBox[{"N", "/", 
           RowBox[{"A", "^", "3"}]}], "*)"}], " ", "/", "nAvogadro"}], " ", 
        "*", " ", 
        RowBox[{"10", "^", "27"}]}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"mol", "/", 
        RowBox[{"dm", "^", "3"}]}], "*)"}], ";", "\n", "\n", "\t", 
      RowBox[{"Grid", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", "\n", "\t\t", 
          RowBox[{
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<Thol2016-EoS Results\>\"", ",", "Bold"}], 
                  "]"}], ",", "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Symbol\>\"", ",", "\"\<Value\>\"", ",", 
                  "\"\<Unit\>\""}], "}"}]}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{"\"\<T\>\"", ",", " ", "tSim", ",", "\"\<K\>\""}], 
                "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SuperscriptBox[\(P\), \(Sat\)]\)\>\"", ",", 
                 "pSatSim", ",", "\"\<bar\>\""}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\)\>\"", ",", 
                 "rhoVSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\)\>\"", ",", 
                 "rhoLSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], 
                "}"}]}], "\n", "\t\t\t", "}"}], ",", 
             RowBox[{"Alignment", "->", "Left"}], ",", 
             RowBox[{"Dividers", "->", "All"}], ",", 
             RowBox[{"Spacings", "->", 
              RowBox[{"{", 
               RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "\t\t", 
            "]"}], ",", "\n", "\t\t", 
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<Simulation Setup\>\"", ",", "Bold"}], "]"}], 
                 ",", "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Symbol\>\"", ",", "\"\<Value\>\"", ",", 
                  "\"\<Unit\>\""}], "}"}]}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(N\), \
\(V\)]\)/\!\(\*SubscriptBox[\(N\), \(L\)]\)\>\"", ",", "1", ",", 
                 "\"\<1\>\""}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \
\(V\)]\),\!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\)\>\"", ",", "rhoSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(V\), \(*\)]\),\!\(\
\*SubsuperscriptBox[\(\[Rho]\), \(L\), \(*\)]\)\>\"", ",", 
                 RowBox[{"rhoSim", "*", "rhoLjRedFac"}], ",", "\"\<1\>\""}], 
                "}"}]}], "\n", "\t\t\t", "}"}], ",", 
             RowBox[{"Alignment", "->", "Left"}], ",", 
             RowBox[{"Dividers", "->", "All"}], ",", 
             RowBox[{"Spacings", "->", 
              RowBox[{"{", 
               RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "\t\t", 
            "]"}]}], "\n", "\t", "}"}], "}"}], ",", 
        RowBox[{"Alignment", "->", "Top"}]}], "]"}]}]}], "\n", "]"}]}], 
  ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[36]:=",ExpressionUUID->"9d868bd0-50da-4a9e-b759-59348f61fb5a"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResultsGridPureEqRhoThol2016", "[", "]"}]], "Code",
 CellLabel->"In[37]:=",ExpressionUUID->"530076bc-b672-4e05-b7b0-71c639b9fe64"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         StyleBox["\<\"Thol2016-EoS Results\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Symbol\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Value\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Unit\"\>",
          StripOnInput->False,
          FontWeight->Bold]},
        {"\<\"T\"\>", "115", "\<\"K\"\>"},
        {"\<\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(Sat\\)]\\)\"\>", 
         "9.23760595457641`", "\<\"bar\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\)\"\>", 
         "1.1288264948653954`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\)\"\>", 
         "30.12948608118392`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"], 
     TagBox[GridBox[{
        {
         StyleBox["\<\"Simulation Setup\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Symbol\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Value\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Unit\"\>",
          StripOnInput->False,
          FontWeight->Bold]},
        {"\<\"\\!\\(\\*SubscriptBox[\\(N\\), \
\\(V\\)]\\)/\\!\\(\\*SubscriptBox[\\(N\\), \\(L\\)]\\)\"\>", "1", "\<\"1\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \
\\(V\\)]\\),\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\)\"\>", 
         "2.6719083049150556`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(V\\), \
\\(*\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(L\\), \
\\(*\\)]\\)\"\>", "0.06297505259820498`", "\<\"1\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Rows" -> {{Top}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[37]=",ExpressionUUID->"97d18f03-a69a-4b60-8040-f8d1da19ca3b"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Simulation Setup for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["n",
      FontSlant->"Plain"], 
     StyleBox["V",
      FontSlant->"Plain"]], "=", 
    SubscriptBox[
     StyleBox["n",
      FontSlant->"Plain"], 
     StyleBox["L",
      FontSlant->"Plain"]]}], TraditionalForm]],ExpressionUUID->
  "1d971bd3-ed5f-41a1-b5da-c25044f5c53b"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["L",
      FontSlant->"Plain"], 
     StyleBox["V",
      FontSlant->"Plain"]], "=", 
    RowBox[{"2", "\[CenterDot]", 
     SubscriptBox[
      StyleBox["L",
       FontSlant->"Plain"], 
      StyleBox["L",
       FontSlant->"Plain"]]}]}], TraditionalForm]],ExpressionUUID->
  "c09c10c8-10d6-41c2-8960-09d2b59b6e9d"],
 " ( ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1.00", "<", 
    SuperscriptBox[
     StyleBox["T",
      FontSlant->"Plain"], "*"], "<=", "1.20"}], TraditionalForm]],
  ExpressionUUID->"31c13be0-3056-419a-a1a0-3ac8a68ff5ff"],
 " )"
}], "Subsection",ExpressionUUID->"ebdd1c7c-134c-4eb0-9064-c64da6d63fff"],

Cell["\<\
The following simulation setup is calculated under the assumption that the \
result of the Thol2016 EoS is the final value of the densities.
We assume a final distribution of the molecules where 40% of the total \
molecules is in the vapor phase and 60% of the total molecules are in the \
liquid phase.
We calculate the theoretical total volume of this simulation setup and use it \
for a setup with equal amounts of molecules in each box and initial box side \
length ratio of 2:1.\
\>", "Text",ExpressionUUID->"0bb7e70d-c653-4888-86c2-0053e234c07f"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"b51fd359-3ea7-47d2-800e-b7d4042739dc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ResultsGridPure2Thol2016", "[", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "Lratio", ",", "V1", ",", "V2", ",", "rhoVInit", ",", "rhoLInit"}], 
      "}"}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"Lratio", " ", "=", " ", "2"}], ";", "\n", "\t", 
      RowBox[{"V1", " ", "=", " ", 
       RowBox[{
        RowBox[{"1", "/", "rhoVSim"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"dm", "^", "3"}], "/", "mol"}], "*)"}], "*", " ", 
        RowBox[{
         RowBox[{"10", "^", "27"}], " ", "/", "nAvogadro"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"A", "^", "3"}], "/", "N"}], "*)"}], " ", "*", " ", 
        "0.4"}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"A", "^", "3"}], "*)"}], ";", "\n", "\t", 
      RowBox[{"V2", " ", "=", " ", 
       RowBox[{
        RowBox[{"1", "/", "rhoLSim"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"dm", "^", "3"}], "/", "mol"}], "*)"}], "*", " ", 
        RowBox[{
         RowBox[{"10", "^", "27"}], " ", "/", "nAvogadro"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"A", "^", "3"}], "/", "N"}], "*)"}], " ", "*", " ", 
        "0.6"}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"A", "^", "3"}], "*)"}], ";", "\n", "\t", 
      RowBox[{"rhoVInit", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"0.5", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Lratio", "^", "3"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"V1", " ", "+", " ", "V2"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Lratio", "^", "3"}], "+", "1"}], ")"}]}]}], ")"}]}], 
         RowBox[{"(*", 
          RowBox[{"N", "/", 
           RowBox[{"A", "^", "3"}]}], "*)"}], " ", "/", "nAvogadro"}], " ", 
        "*", " ", 
        RowBox[{"10", "^", "27"}]}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"mol", "/", 
        RowBox[{"dm", "^", "3"}]}], "*)"}], ";", "\n", "\t", 
      RowBox[{"rhoLInit", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"0.5", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"V1", " ", "+", " ", "V2"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Lratio", "^", "3"}], "+", "1"}], ")"}]}], ")"}]}], 
         RowBox[{"(*", 
          RowBox[{"N", "/", 
           RowBox[{"A", "^", "3"}]}], "*)"}], " ", "/", "nAvogadro"}], " ", 
        "*", " ", 
        RowBox[{"10", "^", "27"}]}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"mol", "/", 
        RowBox[{"dm", "^", "3"}]}], "*)"}], ";", "\n", "\n", "\t", 
      RowBox[{"Grid", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", "\n", "\t\t", 
          RowBox[{
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<Thol2016-EoS Results\>\"", ",", "Bold"}], 
                  "]"}], ",", "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Symbol\>\"", ",", "\"\<Value\>\"", ",", 
                  "\"\<Unit\>\""}], "}"}]}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{"\"\<T\>\"", ",", " ", "tSim", ",", "\"\<K\>\""}], 
                "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SuperscriptBox[\(P\), \(Sat\)]\)\>\"", ",", 
                 "pSatSim", ",", "\"\<bar\>\""}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\)\>\"", ",", 
                 "rhoVSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\)\>\"", ",", 
                 "rhoLSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], 
                "}"}]}], "\n", "\t\t\t", "}"}], ",", 
             RowBox[{"Alignment", "->", "Left"}], ",", 
             RowBox[{"Dividers", "->", "All"}], ",", 
             RowBox[{"Spacings", "->", 
              RowBox[{"{", 
               RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "\t\t", 
            "]"}], ",", "\n", "\t\t", 
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<Simulation Setup\>\"", ",", "Bold"}], "]"}], 
                 ",", "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Symbol\>\"", ",", "\"\<Value\>\"", ",", 
                  "\"\<Unit\>\""}], "}"}]}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(N\), \
\(V\)]\)/\!\(\*SubscriptBox[\(N\), \(L\)]\)\>\"", ",", "1", ",", 
                 "\"\<1\>\""}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\)\>\"", ",", 
                 "rhoVInit", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\)\>\"", ",", 
                 "rhoLInit", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(V\), \(*\)]\)\>\"",
                  ",", 
                 RowBox[{"rhoVInit", "*", "rhoLjRedFac"}], ",", "\"\<1\>\""}],
                 "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(L\), \(*\)]\)\>\"",
                  ",", 
                 RowBox[{"rhoLInit", "*", "rhoLjRedFac"}], ",", "\"\<1\>\""}],
                 "}"}]}], "\n", "\t\t\t", "}"}], ",", 
             RowBox[{"Alignment", "->", "Left"}], ",", 
             RowBox[{"Dividers", "->", "All"}], ",", 
             RowBox[{"Spacings", "->", 
              RowBox[{"{", 
               RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "\t\t", 
            "]"}]}], "\n", "\t", "}"}], "}"}], ",", 
        RowBox[{"Alignment", "->", "Top"}]}], "]"}]}]}], "\n", "]"}]}], 
  ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[38]:=",ExpressionUUID->"3e18ad99-1641-474b-97a6-0867e1a0fef5"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResultsGridPure2Thol2016", "[", "]"}]], "Code",
 CellLabel->"In[39]:=",ExpressionUUID->"ebae75c6-4f41-47e5-becf-e25128966df6"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         StyleBox["\<\"Thol2016-EoS Results\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Symbol\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Value\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Unit\"\>",
          StripOnInput->False,
          FontWeight->Bold]},
        {"\<\"T\"\>", "115", "\<\"K\"\>"},
        {"\<\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(Sat\\)]\\)\"\>", 
         "9.23760595457641`", "\<\"bar\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\)\"\>", 
         "1.1288264948653954`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\)\"\>", 
         "30.12948608118392`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"], 
     TagBox[GridBox[{
        {
         StyleBox["\<\"Simulation Setup\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Symbol\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Value\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Unit\"\>",
          StripOnInput->False,
          FontWeight->Bold]},
        {"\<\"\\!\\(\\*SubscriptBox[\\(N\\), \
\\(V\\)]\\)/\\!\\(\\*SubscriptBox[\\(N\\), \\(L\\)]\\)\"\>", "1", "\<\"1\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\)\"\>", 
         "1.502948421514719`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\)\"\>", 
         "12.023587372117753`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(V\\), \\(*\\)]\\)\"\
\>", "0.03542346708649031`", "\<\"1\"\>"},
        {"\<\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(L\\), \\(*\\)]\\)\"\
\>", "0.28338773669192246`", "\<\"1\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Rows" -> {{Top}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[39]=",ExpressionUUID->"8ff97dab-878b-47ff-a9a1-c039a88c5c17"]
}, Open  ]]
}, Closed]],

Cell["\<\
------------------------------------------------------------------------------\
-\
\>", "Subsection",ExpressionUUID->"122395f9-47bd-4179-9ad3-7b54a7bbddc0"],

Cell[CellGroupData[{

Cell[TextData[{
 "Simulation Setup for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["n",
      FontSlant->"Plain"], 
     StyleBox["V",
      FontSlant->"Plain"]], "=", 
    RowBox[{
     StyleBox["4",
      FontSlant->"Plain"], "\[CenterDot]", 
     SubscriptBox[
      StyleBox["n",
       FontSlant->"Plain"], 
      StyleBox["L",
       FontSlant->"Plain"]]}]}], TraditionalForm]],ExpressionUUID->
  "ab1a5c3b-c496-44de-881c-73d498e775be"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["L",
      FontSlant->"Plain"], 
     StyleBox["V",
      FontSlant->"Plain"]], "=", 
    SubscriptBox[
     StyleBox["L",
      FontSlant->"Plain"], 
     StyleBox["L",
      FontSlant->"Plain"]]}], TraditionalForm]],ExpressionUUID->
  "78ed5dde-eabf-4881-b742-87304cf82095"],
 " ( ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     RowBox[{
      StyleBox["1",
       FontSlant->"Plain"], ".10"}]], "<", 
    SuperscriptBox[
     StyleBox["T",
      FontSlant->"Plain"], "*"], "<=", 
    StyleBox[
     RowBox[{
      StyleBox["1",
       FontSlant->"Plain"], ".30"}]]}], TraditionalForm]],ExpressionUUID->
  "cfa49d6e-30b3-418f-8b53-1bf95e8b3488"],
 " )"
}], "Subsection",ExpressionUUID->"5c7808b2-a1c0-4739-9d78-17faf0196493"],

Cell[TextData[{
 "The following simulation setup is calculated under the assumption that the \
result of the Thol2016 EoS is the final value of the densities.\nWe assume a \
final distribution of the molecules where 40% of the total molecules is in \
the vapor phase and 60% of the total molecules are in the liquid phase.\nWe \
calculate the theoretical total volume of this simulation setup and use it \
for a setup with initial equal volume in each box and a ratio of the initial \
number of molecules equal to four (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox[
      StyleBox["n",
       FontSlant->"Plain"], 
      StyleBox["L",
       FontSlant->"Plain"]], "/", 
     SubscriptBox[
      StyleBox["n",
       FontSlant->"Plain"], 
      StyleBox["V",
       FontSlant->"Plain"]]}], "=", "4"}], TraditionalForm]],ExpressionUUID->
  "7608e070-cec3-4498-b6d2-f8b68367984b"],
 ")."
}], "Text",ExpressionUUID->"cfde15d6-f14b-4b8e-a5aa-13c39e7957e7"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"e951db11-7668-438f-9057-49875dca60d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ResultsGridPureEqVThol2016", "[", "nRatio_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"V1", ",", "V2", ",", "rhoVInit", ",", "rhoLInit"}], "}"}], ",",
      "\n", "\t", 
     RowBox[{
      RowBox[{"V1", " ", "=", " ", 
       RowBox[{
        RowBox[{"1", "/", "rhoVSim"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"dm", "^", "3"}], "/", "mol"}], "*)"}], "*", " ", 
        RowBox[{
         RowBox[{"10", "^", "27"}], " ", "/", "nAvogadro"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"A", "^", "3"}], "/", "N"}], "*)"}], " ", "*", " ", 
        "0.4"}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"A", "^", "3"}], "*)"}], ";", "\n", "\t", 
      RowBox[{"V2", " ", "=", " ", 
       RowBox[{
        RowBox[{"1", "/", "rhoLSim"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"dm", "^", "3"}], "/", "mol"}], "*)"}], "*", " ", 
        RowBox[{
         RowBox[{"10", "^", "27"}], " ", "/", "nAvogadro"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"A", "^", "3"}], "/", "N"}], "*)"}], " ", "*", " ", 
        "0.6"}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"A", "^", "3"}], "*)"}], ";", "\n", "\t", 
      RowBox[{"rhoVInit", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"nRatio", "+", "1"}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"V1", " ", "+", " ", "V2"}], ")"}], "/", "2"}], ")"}]}], 
         RowBox[{"(*", 
          RowBox[{"N", "/", 
           RowBox[{"A", "^", "3"}]}], "*)"}], " ", "/", "nAvogadro"}], " ", 
        "*", " ", 
        RowBox[{"10", "^", "27"}]}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"mol", "/", 
        RowBox[{"dm", "^", "3"}]}], "*)"}], ";", "\n", "\t", 
      RowBox[{"rhoLInit", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"nRatio", "/", 
            RowBox[{"(", 
             RowBox[{"nRatio", "+", "1"}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"V1", " ", "+", " ", "V2"}], ")"}], "/", "2"}], ")"}]}], 
         RowBox[{"(*", 
          RowBox[{"N", "/", 
           RowBox[{"A", "^", "3"}]}], "*)"}], " ", "/", "nAvogadro"}], " ", 
        "*", " ", 
        RowBox[{"10", "^", "27"}]}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"mol", "/", 
        RowBox[{"dm", "^", "3"}]}], "*)"}], ";", "\n", "\n", "\t", 
      RowBox[{"Grid", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", "\n", "\t\t", 
          RowBox[{
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<Thol2016-EoS Results\>\"", ",", "Bold"}], 
                  "]"}], ",", "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Symbol\>\"", ",", "\"\<Value\>\"", ",", 
                  "\"\<Unit\>\""}], "}"}]}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{"\"\<T\>\"", ",", " ", "tSim", ",", "\"\<K\>\""}], 
                "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SuperscriptBox[\(P\), \(Sat\)]\)\>\"", ",", 
                 "pSatSim", ",", "\"\<bar\>\""}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\)\>\"", ",", 
                 "rhoVSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\)\>\"", ",", 
                 "rhoLSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], 
                "}"}]}], "\n", "\t\t\t", "}"}], ",", 
             RowBox[{"Alignment", "->", "Left"}], ",", 
             RowBox[{"Dividers", "->", "All"}], ",", 
             RowBox[{"Spacings", "->", 
              RowBox[{"{", 
               RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "\t\t", 
            "]"}], ",", "\n", "\t\t", 
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<Simulation Setup\>\"", ",", "Bold"}], "]"}], 
                 ",", "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Symbol\>\"", ",", "\"\<Value\>\"", ",", 
                  "\"\<Unit\>\""}], "}"}]}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(N\), \
\(L\)]\)/\!\(\*SubscriptBox[\(N\), \(V\)]\)\>\"", ",", "nRatio", ",", 
                 "\"\<1\>\""}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(L\), \
\(L\)]\)/\!\(\*SubscriptBox[\(L\), \(V\)]\)\>\"", ",", 
                 RowBox[{"CubeRoot", "[", 
                  RowBox[{
                   RowBox[{"rhoVInit", "/", "rhoLInit"}], "*", "nRatio"}], 
                  "]"}], ",", "\"\<1\>\""}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\)\>\"", ",", 
                 "rhoVInit", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\)\>\"", ",", 
                 "rhoLInit", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(V\), \(*\)]\)\>\"",
                  ",", 
                 RowBox[{"rhoVInit", "*", "rhoLjRedFac"}], ",", "\"\<1\>\""}],
                 "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(L\), \(*\)]\)\>\"",
                  ",", 
                 RowBox[{"rhoLInit", "*", "rhoLjRedFac"}], ",", "\"\<1\>\""}],
                 "}"}]}], "\n", "\t\t\t", "}"}], ",", 
             RowBox[{"Alignment", "->", "Left"}], ",", 
             RowBox[{"Dividers", "->", "All"}], ",", 
             RowBox[{"Spacings", "->", 
              RowBox[{"{", 
               RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "\t\t", 
            "]"}]}], "\n", "\t", "}"}], "}"}], ",", 
        RowBox[{"Alignment", "->", "Top"}]}], "]"}]}]}], "\n", "]"}]}], 
  ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[40]:=",ExpressionUUID->"8ea46284-dd23-496d-9adb-029f0fb1fdb7"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"nLnVRatio", " ", "=", " ", "4"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"nL", " ", "/", " ", "nV"}], " ", "*)"}]}], "\n", 
 RowBox[{"ResultsGridPureEqVThol2016", "[", "nLnVRatio", "]"}]}], "Code",
 CellLabel->"In[41]:=",ExpressionUUID->"36f5efe7-6612-446d-ad35-58c7131e2f04"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         StyleBox["\<\"Thol2016-EoS Results\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Symbol\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Value\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Unit\"\>",
          StripOnInput->False,
          FontWeight->Bold]},
        {"\<\"T\"\>", "115", "\<\"K\"\>"},
        {"\<\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(Sat\\)]\\)\"\>", 
         "9.23760595457641`", "\<\"bar\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\)\"\>", 
         "1.1288264948653954`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\)\"\>", 
         "30.12948608118392`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"], 
     TagBox[GridBox[{
        {
         StyleBox["\<\"Simulation Setup\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Symbol\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Value\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Unit\"\>",
          StripOnInput->False,
          FontWeight->Bold]},
        {"\<\"\\!\\(\\*SubscriptBox[\\(N\\), \
\\(L\\)]\\)/\\!\\(\\*SubscriptBox[\\(N\\), \\(V\\)]\\)\"\>", "4", "\<\"1\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(L\\), \
\\(L\\)]\\)/\\!\\(\\*SubscriptBox[\\(L\\), \\(V\\)]\\)\"\>", 
         "1.`", "\<\"1\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\)\"\>", 
         "1.0687633219660224`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\)\"\>", 
         "4.27505328786409`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\
\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(V\\), \\(*\\)]\\)\"\
\>", "0.025190021039281994`", "\<\"1\"\>"},
        {"\<\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(L\\), \\(*\\)]\\)\"\
\>", "0.10076008415712798`", "\<\"1\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Rows" -> {{Top}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[42]=",ExpressionUUID->"db2c819d-2b6a-4d30-9407-d8f85037a846"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Simulation Setup for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["n",
      FontSlant->"Plain"], 
     StyleBox["V",
      FontSlant->"Plain"]], "=", 
    SubscriptBox[
     StyleBox["n",
      FontSlant->"Plain"], 
     StyleBox["L",
      FontSlant->"Plain"]]}], TraditionalForm]],ExpressionUUID->
  "0829d93a-f84b-43f2-aa10-7dfbbd6df19d"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["L",
      FontSlant->"Plain"], 
     StyleBox["V",
      FontSlant->"Plain"]], "=", 
    RowBox[{"4", "\[CenterDot]", 
     SubscriptBox[
      StyleBox["L",
       FontSlant->"Plain"], 
      StyleBox["L",
       FontSlant->"Plain"]]}]}], TraditionalForm]],ExpressionUUID->
  "6a7f098a-2727-4710-8f7a-96ef57925dd6"],
 " ( ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0.80", "<", 
    SuperscriptBox[
     StyleBox["T",
      FontSlant->"Plain"], "*"], "<=", "1.00"}], TraditionalForm]],
  ExpressionUUID->"3df82388-ccf6-4c39-8e68-952b93496797"],
 " )"
}], "Subsection",ExpressionUUID->"a616a0b7-19a9-4a5f-b9d1-98d047d7ae6c"],

Cell["\<\
The following simulation setup is calculated under the assumption that the \
result of the Thol2016 EoS is the final value of the densities.
We assume a final distribution of the molecules where 40% of the total \
molecules is in the vapor phase and 60% of the total molecules are in the \
liquid phase.
We calculate the theoretical total volume of this simulation setup and use it \
for a setup with equal amounts of molecules in each box and initial box side \
length ratio of 4:1.\
\>", "Text",ExpressionUUID->"348cdca4-fa7c-41df-a498-68c5efd3fcca"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"7313e692-8c38-479a-94f1-9bb7c1c970eb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ResultsGridPure4Thol2016", "[", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "Lratio", ",", "V1", ",", "V2", ",", "rhoVInit", ",", "rhoLInit"}], 
      "}"}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"Lratio", " ", "=", " ", "4"}], ";", "\n", "\t", 
      RowBox[{"V1", " ", "=", " ", 
       RowBox[{
        RowBox[{"1", "/", "rhoVSim"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"dm", "^", "3"}], "/", "mol"}], "*)"}], "*", " ", 
        RowBox[{
         RowBox[{"10", "^", "27"}], " ", "/", "nAvogadro"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"A", "^", "3"}], "/", "N"}], "*)"}], " ", "*", " ", 
        "0.4"}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"A", "^", "3"}], "*)"}], ";", "\n", "\t", 
      RowBox[{"V2", " ", "=", " ", 
       RowBox[{
        RowBox[{"1", "/", "rhoLSim"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"dm", "^", "3"}], "/", "mol"}], "*)"}], "*", " ", 
        RowBox[{
         RowBox[{"10", "^", "27"}], " ", "/", "nAvogadro"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"A", "^", "3"}], "/", "N"}], "*)"}], " ", "*", " ", 
        "0.6"}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"A", "^", "3"}], "*)"}], ";", "\n", "\t", 
      RowBox[{"rhoVInit", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"0.5", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Lratio", "^", "3"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"V1", " ", "+", " ", "V2"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Lratio", "^", "3"}], "+", "1"}], ")"}]}]}], ")"}]}], 
         RowBox[{"(*", 
          RowBox[{"N", "/", 
           RowBox[{"A", "^", "3"}]}], "*)"}], " ", "/", "nAvogadro"}], " ", 
        "*", " ", 
        RowBox[{"10", "^", "27"}]}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"mol", "/", 
        RowBox[{"dm", "^", "3"}]}], "*)"}], ";", "\n", "\t", 
      RowBox[{"rhoLInit", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"0.5", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"V1", " ", "+", " ", "V2"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Lratio", "^", "3"}], "+", "1"}], ")"}]}], ")"}]}], 
         RowBox[{"(*", 
          RowBox[{"N", "/", 
           RowBox[{"A", "^", "3"}]}], "*)"}], " ", "/", "nAvogadro"}], " ", 
        "*", " ", 
        RowBox[{"10", "^", "27"}]}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"mol", "/", 
        RowBox[{"dm", "^", "3"}]}], "*)"}], ";", "\n", "\n", "\t", 
      RowBox[{"Grid", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", "\n", "\t\t", 
          RowBox[{
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<Thol2016-EoS Results\>\"", ",", "Bold"}], 
                  "]"}], ",", "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Symbol\>\"", ",", "\"\<Value\>\"", ",", 
                  "\"\<Unit\>\""}], "}"}]}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{"\"\<T\>\"", ",", " ", "tSim", ",", "\"\<K\>\""}], 
                "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SuperscriptBox[\(P\), \(Sat\)]\)\>\"", ",", 
                 "pSatSim", ",", "\"\<bar\>\""}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\)\>\"", ",", 
                 "rhoVSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\)\>\"", ",", 
                 "rhoLSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], 
                "}"}]}], "\n", "\t\t\t", "}"}], ",", 
             RowBox[{"Alignment", "->", "Left"}], ",", 
             RowBox[{"Dividers", "->", "All"}], ",", 
             RowBox[{"Spacings", "->", 
              RowBox[{"{", 
               RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "\t\t", 
            "]"}], ",", "\n", "\t\t", 
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<Simulation Setup\>\"", ",", "Bold"}], "]"}], 
                 ",", "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Symbol\>\"", ",", "\"\<Value\>\"", ",", 
                  "\"\<Unit\>\""}], "}"}]}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(N\), \
\(V\)]\)/\!\(\*SubscriptBox[\(N\), \(L\)]\)\>\"", ",", "1", ",", 
                 "\"\<1\>\""}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\)\>\"", ",", 
                 "rhoVInit", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\)\>\"", ",", 
                 "rhoLInit", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(V\), \(*\)]\)\>\"",
                  ",", 
                 RowBox[{"rhoVInit", "*", "rhoLjRedFac"}], ",", "\"\<1\>\""}],
                 "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(L\), \(*\)]\)\>\"",
                  ",", 
                 RowBox[{"rhoLInit", "*", "rhoLjRedFac"}], ",", "\"\<1\>\""}],
                 "}"}]}], "\n", "\t\t\t", "}"}], ",", 
             RowBox[{"Alignment", "->", "Left"}], ",", 
             RowBox[{"Dividers", "->", "All"}], ",", 
             RowBox[{"Spacings", "->", 
              RowBox[{"{", 
               RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "\t\t", 
            "]"}]}], "\n", "\t", "}"}], "}"}], ",", 
        RowBox[{"Alignment", "->", "Top"}]}], "]"}]}]}], "\n", "]"}]}], 
  ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[43]:=",ExpressionUUID->"ca2e68de-1a80-42b0-8fe1-6210d4c64c81"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResultsGridPure4Thol2016", "[", "]"}]], "Code",
 CellLabel->"In[44]:=",ExpressionUUID->"540e17f1-00d9-4355-99f3-c01e16f9d6ce"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         StyleBox["\<\"Thol2016-EoS Results\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Symbol\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Value\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Unit\"\>",
          StripOnInput->False,
          FontWeight->Bold]},
        {"\<\"T\"\>", "115", "\<\"K\"\>"},
        {"\<\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(Sat\\)]\\)\"\>", 
         "9.23760595457641`", "\<\"bar\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\)\"\>", 
         "1.1288264948653954`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\)\"\>", 
         "30.12948608118392`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"], 
     TagBox[GridBox[{
        {
         StyleBox["\<\"Simulation Setup\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Symbol\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Value\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Unit\"\>",
          StripOnInput->False,
          FontWeight->Bold]},
        {"\<\"\\!\\(\\*SubscriptBox[\\(N\\), \
\\(V\\)]\\)/\\!\\(\\*SubscriptBox[\\(N\\), \\(L\\)]\\)\"\>", "1", "\<\"1\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\)\"\>", 
         "1.3568284360896767`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\)\"\>", 
         "86.83701990973931`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(V\\), \\(*\\)]\\)\"\
\>", "0.03197951889752597`", "\<\"1\"\>"},
        {"\<\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(L\\), \\(*\\)]\\)\"\
\>", "2.046689209441662`", "\<\"1\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Rows" -> {{Top}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[44]=",ExpressionUUID->"d28cc2a7-d350-4a9e-ad99-887df416e7f0"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Simulation Setup for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["n",
      FontSlant->"Plain"], 
     StyleBox["V",
      FontSlant->"Plain"]], "=", 
    SubscriptBox[
     StyleBox["n",
      FontSlant->"Plain"], 
     StyleBox["L",
      FontSlant->"Plain"]]}], TraditionalForm]],ExpressionUUID->
  "430f464d-de69-4205-be35-12703c0a007b"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["L",
      FontSlant->"Plain"], 
     StyleBox["V",
      FontSlant->"Plain"]], "=", 
    RowBox[{"6", "\[CenterDot]", 
     SubscriptBox[
      StyleBox["L",
       FontSlant->"Plain"], 
      StyleBox["L",
       FontSlant->"Plain"]]}]}], TraditionalForm]],ExpressionUUID->
  "f3144c66-e59b-42d8-b0df-8f892dc446d1"],
 " ( ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0.70", "<", 
    SuperscriptBox[
     StyleBox["T",
      FontSlant->"Plain"], "*"], "<=", "0.80"}], TraditionalForm]],
  ExpressionUUID->"0f99dff9-816a-4a4e-b6b2-01c190a51ed5"],
 " )"
}], "Subsection",ExpressionUUID->"f6a7f695-398c-4321-a27d-f31456119102"],

Cell["\<\
The following simulation setup is calculated under the assumption that the \
result of the Thol2016 EoS is the final value of the densities.
We assume a final distribution of the molecules where 40% of the total \
molecules is in the vapor phase and 60% of the total molecules are in the \
liquid phase.
We calculate the theoretical total volume of this simulation setup and use it \
for a setup with equal amounts of molecules in each box and initial box side \
length ratio of 6:1.\
\>", "Text",ExpressionUUID->"6af7b426-01bf-4007-8e29-ce98f353c223"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"5ae5fae0-f033-48de-b855-8a9e3f6932ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ResultsGridPure6Thol2016", "[", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "Lratio", ",", "V1", ",", "V2", ",", "rhoVInit", ",", "rhoLInit"}], 
      "}"}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"Lratio", " ", "=", " ", "6"}], ";", "\n", "\t", 
      RowBox[{"V1", " ", "=", " ", 
       RowBox[{
        RowBox[{"1", "/", "rhoVSim"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"dm", "^", "3"}], "/", "mol"}], "*)"}], "*", " ", 
        RowBox[{
         RowBox[{"10", "^", "27"}], " ", "/", "nAvogadro"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"A", "^", "3"}], "/", "N"}], "*)"}], " ", "*", " ", 
        "0.4"}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"A", "^", "3"}], "*)"}], ";", "\n", "\t", 
      RowBox[{"V2", " ", "=", " ", 
       RowBox[{
        RowBox[{"1", "/", "rhoLSim"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"dm", "^", "3"}], "/", "mol"}], "*)"}], "*", " ", 
        RowBox[{
         RowBox[{"10", "^", "27"}], " ", "/", "nAvogadro"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"A", "^", "3"}], "/", "N"}], "*)"}], " ", "*", " ", 
        "0.6"}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"A", "^", "3"}], "*)"}], ";", "\n", "\t", 
      RowBox[{"rhoVInit", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"0.5", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Lratio", "^", "3"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"V1", " ", "+", " ", "V2"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Lratio", "^", "3"}], "+", "1"}], ")"}]}]}], ")"}]}], 
         RowBox[{"(*", 
          RowBox[{"N", "/", 
           RowBox[{"A", "^", "3"}]}], "*)"}], " ", "/", "nAvogadro"}], " ", 
        "*", " ", 
        RowBox[{"10", "^", "27"}]}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"mol", "/", 
        RowBox[{"dm", "^", "3"}]}], "*)"}], ";", "\n", "\t", 
      RowBox[{"rhoLInit", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"0.5", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"V1", " ", "+", " ", "V2"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Lratio", "^", "3"}], "+", "1"}], ")"}]}], ")"}]}], 
         RowBox[{"(*", 
          RowBox[{"N", "/", 
           RowBox[{"A", "^", "3"}]}], "*)"}], " ", "/", "nAvogadro"}], " ", 
        "*", " ", 
        RowBox[{"10", "^", "27"}]}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"mol", "/", 
        RowBox[{"dm", "^", "3"}]}], "*)"}], ";", "\n", "\n", "\t", 
      RowBox[{"Grid", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", "\n", "\t\t", 
          RowBox[{
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<Thol2016-EoS Results\>\"", ",", "Bold"}], 
                  "]"}], ",", "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Symbol\>\"", ",", "\"\<Value\>\"", ",", 
                  "\"\<Unit\>\""}], "}"}]}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{"\"\<T\>\"", ",", " ", "tSim", ",", "\"\<K\>\""}], 
                "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SuperscriptBox[\(P\), \(Sat\)]\)\>\"", ",", 
                 "pSatSim", ",", "\"\<bar\>\""}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\)\>\"", ",", 
                 "rhoVSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\)\>\"", ",", 
                 "rhoLSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], 
                "}"}]}], "\n", "\t\t\t", "}"}], ",", 
             RowBox[{"Alignment", "->", "Left"}], ",", 
             RowBox[{"Dividers", "->", "All"}], ",", 
             RowBox[{"Spacings", "->", 
              RowBox[{"{", 
               RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "\t\t", 
            "]"}], ",", "\n", "\t\t", 
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<Simulation Setup\>\"", ",", "Bold"}], "]"}], 
                 ",", "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Symbol\>\"", ",", "\"\<Value\>\"", ",", 
                  "\"\<Unit\>\""}], "}"}]}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(N\), \
\(V\)]\)/\!\(\*SubscriptBox[\(N\), \(L\)]\)\>\"", ",", "1", ",", 
                 "\"\<1\>\""}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\)\>\"", ",", 
                 "rhoVInit", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\)\>\"", ",", 
                 "rhoLInit", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(V\), \(*\)]\)\>\"",
                  ",", 
                 RowBox[{"rhoVInit", "*", "rhoLjRedFac"}], ",", "\"\<1\>\""}],
                 "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(L\), \(*\)]\)\>\"",
                  ",", 
                 RowBox[{"rhoLInit", "*", "rhoLjRedFac"}], ",", "\"\<1\>\""}],
                 "}"}]}], "\n", "\t\t\t", "}"}], ",", 
             RowBox[{"Alignment", "->", "Left"}], ",", 
             RowBox[{"Dividers", "->", "All"}], ",", 
             RowBox[{"Spacings", "->", 
              RowBox[{"{", 
               RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "\t\t", 
            "]"}]}], "\n", "\t", "}"}], "}"}], ",", 
        RowBox[{"Alignment", "->", "Top"}]}], "]"}]}]}], "\n", "]"}]}], 
  ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[45]:=",ExpressionUUID->"e3f4e271-809c-4609-af54-863737a5a6bb"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResultsGridPure6Thol2016", "[", "]"}]], "Code",
 CellLabel->"In[46]:=",ExpressionUUID->"e7ee90a9-398a-4443-99ec-2ac86175fdc9"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         StyleBox["\<\"Thol2016-EoS Results\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Symbol\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Value\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Unit\"\>",
          StripOnInput->False,
          FontWeight->Bold]},
        {"\<\"T\"\>", "115", "\<\"K\"\>"},
        {"\<\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(Sat\\)]\\)\"\>", 
         "9.23760595457641`", "\<\"bar\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\)\"\>", 
         "1.1288264948653954`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\)\"\>", 
         "30.12948608118392`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"], 
     TagBox[GridBox[{
        {
         StyleBox["\<\"Simulation Setup\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Symbol\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Value\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Unit\"\>",
          StripOnInput->False,
          FontWeight->Bold]},
        {"\<\"\\!\\(\\*SubscriptBox[\\(N\\), \
\\(V\\)]\\)/\\!\\(\\*SubscriptBox[\\(N\\), \\(L\\)]\\)\"\>", "1", "\<\"1\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\)\"\>", 
         "1.3421391253855721`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\)\"\>", 
         "289.9020510832836`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(V\\), \\(*\\)]\\)\"\
\>", "0.03163330188382056`", "\<\"1\"\>"},
        {"\<\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(L\\), \\(*\\)]\\)\"\
\>", "6.832793206905241`", "\<\"1\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Rows" -> {{Top}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[46]=",ExpressionUUID->"eaa88366-cb5f-4f90-bc3d-71e092a3d0f0"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulation point proposal, based on SRK EoS", "Section",ExpressionUUID->"63761701-b68f-4d1f-80bf-2ededdd80764"],

Cell[CellGroupData[{

Cell["State Definition", "Subsection",ExpressionUUID->"353bdab7-ad52-4bb1-82dc-879a71734a9c"],

Cell["\<\
Choose the temperature between the boiling temperature and the critical \
temperature\
\>", "Text",ExpressionUUID->"d7777d2c-22fb-4062-aef6-d02747b4b8cc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*SubscriptBox[\(T\), \(boil\)]\)\>\"", ",", 
       RowBox[{"physicalPropertyData", "[", 
        RowBox[{"component", ",", "\"\<tBoil\>\""}], "]"}], ",", 
       "\"\<K\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*SubscriptBox[\(T\), \(C\)]\)\>\"", ",", 
       RowBox[{"physicalPropertyData", "[", 
        RowBox[{"component", ",", "\"\<tCrit\>\""}], "]"}], ",", 
       "\"\<K\>\""}], "}"}]}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}], ",", 
   RowBox[{"Spacings", "->", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "]"}]], "Code",
 CellLabel->"In[47]:=",ExpressionUUID->"46335cb3-a334-4a5b-a3be-d87cb3596242"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\\!\\(\\*SubscriptBox[\\(T\\), \\(boil\\)]\\)\"\>", 
     "87.24`", "\<\"K\"\>"},
    {"\<\"\\!\\(\\*SubscriptBox[\\(T\\), \\(C\\)]\\)\"\>", 
     "150.8`", "\<\"K\"\>"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[47]=",ExpressionUUID->"9a6a73ce-55ef-4a73-b0a2-2686602a90b2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tSim", " ", "=", " ", "115"}], ";"}], " ", 
  RowBox[{"(*", "K", "*)"}]}]], "Input",
 Background->RGBColor[1, 1, 0],
 CellLabel->"In[48]:=",ExpressionUUID->"b28a1e94-05aa-4a0d-97a6-3dcdb54ffa87"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation and Visualization", "Subsection",ExpressionUUID->"93953d40-4750-442e-9d8c-013bbc0629d8"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"b3d74d09-2c4d-4106-bcbb-d80d6a179f4f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"dT", " ", "=", " ", "1"}], ";"}], " ", 
  RowBox[{"(*", "%", "*)"}], " ", 
  RowBox[{"(*", 
   RowBox[{"temperature", " ", "step", " ", "size"}], "*)"}], "\n", "\n", 
  RowBox[{"(*", 
   RowBox[{"physical", " ", "property", " ", "data"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"tBoil", " ", "=", " ", 
    RowBox[{"physicalPropertyData", "[", 
     RowBox[{"component", ",", "\"\<tBoil\>\""}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "K", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tCrit", " ", "=", " ", 
    RowBox[{"physicalPropertyData", "[", 
     RowBox[{"component", ",", "\"\<tCrit\>\""}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "K", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pCrit", " ", "=", " ", 
    RowBox[{"physicalPropertyData", "[", 
     RowBox[{"component", ",", "\"\<pCrit\>\""}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "bar", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]", " ", "=", " ", 
    RowBox[{"physicalPropertyData", "[", 
     RowBox[{"component", ",", "\"\<acentricFactor\>\""}], "]"}]}], ";"}], 
  " ", 
  RowBox[{"(*", "1", "*)"}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"tRed", " ", "=", " ", 
    RowBox[{"tSim", "/", "tCrit"}]}], ";"}], " ", 
  RowBox[{"(*", "1", "*)"}], "\n", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"EoS", " ", "Parameter"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"a", ",", "b"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "t_", "]"}], " ", ":=", " ", 
    RowBox[{
     RowBox[{"aCritSRK", "[", 
      RowBox[{"tCrit", ",", "pCrit"}], "]"}], " ", "*", 
     RowBox[{"\[Alpha]SRK", "[", 
      RowBox[{
       RowBox[{"t", "/", "tCrit"}], ",", "\[Omega]"}], "]"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"dm", "^", "3"}], ")"}], "^", "2"}], " ", "bar", " ", 
    RowBox[{"mol", "^", 
     RowBox[{"-", "2"}]}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", " ", "=", " ", 
    RowBox[{"bCritSRK", "[", 
     RowBox[{"tCrit", ",", "pCrit"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"dm", "^", "3"}], " ", 
    RowBox[{"mol", "^", 
     RowBox[{"-", "1"}]}]}], "*)"}], "\n", "\n", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"caclulate", " ", "pSatSRK"}], ",", " ", 
    RowBox[{
    "rhoLSim", " ", "and", " ", "rhoVSim", " ", "at", " ", "the", " ", 
     "simulation", " ", "temperature"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "pGuess", "}"}], ",", "\[IndentingNewLine]", "\t", 
    RowBox[{
     RowBox[{"pGuess", " ", "=", " ", "1"}], ";", " ", 
     RowBox[{"(*", "bar", "*)"}], "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{"start", " ", "calculation", " ", "from", " ", "boiling", " ", 
       RowBox[{"point", " ", "'"}], 
       RowBox[{"tBoil", "'"}], " ", "where", " ", "pSat", " ", 
       RowBox[{"is", " ", "~", "1"}], " ", "bar"}], "*)"}], 
     "\[IndentingNewLine]", "\t", 
     RowBox[{"Do", "[", "\n", "\t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"pSatSRK", " ", "=", " ", 
         RowBox[{"Quiet", "@", 
          RowBox[{"saturationPressureSRK", "[", 
           RowBox[{
            RowBox[{"a", "[", "t", "]"}], ",", "b", ",", "t", ",", "pGuess", 
            ",", 
            RowBox[{"10", "^", 
             RowBox[{"-", "15"}]}], ",", "False"}], "]"}]}]}], ";", "\n", 
        "\t\t", 
        RowBox[{"pGuess", " ", "=", " ", "pSatSRK"}], ";"}], 
       "\[IndentingNewLine]", "\t\t", ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "tBoil", ",", "tSim", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"tSim", ">", "tBoil"}], ",", "#", ",", 
             RowBox[{"-", "#"}]}], "]"}], "&"}], "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"tCrit", "-", "tSim"}], ")"}], "*", 
           RowBox[{"dT", "/", "100"}]}], "]"}]}], "}"}]}], 
      "\[IndentingNewLine]", "\t", "]"}], ";"}]}], "\n", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"pSatSRK", " ", "=!=", " ", "Indeterminate"}], ",", "\n", "\t", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"rhoLSim", ",", "rhoVSim"}], "}"}], " ", "=", " ", 
      RowBox[{"1", "/", 
       RowBox[{
        RowBox[{"vSRK", "[", 
         RowBox[{"tSim", ",", "pSatSRK", ",", 
          RowBox[{"a", "[", "tSim", "]"}], ",", "b"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3"}], "}"}], "]"}], "]"}]}]}], ";"}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{"mol", " ", 
      RowBox[{"dm", "^", 
       RowBox[{"-", "3"}]}]}], " ", "*)"}], "\n", "\t", ",", 
    RowBox[{"(*", 
     RowBox[{"else", ":", " ", 
      RowBox[{"calulation", " ", "was", " ", "unsuccsessful"}]}], "*)"}], 
    "\n", "\t", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"rhoLSim", ",", "rhoVSim"}], "}"}], " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<N/A\>\"", ",", "\"\<N/A\>\""}], "}"}]}], ";"}]}], "\n", 
   "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CalculateSRKPureEoSPlot", "[", "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", "\n", "\t", 
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
       RowBox[{
       "rhoLVec", ",", "rhoVVec", ",", "\[IndentingNewLine]", "\t\t", 
        "pGuess", ",", "pSRK", ",", "\[IndentingNewLine]", "\t\t", "rhoL", 
        ",", "rhoV"}], "\[IndentingNewLine]", "\t", "}"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", 
       RowBox[{"init", " ", "variables"}], "*)"}], "\[IndentingNewLine]", 
      "\t", 
      RowBox[{
       RowBox[{"rhoLVec", " ", "=", " ", 
        RowBox[{"rhoVVec", " ", "=", 
         RowBox[{"{", "}"}]}]}], ";", "\[IndentingNewLine]", "\t", 
       RowBox[{"rhoL", " ", "=", " ", 
        RowBox[{"rhoV", " ", "=", " ", "0"}]}], ";", "\[IndentingNewLine]", 
       "\t", 
       RowBox[{"pGuess", " ", "=", " ", "1"}], ";", " ", 
       RowBox[{"(*", "bar", "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "\t", 
       RowBox[{"Do", "[", "\[IndentingNewLine]", "\t\t", 
        RowBox[{"(*", 
         RowBox[{"Calculate", " ", "Densities", " ", "at", " ", "t"}], "*)"}],
         "\[IndentingNewLine]", "\t\t", 
        RowBox[{
         RowBox[{
          RowBox[{"pSRK", " ", "=", " ", 
           RowBox[{"Quiet", "[", 
            RowBox[{"Check", "[", 
             RowBox[{
              RowBox[{"saturationPressureSRK", "[", 
               RowBox[{
                RowBox[{"a", "[", "t", "]"}], ",", "b", ",", "t", ",", 
                "pGuess", ",", 
                RowBox[{"10", "^", 
                 RowBox[{"-", "15"}]}], ",", "False"}], "]"}], ",", "None"}], 
             "]"}], "]"}]}], ";", "\[IndentingNewLine]", "\t\t", 
          RowBox[{"(*", 
           RowBox[{"check", " ", "if", " ", "error", " ", "ocurred"}], "*)"}],
           "\[IndentingNewLine]", "\t\t", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"pSRK", " ", "==", " ", "None"}], ",", 
            RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
          "\t\t", 
          RowBox[{"(*", 
           RowBox[{
           "safe", " ", "data", " ", "and", " ", "set", " ", "new", " ", 
            "pressure", " ", "guess"}], "*)"}], "\[IndentingNewLine]", "\t\t", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"rhoL", ",", "rhoV"}], "}"}], " ", "=", " ", 
           RowBox[{"1", "/", 
            RowBox[{
             RowBox[{"vSRK", "[", 
              RowBox[{"t", ",", "pSRK", ",", 
               RowBox[{"a", "[", "t", "]"}], ",", "b"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "3"}], "}"}], "]"}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", "\t\t", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"rhoLVec", ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "rhoL"}], "}"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\t\t", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"rhoVVec", ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "rhoV"}], "}"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\t\t", 
          RowBox[{"pGuess", " ", "=", " ", "pSRK"}], ";"}], 
         "\[IndentingNewLine]", "\t\t", ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "tBoil", ",", "tCrit", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"tCrit", "-", "tBoil"}], ")"}], "*", "0.005"}]}], 
          "}"}]}], "\[IndentingNewLine]", "\t", "]"}], ";", 
       "\[IndentingNewLine]", "\t", "\[IndentingNewLine]", "\t", 
       RowBox[{"(*", "RETURN", "*)"}], "\[IndentingNewLine]", "\t", 
       RowBox[{"Return", "[", 
        RowBox[{"{", 
         RowBox[{"rhoLVec", ",", "rhoVVec"}], "}"}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ResultsPlotPureSRK", "[", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"Print", "@", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
          RowBox[{
           RowBox[{"ListLinePlot", "[", 
            RowBox[{
             RowBox[{"CalculateSRKPureEoSPlot", "[", "]"}], "\n", "\t\t\t", 
             RowBox[{"(*", 
              RowBox[{",", 
               RowBox[{
               "PlotLabel", "\[Rule]", " ", 
                "\"\<Reduced Density at Saturation\>\""}]}], "*)"}], "\n", 
             "\t\t\t", ",", 
             RowBox[{"Frame", "\[Rule]", "True"}], ",", 
             RowBox[{"FrameLabel", "\[Rule]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", " ", "14"}], "]"}], "&"}], "/@", 
                RowBox[{"{", " ", 
                 RowBox[{
                 "\"\<T / K\>\"", ",", " ", 
                  "\"\<\[Rho] / mol \!\(\*SuperscriptBox[\(dm\), \
\(-3\)]\)\>\""}], "}"}]}], ")"}]}], "\n", "\t\t\t", ",", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<Saturated Liquid, SRK EOS\>\"", ",", 
                "\"\<Saturated Vapor, SRK EOS\>\""}], "}"}]}]}], "\n", "\t\t",
             "]"}], ",", "\[IndentingNewLine]", "\t\t", 
           RowBox[{"ListPlot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"rhoSatExp", "\[LeftDoubleBracket]", 
                RowBox[{"component", ",", "All", ",", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "3"}], "}"}]}], "\[RightDoubleBracket]"}],
                ",", 
               RowBox[{"rhoSatExp", "[", 
                RowBox[{"[", 
                 RowBox[{"component", ",", "All", ",", 
                  RowBox[{"{", 
                   RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}]}], "}"}], 
             "\n", "\t\t\t", ",", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<Saturated Liquid, Experimental\>\"", ",", 
                "\"\<Saturated Vapor, Experimental\>\""}], "}"}]}], "\n", 
             "\t\t\t", ",", 
             RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}]}], 
            "\n", "\t\t", "]"}], ",", "\[IndentingNewLine]", "\t\t", 
           RowBox[{"ListPlot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"tSim", ",", "rhoLSim"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"tSim", ",", "rhoVSim"}], "}"}]}], "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", "Red", "}"}]}], ",", 
             RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}], ",", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"{", "\"\<Simulation\>\"", "}"}]}]}], "]"}], ",", 
           "\[IndentingNewLine]", "\t\t", 
           RowBox[{"ListPlot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"{", 
               RowBox[{"tCrit", ",", 
                RowBox[{"1", "/", 
                 RowBox[{"physicalPropertyData", "[", 
                  RowBox[{"component", ",", "\"\<vCrit\>\""}], "]"}]}]}], 
               "}"}], "}"}], ",", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"{", "\"\<Critical point\>\"", "}"}]}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", "Green", "}"}]}]}], "]"}]}], "\n", "\t\t", "}"}], 
         ",", 
         RowBox[{"PlotRange", "->", "All"}]}], "\[IndentingNewLine]", "\t", 
        "]"}]}], ";", "\n", "\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"pSatSRK", " ", "=!=", " ", "Indeterminate"}], ",", "\n", 
        "\t\t", 
        RowBox[{"Highlighted", "@", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\"\<Simulation @T=\>\"", "<>", 
             RowBox[{"ToString", "@", "tSim"}], "<>", 
             "\"\<K : \!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\) = \>\""}], ",", 
            RowBox[{"Round", "[", 
             RowBox[{"rhoLSim", ",", "0.00001"}], "]"}], ",", 
            "\"\< mol \!\(\*SuperscriptBox[\(dm\), \(-3\)]\), \
\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\) = \>\"", ",", 
            RowBox[{"Round", "[", 
             RowBox[{"rhoVSim", ",", "0.00001"}], "]"}], ",", 
            "\"\< mol \!\(\*SuperscriptBox[\(dm\), \(-3\)]\)\>\""}], "}"}], 
          "]"}]}], "\n", "\t\t", ",", 
        RowBox[{"(*", 
         RowBox[{"else", ":", " ", 
          RowBox[{"Calculation", " ", "was", " ", "unsuccessful"}]}], "*)"}], 
        "\n", "\t\t", 
        RowBox[{"Highlighted", "@", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<Simulation @T=\>\"", "<>", 
            RowBox[{"ToString", "@", "tSim"}], "<>", 
            "\"\<K : Calculation was not successful, decrease step-size for \
calculation\>\""}], "}"}], "]"}]}]}], "\n", "\t", "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[49]:=",ExpressionUUID->"8205ed6c-d8ab-4ac2-ac61-d99a89ae4592"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResultsPlotPureSRK", "[", "]"}]], "Code",
 CellLabel->"In[62]:=",ExpressionUUID->"3c7883a8-0279-40db-bb13-80580be9e3ec"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 90], 0.011111111111111112`]], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwll3lYTfsXxkOSW0mIBjRKA8116ozvMdzSKOnMw96njKWoWyFKIVSOqRKX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          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 90], 0.011111111111111112`]], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwdlwk0VXsUxhESMhQyZJaKJnpUevX/0lwk9dzBvdc992rQQxqeR6ZGDZKk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          "]]}}}, {{}, {}}}, {{}, {{{
         Directive[
          PointSize[0.012833333333333334`], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{{
                 GrayLevel[1], 
                 DiskBox[{0, 0}, 
                  Offset[{3, 3}]]}, 
                AbsoluteThickness[1.5], 
                Dashing[{}], 
                CircleBox[{0, 0}, 
                 Offset[{3, 3}]]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  RGBColor[0.368417, 0.506779, 0.709798], 
                  AbsoluteThickness[1.6]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Scaled[9.75]], {{{83.81, 35.471}}, {{90., 34.52}}, {{100., 
          32.893}}, {{110., 31.115}}, {{120., 29.113}}, {{130., 26.735}}, {{
          140., 23.623}}, {{150., 17.032}}, {{150.69, 13.407}}}]}, {
         Directive[
          PointSize[0.012833333333333334`], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{{
                 GrayLevel[1], 
                 PolygonBox[
                  NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                AbsoluteThickness[1.5], 
                Dashing[{}], 
                JoinedCurveBox[
                 NCache[
                  Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                  Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  RGBColor[0.880722, 0.611041, 0.142051], 
                  AbsoluteThickness[1.6]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Scaled[9.75]], {{{83.81, 0.102}}, {{90., 0.186}}, {{100., 
          0.422}}, {{110., 0.833}}, {{120., 1.505}}, {{130., 2.593}}, {{140., 
          4.478}}, {{150., 9.875}}, {{150.69, 
          13.407}}}]}}}, {{}, {}}}, {{}, {{{
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{{
                 GrayLevel[1], 
                 DiskBox[{0, 0}, 
                  Offset[{3, 3}]]}, 
                AbsoluteThickness[1.5], 
                Dashing[{}], 
                CircleBox[{0, 0}, 
                 Offset[{3, 3}]]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[1, 0, 0]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Scaled[9.75]], {{{115., 29.47060833734706}}, {{115., 
          1.1149175701299008`}}}]}}}, {{}, {}}}, {{}, {{{
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         PointBox[{{150.8, 13.35113484646195}, {150.8, 
          13.35113484646195}}]}}}, {{}, {}}}}, {
    PlotRange -> All, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, 
     AxesOrigin -> {85.9489375000002, 0}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         TagBox[
          StyleBox[
          "\"\[Rho] / mol \\!\\(\\*SuperscriptBox[\\(dm\\), \\(-3\\)]\\)\"", 
           14, StripOnInput -> False], HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
          StyleBox["\"T / K\"", 14, StripOnInput -> False], HoldForm], 
         TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{85.9489375000002, 149.211}, {0, 35.224749647646526`}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{
          "\"Saturated Liquid, SRK EOS\"", "\"Saturated Vapor, SRK EOS\""}, 
          "LineLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "90"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "90"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
               ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"True", ",", "True"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{
          "\"Saturated Liquid, Experimental\"", 
           "\"Saturated Vapor, Experimental\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], ",", "9.75`"}],
                     "}"}]}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "False"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Simulation\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Critical point\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 1, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Print",
 CellLabel->
  "During evaluation of \
In[62]:=",ExpressionUUID->"31bb60b9-6dbe-4f92-8f28-da1d2f78189a"],

Cell[BoxData[
 TemplateBox[{
   TemplateBox[{
    "\"Simulation @T=115K : \\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\) = \
\"", "29.47061`", 
     "\" mol \\!\\(\\*SuperscriptBox[\\(dm\\), \\(-3\\)]\\), \
\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\) = \"", "1.1149200000000001`", 
     "\" mol \\!\\(\\*SuperscriptBox[\\(dm\\), \\(-3\\)]\\)\""}, 
    "RowDefault"], FrameStyle -> None},
  "Highlighted"]], "Output",
 CellLabel->"Out[62]=",ExpressionUUID->"c7e66c2b-2aff-4212-a921-eb99d9a4c5d0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Simulation Setup for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["n",
      FontSlant->"Plain"], 
     StyleBox["V",
      FontSlant->"Plain"]], "=", 
    SubscriptBox[
     StyleBox["n",
      FontSlant->"Plain"], 
     StyleBox["L",
      FontSlant->"Plain"]]}], TraditionalForm]],ExpressionUUID->
  "db744f7c-d398-4c3e-b353-80fc8badea55"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["L",
      FontSlant->"Plain"], 
     StyleBox["V",
      FontSlant->"Plain"]], "=", 
    SubscriptBox[
     StyleBox["L",
      FontSlant->"Plain"], 
     StyleBox["L",
      FontSlant->"Plain"]]}], TraditionalForm]],ExpressionUUID->
  "df56830c-d94d-42e4-8c5b-2ebb3ee189b7"],
 " ( ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0.75", "<", 
    RowBox[{
     StyleBox["T",
      FontSlant->"Plain"], "/", 
     SubscriptBox[
      StyleBox["T",
       FontSlant->"Plain"], 
      StyleBox["C",
       FontSlant->"Plain"]]}], "<=", "0.98"}], TraditionalForm]],
  ExpressionUUID->"05dc1c33-6d80-4c4c-8029-4c8d2ec52710"],
 " )"
}], "Subsection",ExpressionUUID->"34e5a7eb-27ea-495a-bbae-d993e75da88d"],

Cell["\<\
The following simulation setup is calculated under the assumption that the \
result of the SRK EoS is the final value of the densities.
We assume a final distribution of the molecules where 40% of the total \
molecules is in the vapor phase and 60% of the total molecules are in the \
liquid phase.
We calculate the theoretical total volume of this simulation setup and use it \
for a setup with equal amounts of molecules in each box as well as the same \
initial density.\
\>", "Text",ExpressionUUID->"ec36052f-d702-49e5-8998-67e7b005d0ab"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"402fb62c-db64-4284-a255-26a4cbbf0160"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ResultsGridPureSRK", "[", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"V1", ",", "V2", ",", "rhoSim"}], "}"}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"V1", " ", "=", " ", 
       RowBox[{
        RowBox[{"1", "/", "rhoVSim"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"dm", "^", "3"}], "/", "mol"}], "*)"}], "*", " ", 
        RowBox[{
         RowBox[{"10", "^", "27"}], " ", "/", "nAvogadro"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"A", "^", "3"}], "/", "N"}], "*)"}], " ", "*", " ", 
        "0.4"}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"A", "^", "3"}], "*)"}], ";", "\n", "\t", 
      RowBox[{"V2", " ", "=", " ", 
       RowBox[{
        RowBox[{"1", "/", "rhoLSim"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"dm", "^", "3"}], "/", "mol"}], "*)"}], "*", " ", 
        RowBox[{
         RowBox[{"10", "^", "27"}], " ", "/", "nAvogadro"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"A", "^", "3"}], "/", "N"}], "*)"}], " ", "*", " ", 
        "0.6"}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"A", "^", "3"}], "*)"}], ";", "\n", "\t", 
      RowBox[{"rhoSim", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"V1", "+", "V2"}], ")"}]}], 
         RowBox[{"(*", 
          RowBox[{"N", "/", 
           RowBox[{"A", "^", "3"}]}], "*)"}], " ", "/", "nAvogadro"}], " ", 
        "*", " ", 
        RowBox[{"10", "^", "27"}]}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"mol", "/", 
        RowBox[{"dm", "^", "3"}]}], "*)"}], ";", "\n", "\n", "\t", 
      RowBox[{"Grid", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", "\n", "\t\t", 
          RowBox[{
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<SRK-EoS Results\>\"", ",", "Bold"}], "]"}], 
                 ",", "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Symbol\>\"", ",", "\"\<Value\>\"", ",", 
                  "\"\<Unit\>\""}], "}"}]}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{"\"\<T\>\"", ",", " ", "tSim", ",", "\"\<K\>\""}], 
                "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SuperscriptBox[\(P\), \(Sat\)]\)\>\"", ",", 
                 "pSatSim", ",", "\"\<bar\>\""}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\)\>\"", ",", 
                 "rhoVSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\)\>\"", ",", 
                 "rhoLSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], 
                "}"}]}], "\n", "\t\t\t", "}"}], ",", 
             RowBox[{"Alignment", "->", "Left"}], ",", 
             RowBox[{"Dividers", "->", "All"}], ",", 
             RowBox[{"Spacings", "->", 
              RowBox[{"{", 
               RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "\t\t", 
            "]"}], ",", "\n", "\t\t", 
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<Simulation Setup\>\"", ",", "Bold"}], "]"}], 
                 ",", "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Symbol\>\"", ",", "\"\<Value\>\"", ",", 
                  "\"\<Unit\>\""}], "}"}]}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(N\), \
\(V\)]\)/\!\(\*SubscriptBox[\(N\), \(L\)]\)\>\"", ",", "1", ",", 
                 "\"\<1\>\""}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \
\(V\)]\),\!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\)\>\"", ",", "rhoSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(V\), \(*\)]\),\!\(\
\*SubsuperscriptBox[\(\[Rho]\), \(L\), \(*\)]\)\>\"", ",", 
                 RowBox[{"rhoSim", "*", "rhoLjRedFac"}], ",", "\"\<1\>\""}], 
                "}"}]}], "\n", "\t\t\t", "}"}], ",", 
             RowBox[{"Alignment", "->", "Left"}], ",", 
             RowBox[{"Dividers", "->", "All"}], ",", 
             RowBox[{"Spacings", "->", 
              RowBox[{"{", 
               RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "\t\t", 
            "]"}]}], "\n", "\t", "}"}], "}"}], ",", 
        RowBox[{"Alignment", "->", "Top"}]}], "]"}]}]}], "\n", "]"}]}], 
  ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[63]:=",ExpressionUUID->"e413d0dc-2947-46e8-b553-51f65aeef9fa"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResultsGridPureSRK", "[", "]"}]], "Code",
 CellLabel->"In[64]:=",ExpressionUUID->"31bf1b21-1f8e-43b1-98bf-f66e218f16ed"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         StyleBox["\<\"SRK-EoS Results\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Symbol\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Value\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Unit\"\>",
          StripOnInput->False,
          FontWeight->Bold]},
        {"\<\"T\"\>", "115", "\<\"K\"\>"},
        {"\<\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(Sat\\)]\\)\"\>", 
         "9.23760595457641`", "\<\"bar\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\)\"\>", 
         "1.1149175701299008`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\)\"\>", 
         "29.47060833734706`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"], 
     TagBox[GridBox[{
        {
         StyleBox["\<\"Simulation Setup\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Symbol\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Value\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Unit\"\>",
          StripOnInput->False,
          FontWeight->Bold]},
        {"\<\"\\!\\(\\*SubscriptBox[\\(N\\), \
\\(V\\)]\\)/\\!\\(\\*SubscriptBox[\\(N\\), \\(L\\)]\\)\"\>", "1", "\<\"1\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \
\\(V\\)]\\),\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\)\"\>", 
         "2.6376164136247358`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(V\\), \
\\(*\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(L\\), \
\\(*\\)]\\)\"\>", "0.06216681615770764`", "\<\"1\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Rows" -> {{Top}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[64]=",ExpressionUUID->"6094b81e-f76f-43e4-88fd-67935b3a4eae"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Simulation Setup for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["n",
      FontSlant->"Plain"], 
     StyleBox["V",
      FontSlant->"Plain"]], "=", 
    SubscriptBox[
     StyleBox["n",
      FontSlant->"Plain"], 
     StyleBox["L",
      FontSlant->"Plain"]]}], TraditionalForm]],ExpressionUUID->
  "e04080ec-7771-4dd7-9d8c-d68473676981"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["L",
      FontSlant->"Plain"], 
     StyleBox["V",
      FontSlant->"Plain"]], "=", 
    RowBox[{"2", "\[CenterDot]", 
     SubscriptBox[
      StyleBox["L",
       FontSlant->"Plain"], 
      StyleBox["L",
       FontSlant->"Plain"]]}]}], TraditionalForm]],ExpressionUUID->
  "4bc37748-6d74-4a8f-b065-083589d39a73"],
 " ( ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0.56", "<=", 
    RowBox[{
     StyleBox["T",
      FontSlant->"Plain"], "/", 
     SubscriptBox[
      StyleBox["T",
       FontSlant->"Plain"], 
      StyleBox["C",
       FontSlant->"Plain"]]}], "<=", "0.75"}], TraditionalForm]],
  ExpressionUUID->"dfb7c863-8f52-4ab8-93ce-e5ff548af3c3"],
 " )"
}], "Subsection",ExpressionUUID->"f6cb5052-fc39-4c60-bad2-57da0152b573"],

Cell["\<\
The following simulation setup is calculated under the assumption that the \
result of the SRK EoS is the final value of the densities.
We assume a final distribution of the molecules where 40% of the total \
molecules is in the vapor phase and 60% of the total molecules are in the \
liquid phase.
We calculate the theoretical total volume of this simulation setup and use it \
for a setup with equal amounts of molecules in each box and initial box side \
length ratio of 2:1.\
\>", "Text",ExpressionUUID->"8a788864-3971-4051-a5ea-808f6540f735"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"45858f5f-2652-4baa-bb90-5c4369ee8d08"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ResultsGridPure2SRK", "[", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "Lratio", ",", "V1", ",", "V2", ",", "rhoVInit", ",", "rhoLInit"}], 
      "}"}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"Lratio", " ", "=", " ", "2"}], ";", "\n", "\t", 
      RowBox[{"V1", " ", "=", " ", 
       RowBox[{
        RowBox[{"1", "/", "rhoVSim"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"dm", "^", "3"}], "/", "mol"}], "*)"}], "*", " ", 
        RowBox[{
         RowBox[{"10", "^", "27"}], " ", "/", "nAvogadro"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"A", "^", "3"}], "/", "N"}], "*)"}], " ", "*", " ", 
        "0.4"}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"A", "^", "3"}], "*)"}], ";", "\n", "\t", 
      RowBox[{"V2", " ", "=", " ", 
       RowBox[{
        RowBox[{"1", "/", "rhoLSim"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"dm", "^", "3"}], "/", "mol"}], "*)"}], "*", " ", 
        RowBox[{
         RowBox[{"10", "^", "27"}], " ", "/", "nAvogadro"}], " ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"A", "^", "3"}], "/", "N"}], "*)"}], " ", "*", " ", 
        "0.6"}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"A", "^", "3"}], "*)"}], ";", "\n", "\t", 
      RowBox[{"rhoVInit", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"0.5", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Lratio", "^", "3"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"V1", " ", "+", " ", "V2"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Lratio", "^", "3"}], "+", "1"}], ")"}]}]}], ")"}]}], 
         RowBox[{"(*", 
          RowBox[{"N", "/", 
           RowBox[{"A", "^", "3"}]}], "*)"}], " ", "/", "nAvogadro"}], " ", 
        "*", " ", 
        RowBox[{"10", "^", "27"}]}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"mol", "/", 
        RowBox[{"dm", "^", "3"}]}], "*)"}], ";", "\n", "\t", 
      RowBox[{"rhoLInit", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"0.5", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"V1", " ", "+", " ", "V2"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Lratio", "^", "3"}], "+", "1"}], ")"}]}], ")"}]}], 
         RowBox[{"(*", 
          RowBox[{"N", "/", 
           RowBox[{"A", "^", "3"}]}], "*)"}], " ", "/", "nAvogadro"}], " ", 
        "*", " ", 
        RowBox[{"10", "^", "27"}]}]}], " ", 
      RowBox[{"(*", 
       RowBox[{"mol", "/", 
        RowBox[{"dm", "^", "3"}]}], "*)"}], ";", "\n", "\n", "\t", 
      RowBox[{"Grid", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", "\n", "\t\t", 
          RowBox[{
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<Thol2016-EoS Results\>\"", ",", "Bold"}], 
                  "]"}], ",", "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Symbol\>\"", ",", "\"\<Value\>\"", ",", 
                  "\"\<Unit\>\""}], "}"}]}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{"\"\<T\>\"", ",", " ", "tSim", ",", "\"\<K\>\""}], 
                "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SuperscriptBox[\(P\), \(Sat\)]\)\>\"", ",", 
                 "pSatSim", ",", "\"\<bar\>\""}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\)\>\"", ",", 
                 "rhoVSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\)\>\"", ",", 
                 "rhoLSim", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], 
                "}"}]}], "\n", "\t\t\t", "}"}], ",", 
             RowBox[{"Alignment", "->", "Left"}], ",", 
             RowBox[{"Dividers", "->", "All"}], ",", 
             RowBox[{"Spacings", "->", 
              RowBox[{"{", 
               RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "\t\t", 
            "]"}], ",", "\n", "\t\t", 
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"{", "\n", "\t\t\t", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<Simulation Setup\>\"", ",", "Bold"}], "]"}], 
                 ",", "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Symbol\>\"", ",", "\"\<Value\>\"", ",", 
                  "\"\<Unit\>\""}], "}"}]}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(N\), \
\(V\)]\)/\!\(\*SubscriptBox[\(N\), \(L\)]\)\>\"", ",", "1", ",", 
                 "\"\<1\>\""}], "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\)\>\"", ",", 
                 "rhoVInit", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\)\>\"", ",", 
                 "rhoLInit", ",", 
                 "\"\<mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], "}"}],
                ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(V\), \(*\)]\)\>\"",
                  ",", 
                 RowBox[{"rhoVInit", "*", "rhoLjRedFac"}], ",", "\"\<1\>\""}],
                 "}"}], ",", "\n", "\t\t\t", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(L\), \(*\)]\)\>\"",
                  ",", 
                 RowBox[{"rhoLInit", "*", "rhoLjRedFac"}], ",", "\"\<1\>\""}],
                 "}"}]}], "\n", "\t\t\t", "}"}], ",", 
             RowBox[{"Alignment", "->", "Left"}], ",", 
             RowBox[{"Dividers", "->", "All"}], ",", 
             RowBox[{"Spacings", "->", 
              RowBox[{"{", 
               RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "\t\t", 
            "]"}]}], "\n", "\t", "}"}], "}"}], ",", 
        RowBox[{"Alignment", "->", "Top"}]}], "]"}]}]}], "\n", "]"}]}], 
  ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[65]:=",ExpressionUUID->"8a0e54aa-aaae-4fc8-ab6a-6aab4dfa4354"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResultsGridPure2SRK", "[", "]"}]], "Code",
 CellLabel->"In[66]:=",ExpressionUUID->"218c26ba-f8ff-48ec-8f70-859b57f57850"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         StyleBox["\<\"Thol2016-EoS Results\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Symbol\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Value\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Unit\"\>",
          StripOnInput->False,
          FontWeight->Bold]},
        {"\<\"T\"\>", "115", "\<\"K\"\>"},
        {"\<\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(Sat\\)]\\)\"\>", 
         "9.23760595457641`", "\<\"bar\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\)\"\>", 
         "1.1149175701299008`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\)\"\>", 
         "29.47060833734706`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"], 
     TagBox[GridBox[{
        {
         StyleBox["\<\"Simulation Setup\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Symbol\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Value\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Unit\"\>",
          StripOnInput->False,
          FontWeight->Bold]},
        {"\<\"\\!\\(\\*SubscriptBox[\\(N\\), \
\\(V\\)]\\)/\\!\\(\\*SubscriptBox[\\(N\\), \\(L\\)]\\)\"\>", "1", "\<\"1\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\)\"\>", 
         "1.483659232663914`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\)\"\>", 
         "11.869273861311312`", "\<\"mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\)\"\>"},
        {"\<\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(V\\), \\(*\\)]\\)\"\
\>", "0.03496883408871055`", "\<\"1\"\>"},
        {"\<\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(L\\), \\(*\\)]\\)\"\
\>", "0.2797506727096844`", "\<\"1\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Rows" -> {{Top}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[66]=",ExpressionUUID->"a659a6d1-9bfa-4c41-b8fa-440a53908704"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Binary Mixture with Critical Point Data", "Chapter",ExpressionUUID->"eba7a218-e177-4f7a-8a5e-c94894d154f9"],

Cell[CellGroupData[{

Cell["Component Names", "Section",ExpressionUUID->"6e389be1-8fa2-4cf3-a3a5-384f79966850"],

Cell[TextData[{
 StyleBox["The estimation algorithm in this chapter was tested with the \
following systems:",
  FontWeight->"Bold"],
 "\n\tArgon - Krypton\n\tArgon - Ethane"
}], "Text",ExpressionUUID->"21899dcf-dfbb-42b1-bcc8-bc74ea721907"],

Cell[CellGroupData[{

Cell["Check-Function", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"65fdc864-f2fe-456c-95dc-129e832e4d69"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CheckBinaryInput", "::", "usage"}], " ", "=", " ", 
   "\"\<CheckBinaryInput[] -> Checks if the names in 'components' are valid \
keys in 'physicalPropertyData'.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"CheckBinaryInput", "[", "]"}], " ", ":=", " ", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"AllTrue", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"KeyExistsQ", "[", 
          RowBox[{"physicalPropertyData", ",", "#"}], "]"}], " ", "&"}], "/@",
         " ", "components"}], ",", "TrueQ"}], "]"}], "\n", "\t", ",", 
     RowBox[{
     "Print", "[", 
      "\"\<All components were found in 'physicalPropertyData'\>\"", "]"}], 
     "\n", "\t", ",", 
     RowBox[{
      RowBox[{
      "Print", "[", 
       "\"\<Some components were NOT found in 'physicalPropertyData'\>\"", 
       "]"}], ";", 
      RowBox[{"Beep", "[", "]"}], ";"}]}], "\n", "]"}]}], ";"}]}], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[9]:=",ExpressionUUID->"9a9dafbc-7045-4710-b449-959e31276562"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"components", "=", 
    RowBox[{"{", 
     RowBox[{"\"\<Argon\>\"", ",", "\"\<Krypton\>\""}], "}"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"CheckBinaryInput", "[", "]"}]}], "Input",
 Background->RGBColor[1, 1, 0],
 CellLabel->"In[11]:=",ExpressionUUID->"f97dd372-995a-4dc0-a2c0-6b8d72d5dfa4"],

Cell[BoxData["\<\"All components were found in 'physicalPropertyData'\"\>"], \
"Print",
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"c2df9085-dfc8-4699-ae6d-aafb216ca237"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Experimental and Physical Property Data", "Section",ExpressionUUID->"1e9b91ec-cf0e-4088-8e99-a524b01c68a2"],

Cell["\<\
Mind to update the experimental data according to the set components!\
\>", "Text",ExpressionUUID->"299f7de7-067a-4036-85e1-a31661ba8494"],

Cell[CellGroupData[{

Cell["Saturation Pressure", "Subsection",ExpressionUUID->"68435494-34fb-47e6-b523-60c4912005e6"],

Cell[CellGroupData[{

Cell["Experimental Data", "Subsubsection",ExpressionUUID->"2c17d576-9f8c-4694-a32a-81b98c972023"],

Cell["\<\
Argon, Ethane\t... CRC Handbook, 99th Ed., 6-125 - 6-127
Krypton ... Bowman, D. H., Aziz, R. A., & Lim, C. C. (1969). Vapor pressure \
of liquid argon, krypton, and xenon. Canadian Journal of Physics, 47(3), 267\
\[Dash]273.\
\>", "Text",ExpressionUUID->"5e1d73a6-60c7-4810-ab7c-c25f617cf5b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pSatExp", "=", 
   RowBox[{"<|", 
    RowBox[{"(*", 
     RowBox[{"\"\<Name\>\"", " ", "->", " ", 
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"T", " ", "[", "K", "]"}], ",", " ", 
          RowBox[{
           SuperscriptBox["P", "Sat"], " ", "[", "bar", "]"}]}], "}"}], ",", 
        " ", "..."}], " ", "}"}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\"\<Argon\>\"", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"50.", ",", "0.0003714"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"70.", ",", "0.07670"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"90.", ",", "1.335"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"110.", ",", "6.653"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"130", ",", "20.25"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"150.", ",", "47.35"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\"\<Krypton\>\"", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"120.17", ",", "1.0457"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"129.88", ",", "2.1369"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"140.", ",", "3.9365"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"150.707", ",", "6.7786"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"161.197", ",", "10.913"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\"\<Ethane\>\"", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"120.", ",", "0.004"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"140.", ",", "0.038"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"160.", ",", "0.215"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"180.", ",", "0.787"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"200.", ",", "2.17"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"220.", ",", "4.92"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"240.", ",", "9.67"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"260.", ",", "17.12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"280.", ",", "28.06"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"300.", ",", "43.55"}], "}"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "|>"}]}], ";"}]], "Code",
 CellLabel->"In[13]:=",ExpressionUUID->"3fb818fe-58e8-4c23-8aa2-99afd112baab"]
}, Closed]],

Cell[CellGroupData[{

Cell["Specify Antoine Parameter Set", "Subsubsection",ExpressionUUID->"9c97ede5-42fd-4f52-b7e4-a0ca76db4b14"],

Cell[TextData[StyleBox["Check Antoine parameters for plausibility via the \
normal boiling point {tBoil, 1.01325 bar}\nChange the index in \
\[OpenCurlyQuote]antoineParamIndex\[CloseCurlyQuote] to use a parameter set \
better suited for your temperature range.",
 FontWeight->"Bold"]], "Text",ExpressionUUID->"0214a6a7-5b2e-494d-8a83-\
1194127f1b82"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"AllTrue", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"KeyExistsQ", "[", 
        RowBox[{
         RowBox[{"physicalPropertyData", "[", "#", "]"}], ",", 
         "\"\<antoineParameters\>\""}], "]"}], " ", "&"}], "/@", " ", 
      "components"}], ",", "TrueQ"}], "]"}], ",", "\n", "\t", 
   RowBox[{
    RowBox[{"antoineParamIndex", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}], ";", 
    RowBox[{"(*", 
     RowBox[{
     "index", " ", "of", " ", "Antoine", " ", "parameter", " ", "set", " ", 
      RowBox[{"in", " ", "'"}], 
      RowBox[{"physicalPropertyData", "'"}], " ", "per", " ", "component"}], 
     "*)"}], "\n", "\n", "\t", 
    RowBox[{"Grid", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", "\n", "\t\t", 
         RowBox[{
          RowBox[{
          "\"\<\!\(\*SuperscriptBox[\(P\), \(Sat\)]\) at \
\!\(\*SubscriptBox[\(t\), \(Boil\)]\) of \>\"", "<>", "cp", "<>", 
           "\"\< : \>\"", "<>", "\n", "\t\t", 
           RowBox[{"ToString", "@", 
            RowBox[{"pAntoine", "[", "\n", "\t\t\t", 
             RowBox[{
              RowBox[{"physicalPropertyData", "[", 
               RowBox[{"cp", ",", "\"\<tBoil\>\""}], "]"}], ",", "\n", 
              "\t\t\t", 
              RowBox[{
               RowBox[{
                RowBox[{"physicalPropertyData", "[", 
                 RowBox[{
                 "cp", ",", "\"\<antoineParameters\>\"", ",", "1", ",", "#"}],
                  "]"}], "&"}], "/@", 
               RowBox[{"{", 
                RowBox[{"\"\<A\>\"", ",", "\"\<B\>\"", ",", "\"\<C\>\""}], 
                "}"}]}], ",", "\n", "\t\t\t", "\"\<log10\>\""}], "\n", "\t\t",
              "]"}]}]}], ",", "\"\< bar\>\""}], "\n", "\t\t", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"cp", ",", " ", "components"}], "}"}]}], "\n", "\t", "]"}], 
      ",", 
      RowBox[{"Alignment", "->", "Left"}]}], "]"}]}], "\n", "\t", "\n", "\t", 
   ",", 
   RowBox[{"(*", "else", "*)"}], "\n", "\t", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Antoine parameters were not found for all components!\>\"", "]"}], 
    ";", "\n", "\t", 
    RowBox[{"Beep", "[", "]"}], ";"}]}], "\n", "]"}]], "Code",
 CellLabel->"In[14]:=",ExpressionUUID->"3fd21aa4-cb9a-4d44-a7a7-e788af70c710"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(Sat\\)]\\) at \
\\!\\(\\*SubscriptBox[\\(t\\), \\(Boil\\)]\\) of Argon : 1.00703\"\>", "\<\" \
bar\"\>"},
    {"\<\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(Sat\\)]\\) at \
\\!\\(\\*SubscriptBox[\\(t\\), \\(Boil\\)]\\) of Krypton : 1.03729\"\>", \
"\<\" bar\"\>"}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[14]=",ExpressionUUID->"261d3208-d821-4a9d-a2d0-38545d4b0b6c"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Compare Antoine with Experimental Data", "Subsubsection",ExpressionUUID->"5cec5e44-7bdc-44c9-9373-bc1bd6e1f57c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"{", 
   RowBox[{"Table", "[", "\n", "\t", 
    RowBox[{
     RowBox[{"Show", "[", 
      RowBox[{"{", "\n", "\t\t\t", 
       RowBox[{
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"pAntoine", "[", 
           RowBox[{"x", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"physicalPropertyData", "[", 
               RowBox[{
                RowBox[{"components", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                "\"\<antoineParameters\>\"", ",", 
                RowBox[{"antoineParamIndex", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", "#"}], "]"}], "&"}], "/@", 
             RowBox[{"{", 
              RowBox[{"\"\<A\>\"", ",", "\"\<B\>\"", ",", "\"\<C\>\""}], 
              "}"}]}], ",", "\"\<log10\>\""}], "]"}], "\n", "\t\t\t\t", ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{"Min", "[", 
             RowBox[{"pSatExp", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"components", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "All", ",", "1"}], 
              "\[RightDoubleBracket]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"physicalPropertyData", "[", 
              RowBox[{
               RowBox[{"components", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "\"\<tCrit\>\""}], "]"}],
              "+", "10"}]}], "}"}], "\n", "\t\t\t\t", ",", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"{", "\"\<Antoine\>\"", "}"}]}], ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{"components", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<T [K]\>\"", ",", 
             "\"\<\!\(\*SuperscriptBox[SubscriptBox[\(P\), \(i\)], \(s\)]\) \
[bar]\>\""}], "}"}]}], ",", 
          RowBox[{"ImageSize", "->", "Medium"}]}], "\n", "\t\t\t", "]"}], ",",
         "\n", "\t\t\t", 
        RowBox[{"ListPlot", "[", 
         RowBox[{
          RowBox[{"pSatExp", "[", 
           RowBox[{"[", 
            RowBox[{"components", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], ",", 
          RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}], ",", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"{", "\"\<Experimental\>\"", "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", "Red", "}"}]}]}], "]"}], ",", "\n", "\t\t\t", 
        RowBox[{"ListPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"physicalPropertyData", "[", 
              RowBox[{
               RowBox[{"components", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "\"\<tCrit\>\""}], "]"}],
              ",", 
             RowBox[{"physicalPropertyData", "[", 
              RowBox[{
               RowBox[{"components", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "\"\<pCrit\>\""}], 
              "]"}]}], "}"}], "}"}], ",", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"{", "\"\<Critical point\>\"", "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", "Green", "}"}]}]}], "]"}]}], "\n", "\t\t", "}"}], 
      "\[IndentingNewLine]", "\t", "]"}], "\n", "\t", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "@", "components"}]}], "}"}]}], "\n", "]"}], "}"}], 
  "]"}]], "Code",
 CellLabel->"In[15]:=",ExpressionUUID->"b7a3b516-3e1f-4418-a7e3-d05070db39a3"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{
       GraphicsBox[{{{{{}, {}, 
            TagBox[{
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[1.6]], 
              LineBox[CompressedData["
1:eJwVl2c8Fg4Xho1URqgUpUhUIqKMUM6xPYtn2TKfSNlb5G9HVlE0kJQRIRJp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               "]]}, 
             Annotation[#, "Charting`Private`Tag$47751#1"]& ]}}, {}}, {{}, {{{
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[1, 0, 0]], 
             GeometricTransformationBox[
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox[
                  GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], 
                  GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}, StripOnInput -> False], 
                 TraditionalForm]], {0., 0.}, Automatic, 
               Scaled[9.75]], {{{50., 0.0003714}}, {{70., 0.0767}}, {{90., 
              1.335}}, {{110., 6.653}}, {{130., 20.25}}, {{150., 
              47.35}}}]}}}, {{}, {}}}, {{}, {{{
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[0, 1, 0]], 
             PointBox[{{150.8, 48.7373}, {150.8, 48.7373}}]}}}, {{}, {}}}}, {
        DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
         AxesOrigin -> {50.000000000000114`, 0}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, DisplayFunction -> Identity, 
         PlotRangePadding -> {{
            Scaled[0.02], 
            Scaled[0.02]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
         DisplayFunction -> Identity, AspectRatio -> 
         NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox[
            TagBox["\"T [K]\"", HoldForm], TraditionalForm], 
           FormBox[
            TagBox[
            "\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \\(i\\)], \
\\(s\\)]\\) [bar]\"", HoldForm], TraditionalForm]}, AxesOrigin -> {50., 0}, 
         DisplayFunction :> Identity, 
         Frame -> {{False, False}, {False, False}}, 
         FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> Medium, 
         Method -> {
          "DefaultBoundaryStyle" -> Automatic, 
           "DefaultGraphicsInteraction" -> {
            "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
             "Effects" -> {
              "Highlight" -> {"ratio" -> 2}, 
               "HighlightPoint" -> {"ratio" -> 2}, 
               "Droplines" -> {
                "freeformCursorMode" -> True, 
                 "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
           "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
           None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
               (Identity[#]& )[
                Part[#, 1]], 
               (Identity[#]& )[
                Part[#, 2]]}& ), "CopiedValueFunction" -> ({
               (Identity[#]& )[
                Part[#, 1]], 
               (Identity[#]& )[
                Part[#, 2]]}& )}}, PlotLabel -> 
         FormBox["\"Argon\"", TraditionalForm], 
         PlotRange -> {{50., 160.8}, {0., 59.873129814501326`}}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.02], 
            Scaled[0.02]}, {
            Scaled[0.02], 
            Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
       FormBox[
        TagBox[
         GridBox[{{
            FormBox[
             
             TemplateBox[{"\"Antoine\""}, "LineLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"LineLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    "}"}], ",", 
                   RowBox[{"{", #, "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}, {
            FormBox[
             
             TemplateBox[{"\"Experimental\""}, "PointLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
                   RowBox[{"{", #, "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], "}"}]}], ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", "False", "}"}]}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}, {
            FormBox[
             
             TemplateBox[{"\"Critical point\""}, "PointLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 1, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
                   RowBox[{"{", #, "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", "False", "}"}]}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], 
     TemplateBox[{
       GraphicsBox[{{{{{}, {}, 
            TagBox[{
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[1.6]], 
              LineBox[CompressedData["
1:eJwVz3840wkAx/FR83M4SodTOAkTQjVR9iHO2Gb77qkozDab2b76yeVx/TjS
kfKjUulxfnThctR1D0q5KJmo6VlUdyLVKfqBR6O6RFz3x/t5/f12kGwXyHQp
FAr3S/8bfnA5/x8jIWyb1H/FOWqZScqR8fs0IZ6Yu/gI3LXMAn5NwS1TIdTd
VQ5hDC3zga2LptZCCF7IWFMwW8sUXnKM2G0jRGmOqUFyspa5c9iGY0wXospa
EXVBpWWeZhmyVoUJkTaQ5V+hnGAO04aZOdlCdPg7LHilmmS2X6btumAah7yC
9G0lHz8wb1ae0h3IjcPpDdSPL/ifmGeGrFLC5osgd48v83z3mZluuPiQJFSE
+aIYPwldB9s1ArZOlggt+Y2UpqR5mHO67vnktgjejCapnb0eNFYNAftpYjxW
3TCqoBni9wt9MxXhYqxtNjKjGdLgcZ/xWD9fjLgjHoofj5uhufiWUtslRvXu
KcXASXPkzg44lhlJUOLe3DC2fwFmJtxmD3ElUFEb3f5stsSenNrsqSMSNKhC
3xfoWKHkD7F3tUaCjTcFa+6es8FM8hl9G4t4SLqnW1i7F4N89FWuOT8e/Q8z
By9/a4+9mkav0MJ4TEyuulOickCJ/GiWbk882vrTtr+UOSL2aPnMtKUUP0xH
+r9hOUG4kVF6JUqKwXcHIzPWO2PbNcrYp1NSpBisTjXxc4VdA0W4p0+KHVt9
Ll/c64anXO/9GdYy2Ma2+1ZfdcfTzNHO8EgZpvLObt1HXYH08IGVgmIZptv8
XbM3e2FF/Rzvaa8Mrls4Fopqb2Scj8qtsU3AYFtdoZ7zSlgE+U36xiWgNmD2
mXn9KtSlcQ25pQkQjnO1TgwG3gUWofxZApQtHUb9b30Rct7COdVOjq9nCz96
/eKHh3WLfC1i5Xi7a+4tPWYt9MMJ5Ui5HFblNM4lQQBYmc3s8CdyTOY/omIJ
QOeKIl46JIJvVyyO8gnEN1dXUozEiZCypss8A4PAaT32eLwsEfeoDYW8Deux
ZItT34LBRCwca3W4eTgYcyfeZDXbK1Ao/y59sjEEGaLhDVVSBbJfDLdTjEOx
vlPJ5Z9TQD0a0tgvZWFhj/379CEFdD3+5fjVhyEryaRl3EWJpcuWC67T2dD/
zW31C7kSxq3RioqTHHRm9PT+XKXEqFTH2oQaAfrIxZJjr5T4Vc88te8MDyUf
WsxMnEmoWf3qrlN8WHqdNV3qQqLD0yqSX8xHPvmTib8rCc7EgegHpXykP2Mb
K9xIaNmTmoFKPmR3evXaPUlUDTTKP9Tx4VE28XmvL4l1tGObAjR83AhZNjoa
RkLly+a5GhBYk244Mo9N4k1ejsE1YwJ1TaOvbTgkdhbt8+eZEaj0rH/JiiBh
+X2RaeoiAjnWeF4pIOHbq6fsWkpAMLa5LyaaBFWYMpUXSEDtvO5RcgwJ61dz
PJcQAsES+97DsSSCN2Xat7EIMP4efngljkR00AHPTzwCtq3J3QulJHy6e6jb
hAROTm+65yYjcWu6YDlNQsB0tZ8mKIGEuF52t0ZGgFJLubsjkQTTgNz3OolA
2tBzdbaCxHjr2dycHQQm7DrulClJSALnLaKnEEjaUnP7EknC4PhRa3UqgaET
eZ1dSV9+myOKkvYQ+A9a3x0y
               "]]}, 
             Annotation[#, "Charting`Private`Tag$48961#1"]& ]}}, {}}, {{}, {{{
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[1, 0, 0]], 
             GeometricTransformationBox[
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox[
                  GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], 
                  GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}, StripOnInput -> False], 
                 TraditionalForm]], {0., 0.}, Automatic, 
               Scaled[9.75]], {{{120.17, 1.0457}}, {{129.88, 2.1369}}, {{140.,
               3.9365}}, {{150.707, 6.7786}}, {{161.197, 
              10.913}}}]}}}, {{}, {}}}, {{}, {{{
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[0, 1, 0]], 
             PointBox[{{209.4, 55.195}, {209.4, 55.195}}]}}}, {{}, {}}}}, {
        DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
         AxesOrigin -> {120.17000000000027`, 0}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, DisplayFunction -> Identity, 
         PlotRangePadding -> {{
            Scaled[0.02], 
            Scaled[0.02]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
         DisplayFunction -> Identity, AspectRatio -> 
         NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox[
            TagBox["\"T [K]\"", HoldForm], TraditionalForm], 
           FormBox[
            TagBox[
            "\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \\(i\\)], \
\\(s\\)]\\) [bar]\"", HoldForm], TraditionalForm]}, AxesOrigin -> {120.17, 0},
          DisplayFunction :> Identity, 
         Frame -> {{False, False}, {False, False}}, 
         FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> Medium, 
         Method -> {
          "DefaultBoundaryStyle" -> Automatic, 
           "DefaultGraphicsInteraction" -> {
            "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
             "Effects" -> {
              "Highlight" -> {"ratio" -> 2}, 
               "HighlightPoint" -> {"ratio" -> 2}, 
               "Droplines" -> {
                "freeformCursorMode" -> True, 
                 "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
           "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
           None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
               (Identity[#]& )[
                Part[#, 1]], 
               (Identity[#]& )[
                Part[#, 2]]}& ), "CopiedValueFunction" -> ({
               (Identity[#]& )[
                Part[#, 1]], 
               (Identity[#]& )[
                Part[#, 2]]}& )}}, PlotLabel -> 
         FormBox["\"Krypton\"", TraditionalForm], 
         PlotRange -> {{120.17, 219.4}, {0., 69.92850287141451}}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.02], 
            Scaled[0.02]}, {
            Scaled[0.02], 
            Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
       FormBox[
        TagBox[
         GridBox[{{
            FormBox[
             
             TemplateBox[{"\"Antoine\""}, "LineLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"LineLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    "}"}], ",", 
                   RowBox[{"{", #, "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}, {
            FormBox[
             
             TemplateBox[{"\"Experimental\""}, "PointLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
                   RowBox[{"{", #, "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], "}"}]}], ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", "False", "}"}]}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}, {
            FormBox[
             
             TemplateBox[{"\"Critical point\""}, "PointLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 1, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
                   RowBox[{"{", #, "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", "False", "}"}]}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[15]=",ExpressionUUID->"41273caf-5469-40a4-9abc-ef7d52b26df7"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mixture Data", "Subsection",ExpressionUUID->"4f7865c8-6999-473b-821e-b8ba542d9a81"],

Cell[CellGroupData[{

Cell["Experimental Data", "Subsubsection",ExpressionUUID->"7a60eb14-1be6-43f0-b671-eb05df8ad379"],

Cell[TextData[{
 "\[OpenCurlyDoubleQuote]Argon-Krypton\[CloseCurlyDoubleQuote] ...\tDavies, \
Stavely 1966: Thermodynamics of Liquid  Mixtures of Argon and Krypton\n\
\[OpenCurlyDoubleQuote]Argon-Ethane\[CloseCurlyDoubleQuote] ...\tElshayal \
1971: The binary system argon-ethane at 115.5 K (Excerpt)\n\nEntry Example: \
\[OpenCurlyDoubleQuote]comp1-comp2\[CloseCurlyDoubleQuote] -> <| \
\[OpenCurlyDoubleQuote]tExp\[CloseCurlyDoubleQuote]-> T [K], \
\[OpenCurlyDoubleQuote]data\[CloseCurlyDoubleQuote]->{ { ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]],
  FontWeight->"Plain",ExpressionUUID->"7186aff5-cd64-4468-a07e-2e7bdb6f6f66"],
 " [mol ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["mol", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FontWeight->"Plain",ExpressionUUID->"c49b5e7a-d3d8-4282-9326-773c6117aa58"],
 "], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "1"], TraditionalForm]],
  FontWeight->"Plain",ExpressionUUID->"d441125f-7978-47ca-8e89-c52b316814ed"],
 " [mol ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["mol", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FontWeight->"Plain",ExpressionUUID->"c9a77438-e74f-4974-9b79-aed5c262a0ed"],
 "], P [bar]}, ...} |>"
}], "Text",ExpressionUUID->"0b4e9244-61fb-478a-a269-cd86d06dee43"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"expMixtureDataAsso", "=", 
    RowBox[{"<|", "\[IndentingNewLine]", "\t", 
     RowBox[{
      RowBox[{"\"\<Argon-Krypton\>\"", "->", 
       RowBox[{"<|", "\[IndentingNewLine]", "\t\t", 
        RowBox[{
         RowBox[{"\"\<tExp\>\"", "->", "115.5"}], ",", "\[IndentingNewLine]", 
         "\t\t", 
         RowBox[{"\"\<data\>\"", "->", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.1158", ",", "0.65652", ",", "1.9133"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.2024", ",", "0", ",", "76880", ",", "2.7255"}], "}"}],
             ",", 
            RowBox[{"{", 
             RowBox[{"0.2997", ",", "0.83601", ",", "3.5901"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.328", ",", "0.85026", ",", "3.8297"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.385", ",", "0.86943", ",", "4.3135"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.43", ",", "0.88516", ",", "4.6964"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.519", ",", "0.91305", ",", "5.3933"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.6017", ",", "0.92888", ",", "6.0667"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.7157", ",", "0.95160", ",", "6.9889"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.7941", ",", "0.96548", ",", "7.6454"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.9006", ",", "0.98456", ",", "8.5702"}], "}"}]}], 
           "}"}]}]}], "\[IndentingNewLine]", "\t", "|>"}]}], ",", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"\"\<Argon-Ethane\>\"", "->", 
       RowBox[{"<|", "\[IndentingNewLine]", "\t\t", 
        RowBox[{
         RowBox[{"\"\<tExp\>\"", "->", "115.5"}], ",", "\[IndentingNewLine]", 
         "\t\t", 
         RowBox[{"\"\<data\>\"", "->", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.0690", ",", "None", ",", "1.69611"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.0710", ",", "None", ",", "1.737478837881"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"0.0712", ",", "None", ",", "1.737478837881"}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"0.0926", ",", "None", ",", "2.047743"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.0980", ",", "None", ",", "2.123585"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1873", ",", "None", ",", "3.51633"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.2835", ",", "None", ",", "4.874593"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.3969", ",", "None", ",", "6.026018"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.5046", ",", "None", ",", "6.798231"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.6978", ",", "None", ",", "7.5704435"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.8004", ",", "None", ",", "7.9427604"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.9151", ",", "None", ",", "8.4874462"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.9813", ",", "None", ",", "9.176922"}], "}"}]}], 
           "}"}]}]}], "\[IndentingNewLine]", "\t", "|>"}]}]}], 
     "\[IndentingNewLine]", "|>"}]}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"tExp", " ", "=", " ", 
    RowBox[{"expMixtureDataAsso", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{
        RowBox[{"components", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<>", "\"\<-\>\"", "<>", 
        RowBox[{"components", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", "\"\<tExp\>\""}], "]"}], 
     "]"}]}], ";"}], 
  RowBox[{"(*", " ", "K", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"expMixtureData", " ", "=", " ", 
    RowBox[{"expMixtureDataAsso", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{
        RowBox[{"components", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<>", "\"\<-\>\"", "<>", 
        RowBox[{"components", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", "\"\<data\>\""}], "]"}], 
     "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"mol", " ", 
     SuperscriptBox["mol", 
      RowBox[{"-", "1"}]]}], ",", " ", 
    RowBox[{"mol", " ", 
     SuperscriptBox["mol", 
      RowBox[{"-", "1"}]]}], ",", " ", "bar"}], "*)"}]}]}], "Code",
 CellLabel->"In[16]:=",ExpressionUUID->"d33b982f-504c-4de1-945d-c9d214489362"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The {Pxy}-diagram for experimental temperature using Raoult-Dalton\
\>", "Subsubsection",ExpressionUUID->"bfd812f3-3ba7-4b26-89a2-445a2bdae723"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Saturation", " ", "pressures", " ", "of", " ", "both", " ", 
    "components"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"piSat", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"pAntoine", "[", 
        RowBox[{"tExp", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"physicalPropertyData", "[", 
            RowBox[{
             RowBox[{
             "components", "\[LeftDoubleBracket]", "i", 
              "\[RightDoubleBracket]"}], ",", "\"\<antoineParameters\>\"", 
             ",", 
             RowBox[{"antoineParamIndex", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", "#"}], "]"}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{"\"\<A\>\"", ",", "\"\<B\>\"", ",", "\"\<C\>\""}], "}"}]}],
          ",", "\"\<log10\>\""}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "@", "components"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Mole", " ", "fractions", " ", "of", " ", "the", " ", "liquid", " ", 
      "phase"}], ",", " ", 
     RowBox[{"component", " ", "1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"x1", " ", "=", " ", 
     RowBox[{"Prepend", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Range", "[", "100", "]"}], "/", "100."}], ",", "0."}], 
      "]"}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"mol", " ", 
     SuperscriptBox["mol", 
      RowBox[{"-", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Pressure", " ", "as", " ", "the", " ", "ordinate", " ", "of", " ", "the",
      " ", "diagram"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ordinate", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"#", " ", 
          RowBox[{
          "piSat", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.", "-", "#"}], ")"}], 
          RowBox[{
          "piSat", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}]}],
         ")"}], " ", "&"}], "/@", " ", "x1"}]}], ";"}], 
   RowBox[{"(*", " ", "bar", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Mole", " ", "fractions", " ", "of", " ", "the", " ", "vapor", " ", 
      "phase"}], ",", " ", 
     RowBox[{"component", " ", "1"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"y1", " ", "=", " ", 
     RowBox[{"x1", " ", 
      RowBox[{
       RowBox[{
       "piSat", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "/", 
       "ordinate"}]}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"mol", " ", 
     SuperscriptBox["mol", 
      RowBox[{"-", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"{", "\[IndentingNewLine]", "\t", 
     RowBox[{
      RowBox[{"ListLinePlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{"x1", ",", "ordinate"}], "}"}], "]"}], ",", 
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{"y1", ",", "ordinate"}], "}"}], "]"}]}], "}"}], "\n", 
        "\t\t", ",", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
          "\"\<\!\(\*SubscriptBox[\(x\), \(1\)]\),\!\(\*SubscriptBox[\(y\), \
\(1\)]\) [mol/mol]\>\"", ",", "\"\<P [bar]\>\""}], "}"}]}], "\n", "\t\t", ",", 
        RowBox[{"PlotLabel", "\[Rule]", " ", 
         RowBox[{"StringJoin", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"components", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "<>", "\"\<-\>\"", "<>", 
             RowBox[{"components", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "<>", "\"\<\\nT = \>\""}], ",", 
            RowBox[{"ToString", "[", "tExp", "]"}], ",", "\"\< K\>\""}], 
           "}"}], "]"}]}], "\n", "\t\t", ",", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
          "\"\<Raoult-Dalton, bubble curve\>\"", ",", 
           "\"\<Raoult-Dalton, dew curve\>\""}], "}"}]}], "\n", "\t\t", ",", 
        RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "\n", "\t", "]"}], ",", 
      "\n", "\t", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"expMixtureData", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
        RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", " ", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"{", "\"\<Experimental, dew curve\>\"", "}"}]}]}], "]"}], 
      ",", "\n", "\t", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"expMixtureData", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
        RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", "Green"}], ",", " ", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"{", "\"\<Experimental, bubble curve\>\"", "}"}]}]}], 
       "]"}]}], "\[IndentingNewLine]", "}"}], "]"}]}]}]], "Code",
 CellLabel->"In[19]:=",ExpressionUUID->"441fea66-3851-4b21-83df-c714694c42bb"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJw1kgtQVHUUxgERF5SXLG/usguYMI2YYo2A8v2dBM3HdMHCB1S+wAaMkCHx
rdOKohXgoGaWEMKMsiZqEWtmykMiBAyBZVUe7iKweFkeOqyCz9zd05m5c+c+
/ud83/c7svVfxiRYWVhYJLy5jPf/S5PqvzGyT4ed4tJF2h370ZITe/9pvkDP
R1FbemiNYuUgLksyB6Iv56MzsSspWDRC34ux8knG2YMbH+HkD8YqQVOmc5+m
4jH9X4olruf8w7hR6KONby7hRvHCdXnbDXS+DBFzuvL1qiewUxelzrdTQlmd
0RE5e4z6/YFZK5y9CrLHERSfU2UIvApFt2LlmPCM+l9DQNrCY9GLXqD4zWl1
UQXyLbuaFUUvaV4lPI5kOFlbvEaIqarxQa7oTHCwBTPPvwGbVarIuA4LVm0I
fDOhBlW+p3sOHrZkZj212KtLkZfNtWIxpoH/YN6FcD9tnxUz66vD+FZRpf2x
CUy7w9jwJsojVJ+FvW/NzHobkGZz+lXiI2u2xSgvtREzb6WcyiuYyMz6b0F/
LHxexXIbZqbRhJJPRO365zbM7KcJidNU2z0Vk9hi04Db8B8s9IhaJWJmf7eh
KUtRptnYMuO0+Jxm/LQrPLagzJaZ/bZg9UKRoX69HTPZUbfAbYoqb8xpMvlv
RUtL4exp1yczX6MciQq5P6bcjv5iCuWhwvIN4al7vO3ZpkRjtcHubZHjuTp7
ykeNvx+3nldnODBjN3GpGvIrhcus33KkvO6AfZ0y8E6rI3tibGe4g9fFXE3w
AifK7y46RfvFkSecWISp4T1c3SxsiBt2ojzv4WQT/9uWKGdmkpfZjm1zlFZZ
p5wp3w7EnuBi8kedWWODsTrw7gt5YdnSqZR3J1zWCiM3T09lriaBXXhczTPt
+FTKvwtN05U5T3kXZmoXfx8XvuHu2591IR4afDcsDw547UJ+NEheIewOixUT
Hw2WKPlG/ryY/GkQ6K302WTtSry0mLSX27w7zpX8atHbLf8z71dX4qfFjSjB
TmHrRv67UaTg11SsdSOe3djnoCxpU7pRHt34NI0b1zu4E98HmN8mXzwh0Z3y
eQCfMOF7z7/cifcDPDvF62aKPSivHty1VL4XlexB/HugTOAOxFd5UH49OF4n
V6V5etI+9CJ9hhBwKNWT8uxFzBE+vaDWk/ajF7MM5dW/S7wo3z44ruZcGr7y
on3pw9BV+fruBi/Kuw/1UuHSmL837Y8Oiv28peNOb8pfh6z+cn5aszftkw6b
lnE/hwf5EI9+RF6UD0fv8yEe/QgQCxGfq32IRz8mbOOz9wRzxKMf2vbyzqOZ
HPF4iApwM851cMTjIfKL5LsqQyTE4yF2TxLq1YclxENAXDLvPaSVsFwTDwGh
/5YnWYf6Eg8B7iHcFa9cX+IxAMNxue0snS/xGEDSy/Rf/H2lxGMAq2cGtpYu
kRIPPRava38eulVKPPSYm5ftX1MoJR56TK9ZsJRvlBKPQbg9HU1rH5MSj0FM
DDp7MjFARjwGMbomrurRhzLiMYSebx2EXTtlxGMILdcqnUVnZMRjCFUj6aF5
zTLiMYxLfoHrJK9kxGMYhR+1Z5UE+RGPYeQeyL4452M/4jGCvZcX3Lm+z4/9
B7FN6eE=
          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJw1lYs3lAkfgCdNYxi3cb/MjHHbOJtBxYY+v1+tS8nujtwWKZdoq6XIljbi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          "]]}}}, {{}, {}}}, {{}, {{{
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{{
                 GrayLevel[1], 
                 DiskBox[{0, 0}, 
                  Offset[{3, 3}]]}, 
                AbsoluteThickness[1.5], 
                Dashing[{}], 
                CircleBox[{0, 0}, 
                 Offset[{3, 3}]]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[1, 0, 0]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Scaled[9.75]], {{{0.1158, 1.9133}}, {{0.2024, 76880.}}, {{0.2997, 
          3.5901}}, {{0.328, 3.8297}}, {{0.385, 4.3135}}, {{0.43, 4.6964}}, {{
          0.519, 5.3933}}, {{0.6017, 6.0667}}, {{0.7157, 6.9889}}, {{0.7941, 
          7.6454}}, {{0.9006, 8.5702}}}]}}}, {{}, {}}}, {{}, {{{
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{{
                 GrayLevel[1], 
                 DiskBox[{0, 0}, 
                  Offset[{3, 3}]]}, 
                AbsoluteThickness[1.5], 
                Dashing[{}], 
                CircleBox[{0, 0}, 
                 Offset[{3, 3}]]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[0, 1, 0]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Scaled[9.75]], {{{0.65652, 1.9133}}, {{0., 76880.}}, {{0.83601, 
          3.5901}}, {{0.85026, 3.8297}}, {{0.86943, 4.3135}}, {{0.88516, 
          4.6964}}, {{0.91305, 5.3933}}, {{0.92888, 6.0667}}, {{0.9516, 
          6.9889}}, {{0.96548, 7.6454}}, {{0.98456, 
          8.5702}}}]}}}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox[
        TagBox[
        "\"\\!\\(\\*SubscriptBox[\\(x\\), \
\\(1\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) [mol/mol]\"", 
         HoldForm], TraditionalForm], 
       FormBox[
        TagBox["\"P [bar]\"", HoldForm], TraditionalForm]}, 
     AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Large, 
     Method -> {
      "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"Argon-Krypton\\nT = 115.5 K\"", TraditionalForm], 
     PlotRange -> {{0, 1.}, {0, 9.251463659308}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{
          "\"Raoult-Dalton, bubble curve\"", "\"Raoult-Dalton, dew curve\""}, 
          "LineLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
               ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"True", ",", "True"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Experimental, dew curve\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Experimental, bubble curve\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    TemplateBox[<|"color" -> RGBColor[0, 1, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellLabel->"Out[23]=",ExpressionUUID->"e84fa9e8-d7e4-454a-893a-39939dd7df36"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Estimation using Raoult-Dalton for molar fraction", "Section",ExpressionUUID->"1c394f19-5fd6-4253-8a80-0acb1e7234b1"],

Cell[CellGroupData[{

Cell["State Definition", "Subsection",ExpressionUUID->"b5b9711f-8eea-4ea9-85af-69c61ddb1a5d"],

Cell[CellGroupData[{

Cell["\<\
Choose simulation temperature between the two normal boiling points\
\>", "Subsubsection",ExpressionUUID->"26e4ceee-3c14-402d-9283-4c5b0ed59c3f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[\(T\), \(boil\)]\) [K]\>\""}], "}"}], "}"}],
        ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"#", ",", 
           RowBox[{"physicalPropertyData", "[", 
            RowBox[{"#", ",", "\"\<tBoil\>\""}], "]"}]}], "}"}], "&"}], "/@", 
        "components"}]}], "}"}], ",", "1"}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}], ",", 
   RowBox[{"Spacings", "->", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "]"}]], "Code",
 CellLabel->
  "In[493]:=",ExpressionUUID->"838c990a-610d-4f98-9eca-1f22d1b3fb7c"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(T\\), \\(boil\\)]\\) [K]\"\>"},
    {"\<\"Argon\"\>", "87.24`"},
    {"\<\"Krypton\"\>", "119.74`"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->
  "Out[493]=",ExpressionUUID->"794cd2d4-ec7d-4325-bc26-083543000235"]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"tSim", "=", "100."}], ";"}], 
   RowBox[{"(*", " ", "K", " ", "*)"}]}],
  Background->None]], "Input",
 Background->RGBColor[1, 1, 0],
 CellLabel->
  "In[494]:=",ExpressionUUID->"002a8d37-0b7a-40ac-bdbc-602292333e35"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Choose simulation pressure between the two saturation pressures\
\>", "Subsubsection",ExpressionUUID->"6d7c4005-149a-4d9e-a157-472a397b5f52"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\>\"", ",", 
          "\"\<\!\(\*SuperscriptBox[\(P\), \(Sat\)]\) [bar]\>\""}], "}"}], 
        "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"components", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", 
           RowBox[{"pAntoine", "[", 
            RowBox[{"tSim", ",", 
             RowBox[{
              RowBox[{
               RowBox[{"physicalPropertyData", "[", 
                RowBox[{
                 RowBox[{
                 "components", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], ",", "\"\<antoineParameters\>\"",
                  ",", "1", ",", "#"}], "]"}], "&"}], "/@", 
              RowBox[{"{", 
               RowBox[{"\"\<A\>\"", ",", "\"\<B\>\"", ",", "\"\<C\>\""}], 
               "}"}]}], ",", "\"\<log10\>\""}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "@", "components"}]}], "}"}]}], "]"}]}], "}"}], 
     ",", "1"}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}], ",", 
   RowBox[{"Spacings", "->", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "]"}]], "Code",
 CellLabel->
  "In[495]:=",ExpressionUUID->"6de0b637-3fe8-4a78-8755-38d9cef70c99"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(Sat\\)]\\) \
[bar]\"\>"},
    {"\<\"Argon\"\>", "3.2323846210691207`"},
    {"\<\"Krypton\"\>", "0.1808818799439453`"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->
  "Out[495]=",ExpressionUUID->"23122e2d-c2ab-46af-98d8-975a94919feb"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pSim", "=", "2."}], ";"}], 
  RowBox[{"(*", " ", "bar", " ", "*)"}]}]], "Input",
 Background->RGBColor[1, 1, 0],
 CellLabel->
  "In[496]:=",ExpressionUUID->"94f20215-249c-4ca5-ba4d-cdcdb82118a3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation and Visualization", "Subsection",ExpressionUUID->"18a6ee31-10ea-4f70-a2e8-8c1bb9ebb96a"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"6bb93a86-fb70-475f-82a0-a27fddb7b8e6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"x1Sim", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"pSim", "-", 
      RowBox[{
      "piSat", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"piSat", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
       "-", 
      RowBox[{
      "piSat", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
     ")"}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"mol", " ", 
    SuperscriptBox["mol", 
     RowBox[{"-", "1"}]]}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y1Sim", " ", "=", " ", 
    RowBox[{"x1Sim", " ", 
     RowBox[{
      RowBox[{"piSat", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
       "/", "pSim"}]}]}], 
   RowBox[{"(*", " ", 
    RowBox[{"mol", " ", 
     SuperscriptBox["mol", 
      RowBox[{"-", "1"}]]}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Mole", " ", "fractions", " ", "of", " ", "the", " ", "liquid", " ", 
     "phase"}], ",", " ", 
    RowBox[{"component", " ", "1"}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"x1", " ", "=", " ", 
    RowBox[{"Prepend", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Range", "[", "100", "]"}], "/", "100."}], ",", "0."}], 
     "]"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"mol", " ", 
    SuperscriptBox["mol", 
     RowBox[{"-", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Pressure", " ", "as", " ", "the", " ", "ordinate", " ", "of", " ", "the", 
    " ", "diagram"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ordinate", " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"#", " ", 
         RowBox[{
         "piSat", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
        "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1.", "-", "#"}], ")"}], 
         RowBox[{
         "piSat", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}]}], 
       ")"}], " ", "&"}], "/@", " ", "x1"}]}], ";"}], 
  RowBox[{"(*", " ", "bar", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Mole", " ", "fractions", " ", "of", " ", "the", " ", "vapor", " ", 
     "phase"}], ",", " ", 
    RowBox[{"component", " ", "1"}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y1", " ", "=", " ", 
    RowBox[{"x1", " ", 
     RowBox[{
      RowBox[{"piSat", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
       "/", "ordinate"}]}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"mol", " ", 
    SuperscriptBox["mol", 
     RowBox[{"-", "1"}]]}], " ", "*)"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ResultsPlotBinaryRaoultDalton", "[", "]"}], " ", ":=", " ", 
  RowBox[{"(", "\n", "\t", 
   RowBox[{
    RowBox[{"Print", "@", 
     RowBox[{"Show", "[", 
      RowBox[{"{", "\n", "\t\t", 
       RowBox[{
        RowBox[{"ListLinePlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Transpose", "[", 
             RowBox[{"{", 
              RowBox[{"x1", ",", "ordinate"}], "}"}], "]"}], ",", 
            RowBox[{"Transpose", "[", 
             RowBox[{"{", 
              RowBox[{"y1", ",", "ordinate"}], "}"}], "]"}]}], "}"}], "\n", 
          "\t\t\t", ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"#", ",", "14", ",", "Bold"}], "]"}], "&"}], "/@", 
             RowBox[{"{", 
              RowBox[{
              "\"\<\!\(\*SubscriptBox[\(x\), \
\(1\)]\),\!\(\*SubscriptBox[\(y\), \(1\)]\) [mol/mol]\>\"", ",", 
               "\"\<P [bar]\>\""}], "}"}]}], ")"}]}], "\n", "\t\t\t", ",", 
          RowBox[{"PlotLabel", "\[Rule]", " ", 
           RowBox[{"StringJoin", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<T = \>\"", ",", 
              RowBox[{"ToString", "[", "tSim", "]"}], ",", "\"\< K\>\""}], 
             "}"}], "]"}]}], "\n", "\t\t\t", ",", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Raoult-Dalton, bubble curve\>\"", ",", 
             "\"\<Raoult-Dalton, dew curve\>\""}], "}"}]}], "\n", "\t\t\t", 
          ",", 
          RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", " ", 
          RowBox[{"Frame", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"True", ",", "True"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"PlotRangePadding", " ", "->", " ", "0"}]}], "\n", "\t\t", 
         "]"}], ",", "\n", "\t\t", 
        RowBox[{"ListPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"x1Sim", ",", "pSim"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"y1Sim", ",", "pSim"}], "}"}]}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", "Red", "}"}]}], ",", 
          RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
          RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}], ",", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"{", "\"\<Simulation Point\>\"", "}"}]}]}], "]"}]}], 
       "\[IndentingNewLine]", "\t", "}"}], "]"}]}], ";", 
    "\[IndentingNewLine]", "\t", 
    RowBox[{"Highlighted", "@", 
     RowBox[{"Row", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\"\<Simulation @P=\>\"", "<>", 
         RowBox[{"ToString", "@", "pSim"}], "<>", 
         "\"\<bar : \!\(\*SubscriptBox[\(x\), \(1\)]\) = \>\""}], ",", 
        RowBox[{"Round", "[", 
         RowBox[{"x1Sim", ",", "0.00001"}], "]"}], ",", 
        "\"\< mol \!\(\*SuperscriptBox[\(mol\), \(-1\)]\), \
\!\(\*SubscriptBox[\(y\), \(1\)]\) = \>\"", ",", 
        RowBox[{"Round", "[", 
         RowBox[{"y1Sim", ",", "0.00001"}], "]"}], ",", 
        "\"\< mol \!\(\*SuperscriptBox[\(mol\), \(-1\)]\)\>\""}], "}"}], 
      "]"}]}]}], "\n", ")"}]}]}], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->
  "In[497]:=",ExpressionUUID->"90ea53ab-9d8d-42df-944e-93122fb0608e"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResultsPlotBinaryRaoultDalton", "[", "]"}]], "Code",
 CellLabel->
  "In[503]:=",ExpressionUUID->"de9045ea-adc9-483c-9f24-4dfaffba72fe"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJw1kgtQVHUUxgERF5SXLG/usguYMI2YYo2A8v2dBM3HdMHCB1S+wAaMkCHx
rdOKohXgoGaWEMKMsiZqEWtmykMiBAyBZVUe7iKweFkeOqyCz9zd05m5c+c+
/ud83/c7svVfxiRYWVhYJLy5jPf/S5PqvzGyT4ed4tJF2h370ZITe/9pvkDP
R1FbemiNYuUgLksyB6Iv56MzsSspWDRC34ux8knG2YMbH+HkD8YqQVOmc5+m
4jH9X4olruf8w7hR6KONby7hRvHCdXnbDXS+DBFzuvL1qiewUxelzrdTQlmd
0RE5e4z6/YFZK5y9CrLHERSfU2UIvApFt2LlmPCM+l9DQNrCY9GLXqD4zWl1
UQXyLbuaFUUvaV4lPI5kOFlbvEaIqarxQa7oTHCwBTPPvwGbVarIuA4LVm0I
fDOhBlW+p3sOHrZkZj212KtLkZfNtWIxpoH/YN6FcD9tnxUz66vD+FZRpf2x
CUy7w9jwJsojVJ+FvW/NzHobkGZz+lXiI2u2xSgvtREzb6WcyiuYyMz6b0F/
LHxexXIbZqbRhJJPRO365zbM7KcJidNU2z0Vk9hi04Db8B8s9IhaJWJmf7eh
KUtRptnYMuO0+Jxm/LQrPLagzJaZ/bZg9UKRoX69HTPZUbfAbYoqb8xpMvlv
RUtL4exp1yczX6MciQq5P6bcjv5iCuWhwvIN4al7vO3ZpkRjtcHubZHjuTp7
ykeNvx+3nldnODBjN3GpGvIrhcus33KkvO6AfZ0y8E6rI3tibGe4g9fFXE3w
AifK7y46RfvFkSecWISp4T1c3SxsiBt2ojzv4WQT/9uWKGdmkpfZjm1zlFZZ
p5wp3w7EnuBi8kedWWODsTrw7gt5YdnSqZR3J1zWCiM3T09lriaBXXhczTPt
+FTKvwtN05U5T3kXZmoXfx8XvuHu2591IR4afDcsDw547UJ+NEheIewOixUT
Hw2WKPlG/ryY/GkQ6K302WTtSry0mLSX27w7zpX8atHbLf8z71dX4qfFjSjB
TmHrRv67UaTg11SsdSOe3djnoCxpU7pRHt34NI0b1zu4E98HmN8mXzwh0Z3y
eQCfMOF7z7/cifcDPDvF62aKPSivHty1VL4XlexB/HugTOAOxFd5UH49OF4n
V6V5etI+9CJ9hhBwKNWT8uxFzBE+vaDWk/ajF7MM5dW/S7wo3z44ruZcGr7y
on3pw9BV+fruBi/Kuw/1UuHSmL837Y8Oiv28peNOb8pfh6z+cn5aszftkw6b
lnE/hwf5EI9+RF6UD0fv8yEe/QgQCxGfq32IRz8mbOOz9wRzxKMf2vbyzqOZ
HPF4iApwM851cMTjIfKL5LsqQyTE4yF2TxLq1YclxENAXDLvPaSVsFwTDwGh
/5YnWYf6Eg8B7iHcFa9cX+IxAMNxue0snS/xGEDSy/Rf/H2lxGMAq2cGtpYu
kRIPPRava38eulVKPPSYm5ftX1MoJR56TK9ZsJRvlBKPQbg9HU1rH5MSj0FM
DDp7MjFARjwGMbomrurRhzLiMYSebx2EXTtlxGMILdcqnUVnZMRjCFUj6aF5
zTLiMYxLfoHrJK9kxGMYhR+1Z5UE+RGPYeQeyL4452M/4jGCvZcX3Lm+z4/9
B7FN6eE=
          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJw1lYs3lAkfgCdNYxi3cb/MjHHbOJtBxYY+v1+tS8nujtwWKZdoq6XIljbi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          "]]}}}, {{}, {}}}, {{}, {{{}, {}, {}, {}, {
         Directive[
          RGBColor[1, 0, 0], 
          Opacity[0.3]], 
         LineBox[{{0.1473485045306087, 0.}, {0.1473485045306087, 2.}}], 
         LineBox[{{0.6815946674591532, 0.}, {0.6815946674591532, 2.}}]}}, {{
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{{
                 GrayLevel[1], 
                 DiskBox[{0, 0}, 
                  Offset[{3, 3}]]}, 
                AbsoluteThickness[1.5], 
                Dashing[{}], 
                CircleBox[{0, 0}, 
                 Offset[{3, 3}]]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[1, 0, 0]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Scaled[9.75]], {{{0.1473485045306087, 2.}}, {{0.6815946674591532, 
          2.}}}]}}}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, False}}, FrameLabel -> {{
        FormBox[
         TagBox[
          StyleBox["\"P [bar]\"", 14, Bold, StripOnInput -> False], HoldForm],
          TraditionalForm], None}, {
        FormBox[
         TagBox[
          StyleBox[
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \
\\(1\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) [mol/mol]\"", 14, Bold,
            StripOnInput -> False], HoldForm], TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Large, 
     Method -> {
      "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"T = 100. K\"", TraditionalForm], 
     PlotRange -> {{0, 1.}, {0, 9.251463659308}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{0, 0}, {0, 0}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{
          "\"Raoult-Dalton, bubble curve\"", "\"Raoult-Dalton, dew curve\""}, 
          "LineLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
               ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"True", ",", "True"}], "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Simulation Point\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Print",
 CellLabel->
  "During evaluation of \
In[503]:=",ExpressionUUID->"dd864177-cc12-474c-8247-3a03be36d7d4"],

Cell[BoxData[
 TemplateBox[{
   TemplateBox[{
    "\"Simulation @P=2.bar : \\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\) = \"",
      "0.14735`", 
     "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\), \
\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) = \"", "0.68159`", 
     "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)\""}, 
    "RowDefault"], FrameStyle -> None},
  "Highlighted"]], "Output",
 CellLabel->
  "Out[503]=",ExpressionUUID->"629fae46-a311-4ae4-8523-7e1eed8bd95f"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Estimation using SRK Equation of State", "Section",ExpressionUUID->"8aded346-527a-4fce-963c-2dc473164b81"],

Cell[CellGroupData[{

Cell["State Definition", "Subsection",ExpressionUUID->"98410589-0b15-47be-ab8d-ce57619f14e3"],

Cell[CellGroupData[{

Cell["Choose simulation temperature", "Subsubsection",ExpressionUUID->"dcfcc158-eaf0-40a4-a4c8-b0b78e1245af"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[\(T\), \(boil\)]\) [K]\>\""}], "}"}], "}"}],
        ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"#", ",", 
           RowBox[{"physicalPropertyData", "[", 
            RowBox[{"#", ",", "\"\<tBoil\>\""}], "]"}]}], "}"}], "&"}], "/@", 
        "components"}]}], "}"}], ",", "1"}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}], ",", 
   RowBox[{"Spacings", "->", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "]"}]], "Code",
 CellLabel->"In[24]:=",ExpressionUUID->"3b98a83d-41ad-4784-816f-2795bff97ea3"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(T\\), \\(boil\\)]\\) [K]\"\>"},
    {"\<\"Argon\"\>", "87.24`"},
    {"\<\"Krypton\"\>", "119.74`"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[24]=",ExpressionUUID->"e9fab56c-3584-4a83-bd5a-e4de25cc99a9"]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"tSim", "=", "100."}], ";"}], 
   RowBox[{"(*", " ", "K", " ", "*)"}]}],
  Background->None]], "Input",
 Background->RGBColor[1, 1, 0],
 CellLabel->"In[25]:=",ExpressionUUID->"50c51e13-d54a-4ddc-aec8-f2de40a76f34"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Choose simulation pressure", "Subsubsection",ExpressionUUID->"e68a9a39-ca7a-4996-a231-da33d5482906"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\>\"", ",", 
          "\"\<\!\(\*SuperscriptBox[\(P\), \(Sat\)]\) [bar]\>\""}], "}"}], 
        "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"components", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", 
           RowBox[{"pAntoine", "[", 
            RowBox[{"tSim", ",", 
             RowBox[{
              RowBox[{
               RowBox[{"physicalPropertyData", "[", 
                RowBox[{
                 RowBox[{
                 "components", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], ",", "\"\<antoineParameters\>\"",
                  ",", "1", ",", "#"}], "]"}], "&"}], "/@", 
              RowBox[{"{", 
               RowBox[{"\"\<A\>\"", ",", "\"\<B\>\"", ",", "\"\<C\>\""}], 
               "}"}]}], ",", "\"\<log10\>\""}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "@", "components"}]}], "}"}]}], "]"}]}], "}"}], 
     ",", "1"}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}], ",", 
   RowBox[{"Spacings", "->", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "]"}]], "Code",
 CellLabel->"In[26]:=",ExpressionUUID->"b62dcb59-08b4-4f8b-b7ce-88170ed0bb8d"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(Sat\\)]\\) \
[bar]\"\>"},
    {"\<\"Argon\"\>", "3.2323846210691207`"},
    {"\<\"Krypton\"\>", "0.1808818799439453`"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[26]=",ExpressionUUID->"adc19963-48ca-44b5-8b46-f08a99bc0e33"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pSim", "=", "2."}], ";"}], 
  RowBox[{"(*", " ", "bar", " ", "*)"}]}]], "Input",
 Background->RGBColor[1, 1, 0],
 CellLabel->"In[27]:=",ExpressionUUID->"15014561-ca32-47ef-8ff0-daf1252731b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Binary interaction parameter for Van ",
 StyleBox["der",
  IgnoreSpellCheck->True],
 " Waals mixing rule (set zero if unknown)"
}], "Subsubsection",ExpressionUUID->"c5922b06-3341-49b4-a8c5-68814ff4e64e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"k12", "=", "0.0"}], ";"}]], "Input",
 Background->RGBColor[1, 1, 0],
 CellLabel->"In[28]:=",ExpressionUUID->"2048b3ed-00a5-4031-b52f-028c3fef24fd"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"nComp", "=", 
    RowBox[{"Length", "@", "components"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"no", ".", " ", "components"}], " ", "in", " ", "the", " ", 
    "mixture"}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kij", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"k12", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "nComp"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "nComp"}], "}"}]}], "]"}]}], " ", 
  RowBox[{"(*", " ", "1", " ", "*)"}], ";"}]}], "Code",
 CellLabel->"In[29]:=",ExpressionUUID->"dd7a2ad1-621d-406f-a1d7-c81dfe7118ed"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation and Visualization", "Subsection",ExpressionUUID->"d926d0b1-0538-47b3-a6a5-c96f49f0d23a"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"e62957ea-d4da-43ac-8c01-e630d56b6f57"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Module", "[", "\n", "\t", 
   RowBox[{
    RowBox[{"{", "\n", "\t\t", 
     RowBox[{
     "xInit", ",", "x", ",", "pGuess", ",", "yGuess", ",", "dx", ",", "\n", 
      "\t\t", "pInit", ",", "p", ",", "xSRK", ",", "ySRK", ",", "vLiq", ",", 
      "vVap"}], "\n", "\t", "}"}], ",", "\n", "\n", "\t", 
    RowBox[{
     RowBox[{"nComp", " ", "=", " ", 
      RowBox[{"Length", "@", "components"}]}], ";", "\n", "\t", "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{"EoS", " ", "parameter"}], "*)"}], "\n", "\t", 
     RowBox[{"tCrit", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"physicalPropertyData", "[", 
         RowBox[{"#", ",", "\"\<tCrit\>\""}], "]"}], "&"}], "/@", 
       "components"}]}], ";", 
     RowBox[{"(*", " ", "K", " ", "*)"}], "\[IndentingNewLine]", "\t", 
     RowBox[{"pCrit", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"physicalPropertyData", "[", 
         RowBox[{"#", ",", "\"\<pCrit\>\""}], "]"}], "&"}], "/@", 
       "components"}]}], ";", 
     RowBox[{"(*", " ", "bar", " ", "*)"}], "\[IndentingNewLine]", "\t", 
     RowBox[{"\[Omega]", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"physicalPropertyData", "[", 
         RowBox[{"#", ",", "\"\<acentricFactor\>\""}], "]"}], "&"}], "/@", 
       "components"}]}], ";", 
     RowBox[{"(*", " ", "1", " ", "*)"}], "\n", "\t", 
     RowBox[{"tRed", " ", "=", " ", 
      RowBox[{"tSim", "/", "tCrit"}]}], ";", "\n", "\t", "\n", "\t", 
     RowBox[{"aPure", " ", "=", " ", 
      RowBox[{
       RowBox[{"aCritSRK", "[", 
        RowBox[{"tCrit", ",", "pCrit"}], "]"}], " ", "*", " ", 
       RowBox[{"\[Alpha]SRK", "[", 
        RowBox[{"tRed", ",", "\[Omega]"}], "]"}]}]}], ";", "\n", "\t", 
     RowBox[{"bPure", " ", "=", " ", 
      RowBox[{"bCritSRK", "[", 
       RowBox[{"tCrit", ",", "pCrit"}], "]"}]}], ";", "\n", "\t", "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"start", " ", "calculation", " ", "from", " ", "x1"}], " ", 
       "=", " ", "1"}], "*)"}], "\n", "\t", 
     RowBox[{"xInit", " ", "=", " ", 
      RowBox[{"yGuess", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}]}], ";", "\n", "\t", 
     RowBox[{"dx", " ", "=", " ", 
      RowBox[{"-", "0.01"}]}], ";", "\n", "\t", 
     RowBox[{"pGuess", " ", "=", " ", 
      RowBox[{"pAntoine", "[", 
       RowBox[{"tSim", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"physicalPropertyData", "[", 
           RowBox[{
            RowBox[{"components", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "\"\<antoineParameters\>\"",
             ",", 
            RowBox[{"antoineParamIndex", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "#"}], "]"}], "&"}], "/@", 
         RowBox[{"{", 
          RowBox[{"\"\<A\>\"", ",", "\"\<B\>\"", ",", "\"\<C\>\""}], "}"}]}], 
        ",", "\"\<log10\>\""}], "]"}]}], ";", "\n", "\t", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"pInit", ",", "xSRK", ",", "ySRK", ",", "vLiq", ",", "vVap"}], 
       "}"}], " ", "=", " ", 
      RowBox[{"bubblePressureSRK", "[", 
       RowBox[{
       "aPure", ",", "bPure", ",", "kij", ",", "tSim", ",", "xInit", ",", 
        "pGuess", ",", "yGuess", ",", 
        RowBox[{"10", "^", 
         RowBox[{"-", "6"}]}], ",", "False"}], "]"}]}], ";", "\n", "\t", "\n",
      "\t", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"AnyTrue", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"vLiq", "==", "vVap"}], ",", 
           RowBox[{"vLiq", ">", "vVap"}], ",", 
           RowBox[{"vLiq", "<", "0"}]}], "}"}], ",", "TrueQ"}], "]"}], "\n", 
       "\t\t", ",", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
          RowBox[{"True", ":", " ", 
           RowBox[{"the", " ", "calculation", " ", "has", " ", "failed"}]}], 
          " ", "->", " ", 
          RowBox[{"start", " ", "calculation", " ", "from", " ", "x1"}]}], 
         " ", "=", " ", "0"}], "*)"}], "\n", "\t\t", 
       RowBox[{
        RowBox[{"xInit", " ", "=", " ", 
         RowBox[{"yGuess", " ", "=", " ", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}]}]}], ";", "\n", "\t\t", 
        RowBox[{"dx", " ", "=", " ", "0.01"}], ";", "\n", "\t\t", 
        RowBox[{"pGuess", " ", "=", " ", 
         RowBox[{"pAntoine", "[", 
          RowBox[{"tSim", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"physicalPropertyData", "[", 
              RowBox[{
               RowBox[{"components", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               "\"\<antoineParameters\>\"", ",", 
               RowBox[{"antoineParamIndex", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "#"}], "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{"\"\<A\>\"", ",", "\"\<B\>\"", ",", "\"\<C\>\""}], 
             "}"}]}], ",", "\"\<log10\>\""}], "]"}]}], ";", "\n", "\t\t", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "pInit", ",", "xSRK", ",", "ySRK", ",", "vLiq", ",", "vVap"}], 
          "}"}], " ", "=", " ", 
         RowBox[{"bubblePressureSRK", "[", 
          RowBox[{
          "aPure", ",", "bPure", ",", "kij", ",", "tSim", ",", "xInit", ",", 
           "pGuess", ",", "yGuess", ",", 
           RowBox[{"10", "^", 
            RowBox[{"-", "6"}]}], ",", "False"}], "]"}]}], ";"}]}], "\n", 
      "\t", "]"}], ";", "\n", "\t", "\n", "\t", 
     RowBox[{"p", " ", "=", " ", "pInit"}], ";", "\n", "\t", 
     RowBox[{"x", " ", "=", " ", "xInit"}], ";", "\n", "\t", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"pInit", ">", "pSim"}], ",", 
         RowBox[{"p", ">", "pSim"}], ",", 
         RowBox[{"p", "<", "pSim"}]}], "]"}], ",", "\n", "\t\t", 
       RowBox[{
        RowBox[{"x", " ", "+=", " ", 
         RowBox[{"{", 
          RowBox[{"dx", ",", 
           RowBox[{"-", "dx"}]}], "}"}]}], ";", "\n", "\t\t", 
        RowBox[{"pGuess", " ", "=", " ", "p"}], ";", "\n", "\t\t", 
        RowBox[{"yGuess", " ", "=", " ", "ySRK"}], ";", "\n", "\t\t", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"p", ",", "xSRK", ",", "ySRK", ",", "vLiq", ",", "vVap"}], 
          "}"}], " ", "=", " ", 
         RowBox[{"bubblePressureSRK", "[", 
          RowBox[{
          "aPure", ",", "bPure", ",", "kij", ",", "tSim", ",", "x", ",", 
           "pGuess", ",", "yGuess", ",", 
           RowBox[{"10", "^", 
            RowBox[{"-", "6"}]}], ",", "False"}], "]"}]}], ";"}]}], "\n", 
      "\t", "]"}], ";", "\n", "\t", "\n", "\t", 
     RowBox[{"resSRK", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"p", ",", "xSRK", ",", "ySRK", ",", "vLiq", ",", "vVap"}], 
       "}"}]}], ";", "\n", "\t", "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{"caclculate", " ", "plot", " ", "data"}], "*)"}], "\n", "\t", 
     RowBox[{"p", " ", "=", " ", 
      RowBox[{"pGuess", " ", "=", " ", "pInit"}]}], ";", "\n", "\t", 
     RowBox[{"yGuess", " ", "=", " ", "xInit"}], ";", "\n", "\t", 
     RowBox[{"pVec", " ", "=", " ", 
      RowBox[{"xVec", " ", "=", " ", 
       RowBox[{"yVec", " ", "=", " ", 
        RowBox[{"vLiqVec", " ", "=", " ", 
         RowBox[{"vVapVec", " ", "=", " ", 
          RowBox[{"{", "}"}]}]}]}]}]}], ";", "\n", "\t", 
     RowBox[{"Do", "[", "\n", "\t\t", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"p", ",", "xSRK", ",", "ySRK", ",", "vLiq", ",", "vVap"}], 
          "}"}], " ", "=", " ", 
         RowBox[{"bubblePressureSRK", "[", 
          RowBox[{"aPure", ",", "bPure", ",", "kij", ",", "tSim", ",", 
           RowBox[{"{", 
            RowBox[{"x1", ",", 
             RowBox[{"1", "-", "x1"}]}], "}"}], ",", "pGuess", ",", "yGuess", 
           ",", 
           RowBox[{"10", "^", 
            RowBox[{"-", "6"}]}], ",", "False"}], "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{
         "check", " ", "if", " ", "calculation", " ", "was", " ", 
          "sucsessful", " ", "and", " ", "exit", " ", "if", " ", "it", " ", 
          "failed"}], "*)"}], "\n", "\t\t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"AnyTrue", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"vLiq", "==", "vVap"}], ",", 
              RowBox[{"vLiq", ">", "vVap"}], ",", 
              RowBox[{"vLiq", "<", "0"}]}], "}"}], ",", "TrueQ"}], "]"}], ",", 
          RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"pVec", ",", "p"}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"xVec", ",", 
          RowBox[{"xSRK", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"yVec", ",", 
          RowBox[{"ySRK", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"vLiqVec", ",", "vLiq"}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"vVapVec", ",", "vVap"}], "]"}], ";", "\n", "\t\t", "\n", 
        "\t\t", 
        RowBox[{"pGuess", " ", "=", " ", "p"}], ";", "\n", "\t\t", 
        RowBox[{"yGuess", " ", "=", " ", "ySRK"}], ";"}], "\n", "\t\t", ",", 
       RowBox[{"{", 
        RowBox[{"x1", ",", 
         RowBox[{"xInit", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"1", "-", 
          RowBox[{"xInit", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ",", "dx"}], "}"}]}], "\n", "\t",
       "]"}], ";"}]}], "\n", "]"}], "\n", "\n", 
  RowBox[{"(*", 
   RowBox[{
   "update", " ", "variables", " ", "to", " ", "the", " ", "results", " ", 
    "of", " ", "the", " ", "EOS"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x1Sim", " ", "=", " ", 
   RowBox[{"resSRK", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y1Sim", " ", "=", " ", 
   RowBox[{"resSRK", "[", 
    RowBox[{"[", 
     RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"p", " ", "=", " ", 
   RowBox[{"resSRK", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vLiq", " ", "=", " ", 
   RowBox[{"resSRK", "[", 
    RowBox[{"[", "4", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"vVap", " ", "=", " ", 
   RowBox[{"resSRK", "[", 
    RowBox[{"[", "5", "]"}], "]"}]}], ";"}]}], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->
  False,ExpressionUUID->"eec17ab2-b0a2-40d8-b76d-ef581f509909"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ResultsPlotBinarySRK", "[", "]"}], " ", ":=", " ", 
   RowBox[{"Grid", "[", 
    RowBox[{"{", "\n", "\t", 
     RowBox[{
      RowBox[{"{", "\n", "\t\t", 
       RowBox[{
        RowBox[{"Show", "[", 
         RowBox[{"{", "\n", "\t\t\t", 
          RowBox[{
           RowBox[{"ListLinePlot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Transpose", "@", 
                RowBox[{"{", 
                 RowBox[{"xVec", ",", "pVec"}], "}"}]}], ",", 
               RowBox[{"Transpose", "@", 
                RowBox[{"{", 
                 RowBox[{"yVec", ",", "pVec"}], "}"}]}]}], "}"}], "\n", 
             "\t\t\t\t", ",", 
             RowBox[{"FrameLabel", "\[Rule]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "14", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<\!\(\*SubscriptBox[\(x\), \
\(1\)]\),\!\(\*SubscriptBox[\(y\), \(1\)]\) [mol/mol]\>\"", ",", 
                  "\"\<P [bar]\>\""}], "}"}]}], ")"}]}], "\n", "\t\t\t\t", 
             ",", 
             RowBox[{"PlotLabel", "\[Rule]", " ", 
              RowBox[{"StringJoin", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<T = \>\"", ",", 
                 RowBox[{"ToString", "[", "tSim", "]"}], ",", "\"\< K\>\""}], 
                "}"}], "]"}]}], "\n", "\t\t\t\t", ",", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<SRK, bubble curve\>\"", ",", "\"\<SRK, dew curve\>\"", 
                ",", "\"\<Simulation point\>\""}], "}"}]}], "\n", "\t\t\t\t", 
             ",", 
             RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", " ", 
             RowBox[{"Frame", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"True", ",", "True"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], ",", 
             RowBox[{"PlotRange", "->", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "1"}], "}"}], ",", "All"}], "}"}]}], ",", 
             RowBox[{"PlotRangePadding", " ", "->", " ", "0"}]}], "\n", 
            "\t\t\t", "]"}], ",", "\n", "\t\t\t", 
           RowBox[{"ListPlot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"x1Sim", ",", "pSim"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"y1Sim", ",", "pSim"}], "}"}]}], "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", "Red", "}"}]}], ",", 
             RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
             RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}], ",", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"{", "\"\<Simulation Point\>\"", "}"}]}]}], "]"}]}], 
          "\n", "\t\t", "}"}], "]"}], ",", "\n", "\t\t", 
        RowBox[{"Show", "[", 
         RowBox[{"{", "\n", "\t\t\t", 
          RowBox[{
           RowBox[{"ListLinePlot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Transpose", "@", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"1", "/", "vLiqVec"}], ",", "pVec"}], "}"}]}], ",", 
               RowBox[{"Transpose", "@", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"1", "/", "vVapVec"}], ",", "pVec"}], "}"}]}]}], 
              "}"}], "\n", "\t\t\t\t", ",", 
             RowBox[{"FrameLabel", "\[Rule]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"#", ",", "14", ",", "Bold"}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \
\(V\)]\),\!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\) \
[mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)]\>\"", ",", "\"\<P [bar]\>\""}], 
                 "}"}]}], ")"}]}], "\n", "\t\t\t\t", ",", 
             RowBox[{"PlotLabel", "\[Rule]", " ", 
              RowBox[{"StringJoin", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<T = \>\"", ",", 
                 RowBox[{"ToString", "[", "tSim", "]"}], ",", "\"\< K\>\""}], 
                "}"}], "]"}]}], "\n", "\t\t\t\t", ",", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<SRK, liquid density\>\"", ",", 
                "\"\<SRK, vapor density\>\"", ",", 
                "\"\<Simulation point\>\""}], "}"}]}], "\n", "\t\t\t\t", ",", 
             RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", " ", 
             RowBox[{"Frame", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"True", ",", "False"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], ",", 
             RowBox[{"PlotRange", "->", "All"}]}], "\n", "\t\t\t", "]"}], ",",
            "\n", "\t\t\t", 
           RowBox[{"ListPlot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"1", "/", "vLiq"}], ",", "pSim"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"1", "/", "vVap"}], ",", "pSim"}], "}"}]}], "}"}], 
             ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", "Red", "}"}]}], ",", 
             RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
             RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}], ",", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"{", "\"\<Simulation Point\>\"", "}"}]}]}], "]"}]}], 
          "\n", "\t\t", "}"}], "]"}]}], "\n", "\t", "}"}], ",", 
      RowBox[{"{", "\n", "\t\t", 
       RowBox[{"Highlighted", "@", 
        RowBox[{"Row", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<Simulation @P=\>\"", "<>", 
            RowBox[{"ToString", "@", "pSim"}], "<>", 
            "\"\< bar : \!\(\*SubscriptBox[\(x\), \(1\)]\) = \>\""}], ",", 
           RowBox[{"Round", "[", 
            RowBox[{"x1Sim", ",", "0.00001"}], "]"}], ",", 
           "\"\< mol \!\(\*SuperscriptBox[\(mol\), \(-1\)]\), \
\!\(\*SubscriptBox[\(y\), \(1\)]\) = \>\"", ",", 
           RowBox[{"Round", "[", 
            RowBox[{"y1Sim", ",", "0.00001"}], "]"}], ",", 
           "\"\< mol \!\(\*SuperscriptBox[\(mol\), \(-1\)]\)\>\""}], "}"}], 
         "]"}]}], "\n", "\t", "}"}]}], "\n", "}"}], "]"}]}], ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[53]:=",ExpressionUUID->"2c5037d4-f02d-4124-b230-8226ba7f5125"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ResultsGridBinarySRK", "[", "]"}], " ", ":=", " ", 
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<System State\>\"", ",", "\"\<Value\>\"", ",", "\"\<Unit\>\""}], 
        "}"}], ",", "\[IndentingNewLine]", "\t\t", 
       RowBox[{"{", 
        RowBox[{"\"\<Temperature\>\"", ",", "tSim", ",", "\"\<K\>\""}], "}"}],
        ",", "\[IndentingNewLine]", "\t\t", 
       RowBox[{"{", 
        RowBox[{"\"\<Pressure\>\"", ",", "p", ",", "\"\<bar\>\""}], "}"}], 
       ",", "\[IndentingNewLine]", "\t\t", "\[IndentingNewLine]", "\t\t", 
       RowBox[{"{", 
        RowBox[{
        "\"\<EOS Results\>\"", ",", "\"\<Value\>\"", ",", "\"\<Unit\>\""}], 
        "}"}], ",", "\n", "\t\t", 
       RowBox[{"{", 
        RowBox[{"\"\<\!\(\*SubscriptBox[\(x\), \(1\)]\)\>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"x1Sim", ",", "0.00001"}], "]"}], ",", 
         "\"\<mol \!\(\*SuperscriptBox[\(mol\), \(-1\)]\)\>\""}], "}"}], ",", 
       "\[IndentingNewLine]", "\t\t", 
       RowBox[{"{", 
        RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(1\)]\)\>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"y1Sim", ",", "0.00001"}], "]"}], ",", 
         "\"\<mol \!\(\*SuperscriptBox[\(mol\), \(-1\)]\)\>\""}], "}"}], ",", 
       "\[IndentingNewLine]", "\t\t", 
       RowBox[{"{", 
        RowBox[{"\"\<\!\(\*SubscriptBox[\(v\), \(Vap\)]\)\>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"vVap", ",", "0.00001"}], "]"}], ",", 
         "\"\<\!\(\*SuperscriptBox[\(dm\), \(3\)]\) \
\!\(\*SuperscriptBox[\(mol\), \(-1\)]\)\>\""}], "}"}], ",", 
       "\[IndentingNewLine]", "\t\t", 
       RowBox[{"{", 
        RowBox[{"\"\<\!\(\*SubscriptBox[\(v\), \(Liq\)]\)\>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"vLiq", ",", "0.00001"}], "]"}], ",", 
         "\"\<\!\(\*SuperscriptBox[\(dm\), \(3\)]\) \
\!\(\*SuperscriptBox[\(mol\), \(-1\)]\)\>\""}], "}"}]}], 
      "\[IndentingNewLine]", "\t", "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "\[Rule]", " ", "True"}], ",", 
          RowBox[{"4", "\[Rule]", " ", "True"}], ",", " ", 
          RowBox[{"9", "\[Rule]", " ", "True"}]}], "}"}]}], "}"}]}]}], "\n", 
    "]"}]}], ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[54]:=",ExpressionUUID->"69d6ef33-e9cb-4731-a11c-124b42a58b8b"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResultsPlotBinarySRK", "[", "]"}]], "Code",
 CellLabel->"In[55]:=",ExpressionUUID->"b9be64ad-53e9-4154-8931-dcd88a14a927"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{
       GraphicsBox[{{{}, {{{}, {}, {
             Hue[0.67, 0.6, 0.6], 
             Directive[
              PointSize[
               NCache[
                Rational[1, 72], 0.013888888888888888`]], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJw1lQtMU2ccxUvLo0Xm1DB8TDHqcKjTDfGxZIPzOY0KTlfdADeYbJ0KiiIz
i6iMYbQQFRR8DAQ3lgxnhjgigwlujGGZPBShII+KTNrSlpa2lFeLxYJbv/vt
n9zc3Nx7zz3n/P7JXSA5tGMPn8fj7fnvcJ65GUTZas/tuxtEpHiT6rh3sQVe
12PkMWkiEpUps/pHWSCZOGwwrBcRz86ChCBPC/wCam5oXESkwjfVuL1iAO91
e+3cUS0ke+kMoNnrx9jlKULiTQUHsEXKS00IFhKnWqbMjNtzU6U+kx7kyyCn
ohn6m+vi5lR5kPlOOV8ztglHYhK/8SAPG51jQo/Gu9UfHiSJCpoQ/d10/6U8
D7KEGjShzpj+UuJdd0LtdRpxwFYdMuWUO6FyqUbUjvBq1RvcSSAdI2xTgzLs
7u7EmXaTqh+LfAvvbWlwIzRuZj/yjIfutKe7kWAauB/1uqMPLm1zIyYqZ4Bi
aXDSyeluJC/XOQYMtpVI8ttcyWYqaID0r4DVmhxXYnPGtepxUXa6ShzpSq45
7RXoceaGQ6X0dSU7aIF6hC6Ozb2gFhCOhx7Jz6JHo68LGI8+KO9JZobsFzAe
fdD2zngndIWA8ejD/pxjRZ8N8xkPHQ58+sn9M7f5jIcOVYJ3+TXH+YyHDmMB
KQoR+IyHFglTvJWRAj6h9hK02GidV3m7zoVQOV8tpPv2zJ+V4UIojkYNTvvL
HySLXRgPDabG91zQerswHhosexoo3vqYx3j04tUun5Ffv+cxHr3g2YVfeUt4
jEcvInaFPT60mMd4qLFG8mFcWvsLZFGDaphMuz+YvesFOB5qaAMTSy/rJsHx
UCG2o5BvjZ8Ex0OFmLrRP9eMTYDjocKRFylJ4SkT4Hgo0SXi68QeE+B4KBE9
xa9yYaYDHA8lPp4caq73cYDjocREyzp3kv8cXP89+GjpqvBUv+fg+n6K9ceK
6r+9OQ6u36eIW9uUGB84Dq7PfzBozzjv9bsdXH/dyA5YvvkgsYPa8e9GfoTC
cq72GaS0nyewRr2pjHv/GdTUfhcUC9QnXVvHWP4uhDeHisMixljex6hSezVH
dttYPgVCasovvfK5jeVRQFBxgJzQWsHtUycm5p6W5u6zgtufThh+2To32jwK
bl86ENqQI29KGAW3H+2oOXvmiG5kBNw+tGM8d72l4MgIqL3jbSjNvvq6m30Y
HVTuEWwuHTOFScNYSfk+QsZZSc0NxxDj2Qrrtby3jclDjF8L5oWdzKqbHGS8
WlA6I30gKGWQ8ZFjSWwJL3fSwnjIQTKnPVdPDLD+m/DFlaFt4Q4z6/shYqKW
XbTYTazfRjzibzxYZDNCSQ3fR0yZz9W04X5cof01YG9JhinZbICYCtbjydi0
tef79BDSfupgcxjiy5R9qKZ93AO/8fBls0KHr2n+v/HarPSKNXItVtG8NVj7
xgZHRq2G5bsL486sLPMfvSxPNRS1o7+F3VIz/1XovxJUKStQMb+VOLdxFX9l
tpL5u4PQFbf6173cw/yU463IgEVzBrtxlH6/DAOz/WR9TV3Q0++VIMTz6thP
RQrcovrF2GuwTxWndSCL6hWi/IdT8apdbThB37+GgNLu7LDVraimz+ejmp+z
8GeRnN2/jGlhKemF5Q/YtRTjmp684og6/P8HaYmUBUeMyPAvqWcZEg==
              "]]}, {
             Hue[0.9060679774997897, 0.6, 0.6], 
             Directive[
              PointSize[
               NCache[
                Rational[1, 72], 0.013888888888888888`]], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJw1VWs01fkCPc7xpqiLIpVMutRMM8ar6Q77F7LCcKm8ojTG62TQtbqZSca9
XoshY3ooDPOocQc1EWEuIa53iTxSabyOx3n9fzjO8cjhmnXX3Wvttdde+9Pe
X/aeoOjjIWwWixWywT/0f5hFpZW6Z3CHGvFzDNRNW6HQLArrCUtVIx2Daypq
UoogeQyf76BGGuPEWxMphYl5cwlPQY3EhfOi5vkU9sOavscbVUmJwYSnH4/i
meZP4e8lqJKj/h3Mw98pXJNZKeftVMmbFeaCykuKKsOUZL01FTL4vEbLrY9i
5u6RCIP6DX9t/1TKUwp3VUlY7FcqpJl3waC8jWKEp/PcFCrkqEdCx9PHFIHf
bTHdz1Ih8V9Eqr+upWgTZmyKfaxMGli7mRcPKT6XNTprJCmT9OvFXzXfp2iV
sFrHHZWJFvdJ/XfFFLLNtpnLysrEJCOgOOg2xTu7iltcO5RIs13xBzoFFHnC
6N8GMpTIy6IXtmU5FO1TX3Rdc1ci2sOWZVbZFEP77eIStyiRodT4gNvpFLP9
5UGF/YpET66vuZRIkdxgbsW7qUh6nrhd/vAyxdWmtHoPf0UiTfI77fl3ivSS
1bHRXYpEFH7F80QUhcu+8Nxvxzmkt9pVZB1GEb8UuBBYxCFt/UtlK4EUoy1B
25zPcUhx7YstBb4UkxNb/+JykEOMO3qiDD0pzt38svTsPJu47tHQiXXe6H/6
VGd6FZsoXBo6VHqEop7zMbv5EpsMqJfKqz6iWDRPGFIDmySVtJy7ZU5xXkNn
1J/DJpyzAVFuZhRO0p11VW0KZKn8zqs+o40+3JDd2zMVSOVK7Wdm2ynSTHu6
4j0USG1IYIGrFsXmqJFvJ3UUyIGa80s2yhQHfrfwcHvJIk7R9o3CVQY7XulJ
HhSwiKXez9uCJQxYy6oXdIJY5D9zv0oL+Ax8zni9jN7HInn21sY5Iwysg05E
pA6sw/es1Nx5gIFIFPxX/TPrKHvinljRyWDSIrbi+tQaWJuLLHsbGIQPFrOl
UWtw/J6YFVYyCGtbeGS9KIdPyg/LusUMLq4nxHknyPEv3WPzFgUMXqmxpzxU
5HDa268hyWYQqGFSZ/zNKhK3+Uy4JTPwW5t71q63CsZiuNwuloG894gyKXwL
boPMvoHL4OR+S+8Uk7eosP9Y0O7PwOHL0vYbd1dQqpsce9KNQYRNd2yUxQo8
zjSanbJjMLucmaX572XkZ9r+0HuQQY75e8ciyTKoQLOzfBeDQp8heqV1Cd7d
J/tmNzGQBrw/GvHJEo5TS+3kVTGG9ownKj5fhI/WCC9QIIb3MxcPL59F0LqY
ktgXYtSPaz7zH5bB31Av+1GzGM7N1dd0P5Uh9qO7scb3xeDUfE7+MSmFUcK5
pzdyxZAbpiXncqXI28n1U0oSg3/PzTBQvIB793aon44Qw6XjZk/3+QVI50Oq
Uo+L0fx1+sUpiQS2Pr8NcA+JsZLrQG9flMD7sfu7QkMxKnLy/6y0PI/RR0Zc
0boIMoXBbapx8/Cbr3vgOiZC5tdBzSWrc3Au89g90SiC9E7eIWH8HI5yo/+U
VijCTq/E7La1WYQ2CP6pfkmEiq0ZjG3CLMSWN5QsT4hgFl7Oyl2j6Nfv72o1
E4F8o/12XM7gYZGn42W5EJ/dmnP33tjJe+BBKqdbiLCAA1fpsgjpt/JOrecJ
0cd2iiyVCVF4T7mdE7yRV+rlp84LsBSjvumaqRCh5ZmieDEfescin+rPCPB6
Udsma3oGpdvfWAl+FEC2yo+qHJ1G1uGuFisvAdhPYq6Lh6bwS+kNKCkIsHd7
Ro11zyQGPx3UO3iHD5t3HVczW3kI9nMMdbTlQ+ibnS2unYBNqIFSWucMhloX
HnqVjcM0VPZTp/MMBLds65puj0Hzx75q15ppXHGyZH+YMwoXN23XlK3TcDlY
JjiiNQJuzYOrYyem8IG/+TsGs8OgV6jVJxcnweibNE13v8Ibh8zCtL/x4Kye
v/hz6RAiJy3fNzk8gVD+8maP1EFEGzlkNTaMofr7pKixM/0QVXOqd/SPwLxi
OMfL6jnq9u7Latn3Go3sm8a/qPVA4vum1mi1H9peCRnF1V3IP3xfM0bWjhXe
SN6vPm34/4P0+jfZ+Uia8F8vwC+6
              "]]}}}, {{}, {}}}, {{}, {{{}, {}, {}, {}, {
             Directive[
              RGBColor[1, 0, 0], 
              Opacity[0.3]], 
             LineBox[{{0.5899999999999996, 0.}, {0.5899999999999996, 2.}}], 
             
             LineBox[{{0.9647932689859602, 0.}, {0.9647932689859602, 
              2.}}]}}, {{
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[1, 0, 0]], 
             GeometricTransformationBox[
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox[
                  GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], 
                  GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}, StripOnInput -> False], 
                 TraditionalForm]], {0., 0.}, Automatic, 
               Scaled[9.75]], {{{0.5899999999999996, 2.}}, {{
              0.9647932689859602, 2.}}}]}}}, {{}, {}}}}, {
        DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
         NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
         AxesLabel -> {None, None}, AxesOrigin -> {0, 0.1480511719171024}, 
         DisplayFunction :> Identity, Frame -> {{True, True}, {True, False}}, 
         FrameLabel -> {{
            FormBox[
             TagBox[
              StyleBox["\"P [bar]\"", 14, Bold, StripOnInput -> False], 
              HoldForm], TraditionalForm], None}, {
            FormBox[
             TagBox[
              StyleBox[
              "\"\\!\\(\\*SubscriptBox[\\(x\\), \
\\(1\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) [mol/mol]\"", 14, Bold,
                StripOnInput -> False], HoldForm], TraditionalForm], None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> Medium, 
         Method -> {
          "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
           "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), "CopiedValueFunction" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& )}}, PlotLabel -> 
         FormBox["\"T = 100. K\"", TraditionalForm], 
         PlotRange -> {{0., 1.}, {0.14805117191710207`, 3.2233358699074532`}},
          PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
         Ticks -> {Automatic, Automatic}}], 
       FormBox[
        TagBox[
         GridBox[{{
            FormBox[
             
             TemplateBox[{
              "\"SRK, bubble curve\"", "\"SRK, dew curve\"", 
               "\"Simulation point\""}, "LineLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"LineLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
                   ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"True", ",", "True"}], "}"}]}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}, {
            FormBox[
             
             TemplateBox[{"\"Simulation Point\""}, "PointLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
                   RowBox[{"{", #, "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], "}"}]}], ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", "False", "}"}]}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], 
     TemplateBox[{
       GraphicsBox[{{{}, {{{}, {}, {
             Hue[0.67, 0.6, 0.6], 
             Directive[
              PointSize[
               NCache[
                Rational[1, 72], 0.013888888888888888`]], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVkntUzIkbxqdpaiplK4kVfhsKkZ903bXN+9TQISK7ZrJbynYxpYvW8atd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              "]]}, {
             Hue[0.9060679774997897, 0.6, 0.6], 
             Directive[
              PointSize[
               NCache[
                Rational[1, 72], 0.013888888888888888`]], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVxX88FHYDB/Bzhzt1mkqKyTPdmGllUtkmfb5+PHrwVFf5VbZTt4r5vbWH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              "]]}}}, {{}, {}}}, {{}, {{{}, {}, {}, {}, {
             Directive[
              RGBColor[1, 0, 0], 
              Opacity[0.3]], 
             LineBox[{{32.40163559936317, 0.}, {32.40163559936317, 2.}}], 
             
             LineBox[{{0.25045051316177547`, 0.}, {0.25045051316177547`, 
              2.}}]}}, {{
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[1, 0, 0]], 
             GeometricTransformationBox[
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox[
                  GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], 
                  GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}, StripOnInput -> False], 
                 TraditionalForm]], {0., 0.}, Automatic, 
               Scaled[9.75]], {{{32.40163559936317, 2.}}, {{
              0.25045051316177547`, 2.}}}]}}}, {{}, {}}}}, {
        DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
         NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
         AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
         Identity, Frame -> {{True, False}, {True, False}}, FrameLabel -> {{
            FormBox[
             TagBox[
              StyleBox["\"P [bar]\"", 14, Bold, StripOnInput -> False], 
              HoldForm], TraditionalForm], None}, {
            FormBox[
             TagBox[
              StyleBox[
              "\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \
\\(V\\)]\\),\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\) \
[mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)]\"", 14, Bold, 
               StripOnInput -> False], HoldForm], TraditionalForm], None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> Medium, 
         Method -> {
          "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
           "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), "CopiedValueFunction" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& )}}, PlotLabel -> 
         FormBox["\"T = 100. K\"", TraditionalForm], 
         PlotRange -> {{0, 32.86327996199275}, {0, 3.2233358699074532`}}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.02], 
            Scaled[0.02]}, {
            Scaled[0.02], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
       FormBox[
        TagBox[
         GridBox[{{
            FormBox[
             
             TemplateBox[{
              "\"SRK, liquid density\"", "\"SRK, vapor density\"", 
               "\"Simulation point\""}, "LineLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"LineLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
                   ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"True", ",", "True"}], "}"}]}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}, {
            FormBox[
             
             TemplateBox[{"\"Simulation Point\""}, "PointLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
                   RowBox[{"{", #, "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], "}"}]}], ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", "False", "}"}]}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]},
    {
     TemplateBox[{
       TemplateBox[{
        "\"Simulation @P=2. bar : \\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\) \
= \"", "0.5900000000000001`", 
         "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\), \
\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) = \"", "0.96479`", 
         "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)\""}, 
        "RowDefault"], FrameStyle -> None},
      "Highlighted"], ""}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[55]=",ExpressionUUID->"1ddd62c8-6d09-4fde-a3f6-c7ab3bac5fe0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResultsGridBinarySRK", "[", "]"}]], "Code",
 CellLabel->"In[56]:=",ExpressionUUID->"69a84c80-cc20-4c6e-b58e-af1305b79537"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"System State\"\>", "\<\"Value\"\>", "\<\"Unit\"\>"},
    {"\<\"Temperature\"\>", "100.`", "\<\"K\"\>"},
    {"\<\"Pressure\"\>", "1.9896301453028533`", "\<\"bar\"\>"},
    {"\<\"EOS Results\"\>", "\<\"Value\"\>", "\<\"Unit\"\>"},
    {"\<\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"\>", 
     "0.5900000000000001`", "\<\"mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\
\\)]\\)\"\>"},
    {"\<\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"\>", 
     "0.96479`", "\<\"mol \\!\\(\\*SuperscriptBox[\\(mol\\), \
\\(-1\\)]\\)\"\>"},
    {"\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(Vap\\)]\\)\"\>", 
     "3.9928000000000003`", "\<\"\\!\\(\\*SuperscriptBox[\\(dm\\), \
\\(3\\)]\\) \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)\"\>"},
    {"\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(Liq\\)]\\)\"\>", 
     "0.030860000000000002`", "\<\"\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\
\\) \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)\"\>"}
   },
   AutoDelete->False,
   GridBoxFrame->{
    "Columns" -> None, "RowsIndexed" -> {1 -> True, 4 -> True, 9 -> True}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[56]=",ExpressionUUID->"f2a534e0-15a7-41f8-953a-7b65bf6bc2cf"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Binary Mixture of LJ-fluids", "Chapter",ExpressionUUID->"f6555796-ca6b-4427-b340-72bff96257f4"],

Cell["\<\
The aim of this section is to give aid to choose the initial Temperature and \
Pressure for the simulation as well as appropriate starting values for the \
molar density and molar fraction of the boxes.
The LJ-reduced values marked with an asterisk are calculated using the \
LJ-Parameters as follows:\
\>", "Text",ExpressionUUID->"803da5f2-3a52-4303-9dd0-b928dff7c475"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["P", "*"], "=", 
    FractionBox[
     RowBox[{"P", "*", 
      SuperscriptBox[
       SubscriptBox["\[Sigma]", "11"], "3"]}], 
     SubscriptBox["\[CurlyEpsilon]", "11"]]}], TraditionalForm]], 
  "Subsubitem",ExpressionUUID->"555c3b03-59f9-430a-80e5-3daac02000b4"],
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["T", "*"], "=", 
    FractionBox[
     RowBox[{"T", "*", 
      SubscriptBox["k", "B"]}], 
     SubscriptBox["\[CurlyEpsilon]", "11"]]}], TraditionalForm]],
  ExpressionUUID->"f048457e-8e3f-4b34-b79a-586106d2189e"],
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Rho]", "*"], "=", 
    RowBox[{"\[Rho]", "*", 
     SuperscriptBox[
      SubscriptBox["\[Sigma]", "m"], "3"]}]}], TraditionalForm]],
  ExpressionUUID->"0146ab62-853a-4c0a-b603-ee43e6de4690"]
}], "Item",ExpressionUUID->"ee51da28-d115-4b58-8a23-21d253d2e876"],

Cell["\<\
The index 11 refers to the interaction parameters between two particles of \
the first species in the system.
The density is reduced using a mixture parameter that can be calculated as \
follows:\
\>", "Text",ExpressionUUID->"fa50cb18-46bc-4f4f-9c01-86d18de1da9b"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[Sigma]", "m"], "=", 
   RowBox[{"\[Sum]", 
    RowBox[{"\[Sum]", 
     RowBox[{
      SubscriptBox["x", "i"], "*", 
      SubscriptBox["x", "j"], "*", 
      SuperscriptBox[
       SubscriptBox["\[Sigma]", "ij"], "3"]}]}]}]}], 
  TraditionalForm]],ExpressionUUID->"0cf664a6-e73d-4c36-b638-ec0cd61e7e37"]], \
"Item",ExpressionUUID->"7695f2e9-aa3f-4867-9bf5-965317208156"],

Cell[CellGroupData[{

Cell["Components / Labels", "Section",ExpressionUUID->"846a700c-360c-49a5-b3e8-2808ff05d1f3"],

Cell["\<\
The name of the component needs to be equal to the label of the \
OPLS-parameters in the \[OpenCurlyDoubleQuote]ForceFieldOPLS\
\[CloseCurlyDoubleQuote]-Package\
\>", "Text",ExpressionUUID->"f820cd9a-ff92-4cb9-91d6-8bca18fa6140"],

Cell[BoxData[
 RowBox[{
  RowBox[{"component", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<LJ_ref\>\"", ",", "\"\<LJ_1\>\""}], "}"}]}], ";"}]], "Input",
 Background->RGBColor[1, 1, 0],
 CellLabel->"In[5]:=",ExpressionUUID->"08a462d7-1df6-4044-a7f4-ba005ee72194"],

Cell[CellGroupData[{

Cell["Helper Functions", "Subsubsection",ExpressionUUID->"fe2b3837-1f69-4104-9cff-df9c2506a109"],

Cell[CellGroupData[{

Cell["Pressure Conversion Functions", "Subsubsubsection",ExpressionUUID->"3c831cb5-b66a-4055-9b1b-75425bac7343"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"conversion", " ", "of", " ", "pressure", " ", "to", " ", "Lj"}], 
    "-", 
    RowBox[{"reduced", " ", "quantities", " ", "and", " ", "backwards"}]}], 
   "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"pRedLJ", "[", 
     RowBox[{"p_", ",", "\[Epsilon]_", ",", "\[Sigma]_"}], "]"}], " ", ":=", 
    " ", 
    RowBox[{"p", "*", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Sigma]", "^", "3"}], ")"}], "/", "\[Epsilon]"}], " ", "/", 
      RowBox[{"10", "^", "30"}]}], " ", "*", 
     RowBox[{
      RowBox[{"nAvogadro", " ", "/", "4184"}], " ", "/", 
      RowBox[{"10", "^", 
       RowBox[{"-", "5"}]}]}]}]}], " ", 
   RowBox[{"(*", " ", "1", " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"pLJ", "[", 
     RowBox[{"pAst_", ",", "\[Epsilon]_", ",", "\[Sigma]_"}], "]"}], " ", ":=",
     " ", 
    RowBox[{
     RowBox[{"pAst", "/", 
      RowBox[{"(", 
       RowBox[{"\[Sigma]", "^", "3"}], ")"}]}], "*", "\[Epsilon]", " ", "*", 
     RowBox[{
      RowBox[{"10", "^", "30"}], " ", "/", "nAvogadro"}], " ", "*", "4184", 
     " ", 
     RowBox[{"(*", " ", "Pa", " ", "*)"}], " ", "*", 
     RowBox[{"10", "^", 
      RowBox[{"-", "5", 
       RowBox[{"(*", " ", "bar", " ", "*)"}]}]}]}]}]}]}]], "Code",
 InitializationCell->False,
 CellLabel->"In[6]:=",ExpressionUUID->"86585789-d5f1-43f6-8087-5fb8bdb9e7f8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"pSatLJ", "::", "usage"}], "=", 
   "\"\<Calculate the saturation pressure in bar from T[K], sigma[\
\[CapitalARing]], epsilon[kcal/mol] using the emprirical equation from \
Thol2016.\nThe values can exceed the critical point for extrapolation \
purpose.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pSatLJ", "[", 
    RowBox[{"t_", ",", "\[Sigma]_", ",", "\[Epsilon]_"}], "]"}], " ", ":=", 
   " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tAst", ",", "pAst"}], "}"}], ",", "\[IndentingNewLine]", "\t", 
     RowBox[{
      RowBox[{"tAst", " ", "=", " ", 
       RowBox[{"tRedLJ", "[", 
        RowBox[{"t", ",", "\[Epsilon]"}], "]"}]}], ";", "\[IndentingNewLine]",
       "\t", 
      RowBox[{"pAst", " ", "=", " ", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"pSatRedLJ", "[", 
          RowBox[{"tAst", "/", "tCritLJ"}], "]"}], "]"}], "*", "pCritLJ"}]}], 
      ";", "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", "Return", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"pLJ", "[", 
       RowBox[{"pAst", ",", "\[Epsilon]", ",", "\[Sigma]"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Code",
 CellLabel->"In[8]:=",ExpressionUUID->"a7be0586-5a58-46b2-8782-5575fa339b2c"]
}, Closed]],

Cell[CellGroupData[{

Cell["OPLS Grids", "Subsubsubsection",ExpressionUUID->"1e8e4d15-c8ed-4ed4-8da6-6d37481a9ed8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Summary", " ", "of", " ", "OPLSA", " ", "Data"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"OPLSList", " ", ":=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"StringForm", "[", 
            RowBox[{"\"\<Component ``: ``\>\"", ",", "i", ",", 
             RowBox[{"component", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", "SpanFromLeft"}], 
          "}"}], ",", "\[IndentingNewLine]", "\t\t", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"StringForm", "[", 
            RowBox[{"\"\<\[Sigma]````\>\"", ",", "i", ",", "i"}], "]"}], ",", 
           " ", 
           RowBox[{"\[Sigma]", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "i"}], "]"}], "]"}], ",", 
           "\"\<\[Angstrom]\>\""}], "}"}], ",", "\[IndentingNewLine]", "\t\t", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"StringForm", "[", 
            RowBox[{"\"\<\[Epsilon]````/kB\>\"", ",", "i", ",", "i"}], "]"}], 
           ",", 
           RowBox[{
            RowBox[{"\[Epsilon]", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "i"}], "]"}], "]"}], "/", " ", 
            RowBox[{"(", 
             RowBox[{"rCalor", "*", 
              RowBox[{"10", "^", 
               RowBox[{"-", "3"}]}]}], ")"}]}], ",", "\"\<K\>\""}], "}"}]}], 
        "\[IndentingNewLine]", "\t", "}"}], "\n", "\t", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "@", "component"}]}], "}"}]}], "\n", "]"}]}], 
    ";"}], "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plotOPLSList", " ", ":=", " ", 
     RowBox[{"Grid", "[", "\n", "\t", 
      RowBox[{
       RowBox[{"Prepend", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"OPLSList", ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"\"\<OPLSA Data\>\"", ",", "Bold"}], "]"}], ",", 
           "SpanFromLeft"}], "}"}]}], "]"}], "\n", "\t", ",", 
       RowBox[{"Frame", "\[Rule]", "All"}], ",", 
       RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
       RowBox[{"Spacings", "->", 
        RowBox[{"{", 
         RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "]"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plotOPLS\[Sigma]Grid", " ", ":=", " ", 
     RowBox[{"Grid", "[", 
      RowBox[{
       RowBox[{"{", "\n", "\t\t", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"#", ",", "Bold"}], "]"}], " ", "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\!\(\*SubscriptBox[\(\[Sigma]\), \(i, \
j\)]\)[\[Angstrom]]\>\"", ",", "1", ",", "2"}], "}"}]}], ",", 
         "\[IndentingNewLine]", "\t\t", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"1", ",", "Bold"}], "]"}], ",", 
           RowBox[{"\[Sigma]", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"\[Sigma]", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", "\t\t", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"2", ",", "Bold"}], "]"}], ",", 
           RowBox[{"\[Sigma]", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"\[Sigma]", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "}"}]}], "\n", "\t", 
        "}"}], ",", 
       RowBox[{"Frame", "\[Rule]", "All"}], ",", 
       RowBox[{"Alignment", "\[Rule]", "Center"}], ",", 
       RowBox[{"Spacings", "->", 
        RowBox[{"{", 
         RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plotOPLS\[Epsilon]Grid", " ", ":=", " ", 
     RowBox[{"Grid", "[", 
      RowBox[{
       RowBox[{"{", "\n", "\t\t", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"#", ",", "Bold"}], "]"}], " ", "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\!\(\*SubscriptBox[\(\[Epsilon]\), \(i, j\)]\)[K]\>\"", ",", 
            "1", ",", "2"}], "}"}]}], ",", "\[IndentingNewLine]", "\t\t", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"1", ",", "Bold"}], "]"}], ",", 
           RowBox[{
            RowBox[{"\[Epsilon]", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], "/", 
            RowBox[{"(", 
             RowBox[{"rCalor", "*", 
              RowBox[{"10", "^", 
               RowBox[{"-", "3"}]}]}], ")"}]}], ",", 
           RowBox[{
            RowBox[{"\[Epsilon]", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2"}], "]"}], "]"}], "/", 
            RowBox[{"(", 
             RowBox[{"rCalor", "*", 
              RowBox[{"10", "^", 
               RowBox[{"-", "3"}]}]}], ")"}]}]}], "}"}], ",", 
         "\[IndentingNewLine]", "\t\t", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"2", ",", "Bold"}], "]"}], ",", 
           RowBox[{
            RowBox[{"\[Epsilon]", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "1"}], "]"}], "]"}], "/", 
            RowBox[{"(", 
             RowBox[{"rCalor", "*", 
              RowBox[{"10", "^", 
               RowBox[{"-", "3"}]}]}], ")"}]}], ",", 
           RowBox[{
            RowBox[{"\[Epsilon]", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "2"}], "]"}], "]"}], "/", 
            RowBox[{"(", 
             RowBox[{"rCalor", "*", 
              RowBox[{"10", "^", 
               RowBox[{"-", "3"}]}]}], ")"}]}]}], "}"}]}], "\n", "\t", "}"}], 
       ",", 
       RowBox[{"Frame", "\[Rule]", "All"}], ",", 
       RowBox[{"Alignment", "\[Rule]", "Center"}], ",", 
       RowBox[{"Spacings", "->", 
        RowBox[{"{", 
         RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}]}]}]], "Code",
 CellLabel->"In[10]:=",ExpressionUUID->"a550cae3-780f-4ace-834c-a6aba032a645"]
}, Closed]],

Cell[CellGroupData[{

Cell["Input Grids", "Subsubsubsection",ExpressionUUID->"8fe31597-8531-4b57-93df-408c0adf4276"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PlotBoilingTemperatures", "[", "]"}], " ", ":=", " ", 
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"{", "\n", "\t", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Normal Boiling Temperature\>\"", ",", "Bold"}], 
             "]"}], ",", "SpanFromLeft"}], "}"}], "}"}], ",", 
         "\[IndentingNewLine]", "\t", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Component\>\"", ",", 
             "\"\<\!\(\*SubscriptBox[\(T\), \(Boil\)]\) [K]\>\"", ",", " ", 
             "\"\<\!\(\*SubsuperscriptBox[\(T\), \(Boil\), \(*\)]\)[1]\>\""}],
             "}"}]}], "}"}], ",", "\[IndentingNewLine]", "\t", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"component", "[", 
              RowBox[{"[", "#", "]"}], "]"}], ",", 
             RowBox[{"tBoilVec", "[", 
              RowBox[{"[", "#", "]"}], "]"}], ",", 
             RowBox[{"tRedLJ", "[", 
              RowBox[{
               RowBox[{"tBoilVec", "[", 
                RowBox[{"[", "#", "]"}], "]"}], ",", 
               RowBox[{"\[Epsilon]", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
           "&"}], "/@", 
          RowBox[{"Range", "@", 
           RowBox[{"Length", "@", "component"}]}]}]}], "\[IndentingNewLine]", 
        "\t", "}"}], ",", "1"}], "]"}], ",", 
     RowBox[{"Frame", "\[Rule]", "All"}], ",", 
     RowBox[{"Spacings", "->", 
      RowBox[{"{", 
       RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "]"}]}], 
  ";"}]], "Code",
 CellLabel->"In[14]:=",ExpressionUUID->"78380468-4253-41ad-aa67-d0a82c68a918"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PlotSaturationPressure", "[", "]"}], " ", ":=", " ", 
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"{", "\n", "\t", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"\"\<Saturation Pressure at T = \>\"", "<>", 
               RowBox[{"ToString", "@", "tSim"}], " ", "<>", "\"\< K\>\""}], 
              ",", "Bold"}], "]"}], ",", "SpanFromLeft"}], "}"}], "}"}], ",", 
         "\[IndentingNewLine]", "\t", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Component\>\"", ",", 
             "\"\<\!\(\*SuperscriptBox[\(P\), \(Sat\)]\)[bar]\>\"", ",", " ", 
             "\"\<\!\(\*SuperscriptBox[\(P\), \(\(Sat\)\(*\)\)]\)[1]\>\""}], 
            "}"}]}], "}"}], ",", "\[IndentingNewLine]", "\t", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"component", "[", 
              RowBox[{"[", "#", "]"}], "]"}], ",", 
             RowBox[{"pSatVec", "[", 
              RowBox[{"[", "#", "]"}], "]"}], ",", 
             RowBox[{"pRedLJ", "[", 
              RowBox[{
               RowBox[{"pSatVec", "[", 
                RowBox[{"[", "#", "]"}], "]"}], ",", 
               RowBox[{"\[Epsilon]", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
               RowBox[{"\[Sigma]", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
           "&"}], "/@", 
          RowBox[{"Range", "@", 
           RowBox[{"Length", "@", "component"}]}]}]}], "\[IndentingNewLine]", 
        "\t", "}"}], ",", "1"}], "]"}], ",", 
     RowBox[{"Frame", "\[Rule]", "All"}], ",", 
     RowBox[{"Spacings", "->", 
      RowBox[{"{", 
       RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "]"}]}], 
  ";"}]], "Code",
 CellLabel->"In[15]:=",ExpressionUUID->"91dd0c73-ab18-4357-bd61-5d97c9925cc8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Summary", " ", "of", " ", "input", " ", "Data"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"plotInputSummary", "[", "]"}], " ", ":=", " ", 
    RowBox[{"Grid", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", "\n", "\t", 
        RowBox[{
         RowBox[{"Grid", "[", 
          RowBox[{
           RowBox[{"{", "\n", "\t\t\t", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Style", "[", 
                RowBox[{"\"\<Summary of Input\>\"", ",", "Bold"}], "]"}], ",",
                "SpanFromLeft"}], "}"}], ",", "\[IndentingNewLine]", "\t\t\t", 
             RowBox[{
              RowBox[{
               RowBox[{"Style", "[", 
                RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
              RowBox[{"{", 
               RowBox[{
               "\"\<Symbol\>\"", ",", "\"\<Value\>\"", ",", "\"\<Unit\>\""}], 
               "}"}]}], ",", "\n", "\t\t\t", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Style", "[", 
                RowBox[{"\"\<LJ-reduced units\>\"", ",", "Bold"}], "]"}], ",",
                "SpanFromLeft"}], "}"}], ",", "\[IndentingNewLine]", "\t\t\t", 
             RowBox[{"{", 
              RowBox[{
              "\"\<\!\(\*SuperscriptBox[\(T\), \(*\)]\)\>\"", ",", "tSimAst", 
               ",", "\"\<1\>\""}], "}"}], ",", "\[IndentingNewLine]", 
             "\t\t\t", 
             RowBox[{"{", 
              RowBox[{"\"\<\!\(\*SuperscriptBox[\(P\), \(*\)]\)\>\"", ",", 
               RowBox[{
                RowBox[{"{", "pSimAst", "}"}], "//", "MatrixForm"}], ",", 
               "\"\<1\>\""}], "}"}], ",", "\n", "\t\t\t", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Style", "[", 
                RowBox[{"\"\<Caloric Units\>\"", ",", "Bold"}], "]"}], ",", 
               "SpanFromLeft"}], "}"}], ",", "\[IndentingNewLine]", "\t\t\t", 
             RowBox[{"{", 
              RowBox[{"\"\<T\>\"", ",", "tSim", ",", "\"\<K\>\""}], "}"}], 
             ",", "\[IndentingNewLine]", "\t\t\t", 
             RowBox[{"{", 
              RowBox[{"\"\<P\>\"", ",", 
               RowBox[{
                RowBox[{"{", "pSim", "}"}], "//", "MatrixForm"}], ",", 
               "\"\<bar\>\""}], "}"}]}], "\n", "\t\t", "}"}], ",", 
           RowBox[{"Frame", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "->", "True"}], ",", 
                RowBox[{"3", "->", "True"}], ",", 
                RowBox[{"6", "->", "True"}]}], "}"}]}], "}"}]}], "\n", "\t\t",
            ",", 
           RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
           RowBox[{"Spacings", "->", 
            RowBox[{"{", 
             RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "\n", "\t", 
          "]"}], ",", "\n", "\t", 
         RowBox[{"Grid", "[", 
          RowBox[{
           RowBox[{"{", "\n", "\t\t\t", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Style", "[", 
                RowBox[{"\"\<OPLS Parameter\>\"", ",", "Bold"}], "]"}], ",", 
               "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
             RowBox[{"{", 
              RowBox[{
              "\"\<Combining Rule:\>\"", ",", "ffparamCombiningRule", ",", 
               "SpanFromLeft"}], "}"}], ",", "\n", "\t\t\t", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Style", "[", 
                RowBox[{
                 RowBox[{"\"\<Component 1: \>\"", " ", "<>", " ", 
                  RowBox[{"ToString", "@", 
                   RowBox[{"component", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], ",", "Bold"}], "]"}], 
               ",", "SpanFromLeft"}], "}"}], ",", "\[IndentingNewLine]", 
             "\t\t\t", 
             RowBox[{"{", 
              RowBox[{"\"\<\[Sigma]11\>\"", ",", " ", 
               RowBox[{"\[Sigma]", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
               "\"\<\[Angstrom]\>\""}], "}"}], ",", "\[IndentingNewLine]", 
             "\t\t\t", 
             RowBox[{"{", 
              RowBox[{"\"\<\[Epsilon]11/kB\>\"", ",", 
               RowBox[{
                RowBox[{"\[Epsilon]", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}], "/", " ", 
                RowBox[{"(", 
                 RowBox[{"rCalor", "*", 
                  RowBox[{"10", "^", 
                   RowBox[{"-", "3"}]}]}], ")"}]}], ",", "\"\<K\>\""}], "}"}],
              ",", "\[IndentingNewLine]", "\t\t\t", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Style", "[", 
                RowBox[{
                 RowBox[{"\"\<Component 2: \>\"", " ", "<>", " ", 
                  RowBox[{"ToString", "@", 
                   RowBox[{"component", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}]}], ",", "Bold"}], "]"}], 
               ",", "SpanFromLeft"}], "}"}], ",", "\[IndentingNewLine]", 
             "\t\t\t", 
             RowBox[{"{", 
              RowBox[{"\"\<\[Sigma]22\>\"", ",", " ", 
               RowBox[{"\[Sigma]", "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "2"}], "]"}], "]"}], ",", 
               "\"\<\[Angstrom]\>\""}], "}"}], ",", "\[IndentingNewLine]", 
             "\t\t\t", 
             RowBox[{"{", 
              RowBox[{"\"\<\[Epsilon]22/kB\>\"", ",", 
               RowBox[{
                RowBox[{"\[Epsilon]", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "2"}], "]"}], "]"}], "/", " ", 
                RowBox[{"(", 
                 RowBox[{"rCalor", "*", 
                  RowBox[{"10", "^", 
                   RowBox[{"-", "3"}]}]}], ")"}]}], ",", "\"\<K\>\""}], 
              "}"}]}], "\n", "\t\t", "}"}], ",", 
           RowBox[{"Frame", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "->", "True"}], ",", 
                RowBox[{"3", "->", "True"}], ",", 
                RowBox[{"6", "->", "True"}]}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
           RowBox[{"Spacings", "->", 
            RowBox[{"{", 
             RowBox[{"1", ",", " ", "0.5"}], "}"}]}]}], "\n", "\t", "]"}]}], 
        "\t", "\n", "}"}], "}"}], ",", 
      RowBox[{"Alignment", "->", "Top"}], ",", 
      RowBox[{"Spacings", "->", "5"}]}], "]"}]}], ";"}]}]], "Code",
 CellLabel->"In[16]:=",ExpressionUUID->"bfa76649-9c52-4a42-ba50-962a4cba592e"]
}, Closed]],

Cell[CellGroupData[{

Cell["EoS Calculation Helper Functions", "Subsubsubsection",ExpressionUUID->"19ca15be-3c66-4f86-8506-3b5ebc6c80f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Iteration", " ", "criteria"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Epsilon]Iteration", " ", "=", " ", "0.001"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Functions", " ", "for", " ", "calculating", " ", "molar", " ", 
      "volume"}], ",", " ", 
     RowBox[{"molar", " ", "density", " ", "and", " ", "rhoAst"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"vToRho", "::", "usage"}], "=", 
     "\"\<Calculate of the molar density in [N/\[Angstrom]^3] from the molar \
volume in [\!\(\*SuperscriptBox[\(dm\), \(3\)]\) \
\!\(\*SuperscriptBox[\(mol\), \(-1\)]\)]\>\""}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"vToRho", "[", "v_", "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "/", "v"}], ")"}], "*", 
      RowBox[{"nAvogadro", "/", 
       RowBox[{"10", "^", "27"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"RhoToRhoAst", "::", "usage"}], "=", 
     "\"\<Calculate the LJ-reduced molar density[-] from the molar density[N/\
\[Angstrom]^3]\>\""}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"RhoToRhoAst", "[", 
      RowBox[{"rho_", ",", "x1_"}], "]"}], ":=", 
     RowBox[{"rho", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]m", "[", "x1", "]"}], "^", "3"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Functions", " ", "for", " ", "BWR", " ", "EoS"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"RhoTov", "::", "usage"}], "=", 
     "\"\<reverse function to vToRho\>\""}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"RhoTov", "[", "rho_", "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "/", "rho"}], ")"}], "*", 
      RowBox[{"nAvogadro", "/", 
       RowBox[{"10", "^", "27"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"RhoAstToRho", "::", "usage"}], "=", 
     "\"\<reverse function to RhoAstToRho\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"RhoAstToRho", "[", 
      RowBox[{"RhoAst_", ",", "x1_"}], "]"}], ":=", 
     RowBox[{"RhoAst", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]m", "[", "x1", "]"}], "^", "3"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Visualisation", " ", "single", " ", "Method"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"resMF", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{"x1", ",", " ", "y1"}], "}"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"resMV", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
      "vL", ",", " ", "vV", ",", " ", "\[Rho]L", ",", " ", "\[Rho]V", ",", 
       " ", 
       SuperscriptBox["\[Rho]L", "*"], ",", " ", 
       SuperscriptBox["\[Rho]V", "*"]}], "}"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ShowEoSResults", "[", 
      RowBox[{"Method_", ",", "pSim_", ",", "resMF_", ",", "resMV_"}], "]"}], 
     " ", ":=", " ", 
     RowBox[{"Highlighted", "[", 
      RowBox[{"Grid", "[", 
       RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Method", " ", "<>", " ", "\"\< @\>\"", " ", "<>", " ", 
             RowBox[{"ToString", "@", "pSim"}], "<>", " ", "\"\< bar\>\""}], 
            ",", "SpanFromLeft"}], "}"}], ",", "\[IndentingNewLine]", "\t\t", 
          RowBox[{"{", 
           RowBox[{"\"\<\!\(\*SubscriptBox[\(x\), \(1\)]\)\>\"", ",", 
            RowBox[{"resMF", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            "\"\<[mol \!\(\*SuperscriptBox[\(mol\), \(-1\)]\)]\>\""}], "}"}], 
          ",", "\[IndentingNewLine]", "\t\t", 
          RowBox[{"{", 
           RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(1\)]\)\>\"", ",", 
            RowBox[{"resMF", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            "\"\<[mol \!\(\*SuperscriptBox[\(mol\), \(-1\)]\)]\>\""}], "}"}], 
          ",", "\[IndentingNewLine]", "\t\t", 
          RowBox[{"{", 
           RowBox[{"\"\<\!\(\*SuperscriptBox[\(v\), \(liq\)]\)\>\"", ",", 
            RowBox[{"resMV", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            "\"\<[\!\(\*SuperscriptBox[\(dm\), \(3\)]\)/mol]\>\""}], "}"}], 
          ",", "\[IndentingNewLine]", "\t\t", 
          RowBox[{"{", 
           RowBox[{"\"\<\!\(\*SuperscriptBox[\(v\), \(vap\)]\)\>\"", ",", 
            RowBox[{"resMV", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            "\"\<[\!\(\*SuperscriptBox[\(dm\), \(3\)]\)/mol]\>\""}], "}"}], 
          ",", "\[IndentingNewLine]", "\t\t", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\!\(\*SuperscriptBox[\(\[Rho]\), \(\(liq\)\(\\\ \)\)]\)\>\"", 
            ",", " ", 
            RowBox[{"resMV", "[", 
             RowBox[{"[", "3", "]"}], "]"}], ",", 
            "\"\<[N/\!\(\*SuperscriptBox[\(\[CapitalARing]\), \
\(3\)]\)]\>\""}], "}"}], ",", "\[IndentingNewLine]", "\t\t", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\!\(\*SuperscriptBox[\(\[Rho]\), \(\(vap\)\(\\\ \)\)]\)\>\"", 
            ",", " ", 
            RowBox[{"resMV", "[", 
             RowBox[{"[", "4", "]"}], "]"}], ",", 
            "\"\<[N/\!\(\*SuperscriptBox[\(\[CapitalARing]\), \
\(3\)]\)]\>\""}], "}"}], ",", "\[IndentingNewLine]", "\t\t", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\!\(\*SuperscriptBox[\(\[Rho]\), \(\(liq\)\(\\\ \
\)\(*\)\)]\)\>\"", ",", " ", 
            RowBox[{"resMV", "[", 
             RowBox[{"[", "5", "]"}], "]"}], ",", "\"\<[1]\>\""}], "}"}], ",",
           "\[IndentingNewLine]", "\t\t", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\!\(\*SuperscriptBox[\(\[Rho]\), \(\(vap\)\(\\\ \
\)\(*\)\)]\)\>\"", ",", " ", 
            RowBox[{"resMV", "[", 
             RowBox[{"[", "6", "]"}], "]"}], ",", "\"\<[1]\>\""}], "}"}]}], 
         "\[IndentingNewLine]", "\t", "}"}], ",", 
        RowBox[{"Frame", "\[Rule]", "All"}], ",", 
        RowBox[{"Spacings", "->", 
         RowBox[{"{", 
          RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "]"}], "\n", 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Visualisation", " ", "Summary"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plotEoSSummary", "[", "i_", "]"}], ":=", 
    RowBox[{"Highlighted", "[", 
     RowBox[{"Grid", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"{", "\n", "\t", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"\"\<Summary of Estimations @\>\"", "<>", " ", 
                 RowBox[{"ToString", "@", 
                  RowBox[{"pSim", "[", 
                   RowBox[{"[", "i", "]"}], "]"}]}], " ", "<>", " ", 
                 "\"\< bar\>\""}], ",", "Bold"}], "]"}], ",", 
              "SpanFromLeft"}], "}"}], "}"}], ",", "\[IndentingNewLine]", 
           "\t", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", 
             RowBox[{"{", 
              RowBox[{
              "\"\<Method\>\"", ",", 
               "\"\<\!\(\*SubscriptBox[\(x\), \(1\)]\)[mol/mol]\>\"", ",", 
               "\"\<\!\(\*SubscriptBox[\(y\), \(1\)]\)[mol/mol]\>\"", ",", 
               "\"\<\!\(\*SuperscriptBox[\(v\), \
\(liq\)]\)[\!\(\*SuperscriptBox[\(dm\), \(3\)]\)/mol]\>\"", ",", 
               "\"\<\!\(\*SuperscriptBox[\(v\), \
\(vap\)]\)[\!\(\*SuperscriptBox[\(dm\), \(3\)]\)/mol]\>\"", ",", " ", 
               
               "\"\<\!\(\*SuperscriptBox[\(\[Rho]\), \
\(liq\)]\)[N/\!\(\*SuperscriptBox[\(\[CapitalARing]\), \(3\)]\)]\>\"", ",", 
               "\"\<\!\(\*SuperscriptBox[\(\[Rho]\), \
\(vap\)]\)[N/\!\(\*SuperscriptBox[\(\[CapitalARing]\), \(3\)]\)]\>\"", ",", 
               "\"\<\!\(\*SuperscriptBox[\(\[Rho]\), \(\(liq\)\(*\)\)]\)[-]\>\
\"", ",", "\"\<\!\(\*SuperscriptBox[\(\[Rho]\), \(\(vap\)\(*\)\)]\)[-]\>\""}],
               "}"}]}], "}"}], ",", "\[IndentingNewLine]", "\t", 
           RowBox[{"Flatten", "/@", 
            RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Ideal Gas\>\"", ",", 
                RowBox[{"resMFIdealGas", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"resMVIdealGas", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
              "\[IndentingNewLine]", "\t\t", 
              RowBox[{"{", 
               RowBox[{"\"\<Virial Equation\>\"", ",", 
                RowBox[{"resMFVirial", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"resMVVirial", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
              "\[IndentingNewLine]", "\t\t", 
              RowBox[{"{", 
               RowBox[{"\"\<Van der Waals EoS\>\"", ",", 
                RowBox[{"resMFVdWLJ", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"resMVVdWLJ", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
              "\[IndentingNewLine]", "\t\t", 
              RowBox[{"{", 
               RowBox[{"\"\<t-PR-EoS\>\"", ",", 
                RowBox[{"resMFVTPRLJ", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", 
                   RowBox[{"{", 
                    RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
                RowBox[{"resMVVTPRLJ", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
              "\[IndentingNewLine]", "\t\t", 
              RowBox[{"{", 
               RowBox[{"\"\<BWR(Nicolas 1979)\>\"", ",", 
                RowBox[{"resMFNicolas1979", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"resMVNicolas1979", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
              "\[IndentingNewLine]", "\t\t", 
              RowBox[{"{", 
               RowBox[{"\"\<Thol 2016\>\"", ",", 
                RowBox[{"resMFThol2016", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"resMVThol2016", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "}"}]}], 
             "\[IndentingNewLine]", "\t", "}"}]}]}], "\[IndentingNewLine]", 
          "}"}], ",", "1"}], "]"}], ",", 
       RowBox[{"Frame", "\[Rule]", "All"}], ",", 
       RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
       RowBox[{"Spacings", "->", 
        RowBox[{"{", 
         RowBox[{"1", ",", " ", "Automatic"}], "}"}]}]}], "]"}], 
     "]"}]}]}]}]], "Code",
 CellLabel->"In[17]:=",ExpressionUUID->"746c72d9-502f-455e-b7e7-54cd50e23139"]
}, Closed]],

Cell[CellGroupData[{

Cell["Mixture Parameter Functions", "Subsubsubsection",ExpressionUUID->"4b912b8f-47cb-48d0-8af8-cb37ea1d95c3"],

Cell["\<\
Harismiadis, V. I., et al. How good is conformal solutions theory for phase \
equilibrium predictions?: Gibbs ensemble simulations of binary Lennard-Jones \
mixtures. Fluid Phase Equilibria 65 (1991): 1-18.\
\>", "Affiliation",ExpressionUUID->"210def0b-eb5f-4c6d-b789-259dc3acb8e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Calculation", " ", "of", " ", "mixture", " ", "Parameters", " ", 
    "\[Sigma]_m", " ", "and", " ", "\[Epsilon]_m", " ", "with", " ", 
    "\"\<van der Waals one-fluid approximation\>\""}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]m", "[", 
     RowBox[{"x1_", ",", 
      RowBox[{"\[Sigma]ij_", ":", "\[Sigma]"}]}], "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "xvec", "}"}], ",", "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{"xvec", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{"x1", ",", 
          RowBox[{"1", "-", "x1"}]}], "}"}]}], ";", "\n", "\t", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"Sum", "[", "\n", "\t\t", 
            RowBox[{
             RowBox[{
              RowBox[{"xvec", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "*", 
              RowBox[{"xvec", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "*", 
              RowBox[{
               RowBox[{"\[Sigma]ij", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "j"}], "]"}], "]"}], "^", "3"}]}], "\n", 
             "\t", ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", 
               RowBox[{"Length", "@", "component"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "@", "component"}]}], "}"}]}], "]"}], ")"}], 
        "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "3"}], ")"}]}]}]}], " ", 
     RowBox[{"(*", " ", "A", " ", "*)"}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Epsilon]m", "[", 
     RowBox[{"x1_", ",", 
      RowBox[{"\[Sigma]ij_", ":", "\[Sigma]"}], ",", 
      RowBox[{"\[Epsilon]ij_", ":", "\[Epsilon]"}]}], "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "xvec", "}"}], ",", "\n", "\t", 
      RowBox[{
       RowBox[{"xvec", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{"x1", ",", 
          RowBox[{"1", "-", "x1"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
       "\t", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]m", "[", 
          RowBox[{"x1", ",", "\[Sigma]ij"}], "]"}], "^", 
         RowBox[{"-", "3"}]}], "*", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{"Sum", "[", "\[IndentingNewLine]", "\t\t", 
           RowBox[{
            RowBox[{
             RowBox[{"xvec", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "*", 
             RowBox[{"xvec", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "*", 
             RowBox[{"\[Epsilon]ij", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "j"}], "]"}], "]"}], "*", 
             RowBox[{
              RowBox[{"\[Sigma]ij", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "j"}], "]"}], "]"}], "^", "3"}]}], 
            "\[IndentingNewLine]", "\t", ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", 
              RowBox[{"Length", "@", "component"}]}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "@", "component"}]}], "}"}]}], "]"}]}]}]}], " ", 
     RowBox[{"(*", " ", 
      RowBox[{"kcal", "/", "mol"}], " ", "*)"}], "\[IndentingNewLine]", 
     "]"}]}]}]}]], "Code",
 CellLabel->"In[28]:=",ExpressionUUID->"3c52eacc-bb7c-45d5-b165-bad9a91645b3"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Extracting OPLSA - Parameters", "Subsubsection",ExpressionUUID->"a6d2da7d-5a38-4f27-b5d5-ace56d84e065"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Extracting", " ", "OPLSA"}], "-", 
    RowBox[{"Parameters", " ", "from", " ", "Package"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Choose", " ", "combining", " ", "rule", " ", "for", " ", "pair", " ", 
    "parameters"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "ffparamCombiningRule", " ", "=", " ", "\"\<Lorentz-Berthelot\>\""}], 
    ";"}], "  ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Options", ":", " ", "\"\<Lorentz-Berthelot\>\""}], ",", " ", 
     "\"\<Default\>\""}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Switch", "[", 
    RowBox[{
    "ffparamCombiningRule", "\[IndentingNewLine]", "\t", ",", 
     "\"\<Lorentz-Berthelot\>\"", ",", "\[IndentingNewLine]", "\t\t", 
     RowBox[{
      RowBox[{"\[Sigma]", "=", 
       RowBox[{"Table", "[", "\n", "\t\t\t", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"oplsNonBonded", "[", 
              RowBox[{"component", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "+", 
            RowBox[{
             RowBox[{"oplsNonBonded", "[", 
              RowBox[{"component", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "/", "2"}], "\n", 
         "\t\t\t", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "@", "component"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", 
           RowBox[{"Length", "@", "component"}]}], "}"}]}], "\n", "\t\t", 
        "]"}]}], ";", " ", 
      RowBox[{"(*", " ", "A", " ", "*)"}], "\[IndentingNewLine]", "\t\t", 
      RowBox[{"\[Epsilon]", " ", "=", " ", 
       RowBox[{"Table", "[", "\n", "\t\t\t", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"oplsNonBonded", "[", 
             RowBox[{"component", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], "*", 
           RowBox[{
            RowBox[{"oplsNonBonded", "[", 
             RowBox[{"component", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
         "\t\t\t", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "@", "component"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", 
           RowBox[{"Length", "@", "component"}]}], "}"}]}], "\n", "\t\t", 
        "]"}]}], ";"}], " ", 
     RowBox[{"(*", " ", 
      RowBox[{"kcal", "/", "mol"}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
     ",", "_", " ", ",", " ", 
     RowBox[{"(*", 
      RowBox[{"Default", ":", " ", 
       RowBox[{"Good", "-", 
        RowBox[{"Hope", " ", 
         RowBox[{"(", 
          RowBox[{"geometric", " ", "mean"}], ")"}]}]}]}], "*)"}], 
     "\[IndentingNewLine]", "\t\t", 
     RowBox[{
      RowBox[{"\[Sigma]", "=", 
       RowBox[{"Table", "[", "\n", "\t\t\t", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"oplsNonBonded", "[", 
             RowBox[{"component", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], "*", 
           RowBox[{
            RowBox[{"oplsNonBonded", "[", 
             RowBox[{"component", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "\n", "\t\t\t", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "@", "component"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", 
           RowBox[{"Length", "@", "component"}]}], "}"}]}], "\n", "\t\t", 
        "]"}]}], ";", " ", 
      RowBox[{"(*", " ", "A", " ", "*)"}], "\[IndentingNewLine]", "\t\t", 
      RowBox[{"\[Epsilon]", " ", "=", " ", 
       RowBox[{"Table", "[", "\n", "\t\t\t", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"oplsNonBonded", "[", 
             RowBox[{"component", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], "*", 
           RowBox[{
            RowBox[{"oplsNonBonded", "[", 
             RowBox[{"component", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}]}], "]"}], "\n", "\t\t\t", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "@", "component"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", 
           RowBox[{"Length", "@", "component"}]}], "}"}]}], "\n", "\t\t", 
        "]"}]}], ";"}]}], 
    RowBox[{"(*", " ", 
     RowBox[{"kcal", "/", "mol"}], " ", "*)"}], "\[IndentingNewLine]", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Summary", " ", "of", " ", "OPLSA", " ", "Data"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Grid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
      "plotOPLSList", ",", "plotOPLS\[Sigma]Grid", ",", 
       "plotOPLS\[Epsilon]Grid"}], "}"}], "}"}], "]"}]}]}]], "Code",
 CellLabel->"In[30]:=",ExpressionUUID->"814c49a5-6a51-4615-82de-62d43df9668d"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         StyleBox["\<\"OPLSA Data\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         InterpretationBox["\<\"Component \\!\\(\\*RowBox[{\\\"1\\\"}]\\): \
LJ_ref\"\>",
          StringForm["Component ``: ``", 1, "LJ_ref"],
          Editable->False], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         InterpretationBox["\<\"\[Sigma]\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\\!\\(\
\\*RowBox[{\\\"1\\\"}]\\)\"\>",
          StringForm["\[Sigma]````", 1, 1],
          Editable->False], "1.`", "\<\"\[Angstrom]\"\>"},
        {
         InterpretationBox["\<\"\[Epsilon]\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\\!\\\
(\\*RowBox[{\\\"1\\\"}]\\)/kB\"\>",
          StringForm["\[Epsilon]````/kB", 1, 1],
          Editable->False], "0.9999999998192595`", "\<\"K\"\>"},
        {
         InterpretationBox["\<\"Component \\!\\(\\*RowBox[{\\\"2\\\"}]\\): \
LJ_1\"\>",
          StringForm["Component ``: ``", 2, "LJ_1"],
          Editable->False], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         InterpretationBox["\<\"\[Sigma]\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\\!\\(\
\\*RowBox[{\\\"2\\\"}]\\)\"\>",
          StringForm["\[Sigma]````", 2, 2],
          Editable->False], "1.`", "\<\"\[Angstrom]\"\>"},
        {
         InterpretationBox["\<\"\[Epsilon]\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\\!\\\
(\\*RowBox[{\\\"2\\\"}]\\)/kB\"\>",
          StringForm["\[Epsilon]````/kB", 2, 2],
          Editable->False], "0.7499999998644447`", "\<\"K\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"], 
     TagBox[GridBox[{
        {
         StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(i, j\\)]\\)[\
\[Angstrom]]\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["1",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["2",
          StripOnInput->False,
          FontWeight->Bold]},
        {
         StyleBox["1",
          StripOnInput->False,
          FontWeight->Bold], "1.`", "1.`"},
        {
         StyleBox["2",
          StripOnInput->False,
          FontWeight->Bold], "1.`", "1.`"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Center}}},
       GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"], 
     TagBox[GridBox[{
        {
         StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(\[Epsilon]\\), \\(i, \
j\\)]\\)[K]\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["1",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["2",
          StripOnInput->False,
          FontWeight->Bold]},
        {
         StyleBox["1",
          StripOnInput->False,
          FontWeight->Bold], "0.9999999998192595`", "0.8660254036279127`"},
        {
         StyleBox["2",
          StripOnInput->False,
          FontWeight->Bold], "0.8660254036279127`", "0.7499999998644447`"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Center}}},
       GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[32]=",ExpressionUUID->"a8e243f3-3b68-4892-99e8-66df9e21808e"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Experimental Data (Saturation Pressure)", "Section",ExpressionUUID->"6361cf02-790f-48f5-89c8-e7317aea2a0e"],

Cell[CellGroupData[{

Cell["Experimental Data", "Subsubsection",ExpressionUUID->"c9327891-80e0-491f-a0a3-eb7bcebd8e9c"],

Cell[TextData[{
 "This section contains saturation pressure results from pure component \
simulations done by our own GEMC algorithm.\nEntries can be added to the \
association in the following format:\n \t\[OpenCurlyDoubleQuote]ComponentName\
\[CloseCurlyDoubleQuote] -> { { T [K], ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["P",
     FontSlant->"Plain"], "Sat"], TraditionalForm]],ExpressionUUID->
  "97b100b6-c729-4018-bf0d-66c24337c784"],
 " [bar] }, ... }"
}], "Text",ExpressionUUID->"fd113abe-9e83-49dc-acb2-4f22d18541c9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pSatExpLJ", " ", "=", " ", 
   RowBox[{"<|", 
    RowBox[{"(*", " ", 
     RowBox[{"Label", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"T", "[", "K", "]"}], ",", 
          RowBox[{"P", "[", "bar", "]"}]}], "}"}], ",", "..."}], "}"}]}], 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\"\<LJ_ref\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1.00", ",", "3.3384"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1.00", ",", "2.4621"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.75", ",", "0.3606"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.75", ",", 
          RowBox[{"-", "0.1933"}]}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\"\<LJ_1\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1.00", ",", "14.1858"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1.00", ",", "14.1292"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.75", ",", "2.5932"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.75", ",", "2.8578"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.5625", ",", "0.2653"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.5625", ",", "1.2355"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\"\<LJ_2\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1.00", ",", "34.6635"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1.00", ",", "35.3267"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.75", ",", "15.7105"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.75", ",", "15.7187"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.5", ",", "1.6703"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.5", ",", "1.6282"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.38", ",", "0.1834"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.38", ",", 
          RowBox[{"-", "0.0039"}]}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\"\<LJ_3\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1.00", ",", "279.5756"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1.00", ",", "277.4795"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.75", ",", "125.8011"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.75", ",", "127.9776"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.5", ",", "12.7147"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.5", ",", "12.7086"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.38", ",", "1.3320"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.38", ",", 
          RowBox[{"-", "3.9333"}]}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\"\<Methane,2ndV\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"160", ",", "11.9125"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"210", ",", "66.7913"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"280", ",", "157.971"}], "}"}]}], "}"}]}], ",", "\n", 
     RowBox[{"\"\<Ethane,2ndV\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"160", ",", "0.781441"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"210", ",", "3.17729"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"280", ",", "28.545"}], "}"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "|>"}]}], ";"}]], "Code",
 CellLabel->"In[33]:=",ExpressionUUID->"fe828d43-f0d7-47cd-8cdd-a8d8694f0d0a"]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualisation", "Subsubsection",ExpressionUUID->"ed946af3-a5e9-4c23-9256-ac074a8e17e8"],

Cell["\<\
The Experimental Data is compared to the empirical equation from Thol 2016 / \
Saturation pressure for pure LJ-Fluids 
Equation of state is valid for:\t[ 0.5 < T/Tc < 7 ] and [ P/Pc < 500 ]\
\>", "Text",ExpressionUUID->"04590034-7c2d-4bd7-83cb-1d8a43858c2a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "@", 
  RowBox[{"Transpose", "@", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", "\[IndentingNewLine]", "\t", 
       RowBox[{
        RowBox[{"tCrit", " ", "=", " ", 
         RowBox[{"tLJ", "[", 
          RowBox[{"tCritLJ", ",", 
           RowBox[{"\[Epsilon]", "[", 
            RowBox[{"[", 
             RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}]}], 
        RowBox[{"(*", "K", "*)"}], ";", "\[IndentingNewLine]", "\t", 
        RowBox[{"pCrit", " ", "=", " ", 
         RowBox[{"pLJ", "[", 
          RowBox[{"pCritLJ", ",", 
           RowBox[{"\[Epsilon]", "[", 
            RowBox[{"[", 
             RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
           RowBox[{"\[Sigma]", "[", 
            RowBox[{"[", 
             RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}]}], " ", 
        RowBox[{"(*", "bar", "*)"}], ";", "\[IndentingNewLine]", "\t", 
        RowBox[{"Show", "[", 
         RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
          RowBox[{
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"pSatLJ", "[", 
              RowBox[{"t", ",", 
               RowBox[{"\[Sigma]", "[", 
                RowBox[{"[", 
                 RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
               RowBox[{"\[Epsilon]", "[", 
                RowBox[{"[", 
                 RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", 
               RowBox[{"0.5", "*", "tCrit"}], ",", 
               RowBox[{
                RowBox[{"Max", "@", 
                 RowBox[{"{", 
                  RowBox[{"tCrit", ",", 
                   RowBox[{"Max", "@", 
                    RowBox[{
                    RowBox[{"pSatExpLJ", "[", 
                    RowBox[{"[", 
                    RowBox[{"component", "[", 
                    RowBox[{"[", "#", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "1"}], "]"}], "]"}]}]}], "}"}]}], "*",
                 "1.05"}]}], "}"}], "\n", "\t\t\t", ",", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"{", "\"\<Thol 2016\>\"", "}"}]}], ",", 
             RowBox[{"PlotLabel", "\[Rule]", 
              RowBox[{"component", "[", 
               RowBox[{"[", "#", "]"}], "]"}]}], ",", 
             RowBox[{"AxesLabel", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<T [K]\>\"", ",", 
                "\"\<\!\(\*SuperscriptBox[SubscriptBox[\(P\), \(i\)], \
\(s\)]\) [bar]\>\""}], "}"}]}], "\n", "\t\t\t", ",", 
             RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
             RowBox[{"ImageSize", "->", "Medium"}]}], "\n", "\t\t", "]"}], 
           ",", "\n", "\t\t", 
           RowBox[{"ListPlot", "[", 
            RowBox[{
             RowBox[{"pSatExpLJ", "[", 
              RowBox[{"[", 
               RowBox[{"component", "[", 
                RowBox[{"[", "#", "]"}], "]"}], "]"}], "]"}], "\n", "\t\t\t", 
             ",", 
             RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}], ",", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"{", "\"\<Simulation Data\>\"", "}"}]}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", "Red", "}"}]}]}], "\n", "\t\t", "]"}], ",", "\n", 
           "\t\t", 
           RowBox[{"ListPlot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"{", 
               RowBox[{"tCrit", ",", "pCrit"}], "}"}], "}"}], ",", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"{", "\"\<Critical point\>\"", "}"}]}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", "Green", "}"}]}]}], "]"}]}], "\[IndentingNewLine]",
           "\t", "}"}], "]"}]}], "\[IndentingNewLine]", ")"}], " ", "&"}], "/@",
      " ", 
     RowBox[{"Range", "@", 
      RowBox[{"Length", "@", "component"}]}]}], "}"}]}]}]], "Code",
 CellLabel->"In[34]:=",ExpressionUUID->"e6304f55-8b96-463b-a2c5-aa9c7d51bcd9"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{
       GraphicsBox[{{{{{}, {}, 
            TagBox[{
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[1.6]], 
              LineBox[CompressedData["
1:eJwBsQNO/CFib1JlAgAAADoAAAACAAAAQ9zfWbge5T8VC26ny3u6P/BE1k6L
IOU/N03GVgWUuj+ercxDXiLlP3WiH5ZQrLo/+H65LQQm5T9iXbzoG926P64h
kwFQLeU/hQtp2YY/uz8aZ0ap5zvlP5m/F861B7w/8vGs+BZZ5T8jRHCjt6W9
P6EHepd1k+U//QnYgSeNwD9gEJTTb5XlP/3O+/PRnMA/IBmuD2qX5T+jRCUU
iKzAP6Aq4odem+U/kFbFdhfMwD+gTUp4R6PlP21gLm/DC8E/oJMaWRmz5T+4
7u2AVY3BP54fuxq90uU/yJ5eFI2Zwj+aN/ydBBLmP1pSB+ql18Q/x4UwnTCI
5j8EMmmHxZfJP0qU0y8L/OY/KM4T6pEHzz9op16Lt3nnP+QCvxCc8tI/utib
3wDv5z8BVP3sDafWP6cOwfwbbug/ExX2x5JE2z/qBFWt5eroP7+5vFM2O+A/
YRmbVkxf6T+dUHz34PniP3MyyciE3ek/FPKqdAhV5j+4aakzWlPqP02+vKA6
2ek/U2H4Md7G6j8C0YcJL67tP4ldL/kzROs/Eo1DKxEm8T/zdxi5JrnrP13o
wCopiPM/+JbpQes37D+hMe9zYGH2P1N2KV5etOw/iijB+PR1+T/icxtzbijt
PzNPpy3gmfw/DHb1UFCm7T9YrEvLNigAQGqWgSfPG+4/4lKTKogKAkBju/XG
H5vuP7M3+/NeQQRAsqDY+R4Y7z+coPRUq5wGQDSkbSW7jO8/eWDWshj7CEAp
VvWMlAXwP/nUOfAfvgtAUumMA5pA8D/T38OsloIOQKbc28N2evA/16n3lBK0
EEBH0p5oPLnwP5jkW7mRYRJAAte6idDz8D+uYAwM1wwUQAveSo9NM/E/19i8
uML5FUA/RZLeoXHxP6wc+cvd/BdAjLsyqsSr8T93vcJLC/oZQCc0R1rQ6vE/
YWrgA4RCHEDcu7SGqiXyP1sQDJ1Pgx5AvKPZ/Ftf8j/AqatiZ2sgQOmNclf2
nfI/xrMUfsi/IUAwh2QuX9jyP5tvf+YFDiNAxYLK6bAX8z/R8E2rA4skQHSN
iSHRUvM/evUn2MAAJkBO+P+iyIzzPzaxwWR1gCdAdWXqCKnL8z+Nd8SRhjQp
QLbhLetXBvQ/iVLXqafeKkBEYOWx70X0P47PLCvpwSxA/j5Uwl6E9D/ooGbB
yLIuQNEsHE+cvvQ/bi7NMIpLMEDyHFjAwv30P11fOugQXjFAygu+kcUd9T+N
gbdQdO4xQL0g1HU=
               "]], 
              LineBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAAdP4YEqsf9T+PD5saJ/cxQJN7OeWD
cvU/UTupv4N9M0BG3fkAObH1P7X27dRJsjRAE04Tmbzr9T/2y4111tw1QI4o
99/B7PU/jIhSgCLiNUAKA9smx+31P3LXBVVv5zVAAriitNHv9T+WvUxcC/I1
QPAhMtDm8/U/FhTr4kwHNkDO9VAHEfz1Pwuv3NT1MTZAip2OdWUM9j9LjqJu
34c2QAZ4crxqDfY/k0D/wESNNkCCUlYDcA72P0so6t2qkjZAeQcekXoQ9j/4
4X13eZ02QGhxrayPFPY/e3cjKiCzNkBFRczjuRz2P8nCkpGT3jZAwB+wKr8d
9j9dSRCPBeQ2QDz6k3HEHvY/ugtoV3jpNkA0r1v/ziD2P2XuuEhg9DZAIhnr
GuQk9j+8TWKuOQo3QJ7zzmHpJfY/e+UzA7IPN0AazrKo7ib2P87OBCMrFTdA
EYN6Nvko9j9y8rbDHyA3QIxdXn3+KfY/9lShRJslN0AIOELEAyv2P0tZnZAX
KzdAhBImCwks9j9yja+nlDA3QADtCVIOLfY//nzciRI2N0AZYcLG
               "]]}, 
             Annotation[#, 
              "Charting`Private`Tag$47417#1"]& ], {}}}, {}}, {{}, {{{
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[1, 0, 0]], 
             GeometricTransformationBox[
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox[
                  GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], 
                  GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}, StripOnInput -> False], 
                 TraditionalForm]], {0., 0.}, Automatic, 
               Scaled[9.75]], {{{1., 3.3384}}, {{1., 2.4621}}, {{0.75, 
              0.3606}}, {{0.75, -0.1933}}}]}}}, {{}, {}}}, {{}, {{{
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[0, 1, 0]], 
             
             PointBox[{{1.3199999999999998`, 17.948437000000002`}, {
              1.3199999999999998`, 17.948437000000002`}}]}}}, {{}, {}}}}, {
        DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
         AxesOrigin -> {0.6600000148163279, 0}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, DisplayFunction -> Identity, 
         PlotRangePadding -> {{
            Scaled[0.02], 
            Scaled[0.02]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
         DisplayFunction -> Identity, AspectRatio -> 
         NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox[
            TagBox["\"T [K]\"", HoldForm], TraditionalForm], 
           FormBox[
            TagBox[
            "\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \\(i\\)], \
\\(s\\)]\\) [bar]\"", HoldForm], TraditionalForm]}, 
         AxesOrigin -> {0.6600000148163264, 0}, DisplayFunction :> Identity, 
         Frame -> {{False, False}, {False, False}}, 
         FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> Medium, 
         Method -> {
          "DefaultBoundaryStyle" -> Automatic, 
           "DefaultGraphicsInteraction" -> {
            "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
             "Effects" -> {
              "Highlight" -> {"ratio" -> 2}, 
               "HighlightPoint" -> {"ratio" -> 2}, 
               "Droplines" -> {
                "freeformCursorMode" -> True, 
                 "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
           "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
           None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
               (Identity[#]& )[
                Part[#, 1]], 
               (Identity[#]& )[
                Part[#, 2]]}& ), "CopiedValueFunction" -> ({
               (Identity[#]& )[
                Part[#, 1]], 
               (Identity[#]& )[
                Part[#, 2]]}& )}}, PlotLabel -> 
         FormBox["\"LJ_ref\"", TraditionalForm], PlotRange -> {All, All}, 
         PlotRangeClipping -> True, 
         PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}},
          Ticks -> {Automatic, Automatic}}], 
       FormBox[
        TagBox[
         GridBox[{{
            FormBox[
             
             TemplateBox[{"\"Thol 2016\""}, "LineLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"LineLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    "}"}], ",", 
                   RowBox[{"{", #, "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}, {
            FormBox[
             
             TemplateBox[{"\"Simulation Data\""}, "PointLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
                   RowBox[{"{", #, "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], "}"}]}], ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", "False", "}"}]}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}, {
            FormBox[
             
             TemplateBox[{"\"Critical point\""}, "PointLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 1, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
                   RowBox[{"{", #, "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", "False", "}"}]}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]},
    {
     TemplateBox[{
       GraphicsBox[{{{{{}, {}, 
            TagBox[{
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[1.6]], 
              LineBox[CompressedData["
1:eJwBoQNe/CFib1JlAgAAADkAAAACAAAAarEKhxSu3z+GHxm/2NyzP7kxSHje
sN8/2NhW1V3vsz8IsoVpqLPfP5CdBZvwAbQ/prIATDy53z+2KjpRPye0P+Kz
9hBkxN8/vSH+MIJytD9btuKas9rfP3v3uQOkC7U/pl1dV6kD4D/DtdiAiki2
P5ZiNWtIMOA/khDG53zuuD+2zJtqyzHgPztTShWFBrk/1zYCak4z4D9I6GmB
nx65PxgLz2hUNuA/sJYEPAtPuT+as2hmYDzgP9jL60i/sLk/nQScYXhI4D+T
IiY7one6P6SmAlioYOA/VSTtxZcTvD+y6s9ECJHgP5xOkvRqhr8/ht6by17r
4D/ScxiSSWzDP+ju1qvvQ+E/xU4gfW6fxz+Fffw9AqThP/BfkoFd8Mw/2XdT
fav94T+ifygTGljRP2nwlG7WXuI/sLTFSp3u1D+HhUW5O77iP4c3EaBB+tg/
XIYnsTcX4z9rQesMVULdP2wF9Fq1d+M/FjoICCxA4T808PGxydHjP5lx8/QZ
AOQ/ivdeYhgq5D+QwDJVAADnPxt9tsToieQ/v1rYTiqe6j9jbj/UT+PkP8ca
jBMoW+4/592ylThE5T9+byvW+GnxP/lplbBbo+U/COL1z2/V8z/CYal4Ffzl
P9pfAFBeTfY/xten8lBc5j/59ZeuAzn5P4K51xkjtuY/brHWjCcw/D95GfLy
dhfnP5DceALGrP8//pV7JQV35z9YLUIVoLEBQDp+NgUq0Oc/0UzpzYWPA0Cx
5NuW0DDoP2sVe/7nvAVA4Lay1Q2L6D8MJgR+nOsHQJ2l+G2F4+g/YdxNT5Y0
CkCVEim4fkPpP2LqjmJk2gxAROuKrw6d6T9uw/1723wPQC9C11gg/uk/YI7P
kJFDEUCotZJbbF3qP0ow7jJQ2hJA2JR/C0+26j9f4pmodGwUQEPyVm2zFus/
182tBSY6FkBmu198rnDrP7983g3bARhAF6HX5OPI6z9yo449adgZQAMFOv+a
KOw/IqHiI2zyG0Cm1M3G6IHsP+1NkFnPAh5AhSJMQLji7D8Ijd9vmS4gQBvc
+2YePe0/02v77htWIUA/shrnvpXtP69OSFSNhSJAngYkGeH17T8vt+cXet4j
QLXGXviZT+4/cYfTfaEvJUAHBYSJ1LDuP4BTeMQfriZA518YdEkQ7z+9YiQv
oDcoQH4m3gtVae8/8es6IpK3KUBtAA5VoazvP7mzf1KO5SpAI5jDog==
               "]], 
              LineBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABsAAAACAAAA8460oIev7z8cbAjm2vIqQO0NOCYD
EvA/1ZtGe+MWLUB5dGBOMj7wP2pV3o4wyC5AIxp+TyJu8D+9B+Dxy1cwQKl1
NKfdmvA/ze4C6F5DMUCcrb5jpZvwP7/4JseMRzFAjuVIIG2c8D9KfXREu0sx
QHRVXZn8nfA/dpOaGRpUMUBANYaLG6HwPwTReC7fZDFA1vTXb1mn8D/cCaYF
h4YxQAR0ezjVs/A/wwGhgk3KMUD3qwX1nLTwP5KK4y2PzjFA6uOPsWS18D9n
wMB30dIxQM9TpCr0tvA/ythY51fbMUCaM80cE7rwPxTbXjZs7DFAMfMeAVHA
8D8w8LSWsg4yQCQrqb0YwfA/zNA3Lf4SMkAWYzN64MHwP78bi2JKFzJA/NJH
82/D8D/lHrCp5B8yQMiycOWOxvA/UbZPqiAxMkC76vqhVsfwP9bSsTdxNTJA
riKFXh7I8D9Vhv5jwjkyQJOSmdetyfA/mqVkmWZCMkCGyiOUdcrwP6SGhKK5
RjJAeAKuUD3L8D/x6JtKDUsyQGs6OA0FzPA/uwKukWFPMkBecsLJzMzwPx0I
vne2UzJApXDUIQ==
               "]]}, 
             Annotation[#, 
              "Charting`Private`Tag$48014#1"]& ], {}}}, {}}, {{}, {{{
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[1, 0, 0]], 
             GeometricTransformationBox[
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox[
                  GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], 
                  GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}, StripOnInput -> False], 
                 TraditionalForm]], {0., 0.}, Automatic, 
               Scaled[9.75]], {{{1., 14.1858}}, {{1., 14.1292}}, {{0.75, 
              2.5932}}, {{0.75, 2.8578}}, {{0.5625, 0.2653}}, {{0.5625, 
              1.2355}}}]}}}, {{}, {}}}, {{}, {{{
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[0, 1, 0]], 
             
             PointBox[{{0.99, 13.46132775}, {0.99, 
              13.46132775}}]}}}, {{}, {}}}}, {
        DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
         AxesOrigin -> {0.4950000113265317, 0}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, DisplayFunction -> Identity, 
         PlotRangePadding -> {{
            Scaled[0.02], 
            Scaled[0.02]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
         DisplayFunction -> Identity, AspectRatio -> 
         NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox[
            TagBox["\"T [K]\"", HoldForm], TraditionalForm], 
           FormBox[
            TagBox[
            "\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \\(i\\)], \
\\(s\\)]\\) [bar]\"", HoldForm], TraditionalForm]}, 
         AxesOrigin -> {0.4950000113265306, 0}, DisplayFunction :> Identity, 
         Frame -> {{False, False}, {False, False}}, 
         FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> Medium, 
         Method -> {
          "DefaultBoundaryStyle" -> Automatic, 
           "DefaultGraphicsInteraction" -> {
            "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
             "Effects" -> {
              "Highlight" -> {"ratio" -> 2}, 
               "HighlightPoint" -> {"ratio" -> 2}, 
               "Droplines" -> {
                "freeformCursorMode" -> True, 
                 "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
           "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
           None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
               (Identity[#]& )[
                Part[#, 1]], 
               (Identity[#]& )[
                Part[#, 2]]}& ), "CopiedValueFunction" -> ({
               (Identity[#]& )[
                Part[#, 1]], 
               (Identity[#]& )[
                Part[#, 2]]}& )}}, PlotLabel -> 
         FormBox["\"LJ_1\"", TraditionalForm], PlotRange -> {All, All}, 
         PlotRangeClipping -> True, 
         PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}},
          Ticks -> {Automatic, Automatic}}], 
       FormBox[
        TagBox[
         GridBox[{{
            FormBox[
             
             TemplateBox[{"\"Thol 2016\""}, "LineLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"LineLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    "}"}], ",", 
                   RowBox[{"{", #, "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}, {
            FormBox[
             
             TemplateBox[{"\"Simulation Data\""}, "PointLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
                   RowBox[{"{", #, "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], "}"}]}], ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", "False", "}"}]}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}, {
            FormBox[
             
             TemplateBox[{"\"Critical point\""}, "PointLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 1, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], "}"}], ",", 
                   RowBox[{"{", #, "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", "False", "}"}]}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[34]=",ExpressionUUID->"d245f750-c10c-43f6-b19b-12dfaab3a689"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["State Definition", "Section",ExpressionUUID->"59eb7bb5-0e65-4667-80be-c5bfd686a8a6"],

Cell[CellGroupData[{

Cell["Simulation Temperature", "Subsection",ExpressionUUID->"8046a70d-719f-4065-b5de-306485a649bd"],

Cell[CellGroupData[{

Cell["Normal Boiling Temperature", "Subsubsection",ExpressionUUID->"e33793c7-072f-4af9-993c-603c55a73411"],

Cell[TextData[{
 "Calculation of the normal boiling points using the Thol2016 EoS [ ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     StyleBox["P",
      FontSlant->"Plain"], "Sat"], "(", 
    SubscriptBox[
     StyleBox["T",
      FontSlant->"Plain"], "Boil"], ")"}], TraditionalForm]],ExpressionUUID->
  "b1c48fbf-908f-41e5-ba3a-0ab31a71d8df"],
 " = 1 bar ]\nThese can be used as a reference for choosing the simulation \
temperature"
}], "Text",ExpressionUUID->"35f95a9c-f9a0-4512-8140-806e6733878d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tBoilVec", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"t", "  ", "/.", " ", 
       RowBox[{"FindRoot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"pSatLJ", "[", 
           RowBox[{"t", ",", 
            RowBox[{"\[Sigma]", "[", 
             RowBox[{"[", 
              RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
            RowBox[{"\[Epsilon]", "[", 
             RowBox[{"[", 
              RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], "-", "1"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", 
           RowBox[{
            RowBox[{"\[Epsilon]", "[", 
             RowBox[{"[", 
              RowBox[{"#", ",", "#"}], "]"}], "]"}], "/", 
            RowBox[{"(", 
             RowBox[{"rCalor", "*", 
              RowBox[{"10", "^", 
               RowBox[{"-", "3"}]}]}], ")"}]}]}], "}"}]}], "]"}]}], ")"}], 
     " ", "&"}], "/@", " ", 
    RowBox[{"Range", "@", 
     RowBox[{"Length", "@", "component"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"PlotBoilingTemperatures", "[", "]"}]}], "Code",
 CellLabel->"In[35]:=",ExpressionUUID->"fb8be027-a311-411f-939c-88e1c493c1d9"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"Normal Boiling Temperature\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
    {
     StyleBox["\<\"Component\"\>",
      StripOnInput->False,
      FontWeight->Bold], 
     StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(T\\), \\(Boil\\)]\\) [K]\"\>",
      StripOnInput->False,
      FontWeight->Bold], 
     StyleBox["\<\"\\!\\(\\*SubsuperscriptBox[\\(T\\), \\(Boil\\), \
\\(*\\)]\\)[1]\"\>",
      StripOnInput->False,
      FontWeight->Bold]},
    {"\<\"LJ_ref\"\>", "0.8446665935886027`", "0.8446665935886027`"},
    {"\<\"LJ_1\"\>", "0.6572363708076919`", "0.6572363708076919`"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[36]=",ExpressionUUID->"d44d4a41-c7ea-4b93-a149-9b92f3708d33"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Temperature Input in LJ-reduced values", "Subsubsection",ExpressionUUID->"4cce4dfc-f1ee-4112-9b38-1f83abddcde6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tSimAst", "=", "1.00"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    SuperscriptBox["T", "*"], "[", "1", "]"}], " ", "*)"}]}]], "Input",
 Background->RGBColor[1, 1, 0],
 CellLabel->"In[37]:=",ExpressionUUID->"f4970a45-6cd4-4d3b-b256-f83a315483db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"calculation", " ", "of", " ", "caloric", " ", "values"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"tSim", " ", "=", " ", 
    RowBox[{"tLJ", "[", 
     RowBox[{"tSimAst", ",", 
      RowBox[{"\[Epsilon]", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", "K", " ", "*)"}]}]], "Code",
 CellLabel->"In[38]:=",ExpressionUUID->"7daf9ede-01b5-4474-9977-477c006d1e1d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Temperature Input in absolute values (Do not Execute!)", "Subsubsection",ExpressionUUID->"71764eec-15bf-4c28-bff3-0c8bf6b6b70d"],

Cell["\<\
Do not execute this section if the input is done in LJ-reduced values!\
\>", "Text",ExpressionUUID->"e34dd273-3e43-41e6-b562-125917123bb2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tSim", " ", "=", " ", "1.0"}], ";"}], " ", 
  RowBox[{"(*", " ", "K", " ", "*)"}]}]], "Code",
 Background->RGBColor[
  1, 1, 0],ExpressionUUID->"f3dd02ce-2ee5-4034-bb93-3ac0970f138a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"calculation", " ", "of", " ", "LJ"}], "-", 
    RowBox[{"reduced", " ", "values"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"tSimAst", " ", "=", " ", 
    RowBox[{
     RowBox[{"tSim", "/", 
      RowBox[{"\[Epsilon]", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], " ", "*", 
     RowBox[{"(", 
      RowBox[{"rCalor", "*", 
       RowBox[{"10", "^", 
        RowBox[{"-", "3"}]}]}], ")"}]}]}], ";"}]}]], "Code",
 CellLabel->
  "In[133]:=",ExpressionUUID->"af9f69ca-f2c5-4a3f-ac12-5abf59dd0b49"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simulation Pressure", "Subsection",ExpressionUUID->"97574ac2-997a-45d1-a2b2-6da0b07aa78b"],

Cell[CellGroupData[{

Cell["Saturation Pressure at Simulation Temperature", "Subsubsection",ExpressionUUID->"11179285-7135-416c-8a31-8d6c37b6f29c"],

Cell[TextData[{
 "Calculation of the saturation pressure (",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["P",
     FontSlant->"Plain"], "Sat"], TraditionalForm]],ExpressionUUID->
  "9ac4c151-7218-4322-b039-247cf235fb08"],
 ") using the Thol2016 EoS\nThese can be used as a reference for choosing the \
simulation pressure"
}], "Text",ExpressionUUID->"dba1cf52-1d91-4e26-9d36-94bcab3ed342"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pSatVec", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"pSatLJ", "[", 
      RowBox[{"tSim", ",", 
       RowBox[{"\[Sigma]", "[", 
        RowBox[{"[", 
         RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
       RowBox[{"\[Epsilon]", "[", 
        RowBox[{"[", 
         RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], "/@", 
    " ", 
    RowBox[{"Range", "[", 
     RowBox[{"Length", "[", "component", "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"PlotSaturationPressure", "[", "]"}]}], "Code",
 CellLabel->"In[39]:=",ExpressionUUID->"35d5b3cb-c4c0-4e7d-9f00-3e3c9b97900d"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"Saturation Pressure at T = 1. K\"\>",
      StripOnInput->False,
      FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
    {
     StyleBox["\<\"Component\"\>",
      StripOnInput->False,
      FontWeight->Bold], 
     StyleBox["\<\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(Sat\\)]\\)[bar]\"\>",
      StripOnInput->False,
      FontWeight->Bold], 
     StyleBox["\<\"\\!\\(\\*SuperscriptBox[\\(P\\), \
\\(\\(Sat\\)\\(*\\)\\)]\\)[1]\"\>",
      StripOnInput->False,
      FontWeight->Bold]},
    {"\<\"LJ_ref\"\>", "3.4363212982454816`", "0.024889173846832046`"},
    {"\<\"LJ_1\"\>", "14.208222749878903`", "0.10290973846270053`"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[40]=",ExpressionUUID->"9a0df94b-d33b-46fd-82d7-7dce07fc32ac"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pressure Input in LJ-reduced values", "Subsubsection",ExpressionUUID->"ec9b8309-84c6-4b45-98e9-08f52a8cce91"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pSimAst", "=", 
    RowBox[{"{", 
     RowBox[{"0.045", ",", "0.060", ",", "0.075"}], "}"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["P", "*"], "[", "1", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
     "one", " ", "entry", " ", "for", " ", "each", " ", "simulation", " ", 
      "point"}], ")"}]}], "*)"}]}]], "Input",
 Background->RGBColor[1, 1, 0],
 CellLabel->"In[43]:=",ExpressionUUID->"aa9cd368-5104-4825-ab43-a3c94e721439"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"calculation", " ", "of", " ", "caloric", " ", "values"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"pSim", " ", "=", " ", 
    RowBox[{"pLJ", "[", 
     RowBox[{"pSimAst", ",", 
      RowBox[{"\[Epsilon]", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
      RowBox[{"\[Sigma]", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", "bar", " ", "*)"}]}]], "Code",
 CellLabel->"In[44]:=",ExpressionUUID->"3c63443a-d112-415f-afee-5444bec0327d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pressure Input in absolute values (Do not Execute!)", "Subsubsection",ExpressionUUID->"ae7778d3-4afb-4dda-aa92-125e4c15a921"],

Cell["\<\
Do not execute this section if the input is done in LJ-reduced values!\
\>", "Text",ExpressionUUID->"460a9236-60f9-4370-8902-c3760f756fc1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pSim", " ", "=", " ", 
    RowBox[{"{", "3.6", "}"}]}], ";"}], " ", 
  RowBox[{"(*", " ", "bar", " ", "*)"}]}]], "Code",
 Background->RGBColor[1, 1, 0],
 CellLabel->
  "In[677]:=",ExpressionUUID->"365da29f-99f8-47a3-bef9-7b6857794877"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"calculation", " ", "of", " ", "LJ"}], "-", 
    RowBox[{"reduced", " ", "values"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"pSimAst", " ", "=", " ", 
    RowBox[{"pSim", "*", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Sigma]", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], "^", "3"}], ")"}], "/", 
       RowBox[{"\[Epsilon]", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], " ", "/", 
      RowBox[{"10", "^", "30"}]}], " ", "*", 
     RowBox[{
      RowBox[{"nAvogadro", " ", "/", "4184"}], " ", "/", 
      RowBox[{"10", "^", 
       RowBox[{"-", "5"}]}]}]}]}], ";"}]}]], "Code",
 CellLabel->
  "In[678]:=",ExpressionUUID->"e2a76c7e-3b38-4024-8dd9-3907e6c1f1b1"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary", "Subsection",ExpressionUUID->"74d5afbb-8993-42bf-a337-8c9ff3eacc9c"],

Cell["\<\
Check the specified simulation temperature and pressure (multiple pressure \
points can be estimated at the same temperature)\
\>", "Text",ExpressionUUID->"d587ee67-2fa4-4cef-8224-f4dfafcd6b6a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotInputSummary", "[", "]"}]], "Code",
 CellLabel->"In[45]:=",ExpressionUUID->"642bfd0f-f336-4d41-ae0e-a306ab212c4c"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         StyleBox["\<\"Summary of Input\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Symbol\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Value\"\>",
          StripOnInput->False,
          FontWeight->Bold], 
         StyleBox["\<\"Unit\"\>",
          StripOnInput->False,
          FontWeight->Bold]},
        {
         StyleBox["\<\"LJ-reduced units\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {"\<\"\\!\\(\\*SuperscriptBox[\\(T\\), \\(*\\)]\\)\"\>", 
         "1.`", "\<\"1\"\>"},
        {"\<\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(*\\)]\\)\"\>", 
         TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0.045`", "0.06`", "0.075`"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}],
          Function[BoxForm`e$, 
           MatrixForm[BoxForm`e$]]], "\<\"1\"\>"},
        {
         StyleBox["\<\"Caloric Units\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {"\<\"T\"\>", "0.9999999999999998`", "\<\"K\"\>"},
        {"\<\"P\"\>", 
         TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"6.212920499999999`", "8.283894`", "10.3548675`"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}],
          Function[BoxForm`e$, 
           MatrixForm[BoxForm`e$]]], "\<\"bar\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxFrame->{"RowsIndexed" -> {1 -> True, 3 -> True, 6 -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{Automatic}}}],
      "Grid"], 
     TagBox[GridBox[{
        {
         StyleBox["\<\"OPLS Parameter\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {"\<\"Combining Rule:\"\>", "\<\"Lorentz-Berthelot\"\>", 
         "\[SpanFromLeft]"},
        {
         StyleBox["\<\"Component 1: LJ_ref\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {"\<\"\[Sigma]11\"\>", "1.`", "\<\"\[Angstrom]\"\>"},
        {"\<\"\[Epsilon]11/kB\"\>", "0.9999999998192595`", "\<\"K\"\>"},
        {
         StyleBox["\<\"Component 2: LJ_1\"\>",
          StripOnInput->False,
          FontWeight->Bold], "\[SpanFromLeft]", "\[SpanFromLeft]"},
        {"\<\"\[Sigma]22\"\>", "1.`", "\<\"\[Angstrom]\"\>"},
        {"\<\"\[Epsilon]22/kB\"\>", "0.7499999998644447`", "\<\"K\"\>"}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxFrame->{"RowsIndexed" -> {1 -> True, 3 -> True, 6 -> True}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{0.5}}}],
      "Grid"]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Rows" -> {{Top}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{5}}}],
  "Grid"]], "Output",
 CellLabel->"Out[45]=",ExpressionUUID->"4b23c464-2669-4f41-a71e-76c0ba6d0096"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Estimation of molar fraction and molar density with EoS", "Section",ExpressionUUID->"231750c2-17fb-447a-b50a-8257a3826e66"],

Cell["\<\
The estimation of the VLE for binary mixtures of LJ-fluids has been \
implemented with multiple EoS.
Some EoS can not predict every quantity of the simulation point (e.g.: the \
Ideal Gas calculation can only predict the vapor molar volume)

LJ-Parameters of the first component are used for reduced values of the \
pressure and mixture parameters are used for reduction of the density.\
\>", "Text",ExpressionUUID->"04258fe4-8655-4a52-80c1-53569f3fa983"],

Cell[CellGroupData[{

Cell["Raoult-Dalton / Ideal Gas", "Subsection",ExpressionUUID->"a0b0b673-2f8d-4e73-8ee4-e86bbb2d1ddf"],

Cell["\<\
To estimate the molar fraction, Rault\[CloseCurlyQuote]s Law is used to \
calculate the fugacity/partial pressure of the liquid phase.
The ideal gas equation can only be used to estimate the vapor molar volume.
(saturation pressure is calculated with the Thol2016 EoS)\
\>", "Text",ExpressionUUID->"8c0283b3-ada5-49ba-9d29-95c5f00a6071"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"6870c652-16e9-4999-b73b-d786b347fc0d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CalculateMoleFracIdealGas", "[", 
     RowBox[{"tSim_", ",", "pSim_", ",", "\[Sigma]_", ",", "\[Epsilon]_"}], 
     "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"piSat", ",", "x1", ",", "y1"}], "}"}], ",", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{"piSat", " ", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"pSatLJ", "[", 
           RowBox[{"tSim", ",", 
            RowBox[{"\[Sigma]", "[", 
             RowBox[{"[", 
              RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
            RowBox[{"\[Epsilon]", "[", 
             RowBox[{"[", 
              RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], "/@",
          " ", 
         RowBox[{"Range", "[", "2", "]"}]}]}], ";", " ", 
       RowBox[{"(*", "bar", "*)"}], "\n", "\t", 
       RowBox[{"x1", " ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"pSim", "-", 
           RowBox[{
           "piSat", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
          ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
           "piSat", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
           "-", 
           RowBox[{
           "piSat", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
          ")"}]}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"mol", " ", 
         SuperscriptBox["mol", 
          RowBox[{"-", "1"}]]}], " ", "*)"}], "\n", "\t", 
       RowBox[{"y1", " ", "=", " ", 
        RowBox[{"x1", " ", "*", " ", 
         RowBox[{
          RowBox[{
          "piSat", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
          "/", "pSim"}]}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"mol", " ", 
         SuperscriptBox["mol", 
          RowBox[{"-", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
       RowBox[{"Return", "[", 
        RowBox[{"{", 
         RowBox[{"x1", ",", "y1"}], "}"}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], "\n"}], "\n", 
 RowBox[{
  RowBox[{"CalculateMolarVolumeIdealGas", "[", 
   RowBox[{"tSim_", ",", "pSim_", ",", "y1_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vV", ",", "rhoV", ",", "rhoVAst"}], "}"}], ",", 
    "\[IndentingNewLine]", "\t", 
    RowBox[{
     RowBox[{"vV", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"rJoule", "/", "100."}], ")"}], "*", 
       RowBox[{"tSim", "/", "pSim"}]}]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       SuperscriptBox["dm", "3"], " ", 
       SuperscriptBox["mol", 
        RowBox[{"-", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
     RowBox[{"rhoV", " ", "=", " ", 
      RowBox[{"vToRho", "@", "vV"}]}], ";", 
     RowBox[{"(*", " ", 
      RowBox[{"N", " ", "/", " ", 
       RowBox[{"\[Angstrom]", "^", "3"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "\t", 
     RowBox[{"rhoVAst", " ", "=", " ", 
      RowBox[{"RhoToRhoAst", "[", 
       RowBox[{"rhoV", ",", "y1"}], "]"}]}], ";", "\[IndentingNewLine]", "\t", 
     RowBox[{"{", 
      RowBox[{
      "\"\<-\>\"", ",", "vV", ",", "\"\<-\>\"", ",", "rhoV", ",", "\"\<-\>\"",
        ",", "rhoVAst"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}]}], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[85]:=",ExpressionUUID->"6727b581-8a6c-4cc9-ba31-2e0787570caf"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Calculation", " ", "of", " ", "molar", " ", "fraction", " ", 
    RowBox[{"(", "MF", ")"}], " ", "and", " ", "molar", " ", "volume", " ", 
    RowBox[{"(", "MV", ")"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"resMFIdealGas", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"CalculateMoleFracIdealGas", "[", 
        RowBox[{"tSim", ",", "#", ",", "\[Sigma]", ",", "\[Epsilon]"}], "]"}],
        " ", "&"}], "/@", " ", "pSim"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"resMVIdealGas", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"CalculateMolarVolumeIdealGas", "[", 
        RowBox[{"tSim", ",", 
         RowBox[{"pSim", "[", 
          RowBox[{"[", "#", "]"}], "]"}], ",", 
         RowBox[{"resMFIdealGas", "[", 
          RowBox[{"[", 
           RowBox[{"#", ",", "2"}], "]"}], "]"}]}], "]"}], " ", "&"}], "/@", 
      " ", 
      RowBox[{"Range", "@", 
       RowBox[{"Length", "@", "pSim"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Grid", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"ShowEoSResults", "[", 
         RowBox[{"\"\<Ideal Gas\>\"", ",", 
          RowBox[{"pSim", "[", 
           RowBox[{"[", "#", "]"}], "]"}], ",", 
          RowBox[{"resMFIdealGas", "[", 
           RowBox[{"[", "#", "]"}], "]"}], ",", 
          RowBox[{"resMVIdealGas", "[", 
           RowBox[{"[", "#", "]"}], "]"}]}], "]"}], ")"}], " ", "&"}], "/@", 
      " ", 
      RowBox[{"Range", "@", 
       RowBox[{"Length", "@", "pSim"}]}]}], " ", "}"}]}]}]}]], "Code",
 CellLabel->"In[87]:=",ExpressionUUID->"3c1fe33f-82d6-4728-8270-73bf7b5feb50"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"Ideal Gas @6.21292 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", 
           "0.742236854447505`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", 
           "0.4105258245748828`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", "\"-\"", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.013382535021975573`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "\"-\"", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.04500000000082938`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "\"-\"", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.04500000000082938`", "\"[1]\""}}, AutoDelete -> 
         False, GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"], 
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"Ideal Gas @8.28389 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", 
           "0.5499798504915355`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", 
           "0.22814240185230872`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", "\"-\"", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.010036901266481678`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "\"-\"", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.060000000001105856`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "\"-\"", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.060000000001105856`", "\"[1]\""}}, AutoDelete -> 
         False, GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"], 
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"Ideal Gas @10.3549 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", 
           "0.3577228465355661`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", 
           "0.11871234821876434`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", "\"-\"", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.008029521013185343`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "\"-\"", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.07500000000138231`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "\"-\"", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.07500000000138231`", "\"[1]\""}}, AutoDelete -> 
         False, GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[89]=",ExpressionUUID->"ede6bd33-74d4-46f4-91ef-c0723fd2db94"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualisation", "Subsubsection",ExpressionUUID->"2781829d-a551-49ab-9c53-8be85b8e94e5"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"0ae3b953-f150-43d8-a458-072bc0c4fe1c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plotPxyIdealGas", "[", 
    RowBox[{"tSim_", ",", "pSim_", ",", "\[Sigma]_", ",", "\[Epsilon]_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", "\n", "\t", 
    RowBox[{
     RowBox[{"{", "\n", "\t\t", 
      RowBox[{
      "piSat", ",", "x1Sim", ",", "y1Sim", ",", "\n", "\t\t", "ordinate", ",",
        "x1", ",", "y1"}], "\n", "\t", "}"}], ",", "\[IndentingNewLine]", 
     "\t", 
     RowBox[{"(*", " ", 
      RowBox[{
      "saturation", " ", "pressure", " ", "of", " ", "the", " ", "pure", " ", 
       "components"}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
     RowBox[{
      RowBox[{"piSat", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"pSatLJ", "[", 
          RowBox[{"tSim", ",", 
           RowBox[{"\[Sigma]", "[", 
            RowBox[{"[", 
             RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
           RowBox[{"\[Epsilon]", "[", 
            RowBox[{"[", 
             RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], "/@",
         " ", 
        RowBox[{"Range", "[", "2", "]"}]}]}], ";", " ", 
      RowBox[{"(*", "bar", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{
       "molar", " ", "fractions", " ", "at", " ", "simulation", " ", 
        "pressure"}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"x1Sim", " ", "=", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"pSim", "-", 
          RowBox[{
          "piSat", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
          "piSat", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
          "-", 
          RowBox[{
          "piSat", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}]}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"mol", " ", 
        SuperscriptBox["mol", 
         RowBox[{"-", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"y1Sim", " ", "=", " ", 
       RowBox[{"x1Sim", " ", "*", 
        RowBox[{
         RowBox[{
         "piSat", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "/",
          "pSim"}]}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"mol", " ", 
        SuperscriptBox["mol", 
         RowBox[{"-", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "molar", " ", "fractions", " ", "of", " ", "the", " ", "liquid", " ", 
         "phase"}], ",", " ", 
        RowBox[{"component", " ", "1"}]}], " ", "*)"}], "\[IndentingNewLine]",
       "\t", 
      RowBox[{"x1", " ", "=", " ", 
       RowBox[{"Range", "[", 
        RowBox[{"0", ",", "1", ",", "0.01"}], "]"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"mol", " ", 
        SuperscriptBox["mol", 
         RowBox[{"-", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{
       "pressure", " ", "as", " ", "the", " ", "ordinate", " ", "of", " ", 
        "the", " ", "diagram"}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"ordinate", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", "*", 
            RowBox[{
            "piSat", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}],
            "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1.", "-", "#"}], ")"}], "*", 
            RowBox[{
            "piSat", "\[LeftDoubleBracket]", "2", 
             "\[RightDoubleBracket]"}]}]}], ")"}], " ", "&"}], "/@", " ", 
        "x1"}]}], ";", " ", 
      RowBox[{"(*", " ", "bar", " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "molar", " ", "fractions", " ", "of", " ", "the", " ", "vapor", " ", 
         "phase"}], ",", " ", 
        RowBox[{"component", " ", "1"}]}], " ", "*)"}], "\[IndentingNewLine]",
       "\t", 
      RowBox[{"y1", " ", "=", " ", 
       RowBox[{"x1", "*", 
        RowBox[{
         RowBox[{
         "piSat", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "/",
          "ordinate"}]}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"mol", " ", 
        SuperscriptBox["mol", 
         RowBox[{"-", "1"}]]}], " ", "*)"}], "\n", "\t", "\n", "\t", 
      RowBox[{"Grid", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"{", "\n", "\t\t", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{"{", "\n", "\t\t\t", 
               RowBox[{"Show", "[", 
                RowBox[{"{", "\n", "\t\t\t\t", 
                 RowBox[{
                  RowBox[{"ListLinePlot", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{"x1", ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{"ordinate", ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    "]"}], ",", 
                    RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{"y1", ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{"ordinate", ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    "]"}]}], "}"}], "\n", "\t\t\t\t\t", ",", 
                    RowBox[{"Frame", " ", "->", " ", "True"}], ",", 
                    RowBox[{"PlotRangePadding", "->", "None"}], ",", 
                    RowBox[{"PlotRange", "->", "All"}], ",", 
                    RowBox[{"GridLines", "\[Rule]", "Automatic"}], "\n", 
                    "\t\t\t\t\t", ",", 
                    RowBox[{"FrameLabel", "\[Rule]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "Bold", ",", "14", ",", 
                    RowBox[{"SingleLetterItalics", "->", "False"}]}], "]"}], 
                    "&"}], "/@", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<\!\(\*SubscriptBox[\(x\), \
\(1\)]\),\!\(\*SubscriptBox[\(y\), \(1\)]\) [mol/mol]\>\"", ",", 
                    "\"\<\!\(\*SuperscriptBox[\(P\), \(*\)]\) [1]\>\""}], 
                    "}"}]}], ")"}]}], "\n", "\t\t\t\t\t", ",", 
                    RowBox[{"PlotLabel", "\[Rule]", 
                    RowBox[{"StringJoin", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"component", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "\"\<-\>\"", ",", 
                    RowBox[{"component", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "\"\< @T = \>\"", 
                    ",", 
                    RowBox[{"ToString", "[", "tSim", "]"}], ",", 
                    "\"\< K\\n\>\""}], "}"}], "]"}]}], "\n", "\t\t\t\t\t", 
                    ",", 
                    RowBox[{"PlotLegends", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<Raoult-Dalton, bubble curve\>\"", ",", 
                    "\"\<Raoult-Dalton, dew curve\>\""}], "}"}]}], "\n", 
                    "\t\t\t\t\t", ",", 
                    RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "\n", 
                   "\t\t\t\t", "]"}], ",", "\n", "\t\t\t\t", 
                  RowBox[{"ListPlot", "[", 
                   RowBox[{
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x1Sim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{
                    RowBox[{"pSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"y1Sim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{
                    RowBox[{"pSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}]}],
                     "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "]"}], "\n", 
                    "\t\t\t\t\t", ",", 
                    RowBox[{"PlotStyle", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Red", ",", "Blue", ",", "Orange"}], "}"}]}], ",", 
                    RowBox[{"PlotRange", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Automatic"}], "}"}]}], "}"}]}], "\n", 
                    "\t\t\t\t\t", ",", 
                    RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
                    RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}],
                     "\n", "\t\t\t\t\t", ",", 
                    RowBox[{"PlotLegends", "\[Rule]", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"\"\<Simulation point @\>\"", "<>", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"pSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], "<>", 
                    "\"\< bar\>\""}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "]"}]}]}], 
                   "\n", "\t\t\t\t", "]"}]}], "\[IndentingNewLine]", "\t\t\t",
                  "}"}], "]"}], "\t\t", "\n", "\t\t", "}"}], "}"}], "}"}], 
            ",", "\n", "\t\t", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", "\n", "\t\t\t", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"Row", "[", 
                  RowBox[{"{", 
                   RowBox[{"\"\<Simulation @\>\"", ",", " ", 
                    RowBox[{"pSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    "\"\< bar : \!\(\*SubscriptBox[\(x\), \(1\)]\) = \>\"", 
                    ",", 
                    RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"x1Sim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "0.00001"}], "]"}], 
                    ",", "\"\< mol \!\(\*SuperscriptBox[\(mol\), \(-1\)]\), \
\!\(\*SubscriptBox[\(y\), \(1\)]\) = \>\"", ",", 
                    RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"y1Sim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "0.00001"}], "]"}], 
                    ",", 
                    "\"\< mol \!\(\*SuperscriptBox[\(mol\), \(-1\)]\)\>\""}], 
                   "}"}], "]"}], "}"}], ",", "\n", "\t\t\t", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Row", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<\\t \!\(\*SubscriptBox[\(x\), \(m25  %\)]\) = \>\"", 
                    ",", " ", 
                    RowBox[{"#1", "+", 
                    RowBox[{"#2", "*", "0.25"}]}], ",", " ", 
                    "\"\<\\t \!\(\*SubscriptBox[\(x\), \(m50  %\)]\) = \>\"", 
                    ",", 
                    RowBox[{"#1", "+", 
                    RowBox[{"#2", "*", "0.5"}]}], ",", 
                    "\"\<\\t \!\(\*SubscriptBox[\(x\), \(m75  %\)]\) = \>\"", 
                    ",", " ", 
                    RowBox[{"#1", "+", 
                    RowBox[{"#2", "*", "0.75"}]}]}], "}"}], "]"}], "&"}], "[", 
                  RowBox[{
                   RowBox[{"resMFIdealGas", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"resMFIdealGas", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], "-", 
                    RowBox[{"resMFIdealGas", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ")"}]}], "]"}], 
                 "}"}]}], "\n", "\t\t\t", "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "\n", "\t\t", 
             "]"}]}], "\n", "\t", "}"}], ",", "2"}], "]"}], ",", 
        RowBox[{"Alignment", "->", "Left"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[90]:=",ExpressionUUID->"b527dc57-a9d5-4ce1-a8ae-3b3faa124ba9"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotPxyIdealGas", "[", 
  RowBox[{"tSim", ",", "pSim", ",", "\[Sigma]", ",", "\[Epsilon]"}], 
  "]"}]], "Code",
 CellLabel->"In[91]:=",ExpressionUUID->"efd6f633-fb4a-41f4-9507-5b0d867a7d95"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{
       GraphicsBox[{{{}, {{{}, {}, {
             Hue[0.67, 0.6, 0.6], 
             Directive[
              PointSize[
               NCache[
                Rational[1, 72], 0.013888888888888888`]], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJw1kwlMkwcYhhkIRDZlk8MTiiL3ADezzaDwZgrxQh2XQSTjmAxm0HnM6MCZ
6QQhUDQeTARBKDcCLZTScl86wcJAOb2ghbZQCp3QsoyFMVo/v+TPn//6vvd9
n+/fGP6jb4Sujo5OxNKhOb+vACvriX2BNYg1LdstirkKb8vI7Q42769vY+eG
EqbhjAB8y7hJH34mtq1TDksaBPQ8Fy5rtn7eliTAvTRNFWGz+fmrOYHv3y/D
OtPa/l9tBFD4aO5w8MmqRfuQGT59z4Xhx7ti3Rv5MBpgnXI3qsbCimud65P5
1E8A1YdPGfOBfDgEX29R29dBvtz4zKANn/o3QGTo18abqUbu0tcDrCb06/9u
fqexmuY1Q6j3MupscjW2aqsVrR8wan2OVNP8NggWw1dssa1Gq9p+acIjsBfy
Q1bO8kjPH8j/V85RNPLgqx34BBn/uCx7mswjfe249feZw0VHeBDFaBp2IFHN
K7xmyyO9QlyanZ+PmK3CaY28U50499bjgGdTFenvwnHllaxNzCq8o9GN8KnH
b3WCqshPNwInjTyHbauwRzugBwcmDqbWz3LJXw88ZTfH05u40EwLvv4MbpJ+
txgml/w+x5bRdczAIC60dgaew1b07fCXdlzy34sNwzmfmakqwdDIseyDyWvp
b7NNlZRHH5a/dOzvYVYi8ntN9WNx8KQ9O6iS8hnAXH9FTIpdJTTdTMsGoOid
E0arKiivQYieuTH2N1dgTtNOPYih7kunHVIqKL8hdHW1tBoerYCHtuELPBIa
mEvtKijPF6jr2BfVpuJAKy/uJThPUmpymjmU7ysUPn720eUUDjqFmnqFzDbz
kJCjHMr7NW63BHHc7Tkw0wp8g6SmTL0Najbl/waXG8QB881saNsFD+N8nW3h
YAqbeIzgRM3xed5RNvkZwXf8Mu879mziM4LKaIm7TF5O/kaQFXVCzLpaTrxE
SD6mjg+1LCe/IlwI/cXJYum/eMdPhGPB+t1DPmXkXwyfQOZPqZOlxFMMD3+z
tX5xpZSHGJ9+c7/emFFKfEexxtsmXMh/SPmMQm9PqUGi70PiPQrlri9KvBQl
lNcYXqH+kG58CfEfQ/t2L1UDo4TyGwP3q867sYJi2gcJsrcGuG/zK6Y8JWC6
vhapFEW0HxLEOEXEc+KLKF8pIu2mHE9aFdG+SOFrfe5Px5pCyluKrxkLZ2V+
hbQ/Mjivj1uTO1VA+cuwdvWK+tBrBbRPMuib3Amz2FhAPMYxs9LC4EVNPvEY
x7BRXnGqfz7xGEeHgfMhv+k84jEOvm7VrHFCHvGYAOu/HXeFG/OIxwRuzLft
SKzNJR4TuDjnLfIKyCUeckTN9MbpKlm4oeUhh/90sGNjAot4yLFTPtYVu4lF
PCbhKo0+u60uh3hMYr1YtVodkEM8JmH45mIdR5lNPBRQDS0LO5mYTTwUGOlL
1neyziYeCnT2mBbL6h4QjykIOjMO5h5+QDymsP/WXmnzSBbxmMLmpCOu202z
iMc0Fq78cIG7O5N4TKMv5udm59j7xGMa7DOJRgVlGcRDiYTjaX5W4nTioURY
eFFGmlk68VDCLUggWbX3HvH4Cya+7S7JF9PwP6WfHgc=
              "]]}, {
             Hue[0.9060679774997897, 0.6, 0.6], 
             Directive[
              PointSize[
               NCache[
                Rational[1, 72], 0.013888888888888888`]], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJw1lXs0FIgCh+V5vbKLKPLKM4qWq3VYfruluuVtGmcMu0rNUU7UbWprsRVb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              "]]}}}, {{}, {}}}, {{}, {{{}, {}, {}, {}, {}, {}, {
             Directive[
              RGBColor[1, 0, 0], 
              Opacity[0.3]], 
             
             LineBox[{{0.742236854447505, 0.}, {0.742236854447505, 
              0.04499999999999999}}], 
             
             LineBox[{{0.4105258245748828, 0.}, {0.4105258245748828, 
              0.04499999999999999}}], 
             
             LineBox[{{0.4105258245748828, 0.}, {0.4105258245748828, 
              0.04499999999999999}}]}, {}, {
             Directive[
              RGBColor[0, 0, 1], 
              Opacity[0.3]], 
             
             LineBox[{{0.5499798504915355, 0.}, {0.5499798504915355, 
              0.060000000000000005`}}], 
             
             LineBox[{{0.22814240185230872`, 0.}, {0.22814240185230872`, 
              0.060000000000000005`}}], 
             
             LineBox[{{0.22814240185230872`, 0.}, {0.22814240185230872`, 
              0.060000000000000005`}}]}, {}, {
             Directive[
              RGBColor[1, 0.5, 0], 
              Opacity[0.3]], 
             LineBox[{{0.3577228465355661, 0.}, {0.3577228465355661, 0.075}}], 
             
             LineBox[{{0.11871234821876434`, 0.}, {0.11871234821876434`, 
              0.075}}], 
             
             LineBox[{{0.11871234821876434`, 0.}, {0.11871234821876434`, 
              0.075}}]}}, {{
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[1, 0, 0]], 
             GeometricTransformationBox[
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox[
                  GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], 
                  GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}, StripOnInput -> False], 
                 TraditionalForm]], {0., 0.}, Automatic, 
               Scaled[9.75]], {{{0.742236854447505, 0.04499999999999999}}, {{
              0.4105258245748828, 0.04499999999999999}}, {{0.4105258245748828,
               0.04499999999999999}}}]}, {
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[0, 0, 1]], 
             GeometricTransformationBox[
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox[
                  GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], 
                  GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}, StripOnInput -> False], 
                 TraditionalForm]], {0., 0.}, Automatic, 
               Scaled[9.75]], {{{0.5499798504915355, 
              0.060000000000000005`}}, {{0.22814240185230872`, 
              0.060000000000000005`}}, {{0.22814240185230872`, 
              0.060000000000000005`}}}]}, {
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[1, 0.5, 0]], 
             GeometricTransformationBox[
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox[
                  GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}], 
                  GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]]}, StripOnInput -> False], 
                 TraditionalForm]], {0., 0.}, Automatic, 
               Scaled[9.75]], {{{0.3577228465355661, 0.075}}, {{
              0.11871234821876434`, 0.075}}, {{0.11871234821876434`, 
              0.075}}}]}}}, {{}, {}}}}, {
        DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
         NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
         AxesLabel -> {None, None}, AxesOrigin -> {0, 0.0248891738468321}, 
         DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
         FrameLabel -> {{
            FormBox[
             TagBox[
              StyleBox[
              "\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(*\\)]\\) [1]\"", Bold, 
               14, SingleLetterItalics -> False, StripOnInput -> False], 
              HoldForm], TraditionalForm], None}, {
            FormBox[
             TagBox[
              StyleBox[
              "\"\\!\\(\\*SubscriptBox[\\(x\\), \
\\(1\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) [mol/mol]\"", Bold, 14,
                SingleLetterItalics -> False, StripOnInput -> False], 
              HoldForm], TraditionalForm], None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {Automatic, Automatic}, GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> Medium, 
         Method -> {
          "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
           "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), "CopiedValueFunction" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& )}}, PlotLabel -> 
         FormBox["\"LJ_ref-LJ_1 @T = 1. K\\n\"", TraditionalForm], 
         PlotRange -> {{0, 1.}, {0.024889173846832046`, 
           0.10290973846270053`}}, PlotRangeClipping -> True, 
         PlotRangePadding -> {{None, None}, {None, None}}, 
         Ticks -> {Automatic, Automatic}}], 
       FormBox[
        TagBox[
         GridBox[{{
            FormBox[
             
             TemplateBox[{
              "\"Raoult-Dalton, bubble curve\"", 
               "\"Raoult-Dalton, dew curve\""}, "LineLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"LineLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
                   ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"True", ",", "True"}], "}"}]}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}, {
            FormBox[
             
             TemplateBox[{
              "\"Simulation point @6.21292 bar\"", 
               "\"Simulation point @8.28389 bar\"", 
               "\"Simulation point @10.3549 bar\""}, "PointLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #2}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 0, 1]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0.5, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], ",", "9.75`"}],
                     "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}], ",", "9.75`"}], "}"}]}], "}"}]}], 
                   ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "False", ",", "False"}], "}"}]}], 
                   ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]},
    {
     TemplateBox[{
      "\"Simulation @\"", "6.212920499999999`", 
       "\" bar : \\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\) = \"", "0.74224`",
        "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\), \
\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) = \"", "0.41053`", 
       "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)\""},
      "RowDefault"]},
    {
     TemplateBox[{
      "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m25  %\\)]\\) = \"", 
       "0.6593090969793495`", 
       "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m50  %\\)]\\) = \"", 
       "0.5763813395111939`", 
       "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m75  %\\)]\\) = \"", 
       "0.49345358204303835`"},
      "RowDefault"]},
    {
     TemplateBox[{
      "\"Simulation @\"", "8.283894`", 
       "\" bar : \\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\) = \"", "0.54998`",
        "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\), \
\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) = \"", "0.22814`", 
       "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)\""},
      "RowDefault"]},
    {
     TemplateBox[{
      "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m25  %\\)]\\) = \"", 
       "0.4695204883317288`", 
       "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m50  %\\)]\\) = \"", 
       "0.3890611261719221`", 
       "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m75  %\\)]\\) = \"", 
       "0.3086017640121154`"},
      "RowDefault"]},
    {
     TemplateBox[{
      "\"Simulation @\"", "10.3548675`", 
       "\" bar : \\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\) = \"", 
       "0.35772000000000004`", 
       "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\), \
\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) = \"", "0.11871000000000001`", 
       "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)\""},
      "RowDefault"]},
    {
     TemplateBox[{
      "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m25  %\\)]\\) = \"", 
       "0.29797022195636563`", 
       "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m50  %\\)]\\) = \"", 
       "0.2382175973771652`", 
       "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m75  %\\)]\\) = \"", 
       "0.17846497279796478`"},
      "RowDefault"]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[91]=",ExpressionUUID->"6561af8e-3d09-45f6-9c46-927e41a0254b"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "nd"], TraditionalForm]],ExpressionUUID->
  "5597e4dc-8b1b-45ee-86d0-09de6b4e0987"],
 " Virial Coefficient EoS"
}], "Subsection",ExpressionUUID->"a089c35d-7d12-4d96-89e6-8e6b0c4296a6"],

Cell["\<\
Nordholm S, Forsman J, Woodward C, Freasier B, Abbas Z: Generalized van der \
Waals Theory of Molecular Fluids in bulk and at Surface. Elsevier, 2019. \
ISBN: 978-0-12-811136-9\
\>", "Affiliation",ExpressionUUID->"2c7547cd-1ca6-4ce3-84ee-7910545e88df"],

Cell[TextData[{
 "The virial equation can only be used to estimate the vapor molar volume (",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["v",
     FontSlant->"Plain"], "Vap"], TraditionalForm]],ExpressionUUID->
  "8fa9161b-473a-4677-8ab8-431add03bcde"],
 ") at given vapor molar fraction (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "1"], TraditionalForm]],ExpressionUUID->
  "4b3fde2f-4a64-4fe9-a746-f13ed1cea719"],
 ").\nThe vapor molar fraction is calculated using Raoult-Dalton\
\[CloseCurlyQuote]s law and ideal gas assumption as in the previous section."
}], "Text",ExpressionUUID->"973bbdc6-3e6b-46ee-a7af-0c4cee2bbe4f"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"a179c0fc-548d-48fa-9b0b-bc735f6c8f2f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CalculateMolarVolumeVirial", "[", 
    RowBox[{"tSim_", ",", "pSim_", ",", "y1_"}], "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xvec", ",", "parBLJ", ",", "vV", ",", "rhoV", ",", "rhoVAst"}],
       "}"}], ",", "\[IndentingNewLine]", "\t", 
     RowBox[{
      RowBox[{"parBLJ", " ", "=", " ", 
       RowBox[{
        RowBox[{"b2LJ", "[", 
         RowBox[{"tSim", ",", 
          RowBox[{"\[Sigma]m", "[", "y1", "]"}], ",", 
          RowBox[{"\[Epsilon]m", "[", "y1", "]"}]}], "]"}], 
        RowBox[{"(*", " ", 
         RowBox[{
          SuperscriptBox["cm", "3"], " ", 
          SuperscriptBox["mol", 
           RowBox[{"-", "1"}]]}], " ", "*)"}], "*", 
        RowBox[{"10", "^", 
         RowBox[{"-", "3"}]}]}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
        SuperscriptBox["dm", "3"], " ", 
        SuperscriptBox["mol", 
         RowBox[{"-", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"vV", " ", "=", " ", 
       RowBox[{"Max", "[", 
        RowBox[{"vVirialLeiden", "[", 
         RowBox[{"parBLJ", ",", "tSim", ",", "pSim"}], "]"}], "]"}]}], ";", 
      " ", 
      RowBox[{"(*", " ", 
       RowBox[{
        SuperscriptBox["dm", "3"], " ", 
        SuperscriptBox["mol", 
         RowBox[{"-", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"rhoV", "=", " ", 
       RowBox[{"vToRho", "@", "vV"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"N", " ", "/", " ", 
        RowBox[{"\[Angstrom]", "^", "3"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"rhoVAst", " ", "=", " ", 
       RowBox[{"RhoToRhoAst", "[", 
        RowBox[{"rhoV", ",", "y1"}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\t", 
      RowBox[{"{", 
       RowBox[{
       "\"\<-\>\"", ",", "vV", ",", "\"\<-\>\"", ",", "rhoV", ",", 
        "\"\<-\>\"", ",", "rhoVAst"}], "}"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[92]:=",ExpressionUUID->"736be2d2-450d-4908-b5fc-b6d475c19353"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Calculation", " ", "of", " ", "molar", " ", "fraction", " ", 
    RowBox[{"(", "MF", ")"}], " ", "and", " ", "molar", " ", "volume", " ", 
    RowBox[{"(", "MV", ")"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"resMFVirial", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<-\>\"", ",", " ", "\"\<(Ideal Gas)\>\""}], "}"}], "&"}], 
      "/@", " ", "pSim"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"resMVVirial", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"CalculateMolarVolumeVirial", "[", 
        RowBox[{"tSim", ",", "#", ",", 
         RowBox[{
          RowBox[{"CalculateMoleFracIdealGas", "[", 
           RowBox[{"tSim", ",", "#", ",", "\[Sigma]", ",", "\[Epsilon]"}], 
           "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "&"}], "/@", " ", 
      "pSim"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Grid", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"ShowEoSResults", "[", 
         RowBox[{"\"\<Virial Equation\>\"", ",", 
          RowBox[{"pSim", "[", 
           RowBox[{"[", "#", "]"}], "]"}], ",", 
          RowBox[{"resMFVirial", "[", 
           RowBox[{"[", "#", "]"}], "]"}], ",", 
          RowBox[{"resMVVirial", "[", 
           RowBox[{"[", "#", "]"}], "]"}]}], "]"}], ")"}], " ", "&"}], "/@", 
      " ", 
      RowBox[{"Range", "@", 
       RowBox[{"Length", "@", "pSim"}]}]}], " ", "}"}]}]}]}]], "Code",
 CellLabel->"In[93]:=",ExpressionUUID->"5845acbe-6def-4b34-a287-1ec4d5600f3e"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"Virial Equation @6.21292 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", "\"-\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", "\"(Ideal Gas)\"",
            "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", "\"-\"", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.014540721320203447`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "\"-\"", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.04141569477459555`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "\"-\"", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.04141569477459555`", "\"[1]\""}}, AutoDelete -> 
         False, GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"], 
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"Virial Equation @8.28389 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", "\"-\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", "\"(Ideal Gas)\"",
            "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", "\"-\"", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.011168002991386145`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "\"-\"", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.05392316571409288`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "\"-\"", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.05392316571409288`", "\"[1]\""}}, AutoDelete -> 
         False, GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"], 
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"Virial Equation @10.3549 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", "\"-\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", "\"(Ideal Gas)\"",
            "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", "\"-\"", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.009135768616977182`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "\"-\"", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.0659182714939708`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "\"-\"", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.0659182714939708`", "\"[1]\""}}, AutoDelete -> False,
          GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->"Out[95]=",ExpressionUUID->"778e7c8b-766f-4319-be07-c402ae6c4bb1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualisation", "Subsubsection",ExpressionUUID->"16b68c92-a700-4d7e-9d8e-4fc30c47dab5"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"53ee0fb8-68f5-4f84-8b5b-ca1027837da0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plotPrhoVirial", "[", "]"}], " ", ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"piSat", ",", "rhoAstVSim", ",", "ordinate", ",", "rhoAstV"}], 
      "}"}], ",", "\[IndentingNewLine]", "\t", 
     RowBox[{"(*", " ", 
      RowBox[{
      "saturation", " ", "pressure", " ", "of", " ", "the", " ", "pure", " ", 
       "components"}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
     RowBox[{
      RowBox[{"piSat", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"pSatLJ", "[", 
          RowBox[{"tSim", ",", 
           RowBox[{"\[Sigma]", "[", 
            RowBox[{"[", 
             RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
           RowBox[{"\[Epsilon]", "[", 
            RowBox[{"[", 
             RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], "/@",
         " ", 
        RowBox[{"Range", "[", "2", "]"}]}]}], ";", "   ", 
      RowBox[{"(*", "bar", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{
       "molar", " ", "fractions", " ", "at", " ", "simulation", " ", 
        "pressure"}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"rhoAstVSim", " ", "=", " ", 
       RowBox[{"resMVVirial", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "6"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\t", "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{
       "pressure", " ", "as", " ", "the", " ", "ordinate", " ", "of", " ", 
        "the", " ", "diagram"}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"ordinate", " ", "=", " ", 
       RowBox[{"Range", "[", 
        RowBox[{
         RowBox[{"piSat", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"piSat", "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"piSat", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "-", 
            RowBox[{"piSat", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "100"}]}], "]"}]}],
       ";", "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{"Lj", "-", 
        RowBox[{"reduced", " ", "vapor", " ", "density"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"rhoAstV", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"CalculateMolarVolumeVirial", "[", 
           RowBox[{"tSim", ",", 
            RowBox[{"ordinate", "[", 
             RowBox[{"[", "#", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"CalculateMoleFracIdealGas", "[", 
              RowBox[{"tSim", ",", 
               RowBox[{"ordinate", "[", 
                RowBox[{"[", "#", "]"}], "]"}], ",", "\[Sigma]", ",", 
               "\[Epsilon]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "[", 
          RowBox[{"[", "6", "]"}], "]"}], " ", "&"}], "/@", " ", 
        RowBox[{"Range", "@", 
         RowBox[{"Length", "@", "ordinate"}]}]}]}], ";", 
      "\[IndentingNewLine]", "\t", "\[IndentingNewLine]", "\t", 
      RowBox[{"Print", "@", 
       RowBox[{"Show", "@", 
        RowBox[{"{", "\n", "\t\t", 
         RowBox[{
          RowBox[{"ListLinePlot", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Transpose", "[", 
              RowBox[{"{", 
               RowBox[{"rhoAstV", ",", 
                RowBox[{"pRedLJ", "[", 
                 RowBox[{"ordinate", ",", 
                  RowBox[{"\[Epsilon]", "[", 
                   RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                  RowBox[{"\[Sigma]", "[", 
                   RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
              "]"}], "}"}], "\n", "\t\t\t", ",", 
            RowBox[{"Frame", " ", "->", " ", "True"}], ",", 
            RowBox[{"PlotRangePadding", "->", "None"}], ",", 
            RowBox[{"GridLines", "\[Rule]", "Automatic"}], "\n", "\t\t\t", 
            ",", 
            RowBox[{"FrameLabel", "\[Rule]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Style", "[", 
                 RowBox[{"#", ",", "Bold", ",", "14", ",", 
                  RowBox[{"SingleLetterItalics", "->", "False"}]}], "]"}], 
                "&"}], "/@", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(V\), \(*\)]\) \
[1]\>\"", ",", "\"\<\!\(\*SuperscriptBox[\(P\), \(*\)]\) [1]\>\""}], "}"}]}], 
              ")"}]}], "\n", "\t\t\t", ",", 
            RowBox[{"PlotLabel", "\[Rule]", 
             RowBox[{"StringJoin", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"component", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "<>", "\"\<-\>\"", "<>", 
                 RowBox[{"component", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "<>", "\"\< @T = \>\""}], 
                ",", 
                RowBox[{"ToString", "[", "tSim", "]"}], ",", 
                "\"\< K\\n\>\""}], "}"}], "]"}]}], "\n", "\t\t\t", ",", 
            RowBox[{"PlotLegends", "\[Rule]", 
             RowBox[{
             "{", "\"\<\!\(\*SuperscriptBox[\(2\), \(nd\)]\) Virial, vapor \
density\>\"", "}"}]}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "Medium"}], "\n", "\t\t\t", ",", 
            RowBox[{"PlotRange", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0.31"}], "}"}], ",", "Automatic"}], 
              "}"}]}]}], "\n", "\t\t", "]"}], ",", "\n", "\t\t", 
          RowBox[{"ListPlot", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"rhoAstVSim", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", 
                 RowBox[{"pRedLJ", "[", 
                  RowBox[{
                   RowBox[{"pSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                   RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                   RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
               "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "]"}], "\n", 
            "\t\t\t", ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Red", ",", "Blue", ",", "Orange"}], "}"}]}], ",", 
            RowBox[{"PlotRange", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Automatic", ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "Automatic"}], "}"}]}], "}"}]}], "\n", 
            "\t\t\t", ",", 
            RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
            RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}], "\n", 
            "\t\t\t", ",", 
            RowBox[{"PlotLegends", "\[Rule]", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"\"\<Simulation point @\>\"", "<>", 
                RowBox[{"ToString", "[", 
                 RowBox[{"pSim", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "]"}], "<>", 
                "\"\< bar\>\""}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", 
                 RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "]"}]}]}], "\n", 
           "\t\t", "]"}]}], "\[IndentingNewLine]", "\t", "}"}]}]}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[96]:=",ExpressionUUID->"9193b947-07df-49b0-804a-30fa21379db7"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plotPrhoVirial", "[", "]"}], ";"}]], "Code",
 CellLabel->"In[97]:=",ExpressionUUID->"74051573-5a4c-4709-a05f-ff89433b3118"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVkGk8FAgDhyXH5l3bvo6WKEcZEsnSJrH/ZcebMkuazEq9ibZ1vGhD5agk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          "]]}}}, {{}, {}}}, {{}, {{{}, {}, {}, {}, {}, {}, {
         Directive[
          RGBColor[1, 0, 0], 
          Opacity[0.3]], 
         LineBox[{{0.04141569477459555, 0.}, {0.04141569477459555, 
          0.04499999999999999}}], 
         LineBox[{{0.04141569477459555, 0.}, {0.04141569477459555, 
          0.04499999999999999}}]}, {}, {
         Directive[
          RGBColor[0, 0, 1], 
          Opacity[0.3]], 
         LineBox[{{0.05392316571409288, 0.}, {0.05392316571409288, 
          0.060000000000000005`}}], 
         LineBox[{{0.05392316571409288, 0.}, {0.05392316571409288, 
          0.060000000000000005`}}]}, {}, {
         Directive[
          RGBColor[1, 0.5, 0], 
          Opacity[0.3]], 
         LineBox[{{0.0659182714939708, 0.}, {0.0659182714939708, 0.075}}], 
         LineBox[{{0.0659182714939708, 0.}, {0.0659182714939708, 0.075}}]}}, {{
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{{
                 GrayLevel[1], 
                 DiskBox[{0, 0}, 
                  Offset[{3, 3}]]}, 
                AbsoluteThickness[1.5], 
                Dashing[{}], 
                CircleBox[{0, 0}, 
                 Offset[{3, 3}]]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[1, 0, 0]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Scaled[9.75]], {{{0.04141569477459555, 0.04499999999999999}}, {{
          0.04141569477459555, 0.04499999999999999}}}]}, {
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{{
                 GrayLevel[1], 
                 PolygonBox[
                  NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                AbsoluteThickness[1.5], 
                Dashing[{}], 
                JoinedCurveBox[
                 NCache[
                  Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                  Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[0, 0, 1]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Scaled[9.75]], {{{0.05392316571409288, 0.060000000000000005`}}, {{
          0.05392316571409288, 0.060000000000000005`}}}]}, {
         Directive[
          PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.5, 0]], 
         GeometricTransformationBox[
          InsetBox[
           BoxData[
            FormBox[
             StyleBox[
              GraphicsBox[{{
                 GrayLevel[1], 
                 PolygonBox[{
                   Offset[{0, 3.75}], 
                   Offset[{3.75, 0}], 
                   Offset[{0, -3.75}], 
                   Offset[{-3.75, 0}]}]}, 
                AbsoluteThickness[1.5], 
                Dashing[{}], 
                LineBox[{
                  Offset[{0, 3.75}], 
                  Offset[{3.75, 0}], 
                  Offset[{0, -3.75}], 
                  Offset[{-3.75, 0}], 
                  Offset[{0, 3.75}]}]}], 
              GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[1, 0.5, 0]]}, StripOnInput -> False], 
             TraditionalForm]], {0., 0.}, Automatic, 
           Scaled[9.75]], {{{0.0659182714939708, 0.075}}, {{
          0.0659182714939708, 0.075}}}]}}}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0.0248891738468321}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox[
          StyleBox[
          "\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(*\\)]\\) [1]\"", Bold, 14, 
           SingleLetterItalics -> False, StripOnInput -> False], HoldForm], 
         TraditionalForm], None}, {
        FormBox[
         TagBox[
          StyleBox[
          "\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(V\\), \\(*\\)]\\) \
[1]\"", Bold, 14, SingleLetterItalics -> False, StripOnInput -> False], 
          HoldForm], TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {Automatic, Automatic}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> Medium, 
     Method -> {
      "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"LJ_ref-LJ_1 @T = 1. K\\n\"", TraditionalForm], 
     PlotRange -> {{0., 0.31}, {0.024889173846832046`, 0.10290973846270053`}},
      PlotRangeClipping -> True, 
     PlotRangePadding -> {{None, None}, {None, None}}, 
     Ticks -> {Automatic, Automatic}}], 
   FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{
          "\"\\!\\(\\*SuperscriptBox[\\(2\\), \\(nd\\)]\\) Virial, vapor \
density\""}, "LineLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "True", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{
          "\"Simulation point @6.21292 bar\"", 
           "\"Simulation point @8.28389 bar\"", 
           "\"Simulation point @10.3549 bar\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #2}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 0, 1]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0.5, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], ",", "9.75`"}],
                     "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}], ",", "9.75`"}], "}"}]}], "}"}]}], 
               ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "False", ",", "False"}], "}"}]}], 
               ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Print",
 CellLabel->
  "During evaluation of \
In[97]:=",ExpressionUUID->"7d197a63-d445-458b-b313-a37560f1a9c2"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Van der Waals EoS for LJ-fluids", "Subsection",ExpressionUUID->"221439da-fc2b-4864-8cfb-34833b458e4a"],

Cell["\<\
Nordholm S, Forsman J, Woodward C, Freasier B, Abbas Z: Generalized van der \
Waals Theory of Molecular Fluids in bulk and at Surface. Elsevier, 2019. \
ISBN: 978-0-12-811136-9\
\>", "Affiliation",ExpressionUUID->"558f195f-1633-4e1c-8e31-96f1ee344a63"],

Cell["\<\
The Van der Waals cubic EoS is used to calculate the molar fractions and \
molar volume.
The calculation needs an initial saturation pressure guess which is \
calculated using the Thol2016 EoS.
The calculation assumes that at least one component is below its critical \
point.
This EoS is not recommended for high asymmetric mixtures!\
\>", "Text",ExpressionUUID->"9ad14459-726f-44b0-8b18-96a9a20a70e8"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"72b454e1-2cea-4b9c-a1cc-60116dc95e46"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"bubblePressureVdWLJ", "[", 
    RowBox[{
    "aij_", ",", "bPure_", ",", "t_", ",", "x_", ",", "pGuess_", ",", 
     "yGuess_", ",", "epsilon_", ",", "verbose_"}], "]"}], ":=", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", "\t", 
    RowBox[{"(*", " ", 
     RowBox[{"Local", " ", "variables"}], " ", "*)"}], "\[IndentingNewLine]", 
    "\t", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "nComp", ",", "p", ",", "y", ",", "v", ",", "\[Sigma]Liq", ",", 
       "\[Sigma]Vap", ",", "\[Epsilon]Liq", ",", "\[Epsilon]Vap", ",", "bLiq",
        ",", "bVap", ",", "vLiq", ",", "\[CurlyPhi]Liq", ",", "vVap", ",", 
       "\[CurlyPhi]Vap", ",", "kValue", ",", "s", ",", "i", ",", "j", ",", 
       "trouble"}], "}"}], ",", "\[IndentingNewLine]", "\t", 
     RowBox[{
      RowBox[{"trouble", "=", "False"}], ";", 
      RowBox[{"(*", " ", "flag", " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"nComp", "=", 
       RowBox[{"Length", "[", "x", "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
       "number", " ", "of", " ", "components", " ", "in", " ", "the", " ", 
        "mixture"}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"p", "=", "pGuess"}], ";", 
      RowBox[{"(*", " ", "bar", " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"y", "=", "yGuess"}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"mol", " ", 
        RowBox[{"mol", "^", 
         RowBox[{"-", "1"}]}]}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{"Start", " ", "of", " ", "calculations"}], " ", "*)"}], 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"\[Sigma]Liq", "=", 
       RowBox[{"\[Sigma]m", "[", 
        RowBox[{"x", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", 
      RowBox[{"(*", " ", "A", " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"\[Epsilon]Liq", "=", 
       RowBox[{"\[Epsilon]m", "[", 
        RowBox[{"x", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"kcal", "/", "mol"}], " ", "*)"}], "\[IndentingNewLine]", "\t",
       "\n", "\t", 
      RowBox[{"(*", " ", "Iteration", " ", "*)"}], "\n", "\t", 
      RowBox[{"If", "[", 
       RowBox[{"verbose", ",", "\n", "\t\t", 
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<Step   \\!\\(\\*SubscriptBox[\\(\[CapitalSigma]\\), \\(i\\)]\\)\
\\!\\(\\*SubscriptBox[\\(y\\), \\(i\\)]\\)\>\"", ",", 
          "\"\<\\n------------\>\""}], "]"}]}], "\n", "\t", "]"}], ";", "\n", 
      "\t", "\n", "\t", 
      RowBox[{"Do", "[", "\[IndentingNewLine]", "\t\t", 
       RowBox[{
        RowBox[{
         RowBox[{"vLiq", "=", 
          RowBox[{"Min", "@", 
           RowBox[{"Values", "@", 
            RowBox[{"vVdWLJ", "[", 
             RowBox[{
             "t", ",", "p", ",", "\[Sigma]Liq", ",", "\[Epsilon]Liq"}], 
             "]"}]}]}]}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{"dm", "^", "3"}], " ", 
           RowBox[{"mol", "^", 
            RowBox[{"-", "1"}]}]}], "*)"}], "\[IndentingNewLine]", "\t\t", 
         RowBox[{"(*", " ", 
          RowBox[{
          "Check", " ", "if", " ", "negative", " ", "volume", " ", "or", " ", 
           "imaginary", " ", "solution", " ", "was", " ", "found"}], "*)"}], 
         "\n", "\t\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Im", "[", "vLiq", "]"}], "!=", "0"}], " ", "||", " ", 
            RowBox[{"vLiq", "<", "0."}]}], ",", 
           RowBox[{
            RowBox[{"trouble", "=", "True"}], ";", 
            RowBox[{"Break", "[", "]"}]}]}], "]"}], ";", 
         "\[IndentingNewLine]", "\t\t", 
         RowBox[{"bLiq", "=", 
          RowBox[{"Total", "[", 
           RowBox[{"x", " ", "bPure"}], "]"}]}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{"dm", "^", "3"}], " ", 
           RowBox[{"mol", "^", 
            RowBox[{"-", "1"}]}]}], "*)"}], "\n", "\t\t", 
         RowBox[{"\[CurlyPhi]Liq", "=", 
          RowBox[{"\[CurlyPhi]MixtureVdW", "[", 
           RowBox[{
           "aij", ",", "bLiq", ",", "bPure", ",", "x", ",", "p", ",", "vLiq", 
            ",", "t"}], "]"}]}], ";", 
         RowBox[{"(*", " ", "1", " ", "*)"}], "\[IndentingNewLine]", "\t\t", 
         "\n", "\t\t", 
         RowBox[{"\[Sigma]Vap", "=", 
          RowBox[{"\[Sigma]m", "[", 
           RowBox[{"y", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", 
         RowBox[{"(*", " ", "A", " ", "*)"}], "\n", "\t\t", 
         RowBox[{"\[Epsilon]Vap", "=", 
          RowBox[{"\[Epsilon]m", "[", 
           RowBox[{"y", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{"kcal", "/", "mol"}], " ", "*)"}], "\[IndentingNewLine]", 
         "\t\t", 
         RowBox[{"bVap", "=", 
          RowBox[{"Total", "[", 
           RowBox[{"y", " ", "bPure"}], "]"}]}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{"dm", "^", "3"}], " ", 
           RowBox[{"mol", "^", 
            RowBox[{"-", "1"}]}]}], "*)"}], "\n", "\t\t", 
         RowBox[{"vVap", "=", 
          RowBox[{"Max", "@", 
           RowBox[{"Values", "@", 
            RowBox[{"vVdWLJ", "[", 
             RowBox[{
             "t", ",", "p", ",", "\[Sigma]Vap", ",", "\[Epsilon]Vap"}], 
             "]"}]}]}]}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{"dm", "^", "3"}], " ", 
           RowBox[{"mol", "^", 
            RowBox[{"-", "1"}]}]}], "*)"}], "\n", "\t\t", 
         RowBox[{"\[CurlyPhi]Vap", "=", 
          RowBox[{"\[CurlyPhi]MixtureVdW", "[", 
           RowBox[{
           "aij", ",", "bVap", ",", "bPure", ",", "y", ",", "p", ",", "vVap", 
            ",", "t"}], "]"}]}], ";", 
         RowBox[{"(*", " ", "1", " ", "*)"}], "\[IndentingNewLine]", "\t\t", 
         "\[IndentingNewLine]", "\t\t", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{"verbose", ",", 
             RowBox[{"Print", "@", 
              RowBox[{"{", 
               RowBox[{"p", ",", "x", ",", 
                RowBox[{"Values", "@", 
                 RowBox[{"vVdWLJ", "[", 
                  RowBox[{
                  "t", ",", "p", ",", "\[Sigma]Liq", ",", "\[Epsilon]Liq"}], 
                  "]"}]}], ",", "y", ",", 
                RowBox[{"Values", "@", 
                 RowBox[{"vVdWLJ", "[", 
                  RowBox[{
                  "t", ",", "p", ",", "\[Sigma]Vap", ",", "\[Epsilon]Vap"}], 
                  "]"}]}]}], "}"}]}]}], "]"}], ";"}], "*)"}], "\n", "\t\t", 
         "\n", "\t\t", 
         RowBox[{"kValue", "=", 
          RowBox[{"\[CurlyPhi]Liq", "/", "\[CurlyPhi]Vap"}]}], ";", 
         RowBox[{"(*", " ", "1", " ", "*)"}], "\n", "\t\t", 
         RowBox[{"s", "=", 
          RowBox[{"Total", "[", 
           RowBox[{"x", " ", "kValue"}], "]"}]}], ";", 
         RowBox[{"(*", " ", "1", " ", "*)"}], "\n", "\t\t", 
         RowBox[{"If", "[", 
          RowBox[{"verbose", ",", 
           RowBox[{"Print", "[", 
            RowBox[{"N", ",", "\"\<\\t\>\"", ",", "s"}], "]"}]}], "]"}], ";", 
         "\n", "\t\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"s", "-", "1."}], "]"}], "/", "s"}], " ", "100."}], 
            "<", "epsilon"}], ",", 
           RowBox[{"Break", "[", "]"}]}], "]"}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{"accuracy", " ", "threshold"}], " ", "*)"}], "\n", "\t\t", 
         RowBox[{"p", "=", 
          RowBox[{"p", " ", "s"}]}], ";", "\n", "\t\t", 
         RowBox[{"y", "=", 
          RowBox[{"x", " ", 
           RowBox[{"kValue", "/", "s"}]}]}], ";", "\n", "\t\t", 
         "\[IndentingNewLine]", "\t\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"N", " ", "==", " ", "100"}], ",", " ", 
           RowBox[{
           "Print", "[", "\"\<Maximum Iterations reached!\>\"", "]"}]}], 
          "]"}]}], "\n", "\t\t", ",", 
        RowBox[{"{", 
         RowBox[{"N", ",", "100"}], "}"}]}], "\n", "\t", "]"}], ";", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"trouble", "&&", "verbose"}], ",", 
        RowBox[{
        "Print", "[", 
         "\"\<Negative liquid molar volume or no real liquid molar volume \
solution was found!\>\"", "]"}]}], "]"}], ";", "\[IndentingNewLine]", "\t", 
      RowBox[{"If", "[", 
       RowBox[{"verbose", ",", "\n", "\t\t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{"s", "-", "1."}], "]"}], "/", "s"}], " ", "100."}], ">",
            "\[Epsilon]"}], ",", 
          RowBox[{
          "Print", "[", "\"\<\[SadSmiley] No convergence.\\n\>\"", "]"}], ",",
           "\n", "\t\t\t", 
          RowBox[{
          "Print", "[", 
           "\"\<\[HappySmiley] Bubble condition fulfilled, converged.\\n\>\"",
            "]"}]}], "\n", "\t\t", "]"}]}], "\n", "\t", "]"}], ";", "\n", 
      "\t", "\n", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{"Return", " ", 
        RowBox[{"{", 
         RowBox[{"Pressure", ",", " ", 
          RowBox[{
          "liquid", " ", "phase", " ", "molar", " ", "fraction", " ", "1"}], 
          ",", " ", 
          RowBox[{
          "vapor", " ", "phase", " ", "molar", " ", "fraction", " ", "1"}], 
          ",", " ", 
          RowBox[{"liquid", " ", "molar", " ", "volume"}], ",", " ", 
          RowBox[{"vapor", " ", "molar", " ", "volume"}]}], "}"}]}], " ", 
       "*)"}], "\n", "\t", 
      RowBox[{"{", 
       RowBox[{"p", ",", "x", ",", "y", ",", "vLiq", ",", "vVap"}], "}"}]}]}],
     "\n", "]"}]}], ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[98]:=",ExpressionUUID->"89b91d50-91de-4b26-9ea7-1da7f4dd6380"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CalculateVdWLJ", "[", 
   RowBox[{
   "tSim_", ",", "pSim_", ",", "\[Sigma]ij_", ",", "\[Epsilon]ij_", ",", 
    "epsilon_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", "\t", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
     RowBox[{
     "aVdWLJ", ",", "bVdWLJ", ",", "aij", ",", "bPure", ",", "\n", "\t\t", 
      "xInit", ",", "x", ",", "yGuess", ",", "pGuess", ",", "pInit", ",", 
      "sol", ",", "\n", "\t\t", "dx", ",", "trouble"}], "\[IndentingNewLine]",
      "\t", "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", "\t", 
    RowBox[{"(*", 
     RowBox[{"Van", " ", "der", " ", "Waals", " ", "EoS", " ", "parameter"}], 
     "*)"}], "\[IndentingNewLine]", "\t", 
    RowBox[{
     RowBox[{
      RowBox[{"aVdWLJ", "[", 
       RowBox[{"\[Sigma]_", ",", "\[Epsilon]_"}], "]"}], ":=", 
      RowBox[{"6.02214076", " ", "*", "16", " ", "Pi", " ", "4.184", " ", "*", 
       RowBox[{
        RowBox[{"10", "^", 
         RowBox[{"-", "3"}]}], "/", "9"}], " ", "\[Epsilon]", " ", 
       RowBox[{"\[Sigma]", "^", "3"}]}]}], ";", "\[IndentingNewLine]", "\t", 
     RowBox[{
      RowBox[{"bVdWLJ", "[", "\[Sigma]_", "]"}], ":=", 
      RowBox[{"6.02214076", " ", "*", 
       RowBox[{"10", "^", 
        RowBox[{"-", "4"}]}], " ", 
       RowBox[{"\[Sigma]", "^", "3"}]}]}], ";", "\[IndentingNewLine]", "\t", 
     RowBox[{"aij", "=", 
      RowBox[{"aVdWLJ", "[", 
       RowBox[{"\[Sigma]ij", ",", "\[Epsilon]ij"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\t", 
     RowBox[{"bPure", "=", 
      RowBox[{"bVdWLJ", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Sigma]ij", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"\[Sigma]ij", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "}"}], "]"}]}], ";", "\n",
      "\t", "\n", "\t", 
     RowBox[{"trouble", " ", "=", " ", "False"}], ";", "\[IndentingNewLine]", 
     "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"initial", " ", "calculation", " ", "at", " ", "x1"}], " ", 
       "=", " ", "1"}], "*)"}], "\[IndentingNewLine]", "\t", 
     RowBox[{"xInit", " ", "=", " ", 
      RowBox[{"yGuess", " ", "=", " ", "1"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"First", " ", "Guess", " ", "at", " ", "x1"}], " ", "=", " ", 
       RowBox[{"y1", " ", "=", " ", "1"}]}], "*)"}], "\n", "\t", 
     RowBox[{"dx", " ", "=", " ", 
      RowBox[{"-", "0.05"}]}], ";", "\[IndentingNewLine]", "\t", 
     RowBox[{"pGuess", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"pLJ", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"pSatRedLJ", "[", 
            RowBox[{
             RowBox[{"tRedLJ", "[", 
              RowBox[{"tSim", ",", 
               RowBox[{"\[Epsilon]", "[", 
                RowBox[{"[", 
                 RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], "/", 
             "tCritLJ"}], "]"}], "*", "pCritLJ"}], ",", 
          RowBox[{"\[Epsilon]", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], "[", 
       "1", "]"}]}], ";", "\n", "\t", 
     RowBox[{"sol", " ", "=", " ", 
      RowBox[{"Quiet", "@", 
       RowBox[{"bubblePressureVdWLJ", "[", 
        RowBox[{"aij", ",", "bPure", ",", "tSim", ",", 
         RowBox[{"{", 
          RowBox[{"xInit", ",", 
           RowBox[{"1", "-", "xInit"}]}], "}"}], ",", "pGuess", ",", 
         RowBox[{"{", 
          RowBox[{"yGuess", ",", 
           RowBox[{"1", "-", "yGuess"}]}], "}"}], ",", "epsilon", ",", 
         "False"}], "]"}]}]}], ";", "\n", "\n", "\t", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"AnyTrue", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"sol", "[", 
             RowBox[{"[", "4", "]"}], "]"}], "==", 
            RowBox[{"sol", "[", 
             RowBox[{"[", "5", "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"sol", "[", 
             RowBox[{"[", "4", "]"}], "]"}], ">", 
            RowBox[{"sol", "[", 
             RowBox[{"[", "5", "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"sol", "[", 
             RowBox[{"[", "4", "]"}], "]"}], "<", "0"}]}], "}"}], ",", 
         "TrueQ"}], "]"}], "\n", "\t\t", ",", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
          RowBox[{"True", ":", " ", 
           RowBox[{"the", " ", "calculation", " ", "has", " ", "failed"}]}], 
          " ", "->", " ", 
          RowBox[{"start", " ", "calculation", " ", "from", " ", "x1"}]}], 
         " ", "=", " ", "0"}], "*)"}], "\n", "\t\t", 
       RowBox[{
        RowBox[{"xInit", " ", "=", " ", 
         RowBox[{"yGuess", " ", "=", " ", "0"}]}], ";", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"First", " ", "Guess", " ", "at", " ", "x1"}], " ", "=", 
          " ", 
          RowBox[{"y1", " ", "=", " ", "1"}]}], "*)"}], "\n", "\t\t", 
        RowBox[{"dx", " ", "=", " ", "0.05"}], ";", "\n", "\t\t", 
        RowBox[{"pGuess", " ", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"pLJ", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"pSatRedLJ", "[", 
               RowBox[{
                RowBox[{"tRedLJ", "[", 
                 RowBox[{"tSim", ",", 
                  RowBox[{"\[Epsilon]", "[", 
                   RowBox[{"[", 
                    RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], "/", 
                "tCritLJ"}], "]"}], "*", "pCritLJ"}], ",", 
             RowBox[{"\[Epsilon]", "[", 
              RowBox[{"[", 
               RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
             RowBox[{"\[Sigma]", "[", 
              RowBox[{"[", 
               RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], 
          "[", "2", "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"sol", " ", "=", " ", 
         RowBox[{"Quiet", "@", 
          RowBox[{"bubblePressureVdWLJ", "[", 
           RowBox[{"aij", ",", "bPure", ",", "tSim", ",", 
            RowBox[{"{", 
             RowBox[{"xInit", ",", 
              RowBox[{"1", "-", "xInit"}]}], "}"}], ",", "pGuess", ",", 
            RowBox[{"{", 
             RowBox[{"yGuess", ",", 
              RowBox[{"1", "-", "yGuess"}]}], "}"}], ",", "epsilon", ",", 
            "False"}], "]"}]}]}], ";"}]}], "\n", "\t", "]"}], ";", "\n", "\t",
      "\n", "\t", 
     RowBox[{"pInit", " ", "=", " ", 
      RowBox[{"sol", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{"initial", " ", "calculated", " ", "pressure"}], "*)"}], "\n", 
     "\t", 
     RowBox[{"x", " ", "=", " ", "xInit"}], ";", "\t", "\n", "\t", 
     RowBox[{"Do", "[", "\n", "\t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"If", "[", "\n", "\t\t\t", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"pInit", ">", "pSim"}], ",", 
            RowBox[{
             RowBox[{"sol", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "<", "pSim"}], ",", 
            RowBox[{
             RowBox[{"sol", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ">", "pSim"}]}], "]"}], ",", 
          "\n", "\t\t\t", 
          RowBox[{
           RowBox[{"Break", "[", "]"}], ";"}]}], "\n", "\t\t", "]"}], ";", 
        "\n", "\t\t", "\n", "\t\t", 
        RowBox[{"x", " ", "+=", " ", 
         RowBox[{"dx", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"sol", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "pSim"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"pInit", "-", "pSim"}], ")"}]}]}]}], ";", "\n", "\t\t", 
        RowBox[{"pGuess", " ", "=", " ", 
         RowBox[{"sol", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"yGuess", " ", "=", " ", 
         RowBox[{"sol", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"sol", " ", "=", " ", 
         RowBox[{"Quiet", "@", 
          RowBox[{"bubblePressureVdWLJ", "[", 
           RowBox[{"aij", ",", "bPure", ",", "tSim", ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", 
              RowBox[{"1", "-", "x"}]}], "}"}], ",", "pGuess", ",", 
            RowBox[{"{", 
             RowBox[{"yGuess", ",", 
              RowBox[{"1", "-", "yGuess"}]}], "}"}], ",", "epsilon", ",", 
            "False"}], "]"}]}]}], ";", "\n", "\t\t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"AnyTrue", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"sol", "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "1"}], "]"}], "]"}], "<", "0"}], ",", 
              RowBox[{
               RowBox[{"sol", "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "1"}], "]"}], "]"}], ">", "1"}]}], "}"}], 
            ",", "TrueQ"}], "]"}], ",", 
          RowBox[{
           RowBox[{"trouble", " ", "=", " ", "True"}], ";", 
           RowBox[{"Break", "[", "]"}], ";"}]}], "]"}], ";", "\n", "\t\t", 
        "\n", "\t\t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"nt", "==", "500"}], ",", 
          RowBox[{
           RowBox[{"Print", "@", "\"\<Maximum Iterations Reached!\>\""}], ";", 
           RowBox[{"Break", "[", "]"}], ";"}]}], "]"}], ";"}], "\n", "\t\t", 
       ",", 
       RowBox[{"{", 
        RowBox[{"nt", ",", "500"}], "}"}]}], "\n", "\t", "]"}], ";", 
     "\[IndentingNewLine]", "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{
      "return", " ", "bubble", " ", "pressure", " ", "calculation", " ", 
       "results"}], "*)"}], "\[IndentingNewLine]", "\t", 
     RowBox[{"If", "[", 
      RowBox[{"trouble", ",", "\n", "\t\t", 
       RowBox[{"{", 
        RowBox[{
        "\"\<N/A\>\"", ",", "\"\<N/A\>\"", ",", "\"\<N/A\>\"", ",", 
         "\"\<N/A\>\"", ",", "\"\<N/A\>\""}], "}"}], ",", 
       "\[IndentingNewLine]", "\t\t", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"sol", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"sol", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"sol", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"sol", "[", 
          RowBox[{"[", "4", "]"}], "]"}], ",", 
         RowBox[{"sol", "[", 
          RowBox[{"[", "5", "]"}], "]"}]}], "}"}]}], "\n", "\t", "]"}]}]}], 
   "\n", "]"}]}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->"In[99]:=",ExpressionUUID->"7ab670cc-ffae-44a5-bc16-e17b89639e49"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CalculateMolarVolumeVdWLJ", "[", 
   RowBox[{"vLiq_", ",", "x1_", ",", "vVap_", ",", "y1_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"vLiq", " ", "=!=", " ", "\"\<N/A\>\""}], ",", "\n", "\t", 
    RowBox[{"{", 
     RowBox[{"vLiq", ",", "vVap", ",", 
      RowBox[{"vToRho", "@", "vLiq"}], ",", 
      RowBox[{"vToRho", "@", "vVap"}], ",", 
      RowBox[{"RhoToRhoAst", "[", 
       RowBox[{
        RowBox[{"vToRho", "@", "vLiq"}], ",", "x1"}], "]"}], ",", 
      RowBox[{"RhoToRhoAst", "[", 
       RowBox[{
        RowBox[{"vToRho", "@", "vVap"}], ",", "y1"}], "]"}]}], "}"}], "\n", 
    "\t", ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<N/A\>\"", ",", "\"\<N/A\>\"", ",", "\"\<N/A\>\"", ",", 
      "\"\<N/A\>\"", ",", "\"\<N/A\>\"", ",", "\"\<N/A\>\""}], "}"}]}], "\n", 
   "]"}]}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->
  "In[100]:=",ExpressionUUID->"3ece98c0-f253-4444-8301-a8492b6a0e2e"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Calculation", " ", "of", " ", "molar", " ", "fraction", " ", 
    RowBox[{"(", "MF", ")"}], " ", "and", " ", "molar", " ", "volume", " ", 
    RowBox[{"(", "MV", ")"}]}], "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "resPVdWLJ", ",", "resxVdWLJ", ",", "resyVdWLJ", ",", "resvLiqVdWLJ", 
       ",", "resvVapVdWLJ"}], "}"}], " ", "=", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"CalculateVdWLJ", "[", 
         RowBox[{
         "tSim", ",", "#", ",", "\[Sigma]", ",", "\[Epsilon]", ",", 
          "\[Epsilon]Iteration"}], "]"}], " ", "&"}], "/@", " ", "pSim"}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"resMFVdWLJ", " ", "=", " ", 
     RowBox[{"Transpose", "@", 
      RowBox[{"{", 
       RowBox[{"resxVdWLJ", ",", "resyVdWLJ"}], "}"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"resMVVdWLJ", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"CalculateMolarVolumeVdWLJ", "[", 
        RowBox[{
         RowBox[{"resvLiqVdWLJ", "[", 
          RowBox[{"[", "#", "]"}], "]"}], ",", 
         RowBox[{"resxVdWLJ", "[", 
          RowBox[{"[", "#", "]"}], "]"}], ",", 
         RowBox[{"resvVapVdWLJ", "[", 
          RowBox[{"[", "#", "]"}], "]"}], ",", 
         RowBox[{"resyVdWLJ", "[", 
          RowBox[{"[", "#", "]"}], "]"}]}], "]"}], " ", "&"}], "/@", " ", 
      RowBox[{"Range", "@", 
       RowBox[{"Length", "@", "pSim"}]}]}]}], ";"}], "\n", 
   RowBox[{"Grid", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"ShowEoSResults", "[", 
         RowBox[{"\"\<Van der Waals EoS\>\"", ",", 
          RowBox[{"resPVdWLJ", "[", 
           RowBox[{"[", "#", "]"}], "]"}], ",", 
          RowBox[{"resMFVdWLJ", "[", 
           RowBox[{"[", "#", "]"}], "]"}], ",", 
          RowBox[{"resMVVdWLJ", "[", 
           RowBox[{"[", "#", "]"}], "]"}]}], "]"}], ")"}], " ", "&"}], "/@", 
      " ", 
      RowBox[{"Range", "@", 
       RowBox[{"Length", "@", "pSim"}]}]}], " ", "}"}]}]}]}]], "Code",
 CellLabel->
  "In[101]:=",ExpressionUUID->"c0fb8953-a3eb-4d72-97f4-e298c03cb041"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"Van der Waals EoS @6.21294 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", 
           "0.37007539422472413`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", 
           "0.194840786226125`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", 
           "0.0008587271393330006`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.010872257013647767`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "0.70128687963415`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.055389977926758954`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.70128687963415`", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.055389977926758954`", "\"[1]\""}}, AutoDelete -> 
         False, GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"], 
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"Van der Waals EoS @8.28392 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", 
           "0.030287262016023553`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", 
           "0.014725068879890753`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", 
           "0.0009324439574708518`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.007532457747864832`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "0.6458447943975498`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.07994921394291325`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.6458447943975498`", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.07994921394291325`", "\"[1]\""}}, AutoDelete -> 
         False, GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"], 
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"Van der Waals EoS @N/A bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", "\"N/A\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", "\"N/A\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", "\"N/A\"", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", "\"N/A\"", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "\"N/A\"", 
           
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "\"N/A\"", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "\"N/A\"", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "\"N/A\"", "\"[1]\""}}, AutoDelete -> False, 
         GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->
  "Out[104]=",ExpressionUUID->"d7542c9f-82e1-4b83-a6a8-785d89b04744"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualisation", "Subsubsection",ExpressionUUID->"6f1f60d9-6a1a-4ab9-8d22-1780e368a6a9"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"1f44ebea-aba0-4003-a329-2c55d11983ce"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CalculatePlotDataVdW", "[", 
   RowBox[{
   "tSim_", ",", "pSim_", ",", "\[Sigma]ij_", ",", "\[Epsilon]ij_", ",", 
    "epsilon_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", "\t", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
     RowBox[{
     "aVdWLJ", ",", "bVdWLJ", ",", "aij", ",", "bPure", ",", "\n", "\t\t", 
      "xInit", ",", "x", ",", "yGuess", ",", "pGuess", ",", "pInit", ",", 
      "sol", ",", "\n", "\t\t", "dx", ",", "trouble", ",", "nt"}], 
     "\[IndentingNewLine]", "\t", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "\t", 
    RowBox[{"(*", 
     RowBox[{"Van", " ", "der", " ", "Waals", " ", "EoS", " ", "parameter"}], 
     "*)"}], "\[IndentingNewLine]", "\t", 
    RowBox[{
     RowBox[{
      RowBox[{"aVdWLJ", "[", 
       RowBox[{"\[Sigma]_", ",", "\[Epsilon]_"}], "]"}], ":=", 
      RowBox[{"6.02214076", " ", "*", "16", " ", "Pi", " ", "4.184", " ", "*", 
       RowBox[{
        RowBox[{"10", "^", 
         RowBox[{"-", "3"}]}], "/", "9"}], " ", "\[Epsilon]", " ", 
       RowBox[{"\[Sigma]", "^", "3"}]}]}], ";", "\[IndentingNewLine]", "\t", 
     RowBox[{
      RowBox[{"bVdWLJ", "[", "\[Sigma]_", "]"}], ":=", 
      RowBox[{"6.02214076", " ", "*", 
       RowBox[{"10", "^", 
        RowBox[{"-", "4"}]}], " ", 
       RowBox[{"\[Sigma]", "^", "3"}]}]}], ";", "\[IndentingNewLine]", "\t", 
     RowBox[{"aij", "=", 
      RowBox[{"aVdWLJ", "[", 
       RowBox[{"\[Sigma]ij", ",", "\[Epsilon]ij"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\t", 
     RowBox[{"bPure", "=", 
      RowBox[{"bVdWLJ", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Sigma]ij", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"\[Sigma]ij", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "}"}], "]"}]}], ";", "\n",
      "\t", "\n", "\t", 
     RowBox[{"trouble", " ", "=", " ", "False"}], ";", "\[IndentingNewLine]", 
     "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"initial", " ", "calculation", " ", "at", " ", "x1"}], " ", 
       "=", " ", "1"}], "*)"}], "\[IndentingNewLine]", "\t", 
     RowBox[{"xInit", " ", "=", " ", 
      RowBox[{"yGuess", " ", "=", " ", "1"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"First", " ", "Guess", " ", "at", " ", "x1"}], " ", "=", " ", 
       RowBox[{"y1", " ", "=", " ", "1"}]}], "*)"}], "\n", "\t", 
     RowBox[{"dx", " ", "=", " ", 
      RowBox[{"-", "0.01"}]}], ";", "\[IndentingNewLine]", "\t", 
     RowBox[{"pGuess", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"pLJ", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"pSatRedLJ", "[", 
            RowBox[{
             RowBox[{"tRedLJ", "[", 
              RowBox[{"tSim", ",", 
               RowBox[{"\[Epsilon]", "[", 
                RowBox[{"[", 
                 RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], "/", 
             "tCritLJ"}], "]"}], "*", "pCritLJ"}], ",", 
          RowBox[{"\[Epsilon]", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], "[", 
       "1", "]"}]}], ";", "\n", "\t", 
     RowBox[{"sol", " ", "=", " ", 
      RowBox[{"Quiet", "@", 
       RowBox[{"bubblePressureVdWLJ", "[", 
        RowBox[{"aij", ",", "bPure", ",", "tSim", ",", 
         RowBox[{"{", 
          RowBox[{"xInit", ",", 
           RowBox[{"1", "-", "xInit"}]}], "}"}], ",", "pGuess", ",", 
         RowBox[{"{", 
          RowBox[{"yGuess", ",", 
           RowBox[{"1", "-", "yGuess"}]}], "}"}], ",", "epsilon", ",", 
         "False"}], "]"}]}]}], ";", "\n", "\n", "\t", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"AnyTrue", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"sol", "[", 
             RowBox[{"[", "4", "]"}], "]"}], "==", 
            RowBox[{"sol", "[", 
             RowBox[{"[", "5", "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"sol", "[", 
             RowBox[{"[", "4", "]"}], "]"}], ">", 
            RowBox[{"sol", "[", 
             RowBox[{"[", "5", "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"sol", "[", 
             RowBox[{"[", "4", "]"}], "]"}], "<", "0"}]}], "}"}], ",", 
         "TrueQ"}], "]"}], "\n", "\t\t", ",", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
          RowBox[{"True", ":", " ", 
           RowBox[{"the", " ", "calculation", " ", "has", " ", "failed"}]}], 
          " ", "->", " ", 
          RowBox[{"start", " ", "calculation", " ", "from", " ", "x1"}]}], 
         " ", "=", " ", "0"}], "*)"}], "\n", "\t\t", 
       RowBox[{
        RowBox[{"xInit", " ", "=", " ", 
         RowBox[{"yGuess", " ", "=", " ", "0"}]}], ";", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"First", " ", "Guess", " ", "at", " ", "x1"}], " ", "=", 
          " ", 
          RowBox[{"y1", " ", "=", " ", "1"}]}], "*)"}], "\n", "\t\t", 
        RowBox[{"dx", " ", "=", " ", "0.01"}], ";", "\n", "\t\t", 
        RowBox[{"pGuess", " ", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"pLJ", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"pSatRedLJ", "[", 
               RowBox[{
                RowBox[{"tRedLJ", "[", 
                 RowBox[{"tSim", ",", 
                  RowBox[{"\[Epsilon]", "[", 
                   RowBox[{"[", 
                    RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], "/", 
                "tCritLJ"}], "]"}], "*", "pCritLJ"}], ",", 
             RowBox[{"\[Epsilon]", "[", 
              RowBox[{"[", 
               RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
             RowBox[{"\[Sigma]", "[", 
              RowBox[{"[", 
               RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], 
          "[", "2", "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"sol", " ", "=", " ", 
         RowBox[{"Quiet", "@", 
          RowBox[{"bubblePressureVdWLJ", "[", 
           RowBox[{"aij", ",", "bPure", ",", "tSim", ",", 
            RowBox[{"{", 
             RowBox[{"xInit", ",", 
              RowBox[{"1", "-", "xInit"}]}], "}"}], ",", "pGuess", ",", 
            RowBox[{"{", 
             RowBox[{"yGuess", ",", 
              RowBox[{"1", "-", "yGuess"}]}], "}"}], ",", "epsilon", ",", 
            "False"}], "]"}]}]}], ";"}]}], "\n", "\t", "]"}], ";", "\n", "\t",
      "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{"caclculate", " ", "plot", " ", "data"}], "*)"}], "\n", "\t", 
     RowBox[{"pGuess", " ", "=", " ", 
      RowBox[{"sol", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{"initial", " ", "calculated", " ", "pressure"}], "*)"}], "\t", 
     "\n", "\t", 
     RowBox[{"yGuess", " ", "=", " ", "xInit"}], ";", "\n", "\t", 
     RowBox[{"pVec", " ", "=", " ", 
      RowBox[{"xVec", " ", "=", " ", 
       RowBox[{"yVec", " ", "=", " ", 
        RowBox[{"vLiqVec", " ", "=", " ", 
         RowBox[{"vVapVec", " ", "=", " ", 
          RowBox[{"{", "}"}]}]}]}]}]}], ";", "\n", "\t", 
     RowBox[{"Do", "[", "\n", "\t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"sol", " ", "=", " ", 
         RowBox[{"bubblePressureVdWLJ", "[", 
          RowBox[{"aij", ",", "bPure", ",", "tSim", ",", 
           RowBox[{"{", 
            RowBox[{"x1", ",", 
             RowBox[{"1", "-", "x1"}]}], "}"}], ",", "pGuess", ",", 
           RowBox[{"{", 
            RowBox[{"yGuess", ",", 
             RowBox[{"1", "-", "yGuess"}]}], "}"}], ",", "epsilon", ",", 
           "False"}], "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{
         "check", " ", "if", " ", "calculation", " ", "was", " ", 
          "sucsessful", " ", "and", " ", "exit", " ", "if", " ", "it", " ", 
          "failed"}], "*)"}], "\n", "\t\t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"AnyTrue", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"sol", "[", 
                RowBox[{"[", "4", "]"}], "]"}], "==", 
               RowBox[{"sol", "[", 
                RowBox[{"[", "5", "]"}], "]"}]}], ",", 
              RowBox[{
               RowBox[{"sol", "[", 
                RowBox[{"[", "4", "]"}], "]"}], ">", 
               RowBox[{"sol", "[", 
                RowBox[{"[", "5", "]"}], "]"}]}], ",", 
              RowBox[{
               RowBox[{"sol", "[", 
                RowBox[{"[", "4", "]"}], "]"}], "<", "0"}]}], "}"}], ",", 
            "TrueQ"}], "]"}], ",", 
          RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"pVec", ",", 
          RowBox[{"sol", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"xVec", ",", 
          RowBox[{"sol", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "1"}], "]"}], "]"}]}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"yVec", ",", 
          RowBox[{"sol", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "1"}], "]"}], "]"}]}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"vLiqVec", ",", 
          RowBox[{"sol", "[", 
           RowBox[{"[", "4", "]"}], "]"}]}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"vVapVec", ",", 
          RowBox[{"sol", "[", 
           RowBox[{"[", "5", "]"}], "]"}]}], "]"}], ";", "\n", "\t\t", "\n", 
        "\t\t", 
        RowBox[{"pGuess", " ", "=", " ", 
         RowBox[{"sol", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"yGuess", " ", "=", " ", 
         RowBox[{"sol", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ";"}], "\n", "\t\t", ",", 
       RowBox[{"{", 
        RowBox[{"x1", ",", "xInit", ",", 
         RowBox[{"1", "-", "xInit"}], ",", "dx"}], "}"}]}], "\n", "\t", "]"}],
      ";"}]}], "\n", "]"}]}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->
  "In[105]:=",ExpressionUUID->"49083bda-3869-4926-a6fd-d1d5ed7b95ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plotPxyVdW", "[", "]"}], " ", ":=", " ", 
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"{", "\n", "\t", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"Show", "[", 
             RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
              RowBox[{
               RowBox[{"ListLinePlot", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{"xVec", ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{"pVec", ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    "]"}], ",", 
                   RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{"yVec", ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{"pVec", ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    "]"}]}], "}"}], "\n", "\t\t\t", ",", 
                 RowBox[{"Frame", "->", "True"}], ",", 
                 RowBox[{"GridLines", "\[Rule]", "Automatic"}], "\n", 
                 "\t\t\t", ",", 
                 RowBox[{"FrameLabel", "\[Rule]", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "Bold", ",", "14", ",", 
                    RowBox[{"SingleLetterItalics", "->", "False"}]}], "]"}], 
                    "&"}], "/@", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<\!\(\*SubscriptBox[\(x\), \
\(1\)]\),\!\(\*SubscriptBox[\(y\), \(1\)]\) [mol/mol]\>\"", ",", 
                    "\"\<\!\(\*SuperscriptBox[\(P\), \(*\)]\) [1]\>\""}], 
                    "}"}]}], ")"}]}], "\n", "\t\t\t", ",", 
                 RowBox[{"PlotLabel", "\[Rule]", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"component", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "<>", "\"\<-\>\"", "<>", 
                    RowBox[{"component", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "<>", "\"\< @T = \>\""}], 
                    ",", 
                    RowBox[{"ToString", "[", "tSim", "]"}], ",", 
                    "\"\< K\\n\>\""}], "}"}], "]"}]}], "\n", "\t\t\t", ",", 
                 RowBox[{"PlotLegends", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                   "\"\<VdW, bubble curve\>\"", ",", 
                    "\"\<VdW, dew curve\>\""}], "}"}]}], "\n", "\t\t\t", ",", 
                 RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "1"}], "}"}], ",", "Automatic"}], 
                   "}"}]}]}], "\n", "\t\t", "]"}], ",", "\[IndentingNewLine]",
                "\t\t", 
               RowBox[{"ListPlot", "[", 
                RowBox[{
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"resMFVdWLJ", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{
                    RowBox[{"resPVdWLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"resMFVdWLJ", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{
                    RowBox[{"resPVdWLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}]}],
                     "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "]"}], "\n", 
                 "\t\t\t", ",", 
                 RowBox[{"PlotStyle", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"Red", ",", "Blue", ",", "Orange"}], "}"}]}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"Automatic", ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Automatic"}], "}"}]}], "}"}]}], "\n", 
                 "\t\t\t", ",", 
                 RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
                 RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}], 
                 "\n", "\t\t\t", ",", 
                 RowBox[{"PlotLegends", "\[Rule]", 
                  RowBox[{"Table", "[", 
                   RowBox[{
                    RowBox[{"\"\<Simulation point @\>\"", "<>", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"pSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], "<>", 
                    "\"\< bar\>\""}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "]"}]}]}], 
                "\n", "\t\t", "]"}]}], "\[IndentingNewLine]", "\t", "}"}], 
             "]"}], "}"}], "}"}], "}"}], ",", "\n", "\t", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", "\n", "\t\t", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"Row", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<Simulation @\>\"", ",", " ", 
                 RowBox[{"pSim", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", 
                 "\"\< bar : \!\(\*SubscriptBox[\(x\), \(1\)]\) = \>\"", ",", 
                 RowBox[{"Round", "[", 
                  RowBox[{
                   RowBox[{"resMFVdWLJ", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", "0.00001"}], 
                  "]"}], ",", 
                 "\"\< mol \!\(\*SuperscriptBox[\(mol\), \(-1\)]\), \
\!\(\*SubscriptBox[\(y\), \(1\)]\) = \>\"", ",", 
                 RowBox[{"Round", "[", 
                  RowBox[{
                   RowBox[{"resMFVdWLJ", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", "0.00001"}], 
                  "]"}], ",", 
                 "\"\< mol \!\(\*SuperscriptBox[\(mol\), \(-1\)]\)\>\""}], 
                "}"}], "]"}], "}"}], ",", "\n", "\t\t", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"Row", "[", 
                 RowBox[{"{", 
                  RowBox[{
                  "\"\<\\t \!\(\*SubscriptBox[\(x\), \(m25  %\)]\) = \>\"", 
                   ",", " ", 
                   RowBox[{"#1", "+", 
                    RowBox[{"#2", "*", "0.25"}]}], ",", " ", 
                   "\"\<\\t \!\(\*SubscriptBox[\(x\), \(m50  %\)]\) = \>\"", 
                   ",", 
                   RowBox[{"#1", "+", 
                    RowBox[{"#2", "*", "0.5"}]}], ",", 
                   "\"\<\\t \!\(\*SubscriptBox[\(x\), \(m75  %\)]\) = \>\"", 
                   ",", " ", 
                   RowBox[{"#1", "+", 
                    RowBox[{"#2", "*", "0.75"}]}]}], "}"}], "]"}], "&"}], "[", 
               RowBox[{
                RowBox[{"resMFVdWLJ", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"resMFVdWLJ", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], "-", 
                  RowBox[{"resMFVdWLJ", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ")"}]}], "]"}], 
              "}"}]}], "\n", "\t\t", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "\n", "\t", "]"}]}], 
        "\n", "}"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Alignment", "->", "Left"}]}], "]"}]}], ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->
  "In[106]:=",ExpressionUUID->"993accd7-401a-4dd0-bb64-b48d0e7e70e7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plotPrhoVdW", "[", "]"}], " ", ":=", " ", 
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"{", "\n", "\t", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"Show", "[", 
             RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
              RowBox[{
               RowBox[{"ListLinePlot", "[", 
                RowBox[{
                 RowBox[{"{", "\n", "\t\t\t\t", 
                  RowBox[{
                   RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"RhoToRhoAst", "[", 
                    RowBox[{
                    RowBox[{"vToRho", "[", "vLiqVec", "]"}], ",", "xVec"}], 
                    "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{"pVec", ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    "]"}], ",", "\n", "\t\t\t\t", 
                   RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"RhoToRhoAst", "[", 
                    RowBox[{
                    RowBox[{"vToRho", "[", "vVapVec", "]"}], ",", "yVec"}], 
                    "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{"pVec", ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    "]"}]}], "\n", "\t\t\t", "}"}], "\n", "\t\t\t", ",", 
                 RowBox[{"Frame", "->", "True"}], ",", 
                 RowBox[{"GridLines", "\[Rule]", "Automatic"}], "\n", 
                 "\t\t\t", ",", 
                 RowBox[{"FrameLabel", "\[Rule]", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "Bold", ",", "14", ",", 
                    RowBox[{"SingleLetterItalics", "->", "False"}]}], "]"}], 
                    "&"}], "/@", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(L\), \(*\)]\),\
\!\(\*SubsuperscriptBox[\(\[Rho]\), \(V\), \(*\)]\) [1]\>\"", ",", 
                    "\"\<\!\(\*SuperscriptBox[\(P\), \(*\)]\) [1]\>\""}], 
                    "}"}]}], ")"}]}], "\n", "\t\t\t", ",", 
                 RowBox[{"PlotLabel", "\[Rule]", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"component", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "<>", "\"\<-\>\"", "<>", 
                    RowBox[{"component", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "<>", "\"\< @T = \>\""}], 
                    ",", 
                    RowBox[{"ToString", "[", "tSim", "]"}], ",", 
                    "\"\< K\\n\>\""}], "}"}], "]"}]}], "\n", "\t\t\t", ",", 
                 RowBox[{"PlotLegends", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                   "\"\<liquid density - VdW\>\"", ",", 
                    "\"\<vapor density - VdW\>\""}], "}"}]}], "\n", "\t\t\t", 
                 ",", 
                 RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", "All"}]}], "\n", "\t\t", 
                "]"}], ",", "\[IndentingNewLine]", "\t\t", 
               RowBox[{"ListPlot", "[", 
                RowBox[{
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"{", "\n", "\t\t\t\t", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"RhoToRhoAst", "[", 
                    RowBox[{
                    RowBox[{"vToRho", "[", 
                    RowBox[{"resvLiqVdWLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
                    RowBox[{"resxVdWLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{
                    RowBox[{"resPVdWLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    ",", "\n", "\t\t\t\t", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"RhoToRhoAst", "[", 
                    RowBox[{
                    RowBox[{"vToRho", "[", 
                    RowBox[{"resvVapVdWLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
                    RowBox[{"resyVdWLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{
                    RowBox[{"resPVdWLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}]}],
                     "}"}], "\n", "\t\t\t\t", ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "\n", 
                  "\t\t\t", "]"}], "\n", "\t\t\t", ",", 
                 RowBox[{"PlotStyle", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"Red", ",", "Blue", ",", "Orange"}], "}"}]}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"Automatic", ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Automatic"}], "}"}]}], "}"}]}], "\n", 
                 "\t\t\t", ",", 
                 RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
                 RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}], 
                 "\n", "\t\t\t", ",", 
                 RowBox[{"PlotLegends", "\[Rule]", 
                  RowBox[{"Table", "[", 
                   RowBox[{
                    RowBox[{"\"\<Simulation point @\>\"", "<>", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"pSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], "<>", 
                    "\"\< bar\>\""}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "]"}]}]}], 
                "\n", "\t\t", "]"}]}], "\[IndentingNewLine]", "\t", "}"}], 
             "]"}], "}"}], "}"}], "}"}], ",", "\[IndentingNewLine]", "\t", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", "\n", "\t\t\t", 
            RowBox[{"{", 
             RowBox[{"Row", "[", 
              RowBox[{"{", 
               RowBox[{"\"\<Simulation @\>\"", ",", " ", 
                RowBox[{"resPVdWLJ", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                "\"\< bar : \!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\) = \>\"", 
                ",", 
                RowBox[{"Round", "[", 
                 RowBox[{
                  RowBox[{"1", "/", 
                   RowBox[{"resvLiqVdWLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], ",", "0.00001"}], "]"}],
                 ",", "\"\< mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\), \
\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\) = \>\"", ",", 
                RowBox[{"Round", "[", 
                 RowBox[{
                  RowBox[{"1", "/", 
                   RowBox[{"resvVapVdWLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], ",", "0.00001"}], "]"}],
                 ",", "\"\< mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], 
               "}"}], "]"}], "}"}], "\[IndentingNewLine]", "\t\t", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "\n", "\t", "]"}]}], 
        "\n", "}"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Alignment", "->", "Left"}]}], "]"}]}], ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->
  "In[107]:=",ExpressionUUID->"d006dadd-5194-45ff-a960-2badb30fbdfb"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"CalculatePlotDataVdW", "[", 
  RowBox[{
  "tSim", ",", "pSim", ",", "\[Sigma]", ",", "\[Epsilon]", ",", 
   "\[Epsilon]Iteration"}], "]"}], "\n", 
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"plotPxyVdW", "[", "]"}], ",", 
      RowBox[{"plotPrhoVdW", "[", "]"}]}], "}"}], "}"}], ",", 
   RowBox[{"Alignment", "->", "Top"}]}], "]"}]}], "Code",
 CellLabel->
  "In[108]:=",ExpressionUUID->"e013f686-c7ad-4ad2-b45d-d82078a7c270"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         TemplateBox[{
           GraphicsBox[{{{}, {{{}, {}, {
                 Hue[0.67, 0.6, 0.6], 
                 Directive[
                  PointSize[
                   NCache[
                    Rational[1, 72], 0.013888888888888888`]], 
                  RGBColor[0.368417, 0.506779, 0.709798], 
                  AbsoluteThickness[1.6]], 
                 LineBox[CompressedData["
1:eJw1lQtQVHUYxTdL0c0MG2AcEQqNkTJLkQxRPKEWZsoIkwq+paA0JcAUeYhm
Qg8VxF1kEdj3srssu6sz8jAdW2CxNCge4RopLK998FhUBBUVa/9+fjN37ty5
9557zvl9M9cn+puImHEcDifm/8N5fja3YfKNevHqHB50oR0pbrpB5M1fv2i9
kIfN2dXDfpsHoV+0f4bElQ+uSRYfzB3ERf75fQVH+Kj0zugLr3TAKyRhUug9
PmLZONCSeVSoiMmFGxN0IONK/JPK67lwqmVXD6BxWuLtI6GnkRDsVBxAT3zW
8vGVp/G6U857ADuXFhtD/PJQX+ecfqhOZCwPEuQhlQn2Y7FuOOe2iwBvMYP9
GIj+6/vYJAGYPVMf/MWvDBZZBGByGX3gtpk1gnX5WMCmDw/H1fAjjflwpg3t
6IW+/1hmu/8ZsLjZvbhRmLn9PckZLGWBe7HQ9YeXVr1agH4mZwfHyNkw/2AB
zuQ7xw75PS9YewuwkgnaMSnPVLwnshAjzrjDNrhNm5J6pbYQcqc9mQ1zrVLN
kH8RIliBNuS1nJpzX1SEZzxs4K6deqdpspB4WDHmE76jKFlIPKzIHDHkzLMI
iYcVKWPbJkgjRMTDgqbJ241Dl0XEw4Lp6U/tPHcx8bDAkFj2hvhTMfHogWNF
YpboOzGYvfgexCQkBPMqxGBy3j0wj3gGpQ2IwXDUdWPZdk/eplkS4tGNmJQ9
Uf5REuLRDe6lA+IXsiXEowvhO33SrxklxKMLgcnt3KxRCfHoQtnHLTvWzJMS
j06MeFjFk2KlOMkMdkKT1myrKZASj05UyFdvOdgoJR4d2J/7mu8HLjLi0QHh
7im77i6REY8OjFfGRZ1NlBEPM8YOGWclqmTEwwzOvplPAttkxMOM8keLvSa4
yYmHGX8kZ/7a+omc+m+HMGvTrMpDcuq7DaOXZxwXlcmp3zbsy40MOdUnpz5v
IWjVnawcHwX1dxOBEz6qFW5QgNnxu4l804ZFF08ocJT18y+0cU9X2GoU6GT2
W1F/wTV09qiC8rfiQlq2LHleMeX9B92P22vMscWU7wa2dYx6bC0qpjw3YP9C
NnWouZj2yYRzj0XvSrhK2h8TcnKHHTtDlLQv17Exx7c17ICS9qMFReq49HC9
kvahBSaLa8JeixLMXsrf6DTxw8q9VLjO5Jox8UOPi57rVPBnfJth2HMqWnFc
RTybsDUp6OFnRhXxa0RVhG/5kscq4tUIw8q9by8NUBOfBugXNvTs2q0mHg1I
Md6tNsrV1P+fSIBVvuaWmvqux8vXQpJdPEqo3zqovuUH3gsrgZkZvoYkSZ/F
/ccSCFh/V3Fiazg/rqoEa5ng75ixIHIL51EJJrJ+foOHXft1fYAGBtZHLZTW
8hFTnAZpLL8RJQb/FTPVGgSwvDUwSnpVui4N5asC76tdPx3yLqU8Bjjm1m7M
iyol/5fx/juxsgf8UvJ7CUFjjkeKhlLydwHTV73pKp2sJT8V+NKlVzS4UosD
7PvnMVu/9nBOhhY29r1zUBjPF/5crcVZpq9D4eq792891eIk01MjaUirzQrW
4TB7X45lTWVDolQdDOx5IT5/mOrp/svz+3xoZmp5dx48vz4KQYDFHhiox/M/
SPqxY3WOJD3+AwDeIEw=
                  "]]}, {
                 Hue[0.9060679774997897, 0.6, 0.6], 
                 Directive[
                  PointSize[
                   NCache[
                    Rational[1, 72], 0.013888888888888888`]], 
                  RGBColor[0.880722, 0.611041, 0.142051], 
                  AbsoluteThickness[1.6]], 
                 LineBox[CompressedData["
1:eJw1lYk3FIoCh6dLRK6mHnJDGVJJbtKGll9K6qYUF5GX1qlLJctDKFvZkuky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                  "]]}}}, {{}, {}}}, {{}, {{{}, {}, {}, {}, {}, {}, {
                 Directive[
                  RGBColor[1, 0, 0], 
                  Opacity[0.3]], 
                 
                 LineBox[{{0.37007539422472413`, 0.}, {0.37007539422472413`, 
                  0.0450001051887027}}], 
                 
                 LineBox[{{0.194840786226125, 0.}, {0.194840786226125, 
                  0.0450001051887027}}]}, {}, {
                 Directive[
                  RGBColor[0, 0, 1], 
                  Opacity[0.3]], 
                 
                 LineBox[{{0.030287262016023553`, 0.}, {0.030287262016023553`,
                   0.06000017059513061}}], 
                 
                 LineBox[{{0.014725068879890753`, 0.}, {0.014725068879890753`,
                   0.06000017059513061}}]}}, {{
                 Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[1, 0, 0]], 
                 GeometricTransformationBox[
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], 
                    GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}, StripOnInput -> False], 
                    TraditionalForm]], {0., 0.}, Automatic, 
                   Scaled[9.75]], {{{0.37007539422472413`, 
                  0.0450001051887027}}, {{0.194840786226125, 
                  0.0450001051887027}}}]}, {
                 Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[0, 0, 1]], 
                 GeometricTransformationBox[
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], 
                    GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}, StripOnInput -> False], 
                    TraditionalForm]], {0., 0.}, Automatic, 
                   Scaled[9.75]], {{{0.030287262016023553`, 
                  0.06000017059513061}}, {{0.014725068879890753`, 
                  0.06000017059513061}}}]}, {}}}, {{}, {}}}}, {
            DisplayFunction -> Identity, DisplayFunction -> Identity, 
             AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
             Axes -> {True, True}, AxesLabel -> {None, None}, 
             AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
             Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                FormBox[
                 TagBox[
                  StyleBox[
                  "\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(*\\)]\\) [1]\"", 
                   Bold, 14, SingleLetterItalics -> False, StripOnInput -> 
                   False], HoldForm], TraditionalForm], None}, {
                FormBox[
                 TagBox[
                  StyleBox[
                  "\"\\!\\(\\*SubscriptBox[\\(x\\), \
\\(1\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) [mol/mol]\"", Bold, 14,
                    SingleLetterItalics -> False, StripOnInput -> False], 
                  HoldForm], TraditionalForm], None}}, 
             FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
             GridLines -> {Automatic, Automatic}, GridLinesStyle -> Directive[
               GrayLevel[0.5, 0.4]], ImageSize -> Medium, 
             Method -> {
              "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
               "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                   Identity[
                    Part[#, 1]], 
                   Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                   Identity[
                    Part[#, 1]], 
                   Identity[
                    Part[#, 2]]}& )}}, PlotLabel -> 
             FormBox["\"LJ_ref-LJ_1 @T = 1. K\\n\"", TraditionalForm], 
             PlotRange -> {{0., 1.}, {0, 0.061461889714130344`}}, 
             PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {
                Scaled[0.02], 
                Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
           FormBox[
            TagBox[
             GridBox[{{
                FormBox[
                 
                 TemplateBox[{"\"VdW, bubble curve\"", "\"VdW, dew curve\""}, 
                  "LineLegend", DisplayFunction -> (StyleBox[
                    StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                    FontFamily -> "Arial"}, Background -> Automatic, 
                    StripOnInput -> False]& ), 
                  InterpretationFunction :> (RowBox[{"LineLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                    RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
                    ",", 
                    RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"True", ",", "True"}], "}"}]}], ",", 
                    RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                    "]"}]& ), Editable -> True], TraditionalForm]}, {
                FormBox[
                 
                 TemplateBox[{
                  "\"Simulation point @6.21292 bar\"", 
                   "\"Simulation point @8.28389 bar\"", 
                   "\"Simulation point @10.3549 bar\""}, "PointLegend", 
                  DisplayFunction -> (StyleBox[
                    StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #2}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                    FontFamily -> "Arial"}, Background -> Automatic, 
                    StripOnInput -> False]& ), 
                  InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 0, 1]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0.5, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                    RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], ",", "9.75`"}],
                     "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}], ",", "9.75`"}], "}"}]}], "}"}]}], 
                    ",", 
                    RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "False", ",", "False"}], "}"}]}], 
                    ",", 
                    RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                    "]"}]& ), Editable -> True], TraditionalForm]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> 
              False, GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], 
            TraditionalForm]},
          "Legended",
          DisplayFunction->(GridBox[{{
              TagBox[
               ItemBox[
                PaneBox[
                 TagBox[#, "SkipImageSizeLevel"], 
                 Alignment -> {Center, Baseline}, BaselinePosition -> 
                 Baseline], DefaultBaseStyle -> "Labeled"], 
               "SkipImageSizeLevel"], 
              ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
            GridBoxAlignment -> {
             "Columns" -> {{Center}}, "Rows" -> {{Center}}}, AutoDelete -> 
            False, GridBoxItemSize -> Automatic, 
            BaselinePosition -> {1, 1}]& ),
          Editable->True,
          InterpretationFunction->(RowBox[{"Legended", "[", 
             RowBox[{#, ",", 
               RowBox[{"Placed", "[", 
                 RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]},
        {
         TemplateBox[{
          "\"Simulation @\"", "6.212920499999999`", 
           "\" bar : \\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\) = \"", 
           "0.37008`", 
           "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\), \
\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) = \"", "0.19484`", 
           "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)\""},
          "RowDefault"]},
        {
         TemplateBox[{
          "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m25  %\\)]\\) = \"", 
           "0.32626674222507435`", 
           "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m50  %\\)]\\) = \"", 
           "0.28245809022542456`", 
           "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m75  %\\)]\\) = \"", 
           "0.23864943822577478`"},
          "RowDefault"]},
        {
         TemplateBox[{
          "\"Simulation @\"", "8.283894`", 
           "\" bar : \\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\) = \"", 
           "0.03029`", 
           "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\), \
\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) = \"", "0.014730000000000002`", 
           "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)\""},
          "RowDefault"]},
        {
         TemplateBox[{
          "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m25  %\\)]\\) = \"", 
           "0.026396713731990352`", 
           "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m50  %\\)]\\) = \"", 
           "0.022506165447957152`", 
           "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m75  %\\)]\\) = \"", 
           "0.018615617163923952`"},
          "RowDefault"]},
        {
         TemplateBox[{
          "\"Simulation @\"", "10.3548675`", 
           "\" bar : \\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\) = \"", 
           RowBox[{"Round", "[", 
             RowBox[{"\"N/A\"", ",", "0.00001`"}], "]"}], 
           "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\), \
\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) = \"", 
           RowBox[{"Round", "[", 
             RowBox[{"\"N/A\"", ",", "0.00001`"}], "]"}], 
           "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)\""},
          "RowDefault"]},
        {
         TemplateBox[{
          "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m25  %\\)]\\) = \"", 
           RowBox[{"0.`", "\[VeryThinSpace]", "+", "\"N/A\""}], 
           "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m50  %\\)]\\) = \"", 
           RowBox[{"0.`", "\[VeryThinSpace]", "+", "\"N/A\""}], 
           "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m75  %\\)]\\) = \"", 
           RowBox[{"0.`", "\[VeryThinSpace]", "+", "\"N/A\""}]},
          "RowDefault"]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"], 
     TagBox[GridBox[{
        {
         TemplateBox[{
           GraphicsBox[{{{}, {{{}, {}, {
                 Hue[0.67, 0.6, 0.6], 
                 Directive[
                  PointSize[
                   NCache[
                    Rational[1, 72], 0.013888888888888888`]], 
                  RGBColor[0.368417, 0.506779, 0.709798], 
                  AbsoluteThickness[1.6]], 
                 LineBox[CompressedData["
1:eJwVkHk81AkDxnUsy0ZqIxtax87bxrbkyER6EqVDot0SvVQ2HSpFta5QepsO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                  "]]}, {
                 Hue[0.9060679774997897, 0.6, 0.6], 
                 Directive[
                  PointSize[
                   NCache[
                    Rational[1, 72], 0.013888888888888888`]], 
                  RGBColor[0.880722, 0.611041, 0.142051], 
                  AbsoluteThickness[1.6]], 
                 LineBox[CompressedData["
1:eJwVkHs4FIgCR622MGz0GLt5VGqnx7UqksaUfg1KCRs9kB7imqhM6MZSm5ZL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                  "]]}}}, {{}, {}}}, {{}, {{{}, {}, {}, {}, {}, {}, {
                 Directive[
                  RGBColor[1, 0, 0], 
                  Opacity[0.3]], 
                 
                 LineBox[{{0.70128687963415, 0.}, {0.70128687963415, 
                  0.0450001051887027}}], 
                 
                 LineBox[{{0.055389977926758954`, 0.}, {0.055389977926758954`,
                   0.0450001051887027}}]}, {}, {
                 Directive[
                  RGBColor[0, 0, 1], 
                  Opacity[0.3]], 
                 
                 LineBox[{{0.6458447943975498, 0.}, {0.6458447943975498, 
                  0.06000017059513061}}], 
                 
                 LineBox[{{0.07994921394291325, 0.}, {0.07994921394291325, 
                  0.06000017059513061}}]}}, {{
                 Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[1, 0, 0]], 
                 GeometricTransformationBox[
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], 
                    GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}, StripOnInput -> False], 
                    TraditionalForm]], {0., 0.}, Automatic, 
                   Scaled[9.75]], {{{0.70128687963415, 
                  0.0450001051887027}}, {{0.055389977926758954`, 
                  0.0450001051887027}}}]}, {
                 Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[0, 0, 1]], 
                 GeometricTransformationBox[
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], 
                    GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}, StripOnInput -> False], 
                    TraditionalForm]], {0., 0.}, Automatic, 
                   Scaled[9.75]], {{{0.6458447943975498, 
                  0.06000017059513061}}, {{0.07994921394291325, 
                  0.06000017059513061}}}]}, {}}}, {{}, {}}}}, {
            DisplayFunction -> Identity, DisplayFunction -> Identity, 
             AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
             Axes -> {True, True}, AxesLabel -> {None, None}, 
             AxesOrigin -> {0.005097352649651377, 0}, DisplayFunction :> 
             Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                FormBox[
                 TagBox[
                  StyleBox[
                  "\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(*\\)]\\) [1]\"", 
                   Bold, 14, SingleLetterItalics -> False, StripOnInput -> 
                   False], HoldForm], TraditionalForm], None}, {
                FormBox[
                 TagBox[
                  StyleBox[
                  "\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(L\\), \
\\(*\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(V\\), \\(*\\)]\\) [1]\
\"", Bold, 14, SingleLetterItalics -> False, StripOnInput -> False], 
                  HoldForm], TraditionalForm], None}}, 
             FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
             GridLines -> {Automatic, Automatic}, GridLinesStyle -> Directive[
               GrayLevel[0.5, 0.4]], ImageSize -> Medium, 
             Method -> {
              "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
               "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                   Identity[
                    Part[#, 1]], 
                   Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                   Identity[
                    Part[#, 1]], 
                   Identity[
                    Part[#, 2]]}& )}}, PlotLabel -> 
             FormBox["\"LJ_ref-LJ_1 @T = 1. K\\n\"", TraditionalForm], 
             PlotRange -> {{0.005097352649651377, 0.7682570506762116}, {
               0, 0.061461889714130344`}}, PlotRangeClipping -> True, 
             PlotRangePadding -> {{
                Scaled[0.02], 
                Scaled[0.02]}, {
                Scaled[0.02], 
                Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
           FormBox[
            TagBox[
             GridBox[{{
                FormBox[
                 
                 TemplateBox[{
                  "\"liquid density - VdW\"", "\"vapor density - VdW\""}, 
                  "LineLegend", DisplayFunction -> (StyleBox[
                    StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                    FontFamily -> "Arial"}, Background -> Automatic, 
                    StripOnInput -> False]& ), 
                  InterpretationFunction :> (RowBox[{"LineLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                    RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
                    ",", 
                    RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"True", ",", "True"}], "}"}]}], ",", 
                    RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                    "]"}]& ), Editable -> True], TraditionalForm]}, {
                FormBox[
                 
                 TemplateBox[{
                  "\"Simulation point @6.21292 bar\"", 
                   "\"Simulation point @8.28389 bar\"", 
                   "\"Simulation point @10.3549 bar\""}, "PointLegend", 
                  DisplayFunction -> (StyleBox[
                    StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #2}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                    FontFamily -> "Arial"}, Background -> Automatic, 
                    StripOnInput -> False]& ), 
                  InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 0, 1]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0.5, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                    RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], ",", "9.75`"}],
                     "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}], ",", "9.75`"}], "}"}]}], "}"}]}], 
                    ",", 
                    RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "False", ",", "False"}], "}"}]}], 
                    ",", 
                    RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                    "]"}]& ), Editable -> True], TraditionalForm]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> 
              False, GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], 
            TraditionalForm]},
          "Legended",
          DisplayFunction->(GridBox[{{
              TagBox[
               ItemBox[
                PaneBox[
                 TagBox[#, "SkipImageSizeLevel"], 
                 Alignment -> {Center, Baseline}, BaselinePosition -> 
                 Baseline], DefaultBaseStyle -> "Labeled"], 
               "SkipImageSizeLevel"], 
              ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
            GridBoxAlignment -> {
             "Columns" -> {{Center}}, "Rows" -> {{Center}}}, AutoDelete -> 
            False, GridBoxItemSize -> Automatic, 
            BaselinePosition -> {1, 1}]& ),
          Editable->True,
          InterpretationFunction->(RowBox[{"Legended", "[", 
             RowBox[{#, ",", 
               RowBox[{"Placed", "[", 
                 RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]},
        {
         TemplateBox[{
          "\"Simulation @\"", "6.212935022867719`", 
           "\" bar : \\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\) = \"", 
           "1164.5142600000001`", 
           "\" mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\), \
\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\) = \"", "91.97722`", 
           "\" mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)\""},
          "RowDefault"]},
        {
         TemplateBox[{
          "\"Simulation @\"", "8.283917553199649`", 
           "\" bar : \\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\) = \"", 
           "1072.4505100000001`", 
           "\" mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\), \
\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\) = \"", "132.75879`", 
           "\" mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)\""},
          "RowDefault"]},
        {
         TemplateBox[{
          "\"Simulation @\"", "\"N/A\"", 
           "\" bar : \\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\) = \"", 
           RowBox[{"Round", "[", 
             RowBox[{
               FractionBox["1", "\"N/A\""], ",", "0.00001`"}], "]"}], 
           "\" mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\), \
\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\) = \"", 
           RowBox[{"Round", "[", 
             RowBox[{
               FractionBox["1", "\"N/A\""], ",", "0.00001`"}], "]"}], 
           "\" mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)\""},
          "RowDefault"]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Rows" -> {{Top}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->
  "Out[109]=",ExpressionUUID->"a18a7143-90d3-430c-a313-7ab9dd01b1ec"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["t-PR-LJ EoS", "Subsection",ExpressionUUID->"e291a0db-cdf2-42ca-9071-6065dedb99d3"],

Cell["\<\
Harismiadis, Vassilis I., Athanassios Z. Panagiotopoulos, and Dimitrios P. \
Tassios: Phase equilibria of binary Lennard-Jones mixtures with cubic \
equations of state. Fluid Phase Equilibria 94, 1994, 1-18\
\>", "Affiliation",ExpressionUUID->"ff98e3fa-582c-49f5-bc99-0718c8d71ff4"],

Cell["\<\
The volume translated Peng-Robinson EoS for LJ fluids (t-PR-LJ) is used to \
calculate the molar fractions and molar volume.
The calculation needs an initial saturation pressure guess which is \
calculated using the Thol2016 EoS.
The calculation assumes that at least one component is below its critical \
point.\
\>", "Text",ExpressionUUID->"1ce56e81-f746-4d97-8998-743c55ff37b2"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"f8c5e4a5-6102-4aaf-9f2b-04222db672fc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CalculateVTPRLJ", "[", 
   RowBox[{
   "tSim_", ",", "pSim_", ",", "\[Sigma]ij_", ",", "\[Epsilon]ij_", ",", 
    "epsilon_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", "\t", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
     RowBox[{
     "nComp", ",", "bPure", ",", "bij", ",", "aPure", ",", "aij", ",", 
      "tPure", ",", "\n", "\t\t", "xInit", ",", "x", ",", "yGuess", ",", 
      "pGuess", ",", "pInit", ",", "sol", ",", "\n", "\t\t", "dx", ",", 
      "trouble"}], "\[IndentingNewLine]", "\t", "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "\t", 
    RowBox[{"(*", 
     RowBox[{"t", "-", "PR", "-", 
      RowBox[{"EoS", " ", "parameter"}]}], "*)"}], "\[IndentingNewLine]", 
    "\t", 
    RowBox[{
     RowBox[{"nComp", " ", "=", " ", 
      RowBox[{"Length", "@", "component"}]}], ";", "\[IndentingNewLine]", 
     "\t", 
     RowBox[{"bPure", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"bVTPRLJ", "[", 
         RowBox[{
          RowBox[{"\[Sigma]ij", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
          RowBox[{"\[Epsilon]ij", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], "/@", 
       " ", 
       RowBox[{"Range", "@", "nComp"}]}]}], ";", "\[IndentingNewLine]", "\t", 
     RowBox[{"bij", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"0.5", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"bPure", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "^", 
              RowBox[{"(", 
               RowBox[{"1", "/", "3"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"bPure", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "^", 
              RowBox[{"(", 
               RowBox[{"1", "/", "3"}], ")"}]}]}], ")"}]}], ")"}], " ", "^", 
         "3"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "nComp"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "nComp"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\t", 
     RowBox[{"aPure", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"aVTPRLJ", "[", 
         RowBox[{
          RowBox[{"tRedVTPRLJ", "[", 
           RowBox[{"tSim", ",", 
            RowBox[{"\[Epsilon]ij", "[", 
             RowBox[{"[", 
              RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"\[Sigma]ij", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
          RowBox[{"\[Epsilon]ij", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], "/@", 
       " ", 
       RowBox[{"Range", "@", "nComp"}]}]}], ";", "\[IndentingNewLine]", "\t", 
     RowBox[{"aij", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"bij", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"aPure", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "*", 
            RowBox[{
             RowBox[{"aPure", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"bPure", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "*", 
               RowBox[{"bPure", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}], ")"}]}]}], ")"}], "^", 
          "0.5"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "nComp"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "nComp"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\t", 
     RowBox[{"tPure", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"volumeTranslationVTPRLJ", "[", 
         RowBox[{
          RowBox[{"tRedVTPRLJ", "[", 
           RowBox[{"tSim", ",", 
            RowBox[{"\[Epsilon]ij", "[", 
             RowBox[{"[", 
              RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"\[Sigma]ij", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], "/@", 
       " ", 
       RowBox[{"Range", "@", "nComp"}]}]}], ";", "\n", "\t", "\n", "\t", 
     RowBox[{"trouble", " ", "=", " ", "False"}], ";", "\[IndentingNewLine]", 
     "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"initial", " ", "calculation", " ", "at", " ", "x1"}], " ", 
       "=", " ", "1"}], "*)"}], "\[IndentingNewLine]", "\t", 
     RowBox[{"xInit", " ", "=", " ", 
      RowBox[{"yGuess", " ", "=", " ", "1"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"First", " ", "Guess", " ", "at", " ", "x1"}], " ", "=", " ", 
       RowBox[{"y1", " ", "=", " ", "1"}]}], "*)"}], "\n", "\t", 
     RowBox[{"dx", " ", "=", " ", 
      RowBox[{"-", "0.05"}]}], ";", "\[IndentingNewLine]", "\t", 
     RowBox[{"pGuess", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"pLJ", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"pSatRedLJ", "[", 
            RowBox[{
             RowBox[{"tRedLJ", "[", 
              RowBox[{"tSim", ",", 
               RowBox[{"\[Epsilon]", "[", 
                RowBox[{"[", 
                 RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], "/", 
             "tCritLJ"}], "]"}], "*", "pCritLJ"}], ",", 
          RowBox[{"\[Epsilon]", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], "[", 
       "1", "]"}]}], ";", "\n", "\t", 
     RowBox[{"sol", " ", "=", " ", 
      RowBox[{"Quiet", "@", 
       RowBox[{"bubblePressureVTPRLJ", "[", 
        RowBox[{"aij", ",", "bij", ",", "tPure", ",", "tSim", ",", 
         RowBox[{"{", 
          RowBox[{"xInit", ",", 
           RowBox[{"1", "-", "xInit"}]}], "}"}], ",", "pGuess", ",", 
         RowBox[{"{", 
          RowBox[{"yGuess", ",", 
           RowBox[{"1", "-", "yGuess"}]}], "}"}], ",", "epsilon", ",", 
         "False"}], "]"}]}]}], ";", "\n", "\n", "\t", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"AnyTrue", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Im", "[", 
             RowBox[{"sol", "[", 
              RowBox[{"[", "4", "]"}], "]"}], "]"}], "!=", "0"}], ",", 
           RowBox[{
            RowBox[{"sol", "[", 
             RowBox[{"[", "4", "]"}], "]"}], "==", 
            RowBox[{"sol", "[", 
             RowBox[{"[", "5", "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"sol", "[", 
             RowBox[{"[", "4", "]"}], "]"}], ">", 
            RowBox[{"sol", "[", 
             RowBox[{"[", "5", "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"sol", "[", 
             RowBox[{"[", "4", "]"}], "]"}], "<", "0"}]}], "}"}], ",", 
         "TrueQ"}], "]"}], "\n", "\t\t", ",", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
          RowBox[{"True", ":", " ", 
           RowBox[{"the", " ", "calculation", " ", "has", " ", "failed"}]}], 
          " ", "->", " ", 
          RowBox[{"start", " ", "calculation", " ", "from", " ", "x1"}]}], 
         " ", "=", " ", "0"}], "*)"}], "\n", "\t\t", 
       RowBox[{
        RowBox[{"xInit", " ", "=", " ", 
         RowBox[{"yGuess", " ", "=", " ", "0"}]}], ";", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"First", " ", "Guess", " ", "at", " ", "x1"}], " ", "=", 
          " ", 
          RowBox[{"y1", " ", "=", " ", "1"}]}], "*)"}], "\n", "\t\t", 
        RowBox[{"dx", " ", "=", " ", "0.05"}], ";", "\n", "\t\t", 
        RowBox[{"pGuess", " ", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"pLJ", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"pSatRedLJ", "[", 
               RowBox[{
                RowBox[{"tRedLJ", "[", 
                 RowBox[{"tSim", ",", 
                  RowBox[{"\[Epsilon]", "[", 
                   RowBox[{"[", 
                    RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], "/", 
                "tCritLJ"}], "]"}], "*", "pCritLJ"}], ",", 
             RowBox[{"\[Epsilon]", "[", 
              RowBox[{"[", 
               RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
             RowBox[{"\[Sigma]", "[", 
              RowBox[{"[", 
               RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], 
          "[", "2", "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"sol", " ", "=", " ", 
         RowBox[{"Quiet", "@", 
          RowBox[{"bubblePressureVTPRLJ", "[", 
           RowBox[{"aij", ",", "bij", ",", "tPure", ",", "tSim", ",", 
            RowBox[{"{", 
             RowBox[{"xInit", ",", 
              RowBox[{"1", "-", "xInit"}]}], "}"}], ",", "pGuess", ",", 
            RowBox[{"{", 
             RowBox[{"yGuess", ",", 
              RowBox[{"1", "-", "yGuess"}]}], "}"}], ",", "epsilon", ",", 
            "False"}], "]"}]}]}], ";"}]}], "\n", "\t", "]"}], ";", "\n", "\t",
      "\n", "\t", 
     RowBox[{"pInit", " ", "=", " ", 
      RowBox[{"sol", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{"initial", " ", "calculated", " ", "pressure"}], "*)"}], "\n", 
     "\t", 
     RowBox[{"x", " ", "=", " ", "xInit"}], ";", "\n", "\t", 
     RowBox[{"Do", "[", "\n", "\t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"If", "[", "\n", "\t\t\t", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"pInit", ">", "pSim"}], ",", 
            RowBox[{
             RowBox[{"sol", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "<", "pSim"}], ",", 
            RowBox[{
             RowBox[{"sol", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ">", "pSim"}]}], "]"}], ",", 
          "\n", "\t\t\t", 
          RowBox[{
           RowBox[{"Break", "[", "]"}], ";"}]}], "\n", "\t\t", "]"}], ";", 
        "\n", "\t\t", "\n", "\t\t", 
        RowBox[{"x", " ", "+=", " ", 
         RowBox[{"dx", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"sol", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "pSim"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"pInit", "-", "pSim"}], ")"}]}]}]}], ";", "\n", "\t\t", 
        RowBox[{"pGuess", " ", "=", " ", 
         RowBox[{"sol", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"yGuess", " ", "=", " ", 
         RowBox[{"sol", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"sol", " ", "=", " ", 
         RowBox[{"Quiet", "@", 
          RowBox[{"bubblePressureVTPRLJ", "[", 
           RowBox[{"aij", ",", "bij", ",", "tPure", ",", "tSim", ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", 
              RowBox[{"1", "-", "x"}]}], "}"}], ",", "pGuess", ",", 
            RowBox[{"{", 
             RowBox[{"yGuess", ",", 
              RowBox[{"1", "-", "yGuess"}]}], "}"}], ",", "epsilon", ",", 
            "False"}], "]"}]}]}], ";", "\n", "\t\t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"AnyTrue", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"sol", "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "1"}], "]"}], "]"}], "<", "0"}], ",", 
              RowBox[{
               RowBox[{"sol", "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "1"}], "]"}], "]"}], ">", "1"}], ",", 
              RowBox[{"nt", "==", "500"}]}], "}"}], ",", "TrueQ"}], "]"}], 
          ",", 
          RowBox[{
           RowBox[{"trouble", " ", "=", " ", "True"}], ";", 
           RowBox[{"Break", "[", "]"}], ";"}]}], "]"}], ";", "\n", "\t\t", 
        "\n", "\t\t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"nt", "==", "500"}], ",", 
          RowBox[{
           RowBox[{"Print", "@", "\"\<Maximum Iterations Reached!\>\""}], ";", 
           RowBox[{"Break", "[", "]"}], ";"}]}], "]"}], ";"}], "\n", "\t\t", 
       ",", 
       RowBox[{"{", 
        RowBox[{"nt", ",", "500"}], "}"}]}], "\n", "\t", "]"}], ";", "\n", 
     "\t", "\[IndentingNewLine]", "\t", 
     RowBox[{"(*", 
      RowBox[{
      "return", " ", "bubble", " ", "pressure", " ", "calculation", " ", 
       "results"}], "*)"}], "\n", "\t", 
     RowBox[{"If", "[", 
      RowBox[{"trouble", ",", "\n", "\t\t", 
       RowBox[{"{", 
        RowBox[{
        "\"\<N/A\>\"", ",", "\"\<N/A\>\"", ",", "\"\<N/A\>\"", ",", 
         "\"\<N/A\>\"", ",", "\"\<N/A\>\""}], "}"}], ",", 
       "\[IndentingNewLine]", "\t\t", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"sol", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"sol", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"sol", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"sol", "[", 
          RowBox[{"[", "4", "]"}], "]"}], ",", 
         RowBox[{"sol", "[", 
          RowBox[{"[", "5", "]"}], "]"}]}], "}"}]}], "\n", "\t", "]"}]}]}], 
   "\n", "]"}]}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->
  "In[110]:=",ExpressionUUID->"e8b95a48-5971-40bf-9bcb-a1cb3ec23bf3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CalculateMolarVolumeVTPRLJ", "[", 
   RowBox[{"vLiq_", ",", "x1_", ",", "vVap_", ",", "y1_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"vLiq", " ", "=!=", " ", "\"\<N/A\>\""}], ",", "\n", "\t", 
    RowBox[{"{", 
     RowBox[{"vLiq", ",", "vVap", ",", 
      RowBox[{"vToRho", "@", "vLiq"}], ",", 
      RowBox[{"vToRho", "@", "vVap"}], ",", 
      RowBox[{"RhoToRhoAst", "[", 
       RowBox[{
        RowBox[{"vToRho", "@", "vLiq"}], ",", "x1"}], "]"}], ",", 
      RowBox[{"RhoToRhoAst", "[", 
       RowBox[{
        RowBox[{"vToRho", "@", "vVap"}], ",", "y1"}], "]"}]}], "}"}], "\n", 
    "\t", ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<N/A\>\"", ",", "\"\<N/A\>\"", ",", "\"\<N/A\>\"", ",", 
      "\"\<N/A\>\"", ",", "\"\<N/A\>\"", ",", "\"\<N/A\>\""}], "}"}]}], "\n", 
   "]"}]}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->
  "In[111]:=",ExpressionUUID->"1c111a40-e40d-4c19-8ec6-dc70d87c8ac5"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Calculation", " ", "of", " ", "molar", " ", "fraction", " ", 
    RowBox[{"(", "MF", ")"}], " ", "and", " ", "molar", " ", "volume", " ", 
    RowBox[{"(", "MV", ")"}]}], "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "resPVTPRLJ", ",", "resxVTPRLJ", ",", "resyVTPRLJ", ",", 
       "resvLiqVTPRLJ", ",", "resvVapVTPRLJ"}], "}"}], " ", "=", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"CalculateVTPRLJ", "[", 
         RowBox[{
         "tSim", ",", "#", ",", "\[Sigma]", ",", "\[Epsilon]", ",", 
          "\[Epsilon]Iteration"}], "]"}], " ", "&"}], "/@", " ", "pSim"}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"resMFVTPRLJ", " ", "=", " ", 
     RowBox[{"Transpose", "@", 
      RowBox[{"{", 
       RowBox[{"resxVTPRLJ", ",", "resyVTPRLJ"}], "}"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"resMVVTPRLJ", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"CalculateMolarVolumeVTPRLJ", "[", 
        RowBox[{
         RowBox[{"resvLiqVTPRLJ", "[", 
          RowBox[{"[", "#", "]"}], "]"}], ",", 
         RowBox[{"resxVTPRLJ", "[", 
          RowBox[{"[", "#", "]"}], "]"}], ",", 
         RowBox[{"resvVapVTPRLJ", "[", 
          RowBox[{"[", "#", "]"}], "]"}], ",", 
         RowBox[{"resyVTPRLJ", "[", 
          RowBox[{"[", "#", "]"}], "]"}]}], "]"}], " ", "&"}], "/@", " ", 
      RowBox[{"Range", "@", 
       RowBox[{"Length", "@", "pSim"}]}]}]}], ";"}], "\n", 
   RowBox[{"Grid", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"ShowEoSResults", "[", 
         RowBox[{"\"\<t-PR-LJ EoS\>\"", ",", 
          RowBox[{"resPVTPRLJ", "[", 
           RowBox[{"[", "#", "]"}], "]"}], ",", 
          RowBox[{"resMFVTPRLJ", "[", 
           RowBox[{"[", "#", "]"}], "]"}], ",", 
          RowBox[{"resMVVTPRLJ", "[", 
           RowBox[{"[", "#", "]"}], "]"}]}], "]"}], ")"}], " ", "&"}], "/@", 
      " ", 
      RowBox[{"Range", "@", 
       RowBox[{"Length", "@", "pSim"}]}]}], " ", "}"}]}]}]}]], "Code",
 CellLabel->
  "In[112]:=",ExpressionUUID->"492e11d1-8caa-4133-8836-cc05689b564c"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"t-PR-LJ EoS @6.21293 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", 
           "0.697193764762943`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", 
           "0.46219359493692164`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", 
           "0.0008654899646108713`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.010046266925199566`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "0.6958071157656445`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.059944064843572446`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.6958071157656445`", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.059944064843572446`", "\"[1]\""}}, AutoDelete -> 
         False, GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"], 
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"t-PR-LJ EoS @8.28395 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", 
           "0.4907923576811004`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", 
           "0.290152625807014`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", 
           "0.0009031419694702183`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.0067695685140629095`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "0.6667989046652962`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.08895900451394761`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.6667989046652962`", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.08895900451394761`", "\"[1]\""}}, AutoDelete -> 
         False, GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"], 
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"t-PR-LJ EoS @10.3549 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", 
           "0.3008570486554176`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", 
           "0.17762634894556278`", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", 
           "0.000985739899072462`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.00470091736999211`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "0.6109259415862714`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.12810565015334674`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.6109259415862714`", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.12810565015334674`", "\"[1]\""}}, AutoDelete -> 
         False, GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->
  "Out[115]=",ExpressionUUID->"699b66b3-6c1f-44bb-99ca-c64be9553ae1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualisation", "Subsubsection",ExpressionUUID->"2dcaf874-88b9-437b-a713-8bfe82f9aeee"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"a1b7d1c8-9866-41e7-9d3f-b6eb124725af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CalculatePlotDataVTPRLJ", "[", 
   RowBox[{
   "tSim_", ",", "pSim_", ",", "\[Sigma]ij_", ",", "\[Epsilon]ij_", ",", 
    "epsilon_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", "\t", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
     RowBox[{
     "nComp", ",", "bPure", ",", "bij", ",", "aPure", ",", "aij", ",", 
      "tPure", ",", "\n", "\t\t", "xInit", ",", "x", ",", "yGuess", ",", 
      "pGuess", ",", "pInit", ",", "sol", ",", "\n", "\t\t", "dx", ",", 
      "trouble", ",", "nt"}], "\[IndentingNewLine]", "\t", "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "\t", 
    RowBox[{"(*", 
     RowBox[{"t", "-", "PR", "-", 
      RowBox[{"EoS", " ", "parameter"}]}], "*)"}], "\[IndentingNewLine]", 
    "\t", 
    RowBox[{
     RowBox[{"nComp", " ", "=", " ", 
      RowBox[{"Length", "@", "component"}]}], ";", "\[IndentingNewLine]", 
     "\t", 
     RowBox[{"bPure", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"bVTPRLJ", "[", 
         RowBox[{
          RowBox[{"\[Sigma]ij", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
          RowBox[{"\[Epsilon]ij", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], "/@", 
       " ", 
       RowBox[{"Range", "@", "nComp"}]}]}], ";", "\[IndentingNewLine]", "\t", 
     RowBox[{"bij", " ", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"0.5", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"bPure", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "^", 
              RowBox[{"(", 
               RowBox[{"1", "/", "3"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"bPure", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "^", 
              RowBox[{"(", 
               RowBox[{"1", "/", "3"}], ")"}]}]}], ")"}]}], ")"}], "^", "3"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "nComp"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "nComp"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\t", 
     RowBox[{"aPure", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"aVTPRLJ", "[", 
         RowBox[{
          RowBox[{"tRedVTPRLJ", "[", 
           RowBox[{"tSim", ",", 
            RowBox[{"\[Epsilon]", "[", 
             RowBox[{"[", 
              RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"\[Sigma]ij", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
          RowBox[{"\[Epsilon]ij", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], "/@", 
       " ", 
       RowBox[{"Range", "@", "nComp"}]}]}], ";", "\[IndentingNewLine]", "\t", 
     RowBox[{"aij", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"bij", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"aPure", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "*", 
            RowBox[{
             RowBox[{"aPure", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"bPure", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "*", 
               RowBox[{"bPure", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}], ")"}]}]}], ")"}], "^", 
          "0.5"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "nComp"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "nComp"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\t", 
     RowBox[{"tPure", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"volumeTranslationVTPRLJ", "[", 
         RowBox[{
          RowBox[{"tRedVTPRLJ", "[", 
           RowBox[{"tSim", ",", 
            RowBox[{"\[Epsilon]ij", "[", 
             RowBox[{"[", 
              RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"\[Sigma]ij", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], "/@", 
       " ", 
       RowBox[{"Range", "@", "nComp"}]}]}], ";", "\n", "\t", "\n", "\t", 
     RowBox[{"trouble", " ", "=", " ", "False"}], ";", "\[IndentingNewLine]", 
     "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"initial", " ", "calculation", " ", "at", " ", "x1"}], " ", 
       "=", " ", "1"}], "*)"}], "\[IndentingNewLine]", "\t", 
     RowBox[{"xInit", " ", "=", " ", 
      RowBox[{"yGuess", " ", "=", " ", "1"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"First", " ", "Guess", " ", "at", " ", "x1"}], " ", "=", " ", 
       RowBox[{"y1", " ", "=", " ", "1"}]}], "*)"}], "\n", "\t", 
     RowBox[{"dx", " ", "=", " ", 
      RowBox[{"-", "0.01"}]}], ";", "\[IndentingNewLine]", "\t", 
     RowBox[{"pGuess", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"pLJ", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"pSatRedLJ", "[", 
            RowBox[{
             RowBox[{"tRedLJ", "[", 
              RowBox[{"tSim", ",", 
               RowBox[{"\[Epsilon]", "[", 
                RowBox[{"[", 
                 RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], "/", 
             "tCritLJ"}], "]"}], "*", "pCritLJ"}], ",", 
          RowBox[{"\[Epsilon]", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], "[", 
       "1", "]"}]}], ";", "\n", "\t", 
     RowBox[{"sol", " ", "=", " ", 
      RowBox[{"Quiet", "@", 
       RowBox[{"bubblePressureVTPRLJ", "[", 
        RowBox[{"aij", ",", "bij", ",", "tPure", ",", "tSim", ",", 
         RowBox[{"{", 
          RowBox[{"xInit", ",", 
           RowBox[{"1", "-", "xInit"}]}], "}"}], ",", "pGuess", ",", 
         RowBox[{"{", 
          RowBox[{"yGuess", ",", 
           RowBox[{"1", "-", "yGuess"}]}], "}"}], ",", "epsilon", ",", 
         "False"}], "]"}]}]}], ";", "\n", "\n", "\t", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"AnyTrue", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Im", "[", 
             RowBox[{"sol", "[", 
              RowBox[{"[", "4", "]"}], "]"}], "]"}], "!=", "0"}], ",", 
           RowBox[{
            RowBox[{"sol", "[", 
             RowBox[{"[", "4", "]"}], "]"}], "==", 
            RowBox[{"sol", "[", 
             RowBox[{"[", "5", "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"sol", "[", 
             RowBox[{"[", "4", "]"}], "]"}], ">", 
            RowBox[{"sol", "[", 
             RowBox[{"[", "5", "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"sol", "[", 
             RowBox[{"[", "4", "]"}], "]"}], "<", "0"}]}], "}"}], ",", 
         "TrueQ"}], "]"}], "\n", "\t\t", ",", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
          RowBox[{"True", ":", " ", 
           RowBox[{"the", " ", "calculation", " ", "has", " ", "failed"}]}], 
          " ", "->", " ", 
          RowBox[{"start", " ", "calculation", " ", "from", " ", "x1"}]}], 
         " ", "=", " ", "0"}], "*)"}], "\n", "\t\t", 
       RowBox[{
        RowBox[{"xInit", " ", "=", " ", 
         RowBox[{"yGuess", " ", "=", " ", "0"}]}], ";", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"First", " ", "Guess", " ", "at", " ", "x1"}], " ", "=", 
          " ", 
          RowBox[{"y1", " ", "=", " ", "1"}]}], "*)"}], "\n", "\t\t", 
        RowBox[{"dx", " ", "=", " ", "0.01"}], ";", "\n", "\t\t", 
        RowBox[{"pGuess", " ", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"pLJ", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"pSatRedLJ", "[", 
               RowBox[{
                RowBox[{"tRedLJ", "[", 
                 RowBox[{"tSim", ",", 
                  RowBox[{"\[Epsilon]", "[", 
                   RowBox[{"[", 
                    RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], "/", 
                "tCritLJ"}], "]"}], "*", "pCritLJ"}], ",", 
             RowBox[{"\[Epsilon]", "[", 
              RowBox[{"[", 
               RowBox[{"#", ",", "#"}], "]"}], "]"}], ",", 
             RowBox[{"\[Sigma]", "[", 
              RowBox[{"[", 
               RowBox[{"#", ",", "#"}], "]"}], "]"}]}], "]"}], " ", "&"}], 
          "[", "2", "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"sol", " ", "=", " ", 
         RowBox[{"Quiet", "@", 
          RowBox[{"bubblePressureVTPRLJ", "[", 
           RowBox[{"aij", ",", "bij", ",", "tPure", ",", "tSim", ",", 
            RowBox[{"{", 
             RowBox[{"xInit", ",", 
              RowBox[{"1", "-", "xInit"}]}], "}"}], ",", "pGuess", ",", 
            RowBox[{"{", 
             RowBox[{"yGuess", ",", 
              RowBox[{"1", "-", "yGuess"}]}], "}"}], ",", "epsilon", ",", 
            "False"}], "]"}]}]}], ";"}]}], "\n", "\t", "]"}], ";", "\n", "\t",
      "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{"caclculate", " ", "plot", " ", "data"}], "*)"}], "\n", "\t", 
     RowBox[{"pGuess", " ", "=", " ", 
      RowBox[{"sol", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{"initial", " ", "calculated", " ", "pressure"}], "*)"}], "\t", 
     "\n", "\t", 
     RowBox[{"yGuess", " ", "=", " ", "xInit"}], ";", "\n", "\t", 
     RowBox[{"pVec", " ", "=", " ", 
      RowBox[{"xVec", " ", "=", " ", 
       RowBox[{"yVec", " ", "=", " ", 
        RowBox[{"vLiqVec", " ", "=", " ", 
         RowBox[{"vVapVec", " ", "=", " ", 
          RowBox[{"{", "}"}]}]}]}]}]}], ";", "\n", "\t", 
     RowBox[{"Do", "[", "\n", "\t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"sol", " ", "=", " ", 
         RowBox[{"Quiet", "@", 
          RowBox[{"bubblePressureVTPRLJ", "[", 
           RowBox[{"aij", ",", "bij", ",", "tPure", ",", "tSim", ",", 
            RowBox[{"{", 
             RowBox[{"x1", ",", 
              RowBox[{"1", "-", "x1"}]}], "}"}], ",", "pGuess", ",", 
            RowBox[{"{", 
             RowBox[{"yGuess", ",", 
              RowBox[{"1", "-", "yGuess"}]}], "}"}], ",", "epsilon", ",", 
            "False"}], "]"}]}]}], ";", "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{
         "check", " ", "if", " ", "calculation", " ", "was", " ", 
          "sucsessful", " ", "and", " ", "exit", " ", "if", " ", "it", " ", 
          "failed"}], "*)"}], "\n", "\t\t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Im", "[", 
            RowBox[{"sol", "[", 
             RowBox[{"[", "4", "]"}], "]"}], "]"}], "!=", "0"}], ",", 
          RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"AnyTrue", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"sol", "[", 
                RowBox[{"[", "4", "]"}], "]"}], "==", 
               RowBox[{"sol", "[", 
                RowBox[{"[", "5", "]"}], "]"}]}], ",", 
              RowBox[{
               RowBox[{"sol", "[", 
                RowBox[{"[", "4", "]"}], "]"}], ">", 
               RowBox[{"sol", "[", 
                RowBox[{"[", "5", "]"}], "]"}]}], ",", 
              RowBox[{
               RowBox[{"sol", "[", 
                RowBox[{"[", "4", "]"}], "]"}], "<", "0"}]}], "}"}], ",", 
            "TrueQ"}], "]"}], ",", 
          RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"pVec", ",", 
          RowBox[{"sol", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"xVec", ",", 
          RowBox[{"sol", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "1"}], "]"}], "]"}]}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"yVec", ",", 
          RowBox[{"sol", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "1"}], "]"}], "]"}]}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"vLiqVec", ",", 
          RowBox[{"sol", "[", 
           RowBox[{"[", "4", "]"}], "]"}]}], "]"}], ";", "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"vVapVec", ",", 
          RowBox[{"sol", "[", 
           RowBox[{"[", "5", "]"}], "]"}]}], "]"}], ";", "\n", "\t\t", "\n", 
        "\t\t", 
        RowBox[{"pGuess", " ", "=", " ", 
         RowBox[{"sol", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"yGuess", " ", "=", " ", 
         RowBox[{"sol", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ";"}], "\n", "\t\t", ",", 
       RowBox[{"{", 
        RowBox[{"x1", ",", "xInit", ",", 
         RowBox[{"1", "-", "xInit"}], ",", "dx"}], "}"}]}], "\n", "\t", "]"}],
      ";"}]}], "\n", "]"}]}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->
  "In[116]:=",ExpressionUUID->"06a0856d-153b-494e-8589-bba4ef3a46b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plotPxyVTPRLJ", "[", "]"}], " ", ":=", " ", 
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"{", "\n", "\t", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"Show", "[", 
             RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
              RowBox[{
               RowBox[{"ListLinePlot", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{"xVec", ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{"pVec", ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    "]"}], ",", 
                   RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{"yVec", ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{"pVec", ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    "]"}]}], "}"}], "\n", "\t\t\t", ",", 
                 RowBox[{"Frame", "->", "True"}], ",", 
                 RowBox[{"GridLines", "\[Rule]", "Automatic"}], "\n", 
                 "\t\t\t", ",", 
                 RowBox[{"FrameLabel", "\[Rule]", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "Bold", ",", "14", ",", 
                    RowBox[{"SingleLetterItalics", "->", "False"}]}], "]"}], 
                    "&"}], "/@", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<\!\(\*SubscriptBox[\(x\), \
\(1\)]\),\!\(\*SubscriptBox[\(y\), \(1\)]\) [mol/mol]\>\"", ",", 
                    "\"\<\!\(\*SuperscriptBox[\(P\), \(*\)]\) [1]\>\""}], 
                    "}"}]}], ")"}]}], "\n", "\t\t\t", ",", 
                 RowBox[{"PlotLabel", "\[Rule]", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"component", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "<>", "\"\<-\>\"", "<>", 
                    RowBox[{"component", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "<>", "\"\< @T = \>\""}], 
                    ",", 
                    RowBox[{"ToString", "[", "tSim", "]"}], ",", 
                    "\"\< K\\n\>\""}], "}"}], "]"}]}], "\n", "\t\t\t", ",", 
                 RowBox[{"PlotLegends", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                   "\"\<t-PR-LJ, bubble curve\>\"", ",", 
                    "\"\<t-PR-LJ, dew curve\>\""}], "}"}]}], "\n", "\t\t\t", 
                 ",", 
                 RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "1"}], "}"}], ",", "Automatic"}], 
                   "}"}]}]}], "\n", "\t\t", "]"}], ",", "\[IndentingNewLine]",
                "\t\t", 
               RowBox[{"ListPlot", "[", 
                RowBox[{
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"{", "\n", "\t\t\t\t", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"resMFVTPRLJ", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{
                    RowBox[{"resPVTPRLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    ",", "\n", "\t\t\t\t", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"resMFVTPRLJ", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{
                    RowBox[{"resPVTPRLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}]}],
                     "}"}], "\n", "\t\t\t\t", ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "\n", 
                  "\t\t\t", "]"}], "\n", "\t\t\t", ",", 
                 RowBox[{"PlotStyle", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"Red", ",", "Blue", ",", "Orange"}], "}"}]}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"Automatic", ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Automatic"}], "}"}]}], "}"}]}], "\n", 
                 "\t\t\t", ",", 
                 RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
                 RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}], 
                 "\n", "\t\t\t", ",", 
                 RowBox[{"PlotLegends", "\[Rule]", 
                  RowBox[{"Table", "[", 
                   RowBox[{
                    RowBox[{"\"\<Simulation point @\>\"", "<>", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"pSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], "<>", 
                    "\"\< bar\>\""}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "]"}]}]}], 
                "\n", "\t\t", "]"}]}], "\[IndentingNewLine]", "\t", "}"}], 
             "]"}], "}"}], "}"}], "}"}], ",", "\n", "\t", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", "\n", "\t\t", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"Row", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<Simulation @\>\"", ",", " ", 
                 RowBox[{"pSim", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", 
                 "\"\< bar : \!\(\*SubscriptBox[\(x\), \(1\)]\) = \>\"", ",", 
                 RowBox[{"Round", "[", 
                  RowBox[{
                   RowBox[{"resMFVTPRLJ", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", "0.00001"}], 
                  "]"}], ",", 
                 "\"\< mol \!\(\*SuperscriptBox[\(mol\), \(-1\)]\), \
\!\(\*SubscriptBox[\(y\), \(1\)]\) = \>\"", ",", 
                 RowBox[{"Round", "[", 
                  RowBox[{
                   RowBox[{"resMFVTPRLJ", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", "0.00001"}], 
                  "]"}], ",", 
                 "\"\< mol \!\(\*SuperscriptBox[\(mol\), \(-1\)]\)\>\""}], 
                "}"}], "]"}], "}"}], ",", "\n", "\t\t", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"Row", "[", 
                 RowBox[{"{", 
                  RowBox[{
                  "\"\<\\t \!\(\*SubscriptBox[\(x\), \(m25  %\)]\) = \>\"", 
                   ",", " ", 
                   RowBox[{"#1", "+", 
                    RowBox[{"#2", "*", "0.25"}]}], ",", " ", 
                   "\"\<\\t \!\(\*SubscriptBox[\(x\), \(m50  %\)]\) = \>\"", 
                   ",", 
                   RowBox[{"#1", "+", 
                    RowBox[{"#2", "*", "0.5"}]}], ",", 
                   "\"\<\\t \!\(\*SubscriptBox[\(x\), \(m75  %\)]\) = \>\"", 
                   ",", " ", 
                   RowBox[{"#1", "+", 
                    RowBox[{"#2", "*", "0.75"}]}]}], "}"}], "]"}], "&"}], "[", 
               RowBox[{
                RowBox[{"resMFVTPRLJ", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"resMFVTPRLJ", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], "-", 
                  RowBox[{"resMFVTPRLJ", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ")"}]}], "]"}], 
              "}"}]}], "\n", "\t\t", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "\n", "\t", "]"}]}], 
        "\n", "}"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Alignment", "->", "Left"}]}], "]"}]}], ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->
  "In[117]:=",ExpressionUUID->"18f6f0e3-2d01-4059-8363-832212c57bb9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plotPrhoVTPRLJ", "[", "]"}], " ", ":=", " ", 
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"{", "\n", "\t", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"Show", "[", 
             RowBox[{"{", "\[IndentingNewLine]", "\t\t", 
              RowBox[{
               RowBox[{"ListLinePlot", "[", 
                RowBox[{
                 RowBox[{"{", "\n", "\t\t\t\t", 
                  RowBox[{
                   RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"RhoToRhoAst", "[", 
                    RowBox[{
                    RowBox[{"vToRho", "[", "vLiqVec", "]"}], ",", "xVec"}], 
                    "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{"pVec", ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    "]"}], ",", "\n", "\t\t\t\t", 
                   RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"RhoToRhoAst", "[", 
                    RowBox[{
                    RowBox[{"vToRho", "[", "vVapVec", "]"}], ",", "yVec"}], 
                    "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{"pVec", ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    "]"}]}], "\n", "\t\t\t", "}"}], "\n", "\t\t\t", ",", 
                 RowBox[{"Frame", "->", "True"}], ",", 
                 RowBox[{"GridLines", "\[Rule]", "Automatic"}], "\n", 
                 "\t\t\t", ",", 
                 RowBox[{"FrameLabel", "\[Rule]", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "Bold", ",", "14", ",", 
                    RowBox[{"SingleLetterItalics", "->", "False"}]}], "]"}], 
                    "&"}], "/@", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(L\), \(*\)]\),\
\!\(\*SubsuperscriptBox[\(\[Rho]\), \(V\), \(*\)]\) [1]\>\"", ",", 
                    "\"\<\!\(\*SuperscriptBox[\(P\), \(*\)]\) [1]\>\""}], 
                    "}"}]}], ")"}]}], "\n", "\t\t\t", ",", 
                 RowBox[{"PlotLabel", "\[Rule]", 
                  RowBox[{"StringJoin", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"component", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "<>", "\"\<-\>\"", "<>", 
                    RowBox[{"component", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "<>", "\"\< @T = \>\""}], 
                    ",", 
                    RowBox[{"ToString", "[", "tSim", "]"}], ",", 
                    "\"\< K\\n\>\""}], "}"}], "]"}]}], "\n", "\t\t\t", ",", 
                 RowBox[{"PlotLegends", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                   "\"\<liquid density - t-PR-LJ\>\"", ",", 
                    "\"\<vapor density - t-PR-LJ\>\""}], "}"}]}], "\n", 
                 "\t\t\t", ",", 
                 RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", "All"}]}], "\n", "\t\t", 
                "]"}], ",", "\[IndentingNewLine]", "\t\t", 
               RowBox[{"ListPlot", "[", 
                RowBox[{
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"{", "\n", "\t\t\t\t", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"RhoToRhoAst", "[", 
                    RowBox[{
                    RowBox[{"vToRho", "[", 
                    RowBox[{"resvLiqVTPRLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
                    RowBox[{"resxVTPRLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{
                    RowBox[{"resPVTPRLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    ",", "\n", "\t\t\t\t", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"RhoToRhoAst", "[", 
                    RowBox[{
                    RowBox[{"vToRho", "[", 
                    RowBox[{"resvVapVTPRLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
                    RowBox[{"resyVTPRLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{
                    RowBox[{"resPVTPRLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}]}],
                     "}"}], "\n", "\t\t\t\t", ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "\n", 
                  "\t\t\t", "]"}], "\n", "\t\t\t", ",", 
                 RowBox[{"PlotStyle", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"Red", ",", "Blue", ",", "Orange"}], "}"}]}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"Automatic", ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Automatic"}], "}"}]}], "}"}]}], "\n", 
                 "\t\t\t", ",", 
                 RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
                 RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}], 
                 "\n", "\t\t\t", ",", 
                 RowBox[{"PlotLegends", "\[Rule]", 
                  RowBox[{"Table", "[", 
                   RowBox[{
                    RowBox[{"\"\<Simulation point @\>\"", "<>", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"pSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], "<>", 
                    "\"\< bar\>\""}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "]"}]}]}], 
                "\n", "\t\t", "]"}]}], "\[IndentingNewLine]", "\t", "}"}], 
             "]"}], "}"}], "}"}], "}"}], ",", "\[IndentingNewLine]", "\t", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", "\n", "\t\t\t", 
            RowBox[{"{", 
             RowBox[{"Row", "[", 
              RowBox[{"{", 
               RowBox[{"\"\<Simulation @\>\"", ",", " ", 
                RowBox[{"resPVTPRLJ", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                "\"\< bar : \!\(\*SubscriptBox[\(\[Rho]\), \(L\)]\) = \>\"", 
                ",", 
                RowBox[{"Round", "[", 
                 RowBox[{
                  RowBox[{"1", "/", 
                   RowBox[{"resvLiqVTPRLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], ",", "0.00001"}], "]"}],
                 ",", "\"\< mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\), \
\!\(\*SubscriptBox[\(\[Rho]\), \(V\)]\) = \>\"", ",", 
                RowBox[{"Round", "[", 
                 RowBox[{
                  RowBox[{"1", "/", 
                   RowBox[{"resvVapVTPRLJ", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], ",", "0.00001"}], "]"}],
                 ",", "\"\< mol/\!\(\*SuperscriptBox[\(dm\), \(3\)]\)\>\""}], 
               "}"}], "]"}], "}"}], "\[IndentingNewLine]", "\t\t", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "\n", "\t", "]"}]}], 
        "\n", "}"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Alignment", "->", "Left"}]}], "]"}]}], ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->
  "In[118]:=",ExpressionUUID->"f3b3730c-cb35-4e3b-bb88-223cb2c719b6"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"CalculatePlotDataVTPRLJ", "[", 
  RowBox[{
  "tSim", ",", "pSim", ",", "\[Sigma]", ",", "\[Epsilon]", ",", 
   "\[Epsilon]Iteration"}], "]"}], "\n", 
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"plotPxyVTPRLJ", "[", "]"}], ",", 
      RowBox[{"plotPrhoVTPRLJ", "[", "]"}]}], "}"}], "}"}], ",", 
   RowBox[{"Alignment", "->", "Top"}]}], "]"}]}], "Code",
 CellLabel->
  "In[119]:=",ExpressionUUID->"edab9c17-e948-47c9-b502-e1558228df95"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         TemplateBox[{
           GraphicsBox[{{{}, {{{}, {}, {
                 Hue[0.67, 0.6, 0.6], 
                 Directive[
                  PointSize[
                   NCache[
                    Rational[1, 72], 0.013888888888888888`]], 
                  RGBColor[0.368417, 0.506779, 0.709798], 
                  AbsoluteThickness[1.6]], 
                 LineBox[CompressedData["
1:eJwtkmtQ1GUYxVdk5KLBFqR9EISY5OKIjBpkIxymIpQ2FfiArhAqSiZCWikI
iRAXc+SmiIqSLff7XthdWIgUVkrUhbivIOAu9zuISlLK1L4+z8x//t/Oe875
HetD3/oc0eNwOIH/f7r/m5uDY1JWUtjXmRB6aiPNhbMovKk9e9/kBvxTlS/s
/GfxjZnQqaTyBozVuSdcjWeRaNUT+eqrm1BYJkx6K2aQdtzIVmmQhWB2M/BY
Iea8FmfBnAnOIKV8ZZuQ/wt0aqnKabjeMTjcrX8LJ111itPI2zpvli66hXU6
OctpRNQnOlTyf0WTSndT6Dc1rd6wXIAoJjiF7aWr9m7fJ4A9MziF11/82Z4s
EoDZU0+Cp51dZb0iG0wuYRLH3g4aXPDPxhZ2k7jEtXDmyrKhS+upnYBRodtg
6MocsLipE/g8y6SRG5QDNxZ4AsPKpbrFmhxMMblxcEakxfZmubiRqbtxeHRz
A7JDcrGDCY7DbuEz+cGGXCzo4r4YQ6tP/8UQizzk6ezljkG9XFN953QefFiB
Y9ir7F0T2JKHNzzGYOC7OtrLIZ94jML4nZyGn+LziccomkzS7xo+ySceo+iz
c/Dt21ZAPEbA5+6352YUEI8R/NYXUZowV0A8RmB7jxfE4xUSj2H4NG/edKSo
EMzeiWF0F26dadEvApOzHAa/JjQ27WARGA7VEFoKw1V5t4uIxxCS1Vq5ydpi
4jEEr1GZ7V9nionHIM6M6HFH1cXEYxCvdiUc9HMuIR6DeFq709w6o4R4DEAZ
Hbbe43kJ0pjBARyxm8tq8C0lHgNYPHohXiAtJR5aqKpf1k+ZlREPLRQfXxQk
/lBGPLSQGqSejuksIx4aPM9YOPfYuZx4aDDhHaCfeb2ceGiQdO0yv+afcuKh
wfs2ThPuAULq/wkkE94bHeuE1Hc/onZ+VxFnI6J++9HmF2r56XkR9dkH4QWh
Y9ikiPrrxb3w+9dM7MRgdux64XlC3pzOFyOe9fMYkapt497JYgww+z0Ijztq
5FUnpvw9EOU6BJ19Jqa83UiL6cH0egnlewTn7104N/kSyvMI8e/GWf6cIqE9
qYEy/UdKpYT2o0ZtreCDD/+W0F66sEldYzW1oYL20Ym2+bmH4wcqaA+dmE1x
2+10tQLMXmQHjPXcluofVqCLybXjhSFni2iZFJsZ33bssAqZ17hIiWcbokyX
vgwOkxK/VrQ3d8V+ki8lXq0I7jYRJPZKiU8LbEOfxVqYy4hHCw6Nxy2u5smo
/2ZYFZ9LDY+XUd9N0Kb4n/T9XUb9qrCnMXL3lQUZNMzwAzhbBwzznOS4zvq7
jwj37rVXjsmxhwk24qlyMc03Xw5D1s89+Mz4VYg1ctSxPv7Ay5x1V6+trcSP
LH8Dst7Ta9y0rxJbWd67sM3faHPqaiXlq8fCsQj34I5KylOHhwf2RziaVZH/
2+DZP9jW7FNFfmvhtuwwLzi9ivxVI/ojg67JjiryU4Vdp1Shl9YoEMHel8E7
+q3G4/sVGGPvSTA7eD4wRqCAmOkL4V3vYvXviAL/Ae8p6Lk=
                  "]]}, {
                 Hue[0.9060679774997897, 0.6, 0.6], 
                 Directive[
                  PointSize[
                   NCache[
                    Rational[1, 72], 0.013888888888888888`]], 
                  RGBColor[0.880722, 0.611041, 0.142051], 
                  AbsoluteThickness[1.6]], 
                 LineBox[CompressedData["
1:eJwlxQs8FAYAx/ErJDR5tmWItE4K1ypqi79eWnZ5N0skKYtyPaijllJiFmLC
RHVeeRzn3DmOFC7jjkve5zyOy6M8wsmMFW377Pf5fD8/w5PnnU8vJxAIXv/6
7/83DbPotGjKTym4pdrpHKsyhZxU6XWB6gPsoH7j4Ll+En6aDFJ+6QN0PRy2
y9n3DhEG3Vc/Hk9FxvGft3IpE4g7p0TkKabhVNfblPGMcRxYwSQsMtPA2XBE
h94/hthClVaG+0O0XBC0nNswBqsqxVNi+UfQuSCNY18YRdb2Gc2Eokegz8mZ
rKx9i+CaCJNS98dQV/8UQtB/C8nq1eWb5WhwS/nNa1foG+ymr/px91EarDxY
JLehESx+X9cWU0SDVt3USgXHEZClU6sMV6QjTGa9ebZ6GP7qPoNzHumwaCsJ
6rEYRryanoVaSTrYhUTJleIhKOVYDwaoZIDSO6QcSRqCbZoqX80nA6T0d6+b
2YMY5i1VL1RkQPzK21Lv20EQRth5mzQzoRw1cX5n3WscEKt5pp/NhIvM1GbG
9TWM5/ZzvGszoSBvfUrvjRQtzpK7Z/WyoGEU5nPvZylEcgPlVVey0Jy07qiB
thQ/8no/92rOwu/eETX5zAEouqwJtTPJxuhX/mQVhwEoa2TU3grPxr3ovNN7
BvrxUjXhxcr+bIRScw2Tif3oMzZx6dv1BP5NvFhpoATuasc2qSU+wcH4hilJ
bR+e9gXT70w/AYXuIjuu0wdiPdmHTM4BRd3UyzyoF85NX5ufzs2BaUxRukFr
D8Q52yeb5XPBn7aIU9jeA/eKgLA471xE01tt2SndaM6hCrOe52LbEOkTQa4b
MSIpR1U3Dx2Xgifqz4th96aE+CokDz+kvFw72N+FkJHlam9EeVhU2P+9uUsX
Ptrf8XazyEfMgxXSXwUiyCoPaRkm5kONeauyY68IvFDKxgOz+Uja7UeUPe/E
aePptFoXOrjeHpVVVp1YOBMVTmPTYfuLNNCkqgPC8vmaCc0CBMd7+q/a1wHu
N3dpEUEF2L3YEugoaAdb8d6Vmx0FaP+gnNnn1I7ZxLkbPRaFGC/78HdqbxvG
nDzlU34vhPagq1eQXxuik39zr/i7EHKdvncc51ux3og0ZuPJwJ/ihmGdqFYU
jzmZmlUz4ECpYjz/shXXDl1i3TYqQoHPhjIiswWtbgH6+yKLoBstf2mvbQsY
UQwzyngR7h/WkxEkzainCpJVjZlQabuufpDajIMXOE0J7ky8K38coqjRjKvC
XaNOMUyIU2Z3eHu8AvX2GSW7aiaS+dvvn0xuQlGmic/190w0THb6ydpfIu5m
N95tLMb62TjmhNZLWARaElLdi5HVbTS+zU2IcO3b+r/EFsPeRCRlpjYCBfJd
PF4x5lsYdltfN6CykvbVjr+KwecW0B+ZNMBcVGEwsZmFRZGkRxwkQOvMdOPo
CRZsR6nCF9V8TMVaO5CSWNjbyLlkpcqH8nLrpZpGFoTaulZbPevx50rCtqJl
bERaEoYDCuvwncHZmQFLNpiOda69S3/g2uqlw74UNpZ0/CM9nP5AW1Nn2N5s
NqKij8R2ZtXCV6xKi+hlQ/uRq9zahRcgBrwP09MqgVVD8BEl+xc4OXp7YQ25
BEK5a07hmTwY5N24Rw0vQfkWw8uUhRpIYz0uujwrwVAYyz7eoQaO/KsO9+dK
EN8RJhJmV8PC0HOYTOIgxNKaQ5ivQrCNWPe+PwdaZvp7JJnPIeMtxLlkc2Cj
Qg2ftX8G50k3FnOAgzX5Mu3q+aeYz1iXlKxbiosa3za8p1Ug7YvlfPOjpbBL
iDusfLAcxGxTo8tJpRj5bo/3lbEyzPkH2/i2l2Jgo0Rf8GspGk8cCzbTLMON
jzHWR4kckDc17GpyLoPAbj/hbhUb1stOkX0TyhDzyjUwwpmF0J2KnePtZVhH
OlSf2s+E/WVhQPznXCy7I5yZbGTAKfQz/rljXHx6nLg5WUDH1GCk100aF1sO
tDyU4+bCqcbS4MMIF/8AP3jxUQ==
                  "]]}}}, {{}, {}}}, {{}, {{{}, {}, {}, {}, {}, {}, {
                 Directive[
                  RGBColor[1, 0, 0], 
                  Opacity[0.3]], 
                 
                 LineBox[{{0.697193764762943, 0.}, {0.697193764762943, 
                  0.04500004260992203}}], 
                 
                 LineBox[{{0.46219359493692164`, 0.}, {0.46219359493692164`, 
                  0.04500004260992203}}], 
                 
                 LineBox[{{0.46219359493692164`, 0.}, {0.46219359493692164`, 
                  0.04500004260992203}}]}, {}, {
                 Directive[
                  RGBColor[0, 0, 1], 
                  Opacity[0.3]], 
                 
                 LineBox[{{0.4907923576811004, 0.}, {0.4907923576811004, 
                  0.060000370719502316`}}], 
                 
                 LineBox[{{0.290152625807014, 0.}, {0.290152625807014, 
                  0.060000370719502316`}}], 
                 
                 LineBox[{{0.290152625807014, 0.}, {0.290152625807014, 
                  0.060000370719502316`}}]}, {}, {
                 Directive[
                  RGBColor[1, 0.5, 0], 
                  Opacity[0.3]], 
                 
                 LineBox[{{0.3008570486554176, 0.}, {0.3008570486554176, 
                  0.07500053735071827}}], 
                 
                 LineBox[{{0.17762634894556278`, 0.}, {0.17762634894556278`, 
                  0.07500053735071827}}], 
                 
                 LineBox[{{0.17762634894556278`, 0.}, {0.17762634894556278`, 
                  0.07500053735071827}}]}}, {{
                 Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[1, 0, 0]], 
                 GeometricTransformationBox[
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], 
                    GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}, StripOnInput -> False], 
                    TraditionalForm]], {0., 0.}, Automatic, 
                   Scaled[9.75]], {{{0.697193764762943, 
                  0.04500004260992203}}, {{0.46219359493692164`, 
                  0.04500004260992203}}, {{0.46219359493692164`, 
                  0.04500004260992203}}}]}, {
                 Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[0, 0, 1]], 
                 GeometricTransformationBox[
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], 
                    GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}, StripOnInput -> False], 
                    TraditionalForm]], {0., 0.}, Automatic, 
                   Scaled[9.75]], {{{0.4907923576811004, 
                  0.060000370719502316`}}, {{0.290152625807014, 
                  0.060000370719502316`}}, {{0.290152625807014, 
                  0.060000370719502316`}}}]}, {
                 Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[1, 0.5, 0]], 
                 GeometricTransformationBox[
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}], 
                    GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]]}, StripOnInput -> False], 
                    TraditionalForm]], {0., 0.}, Automatic, 
                   Scaled[9.75]], {{{0.3008570486554176, 
                  0.07500053735071827}}, {{0.17762634894556278`, 
                  0.07500053735071827}}, {{0.17762634894556278`, 
                  0.07500053735071827}}}]}}}, {{}, {}}}}, {
            DisplayFunction -> Identity, DisplayFunction -> Identity, 
             AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
             Axes -> {True, True}, AxesLabel -> {None, None}, 
             AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
             Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                FormBox[
                 TagBox[
                  StyleBox[
                  "\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(*\\)]\\) [1]\"", 
                   Bold, 14, SingleLetterItalics -> False, StripOnInput -> 
                   False], HoldForm], TraditionalForm], None}, {
                FormBox[
                 TagBox[
                  StyleBox[
                  "\"\\!\\(\\*SubscriptBox[\\(x\\), \
\\(1\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) [mol/mol]\"", Bold, 14,
                    SingleLetterItalics -> False, StripOnInput -> False], 
                  HoldForm], TraditionalForm], None}}, 
             FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
             GridLines -> {Automatic, Automatic}, GridLinesStyle -> Directive[
               GrayLevel[0.5, 0.4]], ImageSize -> Medium, 
             Method -> {
              "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
               "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                   Identity[
                    Part[#, 1]], 
                   Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                   Identity[
                    Part[#, 1]], 
                   Identity[
                    Part[#, 2]]}& )}}, PlotLabel -> 
             FormBox["\"LJ_ref-LJ_1 @T = 1. K\\n\"", TraditionalForm], 
             PlotRange -> {{0., 1.}, {0, 0.09727448975150323}}, 
             PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {
                Scaled[0.02], 
                Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
           FormBox[
            TagBox[
             GridBox[{{
                FormBox[
                 
                 TemplateBox[{
                  "\"t-PR-LJ, bubble curve\"", "\"t-PR-LJ, dew curve\""}, 
                  "LineLegend", DisplayFunction -> (StyleBox[
                    StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                    FontFamily -> "Arial"}, Background -> Automatic, 
                    StripOnInput -> False]& ), 
                  InterpretationFunction :> (RowBox[{"LineLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                    RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
                    ",", 
                    RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"True", ",", "True"}], "}"}]}], ",", 
                    RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                    "]"}]& ), Editable -> True], TraditionalForm]}, {
                FormBox[
                 
                 TemplateBox[{
                  "\"Simulation point @6.21292 bar\"", 
                   "\"Simulation point @8.28389 bar\"", 
                   "\"Simulation point @10.3549 bar\""}, "PointLegend", 
                  DisplayFunction -> (StyleBox[
                    StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #2}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                    FontFamily -> "Arial"}, Background -> Automatic, 
                    StripOnInput -> False]& ), 
                  InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 0, 1]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0.5, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                    RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], ",", "9.75`"}],
                     "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}], ",", "9.75`"}], "}"}]}], "}"}]}], 
                    ",", 
                    RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "False", ",", "False"}], "}"}]}], 
                    ",", 
                    RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                    "]"}]& ), Editable -> True], TraditionalForm]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> 
              False, GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], 
            TraditionalForm]},
          "Legended",
          DisplayFunction->(GridBox[{{
              TagBox[
               ItemBox[
                PaneBox[
                 TagBox[#, "SkipImageSizeLevel"], 
                 Alignment -> {Center, Baseline}, BaselinePosition -> 
                 Baseline], DefaultBaseStyle -> "Labeled"], 
               "SkipImageSizeLevel"], 
              ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
            GridBoxAlignment -> {
             "Columns" -> {{Center}}, "Rows" -> {{Center}}}, AutoDelete -> 
            False, GridBoxItemSize -> Automatic, 
            BaselinePosition -> {1, 1}]& ),
          Editable->True,
          InterpretationFunction->(RowBox[{"Legended", "[", 
             RowBox[{#, ",", 
               RowBox[{"Placed", "[", 
                 RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]},
        {
         TemplateBox[{
          "\"Simulation @\"", "6.212920499999999`", 
           "\" bar : \\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\) = \"", 
           "0.6971900000000001`", 
           "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\), \
\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) = \"", "0.46219000000000005`", 
           "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)\""},
          "RowDefault"]},
        {
         TemplateBox[{
          "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m25  %\\)]\\) = \"", 
           "0.6384437223064376`", 
           "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m50  %\\)]\\) = \"", 
           "0.5796936798499324`", 
           "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m75  %\\)]\\) = \"", 
           "0.520943637393427`"},
          "RowDefault"]},
        {
         TemplateBox[{
          "\"Simulation @\"", "8.283894`", 
           "\" bar : \\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\) = \"", 
           "0.49079000000000006`", 
           "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\), \
\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) = \"", "0.29015`", 
           "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)\""},
          "RowDefault"]},
        {
         TemplateBox[{
          "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m25  %\\)]\\) = \"", 
           "0.4406324247125788`", 
           "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m50  %\\)]\\) = \"", 
           "0.3904724917440572`", 
           "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m75  %\\)]\\) = \"", 
           "0.3403125587755356`"},
          "RowDefault"]},
        {
         TemplateBox[{
          "\"Simulation @\"", "10.3548675`", 
           "\" bar : \\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\) = \"", 
           "0.30086`", 
           "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\), \
\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\) = \"", "0.17763`", 
           "\" mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)\""},
          "RowDefault"]},
        {
         TemplateBox[{
          "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m25  %\\)]\\) = \"", 
           "0.2700493737279539`", 
           "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m50  %\\)]\\) = \"", 
           "0.2392416988004902`", 
           "\"\\t \\!\\(\\*SubscriptBox[\\(x\\), \\(m75  %\\)]\\) = \"", 
           "0.2084340238730265`"},
          "RowDefault"]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"], 
     TagBox[GridBox[{
        {
         TemplateBox[{
           GraphicsBox[{{{}, {{{}, {}, {
                 Hue[0.67, 0.6, 0.6], 
                 Directive[
                  PointSize[
                   NCache[
                    Rational[1, 72], 0.013888888888888888`]], 
                  RGBColor[0.368417, 0.506779, 0.709798], 
                  AbsoluteThickness[1.6]], 
                 LineBox[CompressedData["
1:eJwVz3s41PkCBvBRLVkO09LtlCinSIXTtmynzOtIdtOswmmTcqTShUE3hTaX
3Fahcck9jVszBnMft1BhS9HUKZooNWPm93XoomwNzqpnnT/e530+/7zP8y4/
EOETPItGowXO5P/9dvo4m1ZKYJ9ekh5+pBAbDnkM/3PG3GL1+XsmRbiUuTn3
5xkfMxM48uuLIPu7zwmXGadYDcRM/7sYa2x3Hv90lYDNMrRpNyiBQBDxy/kZ
b9UX0T6LSmA6tSKmt4Qgs87oscD/KsztXnpMFRO43DQ41D+nFKn5yQOjRQSV
G8bNcoSlCD+6spNbSBB1O8Wu3v8aPm51H7EvIHhpatq0ZjYH4RMmhnF5BJtr
jP027+HAb1/0QF4uweftd55kCDkQVE4YRWYTMNVjxsv1y+D4x/oti9gEIfMO
anT7yuCf2Lw0LoMgi27hRJeVISxMtIZ3kcCQy9CEGZVDX3VyKiuVwKPEpIt+
sByrI1y/2pREQLV/uTXVXI6SXmVHWTwBjUirV5tVQJL3zbXOX2b+9tMDykIr
kO8W86ksisBW5y4P6qwAu1+5+PvTBP/xeXkp1KIS2/VbfZIjCJSzVU03z1TC
kas/kBpC4Nf+YmHgo0oEO/q9cAkmMPBdEOtpV4XF+y5HVQUSfP1NeeeFpCqw
cx1utuwheGCS0zH3VRVOnu4UJ/gSDNra+Q5uvI7YorbscSaBP33vavqV69gV
9LbG2IPgxmBUTfL76/iVsXaBgkFgc5d5kMnk4phwN3uDM4GPYr1DMI+Lth9L
77g4EPRzN7x7NIcHUWC59/Cqmb3msAR2EA9iRYrcfhnBI+7Znso2HnZ9HN0/
bz5BhlItN1laDavQ3pp0IwLPYZnNw+hq8HqTnl7VI4gms+jDymosUG2c6zZB
YdorOWi3Ex+JCX0/nXlD4UPLNvPlV/g4No9V4Kym0B4bvmrrRz603fIbF/oo
BNu+L+n0rUHok/2sf92jMHU0LYkjrcGYgtVf3UKhp2ny9huzWlTysrxjhRQa
/3GJk3K6FtnWSXxFGQWpweUz8X214GfEGObnUPh4RRf33KkOLPmrY0+SKIx6
B8wpLKiD0V95RXGRFNLzs/2b/1cH3YNdm/KDKaywdhx1DRCAxZc1zt9FQTzq
vc7+lgDbXTy26bZQOLftpCTRWoh1Bb4j366n8Hh32LItqUJwhIU/37OkIEgT
2Ie/FkLnPmwuMaZw9+y9fBNbEY54SUPIpBY/HJcrcvxFmG5baR2k1SKmZ+OI
d4YI5uS3B0seanE28aih5y0RepYMXTVt0kJYYXfw/O8i0NsqD3xXrgU7fgBv
V4mxhDU7NvmiFk6nnGnF/mJYmKYPTJzQIml+4rJfM8XYKw+ITPbTArVznrW3
izFQ8MF1BUOLlhbOyu8mxLC0NXv82wotHJTNVm/WSLBjM18WrK/F4/H33SP7
JTDI5Yh1/9VgLJOxwzFPgr+Ffmhk3dfg61mML7e7JdiWlm3Yytfg01zat0I9
KUpPzovvS9PgR6vQcZWzFJvagm/wjmhwzvTLT4fDpRhRRFusctfgieJpgluV
FPy7Ox0Zlhoc7jfhpLyQ4vLntU7PJodgE/Z7goW5DM1rY8JUj4ZwYCRxagFT
Bq/njAsM7hCsquMun02SoeN+msPzc0NQZ+474dsqQ/D9H05leQ1hZ1fMjlyd
DGQ63cbNcghOywMopqMcEeqO1O63akS59i/NDZFjUd9QwWSTGh/ap9i+VXK8
9zW9eS1RDZ93uyUi1Yz1jBvOeaoxWW6Zl7+0HrWLAyq8TdQoWTSry2FPPS4u
0nR3KVSwqVpnHZlXD/u+VvfISyroQqJcD/fWQ/t6fOHIFhW69++NsjdrgHpr
xzu9sVdgrr6/UeHTgDp9p4fTnq/A0DvEPJzTgAQjhjK+8CVivzd4+rq3AYo7
ktY+5SC8InvCshY2IvVZVGOP3iC8Y//SxdrbiK+i15/i0F9gTJMaGM9pBE25
qdhtagDet52t/iCN+BP0y/1E
                  "]]}, {
                 Hue[0.9060679774997897, 0.6, 0.6], 
                 Directive[
                  PointSize[
                   NCache[
                    Rational[1, 72], 0.013888888888888888`]], 
                  RGBColor[0.880722, 0.611041, 0.142051], 
                  AbsoluteThickness[1.6]], 
                 LineBox[CompressedData["
1:eJwVzmk4FAgAh/EhhQ4m2vS0OdLhmJLk6GD+1a5KWRmUGiTEFkbXFlGOjJJy
RRSqYWbMOOceYxxjZoQiKx0SikfHkkppbafd9sP7/L6+i4MPe4VqEgiEwB/9
rzYlIzzB9QZsLhVdivr9GvIVjebmy26CUzh05rZeASjzk81TpjFwyLDatlxa
ANu8PbeyTzBwzuxJ7Ld9hdjhZjej4S8GsiJ1LVTaRWjh6BrPCSiG6ww+4Tu/
CEtbubTU7mJkVM3qrqZeR1i35wUHtxK4KLQP9GrdwM/tuQ4kZQlY9h8Mc3g3
cF5jeSdlPRMxynPWUupN5NPuLVeImXiqr19L+vFRmDmrKNaWBeeK2Xuc9zLQ
vsNEebGKhe87Wu6n8xhgJn0J/kJiw33o3ezFM4rRKGKndVawET43ZHjSvxhT
3h0JxJWlyCYaOxLFxbA/HNfexiuFLoc8TJtVAiem1gaCPQdbivTaiCElCM/Q
H1bUcvBCNdX0WV6CFY795nM3cUF4KSqzMmSCYyLnfL/NhWsvMaA4ggm1g+xI
pk8ZLCd/lQQ1M0HRvdzdNViGe15PL0YYs7DU+llcR1Q5eqYN1ipOsqBDTDuV
PlWOPap+o8AuFsi+uRtMsyqg7T0/frs1G/kSm4L0JZWYaVDSfJbOhoRD6nsu
q8RdvRy1zjM2ss4+qFntWYUBS2vvgXWleBR5UHB9pApUop8V8UophugFbEJK
NeoGYipSxkvhZrnh6llzHixa3UPc3Tkw0X3vZ6fiwavTblUolwOdXYOV+nZ8
9HLs33ZpceGTPXV3BZ0PqpyWlBXExcLdGmMxPXx0caI7WI1ciKh+9d9IAqT3
DEn0FpXh9OZxH2WSANtfiS3+PFWGS3Inu67HApx6qUl81VMG/3nDLmtWC/HN
IyXI17Ec0YcMHn1ME+J9vdu8xVfKYd5n8dD0pRCq+Kjlrh/LcczFrUCxWYRQ
y/GiZu8KGB0tMRhkiPD54AU6Q1QBv9gZh5kEMTpqPynHDCsx1pv9+k2QGLL1
Fxnn/qiEkcHC4cFmMUTamScTH1aiMH5sIs1Kgo9XJhP6HKvQryVP+ZopwSgl
QOva1SpcJn/r2/xJgkv5l6nyL1UImZttcSxYCvMltqMbA6qhGDIvKOyUQjBK
WWnTVI32pry4bucaxLkdEyYv4YE0pdxEqqpBty/N5JfzPPh7CMvrTGWovlBt
E/Wah0MtiU9rc2Vojb6dr2fJx6GApWe1Ztdi6xFJZw6VDy8vVuS9lFrEdqwb
oaTz4bKS3++sKUd08kHd7U18bI+01g9NkoPHtA45M8GHa2h9dPi0OmQlPsGb
5QLAY/rXw6l1cDzuRCikCpDGDrEtJNaD/lOySWqGAPscUqaTi+qBSq3HKpUA
C84c++hEakB9PWOZwz8CSNV9xf0NDVjVIzcbIwmx5jv130CfRnR/GG8f2S8E
c3gb48vbRrzLIO+0zRMimir0HU1XYKYmeUrZLsTRf488v7+gCX/rENbwNES4
Kcuh69GasM0s4sOgkwgR5bWS5+omxOlP/RYWJYJpYsMCurES9zsfJW1mizBx
8qDaOVaJsF49xrl+EUYZGYEGT5SwoE0kGc8Tg9t2esDfRYXgkeTP893FGAh0
qg9hqWBWlpAZTRcj0Oj01hv6agxl+B/1bhAjQsdbuDRBDc+22J25k2IQ96/l
Jkyo4bg44IW7rQTC6NQje2jNiNnYuyg3XII60+nbRsea8V71OcubLcGs5zO9
7I/fgtdbXyF/UIItsRpkJqEFn0pM8/IXSSGvLF2XmteCogWabav2SvHVZrzn
gUMrLNgrl5zIkyKRPGIkedaKyfCYjWEPpIj1NG4OymtD+36/GBvDGlxf76l4
5ncb7lZ31nV61SB5pse1U2vugKxxwD0spwa7jiveZ5u1I36t9qPXD2rQNe+E
C92qAx4nOmjZRjKkBfuox3bfBSV+Tluknwz+1Vs1X0g68W74fGAiQ4aWq3ON
g2y7QFE6mX19KcN//Ofc0g==
                  "]]}}}, {{}, {}}}, {{}, {{{}, {}, {}, {}, {}, {}, {
                 Directive[
                  RGBColor[1, 0, 0], 
                  Opacity[0.3]], 
                 
                 LineBox[{{0.6958071157656445, 0.}, {0.6958071157656445, 
                  0.04500004260992203}}], 
                 
                 LineBox[{{0.059944064843572446`, 0.}, {0.059944064843572446`,
                   0.04500004260992203}}], 
                 
                 LineBox[{{0.059944064843572446`, 0.}, {0.059944064843572446`,
                   0.04500004260992203}}]}, {}, {
                 Directive[
                  RGBColor[0, 0, 1], 
                  Opacity[0.3]], 
                 
                 LineBox[{{0.6667989046652962, 0.}, {0.6667989046652962, 
                  0.060000370719502316`}}], 
                 
                 LineBox[{{0.08895900451394761, 0.}, {0.08895900451394761, 
                  0.060000370719502316`}}], 
                 
                 LineBox[{{0.08895900451394761, 0.}, {0.08895900451394761, 
                  0.060000370719502316`}}]}, {}, {
                 Directive[
                  RGBColor[1, 0.5, 0], 
                  Opacity[0.3]], 
                 
                 LineBox[{{0.6109259415862714, 0.}, {0.6109259415862714, 
                  0.07500053735071827}}], 
                 
                 LineBox[{{0.12810565015334674`, 0.}, {0.12810565015334674`, 
                  0.07500053735071827}}], 
                 
                 LineBox[{{0.12810565015334674`, 0.}, {0.12810565015334674`, 
                  0.07500053735071827}}]}}, {{
                 Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[1, 0, 0]], 
                 GeometricTransformationBox[
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], 
                    GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}, StripOnInput -> False], 
                    TraditionalForm]], {0., 0.}, Automatic, 
                   Scaled[9.75]], {{{0.6958071157656445, 
                  0.04500004260992203}}, {{0.059944064843572446`, 
                  0.04500004260992203}}, {{0.059944064843572446`, 
                  0.04500004260992203}}}]}, {
                 Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[0, 0, 1]], 
                 GeometricTransformationBox[
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], 
                    GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}, StripOnInput -> False], 
                    TraditionalForm]], {0., 0.}, Automatic, 
                   Scaled[9.75]], {{{0.6667989046652962, 
                  0.060000370719502316`}}, {{0.08895900451394761, 
                  0.060000370719502316`}}, {{0.08895900451394761, 
                  0.060000370719502316`}}}]}, {
                 Directive[
                  PointSize[0.012833333333333334`], 
                  AbsoluteThickness[1.6], 
                  RGBColor[1, 0.5, 0]], 
                 GeometricTransformationBox[
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}], 
                    GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]]}, StripOnInput -> False], 
                    TraditionalForm]], {0., 0.}, Automatic, 
                   Scaled[9.75]], {{{0.6109259415862714, 
                  0.07500053735071827}}, {{0.12810565015334674`, 
                  0.07500053735071827}}, {{0.12810565015334674`, 
                  0.07500053735071827}}}]}}}, {{}, {}}}}, {
            DisplayFunction -> Identity, DisplayFunction -> Identity, 
             AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
             Axes -> {True, True}, AxesLabel -> {None, None}, 
             AxesOrigin -> {0.01545227097530575, 0}, DisplayFunction :> 
             Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                FormBox[
                 TagBox[
                  StyleBox[
                  "\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(*\\)]\\) [1]\"", 
                   Bold, 14, SingleLetterItalics -> False, StripOnInput -> 
                   False], HoldForm], TraditionalForm], None}, {
                FormBox[
                 TagBox[
                  StyleBox[
                  "\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(L\\), \
\\(*\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(V\\), \\(*\\)]\\) [1]\
\"", Bold, 14, SingleLetterItalics -> False, StripOnInput -> False], 
                  HoldForm], TraditionalForm], None}}, 
             FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
             GridLines -> {Automatic, Automatic}, GridLinesStyle -> Directive[
               GrayLevel[0.5, 0.4]], ImageSize -> Medium, 
             Method -> {
              "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
               "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                   Identity[
                    Part[#, 1]], 
                   Identity[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                   Identity[
                    Part[#, 1]], 
                   Identity[
                    Part[#, 2]]}& )}}, PlotLabel -> 
             FormBox["\"LJ_ref-LJ_1 @T = 1. K\\n\"", TraditionalForm], 
             PlotRange -> {{0.01545227097530575, 0.7068283934826963}, {
               0, 0.09727448975150323}}, PlotRangeClipping -> True, 
             PlotRangePadding -> {{
                Scaled[0.02], 
                Scaled[0.02]}, {
                Scaled[0.02], 
                Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
           FormBox[
            TagBox[
             GridBox[{{
                FormBox[
                 
                 TemplateBox[{
                  "\"liquid density - t-PR-LJ\"", 
                   "\"vapor density - t-PR-LJ\""}, "LineLegend", 
                  DisplayFunction -> (StyleBox[
                    StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                    FontFamily -> "Arial"}, Background -> Automatic, 
                    StripOnInput -> False]& ), 
                  InterpretationFunction :> (RowBox[{"LineLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                    RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
                    ",", 
                    RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"True", ",", "True"}], "}"}]}], ",", 
                    RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                    "]"}]& ), Editable -> True], TraditionalForm]}, {
                FormBox[
                 
                 TemplateBox[{
                  "\"Simulation point @6.21292 bar\"", 
                   "\"Simulation point @8.28389 bar\"", 
                   "\"Simulation point @10.3549 bar\""}, "PointLegend", 
                  DisplayFunction -> (StyleBox[
                    StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #2}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                    FontFamily -> "Arial"}, Background -> Automatic, 
                    StripOnInput -> False]& ), 
                  InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 0, 1]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0.5, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                    RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], ",", "9.75`"}],
                     "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}], ",", "9.75`"}], "}"}]}], "}"}]}], 
                    ",", 
                    RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "False", ",", "False"}], "}"}]}], 
                    ",", 
                    RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                    "]"}]& ), Editable -> True], TraditionalForm]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> 
              False, GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], 
            TraditionalForm]},
          "Legended",
          DisplayFunction->(GridBox[{{
              TagBox[
               ItemBox[
                PaneBox[
                 TagBox[#, "SkipImageSizeLevel"], 
                 Alignment -> {Center, Baseline}, BaselinePosition -> 
                 Baseline], DefaultBaseStyle -> "Labeled"], 
               "SkipImageSizeLevel"], 
              ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
            GridBoxAlignment -> {
             "Columns" -> {{Center}}, "Rows" -> {{Center}}}, AutoDelete -> 
            False, GridBoxItemSize -> Automatic, 
            BaselinePosition -> {1, 1}]& ),
          Editable->True,
          InterpretationFunction->(RowBox[{"Legended", "[", 
             RowBox[{#, ",", 
               RowBox[{"Placed", "[", 
                 RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]},
        {
         TemplateBox[{
          "\"Simulation @\"", "6.212926382934624`", 
           "\" bar : \\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\) = \"", 
           "1155.4149`", 
           "\" mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\), \
\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\) = \"", "99.53946`", 
           "\" mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)\""},
          "RowDefault"]},
        {
         TemplateBox[{
          "\"Simulation @\"", "8.283945183351015`", 
           "\" bar : \\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\) = \"", 
           "1107.2456300000001`", 
           "\" mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\), \
\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\) = \"", "147.71990000000002`", 
           "\" mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)\""},
          "RowDefault"]},
        {
         TemplateBox[{
          "\"Simulation @\"", "10.354941689273183`", 
           "\" bar : \\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(L\\)]\\) = \"", 
           "1014.46639`", 
           "\" mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\), \
\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(V\\)]\\) = \"", "212.72444000000002`", 
           "\" mol/\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)\""},
          "RowDefault"]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Rows" -> {{Top}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->
  "Out[120]=",ExpressionUUID->"e4e31d2f-4b5a-46cd-9c34-cecaf0468ce6"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["BWR Nicolas 1979", "Subsection",ExpressionUUID->"338f6e86-27a4-499c-ae22-f337ee2889c4"],

Cell["\<\
Nicolas 1979 Equation of state for the Lennard-Jones fluid. Molecular Physics \
1979, 37(5), 1429-1454.\
\>", "Affiliation",ExpressionUUID->"ec90f239-9400-467f-b577-4f289521d7db"],

Cell[TextData[{
 "The BWR EoS from Nicolas199 is a pressure explicit EoS (",
 Cell[BoxData[
  FormBox[
   RowBox[{"P", "=", 
    RowBox[{"f", "(", 
     RowBox[{"T", ",", 
      SubscriptBox["x", "1"], ",", "\[Rho]"}], ")"}]}], TraditionalForm]],
  ExpressionUUID->"f481ba40-9d2a-477a-ab8e-5bcbff27a35b"],
 ")\t[ ",
 Cell[BoxData[
  RowBox[{"Z", " ", "=", " ", 
   RowBox[{
    SuperscriptBox["P", "*"], " ", "/", " ", 
    RowBox[{"(", " ", 
     RowBox[{
      SuperscriptBox["\[Rho]", "*"], " ", "*", " ", 
      SuperscriptBox["T", "*"]}], ")"}]}]}]],ExpressionUUID->
  "994c0299-fad8-4e34-9c8a-ab9c33d862d7"],
 " ]\nIn order to estimate the molar density, a good estimate for the molar \
fraction is necessary.\nWe use the estimation from the t-PR EoS for LJ fluids \
by Harismiadis 1994."
}], "Text",ExpressionUUID->"34f436f7-59f5-4aef-9d16-c5bb91ebc393"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"7a09e19f-b122-4ef1-bc2c-161bf35f3839"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CalculateMolarVolumeNicolas1979", "[", 
    RowBox[{"tSim_", ",", "pSim_", ",", "x1_", ",", "y1_"}], "]"}], " ", ":=", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", "\t", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "tAstL", ",", "tAstV", ",", "pAstL", ",", "pAstV", ",", "rhoAst", ",", 
       "rhoVAst", ",", "rhoLAst", ",", "rhoV", ",", "rhoL", ",", "vV", ",", 
       "vL"}], "}"}], ",", "\[IndentingNewLine]", "\t", 
     RowBox[{
      RowBox[{"tAstL", " ", "=", " ", 
       RowBox[{"tRedLJ", "[", 
        RowBox[{"tSim", ",", 
         RowBox[{"\[Epsilon]m", "[", "x1", "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"tAstV", " ", "=", " ", 
       RowBox[{"tRedLJ", "[", 
        RowBox[{"tSim", ",", 
         RowBox[{"\[Epsilon]m", "[", "y1", "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"pAstL", "=", 
       RowBox[{"pRedLJ", "[", 
        RowBox[{"pSim", ",", 
         RowBox[{"\[Epsilon]m", "[", "x1", "]"}], ",", 
         RowBox[{"\[Sigma]m", "[", "x1", "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"pAstV", "=", 
       RowBox[{"pRedLJ", "[", 
        RowBox[{"pSim", ",", 
         RowBox[{"\[Epsilon]m", "[", "y1", "]"}], ",", 
         RowBox[{"\[Sigma]m", "[", "y1", "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"rhoVAst", "=", " ", 
       RowBox[{"Values", "@", 
        RowBox[{
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"zLJNicolas1979", "[", 
              RowBox[{"tAstV", ",", "rhoAst"}], "]"}], "*", 
             RowBox[{"(", 
              RowBox[{"rhoAst", "*", "tAstV"}], ")"}]}], "-", "pAstV"}], ",", 
           RowBox[{"{", 
            RowBox[{"rhoAst", ",", "0.01"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", "\t", 
      RowBox[{"rhoLAst", " ", "=", " ", 
       RowBox[{"Values", "@", 
        RowBox[{
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"zLJNicolas1979", "[", 
              RowBox[{"tAstL", ",", "rhoAst"}], "]"}], "*", 
             RowBox[{"(", 
              RowBox[{"rhoAst", "*", "tAstL"}], ")"}]}], "-", "pAstL"}], ",", 
           RowBox[{"{", 
            RowBox[{"rhoAst", ",", "1.0"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", "\t", 
      RowBox[{"rhoV", " ", "=", " ", 
       RowBox[{"RhoAstToRho", "[", 
        RowBox[{"rhoVAst", ",", "y1"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"N", " ", "/", " ", 
        RowBox[{"\[Angstrom]", "^", "3"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"rhoL", " ", "=", " ", 
       RowBox[{"RhoAstToRho", "[", 
        RowBox[{"rhoLAst", ",", "x1"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"N", " ", "/", " ", 
        RowBox[{"\[Angstrom]", "^", "3"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", "\t", 
      RowBox[{"vV", " ", "=", " ", 
       RowBox[{"RhoTov", "@", "rhoV"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
        SuperscriptBox["dm", "3"], " ", 
        SuperscriptBox["mol", 
         RowBox[{"-", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"vL", " ", "=", " ", 
       RowBox[{"RhoTov", "@", "rhoL"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
        SuperscriptBox["dm", "3"], " ", 
        SuperscriptBox["mol", 
         RowBox[{"-", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"{", 
       RowBox[{
       "vL", ",", "vV", ",", "rhoL", ",", "rhoV", ",", "rhoLAst", ",", 
        "rhoVAst"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->
  "In[121]:=",ExpressionUUID->"344b5cb8-1f1c-45b7-b3a8-f4a4d3251c7f"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Calculation", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"resMFNicolas1979", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<(t-PR-LJ)\>\"", ",", "\"\<(t-PR-LJ)\>\""}], "}"}], " ", 
       "&"}], "/@", " ", "pSim"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"resMVNicolas1979", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"CalculateMolarVolumeNicolas1979", "[", 
        RowBox[{"tSim", ",", 
         RowBox[{"pSim", "[", 
          RowBox[{"[", "#", "]"}], "]"}], ",", 
         RowBox[{"resMFVTPRLJ", "[", 
          RowBox[{"[", 
           RowBox[{"#", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"resMFVTPRLJ", "[", 
          RowBox[{"[", 
           RowBox[{"#", ",", "2"}], "]"}], "]"}]}], "]"}], " ", "&"}], "/@", 
      " ", 
      RowBox[{"Range", "@", 
       RowBox[{"Length", "@", "pSim"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Grid", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"ShowEoSResults", "[", 
         RowBox[{"\"\<BWR(Nicolas 1979)\>\"", ",", 
          RowBox[{"pSim", "[", 
           RowBox[{"[", "#", "]"}], "]"}], ",", 
          RowBox[{"resMFNicolas1979", "[", 
           RowBox[{"[", "#", "]"}], "]"}], ",", 
          RowBox[{"resMVNicolas1979", "[", 
           RowBox[{"[", "#", "]"}], "]"}]}], "]"}], ")"}], 
       "\[IndentingNewLine]", "&"}], "/@", " ", 
      RowBox[{"Range", "@", 
       RowBox[{"Length", "@", "pSim"}]}]}], " ", "}"}]}]}]}]], "Code",
 CellLabel->
  "In[122]:=",ExpressionUUID->"f9d3bc76-f4f0-4992-a27a-5942ed8acb1d"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"BWR(Nicolas 1979) @6.21292 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", "\"(t-PR-LJ)\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", "\"(t-PR-LJ)\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", 
           "0.0009111801587667986`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.010484860004492336`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "0.6609165818700917`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.05743653951907568`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.6609165818700917`", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.05743653951907568`", "\"[1]\""}}, AutoDelete -> 
         False, GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"], 
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"BWR(Nicolas 1979) @8.28389 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", "\"(t-PR-LJ)\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", "\"(t-PR-LJ)\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", 
           "0.000961836706880587`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.007222265233645622`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "0.6261084357583844`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.08338299086476739`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.6261084357583844`", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.08338299086476739`", "\"[1]\""}}, AutoDelete -> 
         False, GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"], 
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"BWR(Nicolas 1979) @10.3549 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", "\"(t-PR-LJ)\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", "\"(t-PR-LJ)\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", 
           "0.001027569539452978`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.005129949545749037`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "0.5860567610057671`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.11739181265418647`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.5860567610057671`", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.11739181265418647`", "\"[1]\""}}, AutoDelete -> 
         False, GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->
  "Out[124]=",ExpressionUUID->"069af358-861b-41b8-ade4-de1f953eb405"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualisation", "Subsubsection",ExpressionUUID->"1a338604-519b-44dc-bd7d-063a556d4f8b"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"d5dad47f-fea8-4245-a626-96028687ec80"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plotPrhoNicolas1979", "[", "]"}], ":=", 
   RowBox[{"Module", "[", "\n", "\t", 
    RowBox[{
     RowBox[{"{", "\n", "\t\t", 
      RowBox[{
      "piSat", ",", "x1Sim", ",", "y1Sim", ",", "rhoLSim", ",", "rhoVSim", 
       ",", "\n", "\t\t", "ordinate", ",", "x1", ",", "y1", ",", "rhoL", ",", 
       "rhoV"}], "\n", "\t", "}"}], ",", "\n", "\t", "\n", "\t", 
     RowBox[{
      RowBox[{"CalculatePlotDataVTPRLJ", "[", 
       RowBox[{
       "tSim", ",", "pSim", ",", "\[Sigma]", ",", "\[Epsilon]", ",", 
        "\[Epsilon]Iteration"}], "]"}], ";", " ", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"calculate", " ", "t"}], "-", "PR", "-", 
        RowBox[{"EoS", " ", "plot", " ", "data", " ", "first"}]}], "*)"}], 
      "\n", "\t", "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{
       "molar", " ", "densities", " ", "at", " ", "simulation", " ", 
        "Pressure"}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x1Sim", ",", "y1Sim"}], "}"}], " ", "=", " ", 
       RowBox[{"Transpose", "@", "resMFVTPRLJ"}]}], ";", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"rhoLSim", ",", "rhoVSim"}], "}"}], "=", 
       RowBox[{"Transpose", "@", 
        RowBox[{"(", "\[IndentingNewLine]", "\t\t", 
         RowBox[{
          RowBox[{
           RowBox[{"Quiet", "@", 
            RowBox[{
             RowBox[{"CalculateMolarVolumeNicolas1979", "[", 
              RowBox[{"tSim", ",", 
               RowBox[{"pSim", "[", 
                RowBox[{"[", "#", "]"}], "]"}], ",", 
               RowBox[{"x1Sim", "[", 
                RowBox[{"[", "#", "]"}], "]"}], ",", 
               RowBox[{"y1Sim", "[", 
                RowBox[{"[", "#", "]"}], "]"}]}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"5", ";;", "6"}], "]"}], "]"}]}], " ", "&"}], "/@", " ", 
          RowBox[{"Range", "@", 
           RowBox[{"Length", "@", "pSim"}]}]}], "\n", "\t", ")"}]}]}], ";", 
      "\[IndentingNewLine]", "\t", "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Pressure", " ", "as", " ", "the", " ", "ordinate", " ", "of", " ", 
        "the", " ", "diagram"}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"ordinate", " ", "=", " ", "pVec"}], ";", "\[IndentingNewLine]",
       "\t", "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{"reduced", " ", "molar", " ", "densities"}], " ", "*)"}], 
      "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x1", ",", "y1"}], "}"}], " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{"xVec", ",", "yVec"}], "}"}]}], ";", "\[IndentingNewLine]", 
      "\t", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"rhoL", ",", "rhoV"}], "}"}], "=", 
       RowBox[{"Transpose", "[", "\n", "\t\t", 
        RowBox[{
         RowBox[{
          RowBox[{"Quiet", "@", 
           RowBox[{
            RowBox[{"CalculateMolarVolumeNicolas1979", "[", 
             RowBox[{"tSim", ",", 
              RowBox[{"pVec", "[", 
               RowBox[{"[", "#", "]"}], "]"}], ",", 
              RowBox[{"xVec", "[", 
               RowBox[{"[", "#", "]"}], "]"}], ",", 
              RowBox[{"yVec", "[", 
               RowBox[{"[", "#", "]"}], "]"}]}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"{", 
              RowBox[{"5", ",", "6"}], "}"}], "]"}], "]"}]}], "\n", "\t\t\t", 
          "&"}], "/@", " ", 
         RowBox[{"Range", "@", 
          RowBox[{"Length", "@", "pVec"}]}]}], "\n", "\t", "]"}]}], ";", 
      "\[IndentingNewLine]", "\t\t", "\n", "\t", 
      RowBox[{"Grid", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"{", "\n", "\t\t", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{"{", 
               RowBox[{"Show", "@", 
                RowBox[{"Flatten", "@", 
                 RowBox[{"{", "\n", "\t\t\t", 
                  RowBox[{
                   RowBox[{"ListLinePlot", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{"rhoL", ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{"ordinate", ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    "]"}], ",", 
                    RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{"rhoV", ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{"ordinate", ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    "]"}]}], "}"}], "\n", "\t\t\t\t", ",", 
                    RowBox[{"Frame", "->", "True"}], ",", 
                    RowBox[{"GridLines", "\[Rule]", "Automatic"}], "\n", 
                    "\t\t\t\t", ",", 
                    RowBox[{"FrameLabel", "\[Rule]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "Bold", ",", "14", ",", 
                    RowBox[{"SingleLetterItalics", "->", "False"}]}], "]"}], 
                    "&"}], "/@", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(L\), \(*\)]\),\
\!\(\*SubsuperscriptBox[\(\[Rho]\), \(V\), \(*\)]\) [1]\>\"", ",", 
                    "\"\<\!\(\*SuperscriptBox[\(P\), \(*\)]\) [1]\>\""}], 
                    "}"}]}], ")"}]}], "\n", "\t\t\t\t", ",", 
                    RowBox[{"PlotLabel", "\[Rule]", 
                    RowBox[{"StringJoin", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"component", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "<>", "\"\<-\>\"", "<>", 
                    RowBox[{"component", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "<>", "\"\< @T = \>\""}], 
                    ",", 
                    RowBox[{"ToString", "[", "tSim", "]"}], ",", 
                    "\"\< K\\n\>\""}], "}"}], "]"}]}], "\n", "\t\t\t\t", ",", 
                    RowBox[{"PlotLegends", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<Liquid \!\(\*SuperscriptBox[\(\[Rho]\), \(Sat\)]\) - \
Nicolas1979\>\"", ",", 
                    "\"\<Vapor \!\(\*SuperscriptBox[\(\[Rho]\), \(Sat\)]\) - \
Nicolas1979\>\""}], "}"}]}], "\n", "\t\t\t\t", ",", 
                    RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
                    RowBox[{"PlotRange", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0.9"}], "}"}], ",", "Automatic"}], 
                    "}"}]}]}], "\n", "\t\t\t", "]"}], ",", "\n", "\t\t\t", 
                   RowBox[{"ListPlot", "[", 
                    RowBox[{
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"rhoLSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"pSimAst", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"rhoVSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"pSimAst", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "}"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Length", "@", "pSimAst"}]}], "}"}]}], "]"}], 
                    "\n", "\t\t\t\t", ",", 
                    RowBox[{"PlotStyle", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Red", ",", "Blue", ",", "Orange"}], "}"}]}], ",", 
                    RowBox[{"PlotRange", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Automatic"}], "}"}]}], "}"}]}], "\n", 
                    "\t\t\t\t", ",", 
                    RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
                    RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}],
                     "\n", "\t\t\t\t", ",", 
                    RowBox[{"PlotLegends", "\[Rule]", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"\"\<Simulation point @\>\"", "<>", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"pSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], "<>", 
                    "\"\< bar\>\""}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "]"}]}]}], 
                    "\n", "\t\t\t", "]"}]}], "\[IndentingNewLine]", "\t", 
                  "}"}]}]}], "}"}], "}"}], "}"}], ",", "\[IndentingNewLine]", 
            "\t\t", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", "\[IndentingNewLine]", "\t\t\t\t", 
               RowBox[{"{", 
                RowBox[{"Row", "[", 
                 RowBox[{"{", 
                  RowBox[{"\"\<Simulation @\>\"", ",", " ", 
                   RowBox[{"pSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                   "\"\< bar : \!\(\*SuperscriptBox[SubscriptBox[\(\[Rho]\), \
\(L\)], \(*\)]\) = \>\"", ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"rhoLSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "0.00001"}], "]"}], 
                   ",", "\"\< [1], \!\(\*SuperscriptBox[SubscriptBox[\(\[Rho]\
\), \(V\)], \(*\)]\) = \>\"", ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"rhoVSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "0.00001"}], "]"}], 
                   ",", "\"\< [1]\>\""}], "}"}], "]"}], "}"}], 
               "\[IndentingNewLine]", "\t\t\t", "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "\n", "\t\t", 
             "]"}]}], "\n", "\t", "}"}], ",", "2"}], "]"}], ",", 
        RowBox[{"Alignment", "->", "Left"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->
  "In[125]:=",ExpressionUUID->"c84e1b41-e553-40e2-87a8-d25be295c263"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotPrhoNicolas1979", "[", "]"}]], "Code",
 CellLabel->
  "In[126]:=",ExpressionUUID->"8c4c0d8a-0713-4a12-957f-0a9865ecf1fd"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{
       GraphicsBox[{{{}, {{{}, {}, {
             Hue[0.67, 0.6, 0.6], 
             Directive[
              PointSize[
               NCache[
                Rational[1, 72], 0.013888888888888888`]], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVj3081AcAh69UXhLXVKqlkfJWYb2c2uKrhNKVoU2RiIgTqxFmhRA1L5GF
6pJ35/3cHXmpRC2KpPSm0P3u92LYYpiXeWntj+fz/PH89Wi5/2jvOZfFYrl+
5n/LD698VhHOwDCeH+9/4hq86VQH8zMMCm4Q5x6rXIfdeOCD+zwGPmplxkVV
12FI3Gra5MYgRvNd6PTRG1A2NdFO/Z5B0klF3UZ5Pq73XUvrt2FguUDImhHy
4Uw4UEbmDBJLF74oc7oJ6/eLmjy3MjCtlz/eOS8D0wbj6vEGDHK3DKullGfA
/+JPTtlfMQhpiDGocroFomS1m2AJgx5V1Zr1cplYG+7dc1ORwY5i5UM7Dmdi
ZEPoxchZGjP7HnUklGcizl1H9YcRGlxiUFlrQRb2rX+uufwPGrzFHuTYkSyM
dDr6NHfRSGZrcNiSLIxeGk/2ek5DscCM9FuYDVPfTTuHf6dhxVdpZntkQyFS
vNK3lgbdOHt/sjYbFVPG9e1lNFiMuFBfLQeWUm7rmhwalp1slyzfHPBnArrc
0mjoje2uPPYwBwJ2XcyvcTSe2/fE+Wrkon+k5uitcBpv5KQ19UG5WHPv+GhG
AI1DjV3qru254CfIOi6eoCHvsCzMxiAPkyvcLxxxpqH0RfbDyOg8vL06EL/C
lsZTlZQHCh/y0DNgxKvfRaNbz8Che3s+tJv4T/dzaDixnfXZV/ORdojX/ECf
Rl13SPGFoXys7TsxralBQ7eJ68HlFuC66ctXx9k07Ns2GXkKClC34VRdohyN
zoItH9vnCcD33qGSMUbBqdbvfNIxAaqNjfSv9FFoLwhuzb0ngMCCduN1UUh4
Q1SqrCqErcd+OZ1nFGx6JbrPfi7EJO+A48MGCj8zc9m9bwpxdtEJ/m4JhekD
F445coowpWmtlJ9P4e87e5doXS0Ci3+svTedQmOYv47laBGyXwUtVYyj4Kk3
xH/oUIxCi2XjCucoTHpfis4UF+PkY+0exp9Ca81Ew59qJVgjeL45y41C9Tdx
mTGBJWj307Mwsacglr8cFPGqBL3mvp8KLCiMXh0Lf88pRdudFNvhLRT67Vzm
XUsvxRzt9EVLdSjEp11xqv23FKKt6fNV1Sms0TbuN3cpg/m3k6M98hQq+u02
Gt4vQ7vU/1LUBIlf9v4kitIuR6TjoOvUHyReOPqttogtByc8Sc6yk0TZpTJD
/4FyTMwm+Lg+JtEU/DhNRU+IgSPBC/fUkLA+VdmW4iRE9eJ7eTMCEqGt2/vs
EoRwTn7rH5ZOIjjKW9HmvhDEi7+immNJlOcYeJwbEUL59CemM4hEUsQ7/KVT
Ae9Hz84KPUlwAkxYN5wq4BF2RcnmIInopVGrLyZWoKVNozt3FwmUzHvb2FiB
QN2vt981JnHnTua6reMVEF0uVkheTcLoTa3mn+tFUDddEayh/PlneKilz02E
rYbVEa6TMgwmmtkap4pA1R396MDIoDTXbLahRQSbAJP1Ey9k+EeBtbl8jhih
KwKnrepl2KPpOyw1EWNTSuEG02IZflGd3e/lL0YGxzfqdaoMHW2vz+/KE+Pe
VKyPaqQMXp0qmTFdYuzZ4GlNnJRB12/kvMYSCbwXdGRZO8rg3hc1uYwrgR0/
6NGOnTJoFoZfDo6WIHpnWGOdgQxE4pHTDnclKFf+p6pOTYbvmkNtfxuTIHFl
2CHONAGOlgvNNa7EEE9kvI4iEGLeueo3XiXmb0saP9tC4O/GySSHvEp8+eFJ
P0dEwP6jo0gorcQy1sA7y3QCE9lfpaatqgKpdOFg1jkC/OVzm40OV+Gmlsm2
b90J6OZt1D6TWoUA3+JeOSsCY7wQc6+XVbhsn3V4UI9Ai5tziKHabeS0W93s
VyLA1X+yvc3+NoamtUqpASnM5hzneqXcRn2X1fsHLVKEbZN/PfDyNnz05G0C
i6Q4cKbVL1m9Gn0uu3vexUphF7ao+aRzNTquSbpfekgxSMa6RmRWY0YnImeX
2efeYKI5xVTjPy6+/IM=
              "]]}, {
             Hue[0.9060679774997897, 0.6, 0.6], 
             Directive[
              PointSize[
               NCache[
                Rational[1, 72], 0.013888888888888888`]], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVkHs8EwgAx72uJcVK1+tTmnZ5dUld0arbT3UlWneHqxiu5FERh+68Os+E
E0VEWBnbzDz23pjUZjkUppSWSsf1iYiSipJ03R/fz/eP739f8yO/uQXo6ejo
HPrC/46wiGrOar4M20xGZujRQsi3P6CuYlwBt7g/7qZxEVpGyZVFJ0tw3JRv
VykvwkXvB0fDLJhIJT2Mnf61GOPU2PaZXCayTxhaqgkMhGu2mMXplWLXLKHO
JyEDs1vmm42Fl+JcjVEXn34Zyft9JN7/luJ7JcG/x+AKWCTGSq17Gdgbx01z
BVegtS/McmouQ3Rjqo2cXoKAJWfcGiksPDExUazRZ2Kwf860M5+FbVVzPbZ5
MqFP4+0cJLPxaW/z3SwBE/Xv24glRWzQ+l/NNZ9VCuvGs7FRCzgImu/3dMK7
FA9O5N+MPMtBDnGFPVFaCmoYYllflcOQS30aYlQGCvcq1SCpHLsZxq1EvzIk
+GXoMj+V45l6RvWhvgzyNOPncae40BmQ8KxNWTC5Rd/PmeJiVw/RpzSYBQJn
4+iKUxWwmvhB5tvEwtoR14JX0xW44/bkbPAKNvpCu5NXJfKg1e9TKCPZeFRo
YqM0qISH+vHiQ7fZ8MhOP6DJqATBfVG8iw0Hul2eqz0XVGHOgrKm5BQOlto+
MTpeXIUO49wbs//hID1B+ZhgUY1eKxv3Xko5dCgd+Z7iatCJXtbEi+WYvbn/
moNjDa72RledGSvHo6CQ502dNbBsofnRaFxc6EpjzvXlw02zYV1ABRfMdb4j
y97y0cPd+PK2QQX253zjMZ0uAL0+JCnbtwI9B/w/PzER4jY3qp19vQKHXty5
ae8tRJa2X2a8nIfhfcHyTJ4QLoNSy84YHgIVrk7PJ4WIGdAjDmp5uPfDgJer
kwjTP57xPWhfiWyDDIfbBSK8bnBeaH6xEjz65/SQIRHU8aEWu95WYmdKfMSG
bWIEWI0xmtyrEKrNuWCVLcaHY3+lMCVVGGvRWxvyTIx2xfvGEdNqdDJNOwe2
SlC35Swz9fdqsEv4RuJcCSSE85GJ3dWYDpo3+HBEgrcXJxIe2ddAk790eaiT
FMOuPgaFl2pgY3HFNoYlRWbBBXr9VA3mha+Om6Mrwyqy3bCjDx9KVe8v6w/L
IBp2XWur4kN3QQdhRiXDKecI8WmyALz1FV8lk+XoOhhitjNNgJr7gsnONDn4
f/FtQ18I8Dnsfcmil3K0RN0sMLYSQm19MoByoBZOYTJNLl2I0a1RdkdVtYht
pwy5Zn35dqHHUPFtHaJOHzN0UQlB7ps/41xcBwHLxi/ujRDTfct8HOYqkJ34
EKMWIuxd9XCGmaCA/UkHnWK6CNXbp3J47xRI+fq0Wfo5EVpNCBZFofVAtcED
tVqEHXFhZK/hejQ0MFdvmhQhuNyje/Pxq1inrSeNrBGjP8qXF/DiKrrGx9qG
DosxbMb2XxregFfnqD/Z5YvBNDoxlTPVgDl61JnGNjG2EG3ctqdfw7vZOt8J
dCXQHXqzibzsOvaQgsf7HCTwll6ylAmv45TJzL7AUAn8BrUUOk2Ju5r7STs4
EhgtsXKUjSoR2GPMTH0swSfGr5ORLipYhrxJWrFQiiXVhRrfUhWODJ3+sIgm
hXPOm+jxjyqQeAnno1KkiHExVwrpjeg/5x3ufk0Kv4i884+vNeLn1tif8iak
YNS4asgWatib+zyj2cnQmUHY5Z+nRrRjz/K8IBn+XKPP2GR4A6/VH7LdOTIo
J2M89VNvwO3lQbGwT4akPc+Cxoya8L5sZX7BcjmKA+J7915uAmOJXus6Tzle
Crr1udv+hiVnLfmPfDnebddado3+jYmgaMfAe3JQd1/nKGqb0XbYK9rWtBYU
UkabiNMCmvUtisatFrobP8oz77SCqutPC8ytRUQkJ8477xbiNxPuv7hXC08V
IdlgvB0//tEekrO4Dgu7PZ82UzvgGj+v9YRXHcaDM5+Tcjrw6mnaoURmHfLa
TUiPhr70RgfSx4E6/AcX2eYj
              "]]}}}, {{}, {}}}, {{}, {{{}, {}, {}, {}, {}, {}, {
             Directive[
              RGBColor[1, 0, 0], 
              Opacity[0.3]], 
             LineBox[{{0.6609165818700917, 0.}, {0.6609165818700917, 0.045}}], 
             
             LineBox[{{0.05743653951907568, 0.}, {0.05743653951907568, 
              0.045}}], 
             
             LineBox[{{0.05743653951907568, 0.}, {0.05743653951907568, 
              0.045}}]}, {}, {
             Directive[
              RGBColor[0, 0, 1], 
              Opacity[0.3]], 
             LineBox[{{0.6261084357583844, 0.}, {0.6261084357583844, 0.06}}], 
             
             LineBox[{{0.08338299086476739, 0.}, {0.08338299086476739, 
              0.06}}], 
             
             LineBox[{{0.08338299086476739, 0.}, {0.08338299086476739, 
              0.06}}]}, {}, {
             Directive[
              RGBColor[1, 0.5, 0], 
              Opacity[0.3]], 
             LineBox[{{0.5860567610057671, 0.}, {0.5860567610057671, 0.075}}], 
             
             LineBox[{{0.11739181265418647`, 0.}, {0.11739181265418647`, 
              0.075}}], 
             
             LineBox[{{0.11739181265418647`, 0.}, {0.11739181265418647`, 
              0.075}}]}}, {{
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[1, 0, 0]], 
             GeometricTransformationBox[
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox[
                  GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], 
                  GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}, StripOnInput -> False], 
                 TraditionalForm]], {0., 0.}, Automatic, 
               Scaled[9.75]], {{{0.6609165818700917, 0.045}}, {{
              0.05743653951907568, 0.045}}, {{0.05743653951907568, 
              0.045}}}]}, {
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[0, 0, 1]], 
             GeometricTransformationBox[
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox[
                  GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], 
                  GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}, StripOnInput -> False], 
                 TraditionalForm]], {0., 0.}, Automatic, 
               Scaled[9.75]], {{{0.6261084357583844, 0.06}}, {{
              0.08338299086476739, 0.06}}, {{0.08338299086476739, 0.06}}}]}, {
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[1, 0.5, 0]], 
             GeometricTransformationBox[
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox[
                  GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}], 
                  GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]]}, StripOnInput -> False], 
                 TraditionalForm]], {0., 0.}, Automatic, 
               Scaled[9.75]], {{{0.5860567610057671, 0.075}}, {{
              0.11739181265418647`, 0.075}}, {{0.11739181265418647`, 
              0.075}}}]}}}, {{}, {}}}}, {
        DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
         NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
         AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
         Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
            FormBox[
             TagBox[
              StyleBox[
              "\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(*\\)]\\) [1]\"", Bold, 
               14, SingleLetterItalics -> False, StripOnInput -> False], 
              HoldForm], TraditionalForm], None}, {
            FormBox[
             TagBox[
              StyleBox[
              "\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(L\\), \
\\(*\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(V\\), \\(*\\)]\\) [1]\
\"", Bold, 14, SingleLetterItalics -> False, StripOnInput -> False], 
              HoldForm], TraditionalForm], None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {Automatic, Automatic}, GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> Medium, 
         Method -> {
          "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
           "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), "CopiedValueFunction" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& )}}, PlotLabel -> 
         FormBox["\"LJ_ref-LJ_1 @T = 1. K\\n\"", TraditionalForm], 
         PlotRange -> {{0., 0.9}, {0, 0.09727448975150323}}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {
            Scaled[0.02], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
       FormBox[
        TagBox[
         GridBox[{{
            FormBox[
             
             TemplateBox[{
              "\"Liquid \\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(Sat\\)]\\) - \
Nicolas1979\"", 
               "\"Vapor \\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(Sat\\)]\\) - \
Nicolas1979\""}, "LineLegend", DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"LineLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
                   ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"True", ",", "True"}], "}"}]}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}, {
            FormBox[
             
             TemplateBox[{
              "\"Simulation point @6.21292 bar\"", 
               "\"Simulation point @8.28389 bar\"", 
               "\"Simulation point @10.3549 bar\""}, "PointLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #2}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 0, 1]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0.5, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], ",", "9.75`"}],
                     "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}], ",", "9.75`"}], "}"}]}], "}"}]}], 
                   ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "False", ",", "False"}], "}"}]}], 
                   ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]},
    {
     TemplateBox[{
      "\"Simulation @\"", "6.212920499999999`", 
       "\" bar : \\!\\(\\*SuperscriptBox[SubscriptBox[\\(\[Rho]\\), \\(L\\)], \
\\(*\\)]\\) = \"", "0.6609200000000001`", 
       "\" [1], \\!\\(\\*SuperscriptBox[SubscriptBox[\\(\[Rho]\\), \\(V\\)], \
\\(*\\)]\\) = \"", "0.057440000000000005`", "\" [1]\""},
      "RowDefault"]},
    {
     TemplateBox[{
      "\"Simulation @\"", "8.283894`", 
       "\" bar : \\!\\(\\*SuperscriptBox[SubscriptBox[\\(\[Rho]\\), \\(L\\)], \
\\(*\\)]\\) = \"", "0.62611`", 
       "\" [1], \\!\\(\\*SuperscriptBox[SubscriptBox[\\(\[Rho]\\), \\(V\\)], \
\\(*\\)]\\) = \"", "0.08338000000000001`", "\" [1]\""},
      "RowDefault"]},
    {
     TemplateBox[{
      "\"Simulation @\"", "10.3548675`", 
       "\" bar : \\!\\(\\*SuperscriptBox[SubscriptBox[\\(\[Rho]\\), \\(L\\)], \
\\(*\\)]\\) = \"", "0.58606`", 
       "\" [1], \\!\\(\\*SuperscriptBox[SubscriptBox[\\(\[Rho]\\), \\(V\\)], \
\\(*\\)]\\) = \"", "0.11739000000000001`", "\" [1]\""},
      "RowDefault"]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->
  "Out[126]=",ExpressionUUID->"5a44bc01-a425-4b7b-84d8-a8e6cd7f7f2c"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Thol2016", "Subsection",ExpressionUUID->"91921058-e3ec-418d-a87a-aaa324608622"],

Cell["\<\
Thol 2016 Equation of State for the Lennard-Jones Fluid. J. Phys. Chem. Ref. \
Data 2016, 45(2), 023101-1 - 023101-36.\
\>", "Affiliation",ExpressionUUID->"027bc494-d58f-4129-b49c-62d1f50b8b81"],

Cell["\<\
In order to estimate the molar density, a good estimate for the molar \
fraction is necessary.
We use the estimation from the t-PR for LJ fluid EoS by Harismiadis\
\>", "Text",ExpressionUUID->"a7a90047-53a2-4348-9179-637bc8636ac8"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"efa527fd-0cd7-4696-9c80-440389682b7d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CalculateMolarVolumeThol2016", "[", 
   RowBox[{"tSim_", ",", "pSim_", ",", "x1_", ",", "y1_"}], "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", "\t", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "pThol2016", ",", "\[Rho]LiqAst", ",", "\[Rho]VapAst", ",", "rhoV", ",", 
      "rhoL", ",", "vV", ",", "vL"}], "}"}], ",", "\[IndentingNewLine]", "\t",
     "\[IndentingNewLine]", "\t", 
    RowBox[{
     RowBox[{
      RowBox[{"pThol2016", "::", "usage"}], "=", 
      "\"\<Calculate the pressure in bar from Thol2016 EoS\>\""}], ";", 
     "\[IndentingNewLine]", "\t", 
     RowBox[{
      RowBox[{"pThol2016", " ", "[", 
       RowBox[{"t_", ",", "x_", ",", "\[Rho]Ast_"}], "]"}], ":=", " ", 
      RowBox[{
       RowBox[{"zLJThol2016", "[", 
        RowBox[{
         RowBox[{"tRedLJ", "[", 
          RowBox[{"t", ",", 
           RowBox[{"\[Epsilon]m", "[", "x", "]"}]}], "]"}], ",", 
         "\[Rho]Ast"}], "]"}], "*", "\[IndentingNewLine]", "\t", 
       RowBox[{"(", 
        RowBox[{"rJoule", "*", "t", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Rho]Ast", "/", 
            RowBox[{
             RowBox[{"\[Sigma]m", "[", "x", "]"}], "^", "3"}]}], " ", 
           RowBox[{"(*", 
            RowBox[{"N", "/", 
             RowBox[{"A", "^", "3"}]}], "*)"}], "*", 
           RowBox[{
            RowBox[{"10", "^", "30"}], " ", "/", "nAvogadro"}]}], 
          RowBox[{"(*", 
           RowBox[{"mol", "/", 
            RowBox[{"m", "^", "3"}]}], "*)"}], ")"}]}], ")"}], 
       RowBox[{"(*", "Pa", "*)"}], "*", 
       RowBox[{"10", "^", 
        RowBox[{"-", "5"}]}]}]}], " ", 
     RowBox[{"(*", "bar", "*)"}], ";", "\[IndentingNewLine]", "\t", 
     "\[IndentingNewLine]", "\t", 
     RowBox[{"\[Rho]LiqAst", " ", "=", 
      RowBox[{"Max", "@", 
       RowBox[{"Values", "@", 
        RowBox[{"NSolve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"pThol2016", " ", "[", 
             RowBox[{"tSim", ",", "x1", ",", "\[Rho]Ast"}], "]"}], "\[Equal]",
             "pSim"}], " ", "&&", " ", 
           RowBox[{"0.0", "<", "\[Rho]Ast", "<", "10"}]}], ",", "\[Rho]Ast", 
          ",", "Reals"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", "\t", 
     RowBox[{"\[Rho]VapAst", " ", "=", 
      RowBox[{"Min", "@", 
       RowBox[{"Values", "@", 
        RowBox[{"NSolve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"pThol2016", " ", "[", 
             RowBox[{"tSim", ",", "y1", ",", "\[Rho]Ast"}], "]"}], "\[Equal]",
             "pSim"}], " ", "&&", " ", 
           RowBox[{"0.0", "<", "\[Rho]Ast", "<", "10"}]}], ",", "\[Rho]Ast", 
          ",", "Reals"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", "\t", 
     "\[IndentingNewLine]", "\t", 
     RowBox[{"(*", 
      RowBox[{
      "Calculation", " ", "of", " ", "absolute", " ", "values", " ", "from", 
       " ", "reduced", " ", "values"}], "*)"}], "\[IndentingNewLine]", "\t", 
     RowBox[{"rhoV", " ", "=", " ", 
      RowBox[{"RhoAstToRho", "[", 
       RowBox[{"\[Rho]LiqAst", ",", "y1"}], "]"}]}], ";", 
     RowBox[{"(*", " ", 
      RowBox[{"N", " ", "/", " ", 
       RowBox[{"\[Angstrom]", "^", "3"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "\t", 
     RowBox[{"rhoL", " ", "=", " ", 
      RowBox[{"RhoAstToRho", "[", 
       RowBox[{"\[Rho]VapAst", ",", "x1"}], "]"}]}], ";", 
     RowBox[{"(*", " ", 
      RowBox[{"N", " ", "/", " ", 
       RowBox[{"\[Angstrom]", "^", "3"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "\t", 
     RowBox[{"vV", " ", "=", " ", 
      RowBox[{"RhoTov", "@", "rhoV"}]}], ";", 
     RowBox[{"(*", " ", 
      RowBox[{
       SuperscriptBox["dm", "3"], " ", 
       SuperscriptBox["mol", 
        RowBox[{"-", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
     RowBox[{"vL", " ", "=", " ", 
      RowBox[{"RhoTov", "@", "rhoL"}]}], ";", 
     RowBox[{"(*", " ", 
      RowBox[{
       SuperscriptBox["dm", "3"], " ", 
       SuperscriptBox["mol", 
        RowBox[{"-", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
     "\[IndentingNewLine]", "\t", 
     RowBox[{"{", 
      RowBox[{
      "vL", ",", "vV", ",", "rhoL", ",", "rhoV", ",", "\[Rho]LiqAst", ",", 
       "\[Rho]VapAst"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->
  "In[127]:=",ExpressionUUID->"0b29e4ac-3912-48aa-ab69-798a2c897a94"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Calculation", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"resMFThol2016", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<(t-PR-LJ)\>\"", ",", "\"\<(t-PR-LJ)\>\""}], "}"}], " ", 
       "&"}], "/@", " ", "pSim"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"resMVThol2016", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"CalculateMolarVolumeThol2016", "[", 
        RowBox[{"tSim", ",", 
         RowBox[{"pSim", "[", 
          RowBox[{"[", "#", "]"}], "]"}], ",", 
         RowBox[{"resMFVTPRLJ", "[", 
          RowBox[{"[", 
           RowBox[{"#", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"resMFVTPRLJ", "[", 
          RowBox[{"[", 
           RowBox[{"#", ",", "2"}], "]"}], "]"}]}], "]"}], " ", "&"}], "/@", 
      " ", 
      RowBox[{"Range", "@", 
       RowBox[{"Length", "@", "pSim"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Grid", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"ShowEoSResults", "[", 
         RowBox[{"\"\<Thol 2016\>\"", ",", 
          RowBox[{"pSim", "[", 
           RowBox[{"[", "#", "]"}], "]"}], ",", 
          RowBox[{"resMFThol2016", "[", 
           RowBox[{"[", "#", "]"}], "]"}], ",", 
          RowBox[{"resMVThol2016", "[", 
           RowBox[{"[", "#", "]"}], "]"}]}], "]"}], ")"}], " ", "&"}], "/@", 
      " ", 
      RowBox[{"Range", "@", 
       RowBox[{"Length", "@", "pSim"}]}]}], " ", "}"}]}]}]}]], "Code",
 CellLabel->
  "In[128]:=",ExpressionUUID->"31b1c85a-6202-4b7b-8754-e1b6db312ab3"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"Thol 2016 @6.21292 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", "\"(t-PR-LJ)\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", "\"(t-PR-LJ)\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", 
           "0.010332633681649502`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.0009225450443710915`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "0.058282727768576285`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.6527747123833239`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.6527747123833239`", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.058282727768576285`", "\"[1]\""}}, AutoDelete -> 
         False, GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"], 
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"Thol 2016 @8.28389 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", "\"(t-PR-LJ)\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", "\"(t-PR-LJ)\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", 
           "0.00708741972885332`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.0009888894193541924`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "0.0849694386729136`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.6089801996195733`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.6089801996195733`", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.0849694386729136`", "\"[1]\""}}, AutoDelete -> False,
          GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"], 
     TemplateBox[{
       TagBox[
        GridBox[{{
          "\"Thol 2016 @10.3549 bar\"", "\[SpanFromLeft]", 
           "\[SpanFromLeft]"}, {
          "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"", "\"(t-PR-LJ)\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)\"", "\"(t-PR-LJ)\"", 
           "\"[mol \\!\\(\\*SuperscriptBox[\\(mol\\), \\(-1\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(liq\\)]\\)\"", 
           "0.005035722954373685`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(v\\), \\(vap\\)]\\)\"", 
           "0.0010849147342145888`", 
           "\"[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\)]\\)\"", "0.1195884049731048`", 
           
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\)]\\)\"", "0.5550796362222564`", 
           "\"[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(liq\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.5550796362222564`", "\"[1]\""}, {
          "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(\\(vap\\)\\(\\\\ \
\\)\\(*\\)\\)]\\)\"", "0.1195884049731048`", "\"[1]\""}}, AutoDelete -> False,
          GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->
  "Out[130]=",ExpressionUUID->"2eba4408-b84d-47f4-a12a-77df012a007e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualisation", "Subsubsection",ExpressionUUID->"d5e524f2-1444-48c2-9e7a-69443ba9c8ad"],

Cell[CellGroupData[{

Cell["Calculation", "Item",
 CellGroupingRules->{
  "GroupTogetherGrouping", 
   10000.},ExpressionUUID->"af3b4e5e-f94a-4e3d-bf9f-5c567fdb3c38"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plotPrhoThol2016", "[", "]"}], ":=", 
   RowBox[{"Module", "[", "\n", "\t", 
    RowBox[{
     RowBox[{"{", "\n", "\t\t", 
      RowBox[{
      "x1Sim", ",", "y1Sim", ",", "\n", "\t\t", "piSat", ",", "rhoLSim", ",", 
       "rhoVSim", ",", "\n", "\t\t", "ordinate", ",", "x1", ",", "y1", ",", 
       "rhoL", ",", "rhoV"}], "\n", "\t", "}"}], ",", "\n", "\t", "\n", "\t", 
     "\n", "\t", 
     RowBox[{
      RowBox[{"CalculatePlotDataVTPRLJ", "[", 
       RowBox[{
       "tSim", ",", "pSim", ",", "\[Sigma]", ",", "\[Epsilon]", ",", 
        "\[Epsilon]Iteration"}], "]"}], ";", " ", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"calculate", " ", "t"}], "-", "PR", "-", 
        RowBox[{"EoS", " ", "plot", " ", "data", " ", "first"}]}], "*)"}], 
      "\n", "\t", "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{
       "molar", " ", "densities", " ", "at", " ", "simulation", " ", 
        "Pressure"}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x1Sim", ",", "y1Sim"}], "}"}], " ", "=", " ", 
       RowBox[{"Transpose", "@", "resMFVTPRLJ"}]}], ";", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"rhoLSim", ",", "rhoVSim"}], "}"}], "=", 
       RowBox[{"Transpose", "@", 
        RowBox[{"(", "\[IndentingNewLine]", "\t\t", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"CalculateMolarVolumeThol2016", "[", 
             RowBox[{"tSim", ",", 
              RowBox[{"pSim", "[", 
               RowBox[{"[", "#", "]"}], "]"}], ",", 
              RowBox[{"x1Sim", "[", 
               RowBox[{"[", "#", "]"}], "]"}], ",", 
              RowBox[{"y1Sim", "[", 
               RowBox[{"[", "#", "]"}], "]"}]}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"5", ";;", "6"}], "]"}], "]"}], " ", "&"}], "/@", " ", 
          RowBox[{"Range", "@", 
           RowBox[{"Length", "@", "pSim"}]}]}], "\n", "\t", ")"}]}]}], ";", 
      "\[IndentingNewLine]", "\t", "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Pressure", " ", "as", " ", "the", " ", "ordinate", " ", "of", " ", 
        "the", " ", "diagram"}], " ", "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"ordinate", " ", "=", " ", "pVec"}], ";", "\[IndentingNewLine]",
       "\t", "\[IndentingNewLine]", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{"reduced", " ", "molar", " ", "densities"}], " ", "*)"}], 
      "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x1", ",", "y1"}], "}"}], " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{"xVec", ",", "yVec"}], "}"}]}], ";", "\[IndentingNewLine]", 
      "\t", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"rhoL", ",", "rhoV"}], "}"}], "=", 
       RowBox[{"Transpose", "[", "\n", "\t\t", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"CalculateMolarVolumeThol2016", "[", 
            RowBox[{"tSim", ",", 
             RowBox[{"pVec", "[", 
              RowBox[{"[", "#", "]"}], "]"}], ",", 
             RowBox[{"xVec", "[", 
              RowBox[{"[", "#", "]"}], "]"}], ",", 
             RowBox[{"yVec", "[", 
              RowBox[{"[", "#", "]"}], "]"}]}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"{", 
             RowBox[{"5", ",", "6"}], "}"}], "]"}], "]"}], "\n", "\t\t\t", 
          "&"}], "/@", " ", 
         RowBox[{"Range", "@", 
          RowBox[{"Length", "@", "pVec"}]}]}], "\n", "\t", "]"}]}], ";", "\n",
       "\t\t", "\n", "\t", 
      RowBox[{"Grid", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"{", "\n", "\t\t", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{"{", 
               RowBox[{"Show", "@", 
                RowBox[{"Flatten", "@", 
                 RowBox[{"{", "\n", "\t\t\t", 
                  RowBox[{
                   RowBox[{"ListLinePlot", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{"rhoL", ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{"ordinate", ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    "]"}], ",", 
                    RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{"rhoV", ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{"ordinate", ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    "]"}]}], "}"}], "\n", "\t\t\t\t", ",", 
                    RowBox[{"Frame", "->", "True"}], ",", 
                    RowBox[{"GridLines", "\[Rule]", "Automatic"}], "\n", 
                    "\t\t\t\t", ",", 
                    RowBox[{"FrameLabel", "\[Rule]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "Bold", ",", "14", ",", 
                    RowBox[{"SingleLetterItalics", "->", "False"}]}], "]"}], 
                    "&"}], "/@", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<\!\(\*SubsuperscriptBox[\(\[Rho]\), \(L\), \(*\)]\),\
\!\(\*SubsuperscriptBox[\(\[Rho]\), \(V\), \(*\)]\) [1]\>\"", ",", 
                    "\"\<\!\(\*SuperscriptBox[\(P\), \(*\)]\) [1]\>\""}], 
                    "}"}]}], ")"}]}], "\n", "\t\t\t\t", ",", 
                    RowBox[{"PlotLabel", "\[Rule]", 
                    RowBox[{"StringJoin", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"component", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "<>", "\"\<-\>\"", "<>", 
                    RowBox[{"component", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "<>", "\"\< @T = \>\""}], 
                    ",", 
                    RowBox[{"ToString", "[", "tSim", "]"}], ",", 
                    "\"\< K\\n\>\""}], "}"}], "]"}]}], "\n", "\t\t\t\t", ",", 
                    RowBox[{"PlotLegends", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<Liquid \!\(\*SuperscriptBox[\(\[Rho]\), \(Sat\)]\) - \
Thol2016\>\"", ",", 
                    "\"\<Vapor \!\(\*SuperscriptBox[\(\[Rho]\), \(Sat\)]\) - \
Thol2016\>\""}], "}"}]}], "\n", "\t\t\t\t", ",", 
                    RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
                    RowBox[{"PlotRange", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0.9"}], "}"}], ",", "Automatic"}], 
                    "}"}]}]}], "\n", "\t\t\t", "]"}], ",", "\n", "\t\t\t", 
                   RowBox[{"ListPlot", "[", 
                    RowBox[{
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"{", "\n", "\t\t\t\t\t", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"rhoLSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{
                    RowBox[{"pSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}], 
                    ",", "\n", "\t\t\t\t\t", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"rhoVSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"pRedLJ", "[", 
                    RowBox[{
                    RowBox[{"pSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"\[Epsilon]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"\[Sigma]", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], "}"}]}],
                     "}"}], "\n", "\t\t\t\t\t", ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "\n", 
                    "\t\t\t\t", "]"}], "\n", "\t\t\t\t", ",", 
                    RowBox[{"PlotStyle", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Red", ",", "Blue", ",", "Orange"}], "}"}]}], ",", 
                    RowBox[{"PlotRange", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Automatic"}], "}"}]}], "}"}]}], "\n", 
                    "\t\t\t\t", ",", 
                    RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
                    RowBox[{"PlotMarkers", "\[Rule]", "\"\<OpenMarkers\>\""}],
                     "\n", "\t\t\t\t", ",", 
                    RowBox[{"PlotLegends", "\[Rule]", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"\"\<Simulation point @\>\"", "<>", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"pSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], "<>", 
                    "\"\< bar\>\""}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "]"}]}]}], 
                    "\n", "\t\t\t", "]"}]}], "\[IndentingNewLine]", "\t", 
                  "}"}]}]}], "}"}], "}"}], "}"}], ",", "\[IndentingNewLine]", 
            "\t\t", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", "\[IndentingNewLine]", "\t\t\t\t", 
               RowBox[{"{", 
                RowBox[{"Row", "[", 
                 RowBox[{"{", 
                  RowBox[{"\"\<Simulation @\>\"", ",", " ", 
                   RowBox[{"pSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                   "\"\< bar : \!\(\*SuperscriptBox[SubscriptBox[\(\[Rho]\), \
\(L\)], \(*\)]\) = \>\"", ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"rhoLSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "0.00001"}], "]"}], 
                   ",", "\"\< [1], \!\(\*SuperscriptBox[SubscriptBox[\(\[Rho]\
\), \(V\)], \(*\)]\) = \>\"", ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"rhoVSim", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "0.00001"}], "]"}], 
                   ",", "\"\< [1]\>\""}], "}"}], "]"}], "}"}], 
               "\[IndentingNewLine]", "\t\t\t", "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{"Length", "@", "pSim"}]}], "}"}]}], "\n", "\t\t", 
             "]"}]}], "\n", "\t", "}"}], ",", "2"}], "]"}], ",", 
        RowBox[{"Alignment", "->", "Left"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Code",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellLabel->
  "In[131]:=",ExpressionUUID->"3c9cbecf-daa1-4985-81a4-199af66a24d9"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotPrhoThol2016", "[", "]"}]], "Code",
 CellLabel->
  "In[132]:=",ExpressionUUID->"dcb8ff77-1554-4dbc-bf18-bd3cab53732f"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{
       GraphicsBox[{{{}, {{{}, {}, {
             Hue[0.67, 0.6, 0.6], 
             Directive[
              PointSize[
               NCache[
                Rational[1, 72], 0.013888888888888888`]], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVjHk4lAkAhyfkSkPRsftILKW0jTPhKT+1asOUzOxuIimkQ9QWmehgiWxY
JVekMUxyzowx40iK7VCmO0mOZuabb1wT6Ri1W9r2j/d5/3if57UIOcDYpUGh
UIK/8b8HDJyCV8QoQUsvSo/aXYC4Y8FlOXuVKC+UHb9LvYCw3EGLgSAl9hrX
2lWKL+CayN6XylAixfxl3OfthSjua21dtF6JrP161u06Rei6YEKxclNinTaf
8oVfBNfaS5d0aUpk1sx4UhtwEW9t8hc/tVBi9XWdsB6tYtTYRbslzVGizOmt
cTavGPlNpRbz9ZRgtaXYiAMu4VS1JPbsZxIDhoZNyzTZmG21vHFsnMSqKgP/
VVvZYGrYBdgSJL743H6awWOj18r7MeM5Cbps3MBCuwS+k8/S/e+S2DcrlFBv
K0H8L4OTaCFx1miBs1F9CUKKfzyqyyOhV+5ORM7gQHei6ZCghMT6ImqHUSgH
fUzZGrfzJMj2qRufmjlwvKcBTgoJilJYsdS4FMbmgdeGWCTW9RgFlUSUYo3v
I/2ZESSWqD1FO2+WIo959QA1iMRjxsCZiAVlUK7l0VSbSHRrSpuuHylDGGt1
MteDhH9737zgR2XoKxZfdnUgocOce8LbhguzHUO3yi1J6M/m3PwjmQvu0W79
cRMS96nZf+u+4uLPiZg8qjaJ/iU2zH7XyzDwPn5n+qQCAUaBS41yLoM9I9bh
6aACV/tZVafeXIaP/fdmR14oYH2HHkqnl2O/32j66w4FGA8cbHddKYfp96Us
lyYFesqdxh5pXYF6w73Hv1Z8+zVHJmbtvIK1e71PehYo8Kg8VlLWegVnzCaD
NNMUyOiWiaimFeB6GnqcZSngPVhv/fBoBarnilSq3QocVWoYDXZXwDRm28I5
WxT4vOnUzi3OlVjuSUvVXa/ARIuXiUVOJbyag2/fclKg/UTU4nXvK1G56djv
PpYK7FrypugmswprOtnU/FkKfNqTlswWVkGYnJpS+ZWApOljm8q4Gm7TNfcl
vCbQ6HaGnRJdDW0Nl+j5vQSEOn8dSeiqxi2NuqGDHQTe56hP9jrXwICaMZkq
IjDiF6RVkF+DRCuXlkAOgfS8cwHN/9Sg1U1/1UgmgR8s7UY8gmrBeS8Is48n
IBjxW067UYsM23h9290E4r0O1SVZ8uDPCVNKGQSebIk0+ymVhyb1VLanO4Ha
tFpa1CgPuYJRT/+lBO7E3s2jLuFD4hBHmW9C4OeDogfZAXwUFDAuJE7JESdx
HfbL4GN2jY/ZuSE5YpP26Hnf4GPG5oaI9U/k4JXahB5/x0dU/s/2hVflyEp4
ideLBThts2EovUwO58MrKYUBArh7OTyclyFH8pwks9OZAtx+/nDUJUYOVGu9
aG8XYFgSTR3ZJkdLC3vRikkBxrTTEqw95bDtbjZXLatDdfNFX5WNHE/evukc
3lEHR/N1ixxnyTGe6e5rl/utV391U6tl0Ndwn2rrrINDsrbYrk+GD7oUR940
ITbmdjv23JBhg3nEW+lKIQ713j84XCZDvOHUxvAoIdp8V6zZelqGpw+eJ67l
ChFsuppuESFDeA+VndInxMRhEc9powzWke8SF5jUY86dl9fTaDKEDCd9mkuv
x3cvGA4mhjKYV5z8Kza5HhlW+091jEkhy9z2O/NaPST+Ks/s+1Js7ojzPa+u
x0yvseawKimcLYJIup0IeqWa0mWnpWB59Jie3ydC1HSxShIqxUT7pywmV4SN
WrMXOrpLwRjbUseXitD5g1Wh2zwpPnIW5uaZiuE+9iEnvf8ViuZrdNhuFcM+
ZHA3M+0VrLnLLWNyxdg+LUsVbP8K6n0sj/BnYiSH/+ZM7xpA545AFs24Afcz
m4b+iB4Afek91weMBpwks7xCqANwnxZGD89ugEdMPPdrST9OuOg8H33WAH++
pjqc1o9NMZLIs/MaIZN2dXnV9cHvxMyO/YGNWJnQOilb1odxIjU4gd0In4+f
D5sW9MKvbaX5v8pG/AfkUeh4
              "]]}, {
             Hue[0.9060679774997897, 0.6, 0.6], 
             Directive[
              PointSize[
               NCache[
                Rational[1, 72], 0.013888888888888888`]], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0v0/FAYAx/HrsiRNV/Q4mstrniqpxFX4qtVu1ZWw1+I8JOa2NKxW0ZNq
ipqHMUrl6R64c849PziXcXeOzsNMFEN5KGOpKElZsbUfPq/3P/AhR8T5RxEJ
BMLBD/1v+UKBl9C8EC5p+Wmx396EWxzZau1gIXh5A+caLG6BHK73EVcX4bCl
yLVMdQtNG8/XZOxlItm2+/T7sDxEfEoyaKuYyPzezEFvmo+nBUTZ+BoWds6R
EKYl+bB/niV3KmQhQ2jeJqIXYFlK+/IjJDa8aky/6TIpxMaK382bk9godhu3
zBYXIoordnN7y0aCLtlZRS9CSKpnbUUMB70LFlSuns1Eg5QoDhnkwFMwP9Az
iImtAT0rnEKKMb2nvj1dzMTh0fqv7e4XgzYwNp88h4VNzxgDfr4liF4Y+Xgy
hIUUzo3DtxtLkEWycScpWBgf39DKoHJhxvN+HGPOxo2JYafgOi6+yLcwkiLZ
sBLQdEU7ePhLP6Od0rBh0zd3uWcdD4QhOd/JkoNw9fpRD2opdnaRQllHOGAR
2rbkNZbCcXKH8pCBg39DOJRYXz7u+vemHrEpBmX9+8jK+3x0zu6vrDlZDM7X
k4mXQ8sQqH+w9GBrMajU9pyeoTKYBixJ3O1cguEh9rThqADzFrENP10qgYy/
IWLPjAC/W2TXzu0rwZdn92gT0srx0NE54OFmLu5+1Rt4zFoIOinYiXSNi2jT
BO4CkRC3HyYILr/g4lHdkv3Ht4ngcIcWSaPxkDuT0i/oEMG/ZcO6qFIe4te4
+eljxOjiuY22mpSiMzDKLGK2BHRNzMXMQ6UQ3gmc17dfglZefHNxdSm0R9OH
wookSO8cUFpY8xGk+5v596gEu4cVDn+c4qN/avhKEqQ4NUQkDXfysUzdA48s
Kd7vu3zogHsZtuUVVZsPSvGyapcV+VoZVjT2BJtRZNAnxtrvnChDTH1fGyVd
hijHF/mGAAFWEh33cB7LMPXd1UtMuQDBDYYfGFvlaK58q3tmWY5PuK6xjBw5
1FtSmcnHy7FCsWimZlQOuekvJy/cL0d8tWto4m4FJq5Nnu9xF+LhurYoIU+B
Eb9Qk5s3hLBawysKmqNEWu6vdM0/Qvxc+G5fJkOJVXauIz6hIijCmZcPGpWQ
jvitddGKkEas39SxWoUzu47JkuzEII98TDXJUqHtQMzKz1PEWK8li/55o4Lo
qsgl9qkY0QmG9OHwCtyJb8i1cJTg3FmKkd9UAeoPypZsugS+H20jxVHUON28
+YlfugS34nxa9/LUiE/6zmy3VoJIL51j2LJKiDnOkedeSSDrSLLXpFYi80I3
nttLMUj95N25WRq4/+hByKNL4Zx918t4SoNLi5NWXsmQwsr6xL3eCQ1QbvKn
Xi/F6eD5n7OP3UZVFfOzTW+ksM+32EZ/dRvrOjW2z1bLsNDLM2dDfBXaxl80
PQmXwYXTcDh4pgpjGd6+rtdlYPQeJcy7+hvmEb1ndE0yhHVIMnlLq/F6LmGj
eJYcx1uec8ll1fjS9sh4v4ccrEevDz3xqcGZBTN7GbFypC8+YPR7UIP2lo6L
20vkWDVtU3/CWwtGlwUz+YEcKRYF9RFZWjjEvLpoY6VAZ1Duiu3DWkQ8SZpa
QlOgv3fx6yAfHWz553+Jv6TAeaJbu3WBDgMZIUcDflPA/ScWRTytw37jad+c
SQXG3iR750fo4U4O/YvmqsRJVVf3r816JPh0WedEK7E3jUp/vrUWL/VTmQEl
SlgbVzVUS2vhP3pAJulXYqKDGSZxMeAt+9PrudYqkJG0JEBhQP4yonFdkArH
U0nfLt5RB4eStXYnrqswpqlTD/bVYTI6wYdx78MXr0aurUqtR1N4cIKLZQUK
Nm6dM7zrDmhOjZtb/CuQW529i2JnhPesb2iM7Aq44sbrZ+QGJFJMO57eqwC/
fPWjF6GN2HeiOSZrqRpDF91m1S5vhl/ix8bvg9WIy6GnF1O7MfY45eAFphr8
EImYb94NP52H7bshNf4Dw4Lngg==
              "]]}}}, {{}, {}}}, {{}, {{{}, {}, {}, {}, {}, {}, {
             Directive[
              RGBColor[1, 0, 0], 
              Opacity[0.3]], 
             
             LineBox[{{0.6527747123833239, 0.}, {0.6527747123833239, 
              0.04499999999999999}}], 
             
             LineBox[{{0.058282727768576285`, 0.}, {0.058282727768576285`, 
              0.04499999999999999}}], 
             
             LineBox[{{0.058282727768576285`, 0.}, {0.058282727768576285`, 
              0.04499999999999999}}]}, {}, {
             Directive[
              RGBColor[0, 0, 1], 
              Opacity[0.3]], 
             
             LineBox[{{0.6089801996195733, 0.}, {0.6089801996195733, 
              0.060000000000000005`}}], 
             
             LineBox[{{0.0849694386729136, 0.}, {0.0849694386729136, 
              0.060000000000000005`}}], 
             
             LineBox[{{0.0849694386729136, 0.}, {0.0849694386729136, 
              0.060000000000000005`}}]}, {}, {
             Directive[
              RGBColor[1, 0.5, 0], 
              Opacity[0.3]], 
             LineBox[{{0.5550796362222564, 0.}, {0.5550796362222564, 0.075}}], 
             LineBox[{{0.1195884049731048, 0.}, {0.1195884049731048, 0.075}}], 
             
             LineBox[{{0.1195884049731048, 0.}, {0.1195884049731048, 
              0.075}}]}}, {{
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[1, 0, 0]], 
             GeometricTransformationBox[
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox[
                  GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], 
                  GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}, StripOnInput -> False], 
                 TraditionalForm]], {0., 0.}, Automatic, 
               Scaled[9.75]], {{{0.6527747123833239, 0.04499999999999999}}, {{
              0.058282727768576285`, 0.04499999999999999}}, {{
              0.058282727768576285`, 0.04499999999999999}}}]}, {
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[0, 0, 1]], 
             GeometricTransformationBox[
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox[
                  GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], 
                  GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}, StripOnInput -> False], 
                 TraditionalForm]], {0., 0.}, Automatic, 
               Scaled[9.75]], {{{0.6089801996195733, 
              0.060000000000000005`}}, {{0.0849694386729136, 
              0.060000000000000005`}}, {{0.0849694386729136, 
              0.060000000000000005`}}}]}, {
             Directive[
              PointSize[0.012833333333333334`], 
              AbsoluteThickness[1.6], 
              RGBColor[1, 0.5, 0]], 
             GeometricTransformationBox[
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox[
                  GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}], 
                  GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[0.012833333333333334`], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]]}, StripOnInput -> False], 
                 TraditionalForm]], {0., 0.}, Automatic, 
               Scaled[9.75]], {{{0.5550796362222564, 0.075}}, {{
              0.1195884049731048, 0.075}}, {{0.1195884049731048, 
              0.075}}}]}}}, {{}, {}}}}, {
        DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
         NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
         AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
         Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
            FormBox[
             TagBox[
              StyleBox[
              "\"\\!\\(\\*SuperscriptBox[\\(P\\), \\(*\\)]\\) [1]\"", Bold, 
               14, SingleLetterItalics -> False, StripOnInput -> False], 
              HoldForm], TraditionalForm], None}, {
            FormBox[
             TagBox[
              StyleBox[
              "\"\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(L\\), \
\\(*\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(\[Rho]\\), \\(V\\), \\(*\\)]\\) [1]\
\"", Bold, 14, SingleLetterItalics -> False, StripOnInput -> False], 
              HoldForm], TraditionalForm], None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {Automatic, Automatic}, GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> Medium, 
         Method -> {
          "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
           "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), "CopiedValueFunction" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& )}}, PlotLabel -> 
         FormBox["\"LJ_ref-LJ_1 @T = 1. K\\n\"", TraditionalForm], 
         PlotRange -> {{0., 0.9}, {0, 0.09727448975150323}}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {
            Scaled[0.02], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
       FormBox[
        TagBox[
         GridBox[{{
            FormBox[
             
             TemplateBox[{
              "\"Liquid \\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(Sat\\)]\\) - \
Thol2016\"", 
               "\"Vapor \\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \\(Sat\\)]\\) - \
Thol2016\""}, "LineLegend", DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"LineLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    
                    TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
                   ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"True", ",", "True"}], "}"}]}], ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}, {
            FormBox[
             
             TemplateBox[{
              "\"Simulation point @6.21292 bar\"", 
               "\"Simulation point @8.28389 bar\"", 
               "\"Simulation point @10.3549 bar\""}, "PointLegend", 
              DisplayFunction -> (StyleBox[
                StyleBox[
                 PaneBox[
                  TagBox[
                   GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #2}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    InsetBox[
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 9.75}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.09205128205128206] -> 
                    Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                    "Grid"], Alignment -> Left, AppearanceElements -> None, 
                  ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                  "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
                False]& ), 
              InterpretationFunction :> (RowBox[{"PointLegend", "[", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 0, 1]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.012833333333333334`", "]"}], 
                    ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0.5, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                   RowBox[{"LegendMarkers", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    DiskBox[{0, 0}, 
                    Offset[{3, 3}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    CircleBox[{0, 0}, 
                    Offset[{3, 3}]]}], ",", "9.75`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[
                    NCache[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}]}, {
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}]}]]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    JoinedCurveBox[
                    NCache[
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{(-2) 3^Rational[1, 2], -2}], 
                    Offset[{2 3^Rational[1, 2], -2}], 
                    Offset[{0, 4}]}], 
                    Line[{
                    Offset[{0, 4}], 
                    Offset[{-3.4641016151377544`, -2}], 
                    Offset[{3.4641016151377544`, -2}], 
                    Offset[{0, 4}]}]], CurveClosed -> True]}], ",", "9.75`"}],
                     "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[1], 
                    PolygonBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}]}]}, 
                    AbsoluteThickness[1.5], 
                    Dashing[{}], 
                    LineBox[{
                    Offset[{0, 3.75}], 
                    Offset[{3.75, 0}], 
                    Offset[{0, -3.75}], 
                    Offset[{-3.75, 0}], 
                    Offset[{0, 3.75}]}]}], ",", "9.75`"}], "}"}]}], "}"}]}], 
                   ",", 
                   RowBox[{"Joined", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "False", ",", "False"}], "}"}]}], 
                   ",", 
                   RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"{", "}"}]}], ",", 
                   RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                 "]"}]& ), Editable -> True], TraditionalForm]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]},
    {
     TemplateBox[{
      "\"Simulation @\"", "6.212920499999999`", 
       "\" bar : \\!\\(\\*SuperscriptBox[SubscriptBox[\\(\[Rho]\\), \\(L\\)], \
\\(*\\)]\\) = \"", "0.6527700000000001`", 
       "\" [1], \\!\\(\\*SuperscriptBox[SubscriptBox[\\(\[Rho]\\), \\(V\\)], \
\\(*\\)]\\) = \"", "0.058280000000000005`", "\" [1]\""},
      "RowDefault"]},
    {
     TemplateBox[{
      "\"Simulation @\"", "8.283894`", 
       "\" bar : \\!\\(\\*SuperscriptBox[SubscriptBox[\\(\[Rho]\\), \\(L\\)], \
\\(*\\)]\\) = \"", "0.6089800000000001`", 
       "\" [1], \\!\\(\\*SuperscriptBox[SubscriptBox[\\(\[Rho]\\), \\(V\\)], \
\\(*\\)]\\) = \"", "0.08497`", "\" [1]\""},
      "RowDefault"]},
    {
     TemplateBox[{
      "\"Simulation @\"", "10.3548675`", 
       "\" bar : \\!\\(\\*SuperscriptBox[SubscriptBox[\\(\[Rho]\\), \\(L\\)], \
\\(*\\)]\\) = \"", "0.55508`", 
       "\" [1], \\!\\(\\*SuperscriptBox[SubscriptBox[\\(\[Rho]\\), \\(V\\)], \
\\(*\\)]\\) = \"", "0.11959000000000002`", "\" [1]\""},
      "RowDefault"]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->
  "Out[132]=",ExpressionUUID->"2af760a3-5867-4607-8431-75e180fd1e6d"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Summary", "Subsection",ExpressionUUID->"407bd18e-3850-463d-9493-911b98cc2784"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "@", 
  RowBox[{"Transpose", "@", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"plotEoSSummary", "[", "#", "]"}], " ", "&"}], "/@", " ", 
     RowBox[{"Range", "@", 
      RowBox[{"Length", "@", "pSim"}]}]}], "}"}]}]}]], "Code",
 CellLabel->
  "In[133]:=",ExpressionUUID->"b4848c7d-5ca7-41b6-b6d9-63f7c6fd43b1"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{
       TagBox[
        GridBox[{{
           StyleBox[
           "\"Summary of Estimations @6.21292 bar\"", Bold, StripOnInput -> 
            False], "\[SpanFromLeft]", "\[SpanFromLeft]", "\[SpanFromLeft]", 
           "\[SpanFromLeft]", "\[SpanFromLeft]", "\[SpanFromLeft]", 
           "\[SpanFromLeft]", "\[SpanFromLeft]"}, {
           StyleBox["\"Method\"", Bold, StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)[mol/mol]\"", Bold, 
            StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)[mol/mol]\"", Bold, 
            StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(v\\), \
\\(liq\\)]\\)[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\"", Bold, 
            StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(v\\), \
\\(vap\\)]\\)[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\"", Bold, 
            StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \
\\(liq\\)]\\)[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\"", Bold, StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \
\\(vap\\)]\\)[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\"", Bold, StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \
\\(\\(liq\\)\\(*\\)\\)]\\)[-]\"", Bold, StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \
\\(\\(vap\\)\\(*\\)\\)]\\)[-]\"", Bold, StripOnInput -> False]}, {
          "\"Ideal Gas\"", "0.742236854447505`", "0.4105258245748828`", 
           "\"-\"", "0.013382535021975573`", "\"-\"", "0.04500000000082938`", 
           "\"-\"", "0.04500000000082938`"}, {
          "\"Virial Equation\"", "\"-\"", "\"(Ideal Gas)\"", "\"-\"", 
           "0.014540721320203447`", "\"-\"", "0.04141569477459555`", "\"-\"", 
           "0.04141569477459555`"}, {
          "\"Van der Waals EoS\"", "0.37007539422472413`", 
           "0.194840786226125`", "0.0008587271393330006`", 
           "0.010872257013647767`", "0.70128687963415`", 
           "0.055389977926758954`", "0.70128687963415`", 
           "0.055389977926758954`"}, {
          "\"t-PR-EoS\"", "0.697193764762943`", "0.46219359493692164`", 
           "0.0008654899646108713`", "0.010046266925199566`", 
           "0.6958071157656445`", "0.059944064843572446`", 
           "0.6958071157656445`", "0.059944064843572446`"}, {
          "\"BWR(Nicolas 1979)\"", "\"(t-PR-LJ)\"", "\"(t-PR-LJ)\"", 
           "0.0009111801587667986`", "0.010484860004492336`", 
           "0.6609165818700917`", "0.05743653951907568`", 
           "0.6609165818700917`", "0.05743653951907568`"}, {
          "\"Thol 2016\"", "\"(t-PR-LJ)\"", "\"(t-PR-LJ)\"", 
           "0.010332633681649502`", "0.0009225450443710915`", 
           "0.058282727768576285`", "0.6527747123833239`", 
           "0.6527747123833239`", "0.058282727768576285`"}}, 
         GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
         GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"]},
    {
     TemplateBox[{
       TagBox[
        GridBox[{{
           StyleBox[
           "\"Summary of Estimations @8.28389 bar\"", Bold, StripOnInput -> 
            False], "\[SpanFromLeft]", "\[SpanFromLeft]", "\[SpanFromLeft]", 
           "\[SpanFromLeft]", "\[SpanFromLeft]", "\[SpanFromLeft]", 
           "\[SpanFromLeft]", "\[SpanFromLeft]"}, {
           StyleBox["\"Method\"", Bold, StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)[mol/mol]\"", Bold, 
            StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)[mol/mol]\"", Bold, 
            StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(v\\), \
\\(liq\\)]\\)[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\"", Bold, 
            StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(v\\), \
\\(vap\\)]\\)[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\"", Bold, 
            StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \
\\(liq\\)]\\)[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\"", Bold, StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \
\\(vap\\)]\\)[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\"", Bold, StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \
\\(\\(liq\\)\\(*\\)\\)]\\)[-]\"", Bold, StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \
\\(\\(vap\\)\\(*\\)\\)]\\)[-]\"", Bold, StripOnInput -> False]}, {
          "\"Ideal Gas\"", "0.5499798504915355`", "0.22814240185230872`", 
           "\"-\"", "0.010036901266481678`", "\"-\"", "0.060000000001105856`",
            "\"-\"", "0.060000000001105856`"}, {
          "\"Virial Equation\"", "\"-\"", "\"(Ideal Gas)\"", "\"-\"", 
           "0.011168002991386145`", "\"-\"", "0.05392316571409288`", "\"-\"", 
           "0.05392316571409288`"}, {
          "\"Van der Waals EoS\"", "0.030287262016023553`", 
           "0.014725068879890753`", "0.0009324439574708518`", 
           "0.007532457747864832`", "0.6458447943975498`", 
           "0.07994921394291325`", "0.6458447943975498`", 
           "0.07994921394291325`"}, {
          "\"t-PR-EoS\"", "0.4907923576811004`", "0.290152625807014`", 
           "0.0009031419694702183`", "0.0067695685140629095`", 
           "0.6667989046652962`", "0.08895900451394761`", 
           "0.6667989046652962`", "0.08895900451394761`"}, {
          "\"BWR(Nicolas 1979)\"", "\"(t-PR-LJ)\"", "\"(t-PR-LJ)\"", 
           "0.000961836706880587`", "0.007222265233645622`", 
           "0.6261084357583844`", "0.08338299086476739`", 
           "0.6261084357583844`", "0.08338299086476739`"}, {
          "\"Thol 2016\"", "\"(t-PR-LJ)\"", "\"(t-PR-LJ)\"", 
           "0.00708741972885332`", "0.0009888894193541924`", 
           "0.0849694386729136`", "0.6089801996195733`", 
           "0.6089801996195733`", "0.0849694386729136`"}}, 
         GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
         GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"]},
    {
     TemplateBox[{
       TagBox[
        GridBox[{{
           StyleBox[
           "\"Summary of Estimations @10.3549 bar\"", Bold, StripOnInput -> 
            False], "\[SpanFromLeft]", "\[SpanFromLeft]", "\[SpanFromLeft]", 
           "\[SpanFromLeft]", "\[SpanFromLeft]", "\[SpanFromLeft]", 
           "\[SpanFromLeft]", "\[SpanFromLeft]"}, {
           StyleBox["\"Method\"", Bold, StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)[mol/mol]\"", Bold, 
            StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SubscriptBox[\\(y\\), \\(1\\)]\\)[mol/mol]\"", Bold, 
            StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(v\\), \
\\(liq\\)]\\)[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\"", Bold, 
            StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(v\\), \
\\(vap\\)]\\)[\\!\\(\\*SuperscriptBox[\\(dm\\), \\(3\\)]\\)/mol]\"", Bold, 
            StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \
\\(liq\\)]\\)[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\"", Bold, StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \
\\(vap\\)]\\)[N/\\!\\(\\*SuperscriptBox[\\(\[CapitalARing]\\), \
\\(3\\)]\\)]\"", Bold, StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \
\\(\\(liq\\)\\(*\\)\\)]\\)[-]\"", Bold, StripOnInput -> False], 
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(\[Rho]\\), \
\\(\\(vap\\)\\(*\\)\\)]\\)[-]\"", Bold, StripOnInput -> False]}, {
          "\"Ideal Gas\"", "0.3577228465355661`", "0.11871234821876434`", 
           "\"-\"", "0.008029521013185343`", "\"-\"", "0.07500000000138231`", 
           "\"-\"", "0.07500000000138231`"}, {
          "\"Virial Equation\"", "\"-\"", "\"(Ideal Gas)\"", "\"-\"", 
           "0.009135768616977182`", "\"-\"", "0.0659182714939708`", "\"-\"", 
           "0.0659182714939708`"}, {
          "\"Van der Waals EoS\"", "\"N/A\"", "\"N/A\"", "\"N/A\"", "\"N/A\"",
            "\"N/A\"", "\"N/A\"", "\"N/A\"", "\"N/A\""}, {
          "\"t-PR-EoS\"", "0.3008570486554176`", "0.17762634894556278`", 
           "0.000985739899072462`", "0.00470091736999211`", 
           "0.6109259415862714`", "0.12810565015334674`", 
           "0.6109259415862714`", "0.12810565015334674`"}, {
          "\"BWR(Nicolas 1979)\"", "\"(t-PR-LJ)\"", "\"(t-PR-LJ)\"", 
           "0.001027569539452978`", "0.005129949545749037`", 
           "0.5860567610057671`", "0.11739181265418647`", 
           "0.5860567610057671`", "0.11739181265418647`"}, {
          "\"Thol 2016\"", "\"(t-PR-LJ)\"", "\"(t-PR-LJ)\"", 
           "0.005035722954373685`", "0.0010849147342145888`", 
           "0.1195884049731048`", "0.5550796362222564`", 
           "0.5550796362222564`", "0.1195884049731048`"}}, 
         GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
         GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{Automatic}}}], 
        "Grid"], FrameStyle -> None},
      "Highlighted"]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellLabel->
  "Out[133]=",ExpressionUUID->"ac9008f0-8603-4dcb-991a-ea68594e52a2"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Credits", "Chapter",ExpressionUUID->"44aeabb7-6bad-4729-8a60-f1d2e55dc1e9"],

Cell["Version 2.0: Niklas Mayr", "Item",ExpressionUUID->"f8912e85-3b28-41c8-9b03-f9e6574d8594"],

Cell["Version 3.1: Michael Haring", "Item",ExpressionUUID->"17d1e8e6-1f88-45d8-b10c-a4834de63a76"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{836.25, 675.},
WindowMargins->{{Automatic, 291.75}, {Automatic, 9.75}},
PrintingPageRange->{Automatic, Automatic},
TaggingRules->{
 "WelcomeScreenSettings" -> {"FEStarting" -> False}, "TryRealOnly" -> False},
TrackCellChangeTimes->False,
IgnoreSpellCheck->False,
Magnification:>1. Inherited,
Background->RGBColor[1, 1, 1],
FrontEndVersion->"13.1 for Microsoft Windows (64-bit) (August 22, 2022)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Code"], InitializationCell -> False, Background -> 
    RGBColor[0.9529411764705882, 0.9529411764705882, 0.9529411764705882]]}, 
  Visible -> False, FrontEndVersion -> 
  "13.1 for Microsoft Windows (64-bit) (August 22, 2022)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"80a8eee9-2ff8-4ddc-a4de-c0afc39cfb9e"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 103, 0, 74, "Title",ExpressionUUID->"4cc34c80-8806-4723-afae-8aad8dfaee4b"],
Cell[686, 24, 177, 3, 63, "Subtitle",ExpressionUUID->"d0f29692-bbf9-4505-bd33-b38cefc5770d"],
Cell[866, 29, 441, 8, 102, "Abstract",ExpressionUUID->"3eb46d30-9946-41f7-8b86-4c9558d9a50d"],
Cell[1310, 39, 733, 20, 78, "Code",ExpressionUUID->"eb8e52dc-3683-4c37-83ed-9994e71f8b90",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2068, 63, 88, 0, 51, "Chapter",ExpressionUUID->"40be499d-edf5-4286-a365-4a28f3485f9b"],
Cell[CellGroupData[{
Cell[2181, 67, 98, 0, 70, "Section",ExpressionUUID->"0b5c408b-e640-4b43-b45b-143a61cb01ba"],
Cell[2282, 69, 454, 8, 70, "Text",ExpressionUUID->"65aa9bbe-68f8-49e7-8516-6625826560b7"],
Cell[CellGroupData[{
Cell[2761, 81, 147, 3, 70, "Item",ExpressionUUID->"cc4a6757-31b6-41ff-b742-747ef4f35b42",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2911, 86, 1400, 37, 70, "Code",ExpressionUUID->"6c59b5ec-04ee-4917-953f-47d77a4489b2",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[4348, 128, 744, 19, 70, "Input",ExpressionUUID->"96f54c96-010b-43c8-89b4-16419dcb7d52"],
Cell[CellGroupData[{
Cell[5117, 151, 183, 3, 70, "Print",ExpressionUUID->"ca5e31de-fd2b-4ac9-b4b9-fd7732e5aac2"],
Cell[5303, 156, 172, 3, 70, "Print",ExpressionUUID->"c05ec7f2-27a7-45b9-9aea-0ebf54021d5b"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5536, 166, 113, 0, 70, "Section",ExpressionUUID->"7fa950cc-0aab-40d2-8d23-235c5b00985b"],
Cell[5652, 168, 298, 5, 70, "Text",ExpressionUUID->"4a5478a5-88a9-4252-b855-fcf53dfa9cbf"],
Cell[CellGroupData[{
Cell[5975, 177, 94, 0, 70, "Subsection",ExpressionUUID->"03cf1172-7266-44a1-b482-895fc8516f20"],
Cell[6072, 179, 269, 6, 70, "Text",ExpressionUUID->"a7cc6462-2c07-4996-b378-e60d6c034d51"],
Cell[6344, 187, 627, 15, 70, "Text",ExpressionUUID->"5b40000c-8b99-4f86-aec4-0e29e2faff04"],
Cell[6974, 204, 3874, 100, 70, "Code",ExpressionUUID->"e2b5119c-03c0-4952-8b46-79d43339e8be",
 InitializationCell->False]
}, Closed]],
Cell[CellGroupData[{
Cell[10885, 309, 98, 0, 70, "Subsection",ExpressionUUID->"81da45b4-f0af-420c-8e8b-1cc1d169c0ae"],
Cell[10986, 311, 3544, 97, 70, "Code",ExpressionUUID->"970d64b2-42db-45af-ab06-05d8d3f96b04",
 InitializationCell->False]
}, Closed]],
Cell[CellGroupData[{
Cell[14567, 413, 116, 0, 70, "Subsection",ExpressionUUID->"91bd02bf-33ef-47dc-ab27-f3d8bb01a5ae"],
Cell[CellGroupData[{
Cell[14708, 417, 3261, 78, 70, "Code",ExpressionUUID->"70ff5398-64cd-408e-b69f-3e082f351e44",
 InitializationCell->False],
Cell[17972, 497, 17621, 382, 70, "Output",ExpressionUUID->"d0205640-9141-4bb2-8e07-cbcbb71b124a"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[35642, 885, 130, 0, 70, "Subsection",ExpressionUUID->"bd3a149d-31f5-4059-b4af-edecf198209f"],
Cell[35775, 887, 1016, 23, 70, "Text",ExpressionUUID->"508de601-a947-4dcb-9ade-c403a078a626"],
Cell[CellGroupData[{
Cell[36816, 914, 5102, 123, 70, "Code",ExpressionUUID->"4f4ab980-1b66-48c9-be9b-4fcbd56d55a7",
 InitializationCell->False],
Cell[41921, 1039, 29160, 623, 70, "Output",ExpressionUUID->"cd7f2a09-9ef2-431e-a63a-ecc6d9550fc8"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[71142, 1669, 122, 0, 70, "Section",ExpressionUUID->"a293ef4b-084b-49b7-bd48-e86c986c3af2"],
Cell[71267, 1671, 1247, 39, 70, "Text",ExpressionUUID->"5ccd3c69-054c-4943-9686-0c0265dc59e1"],
Cell[CellGroupData[{
Cell[72539, 1714, 93, 0, 70, "Subsection",ExpressionUUID->"6aaffb1f-8280-4895-a800-06cd2f6db86d"],
Cell[72635, 1716, 180, 3, 70, "Text",ExpressionUUID->"3fb46bd8-ee56-4fb3-9b4b-85fd9c9e09a5"],
Cell[CellGroupData[{
Cell[72840, 1723, 761, 20, 70, "Code",ExpressionUUID->"e7fb6f4f-2b2b-406a-9cf0-90305525d25e",
 InitializationCell->False],
Cell[73604, 1745, 550, 12, 70, "Output",ExpressionUUID->"f8091540-888c-49b0-b7df-17998230769d"]
}, Open  ]],
Cell[74169, 1760, 532, 14, 70, "Input",ExpressionUUID->"4d5c4b5a-a356-41a9-b16a-d2028988e8c5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74738, 1779, 106, 0, 70, "Subsection",ExpressionUUID->"a0999732-1fe2-48df-8744-b436189cf74c"],
Cell[CellGroupData[{
Cell[74869, 1783, 144, 3, 70, "Item",ExpressionUUID->"c236e83b-e78d-4219-a601-4b19b5fce01d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[75016, 1788, 6539, 163, 70, "Code",ExpressionUUID->"c144d3f3-68ac-4f9f-a97e-a72b2fb9ffba",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[81592, 1956, 149, 2, 70, "Code",ExpressionUUID->"4ab698b3-a25b-4473-9f11-f0d7fdd1d0ab"],
Cell[81744, 1960, 33946, 736, 70, "Print",ExpressionUUID->"fcde49e1-1190-48b2-8449-67a9887b631f"],
Cell[115693, 2698, 499, 10, 70, "Output",ExpressionUUID->"bd936ef3-d263-4a8d-9a0b-982dcc85b644"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[116241, 2714, 1051, 40, 70, "Subsection",ExpressionUUID->"0f9d22e3-5f17-42c6-a6c2-8fc1200b89eb"],
Cell[117295, 2756, 557, 9, 70, "Text",ExpressionUUID->"9c76cdd9-333c-4a15-a47f-4717bebc1821"],
Cell[CellGroupData[{
Cell[117877, 2769, 144, 3, 70, "Item",ExpressionUUID->"e90744d5-5008-4130-8d98-f690e0ae0af7",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[118024, 2774, 5879, 141, 70, "Code",ExpressionUUID->"9d868bd0-50da-4a9e-b759-59348f61fb5a",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[123940, 2920, 154, 2, 70, "Code",ExpressionUUID->"530076bc-b672-4e05-b7b0-71c639b9fe64"],
Cell[124097, 2924, 2893, 70, 70, "Output",ExpressionUUID->"97d18f03-a69a-4b60-8040-f8d1da19ca3b"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[127039, 3000, 1092, 41, 70, "Subsection",ExpressionUUID->"ebdd1c7c-134c-4eb0-9064-c64da6d63fff"],
Cell[128134, 3043, 562, 9, 70, "Text",ExpressionUUID->"0bb7e70d-c653-4888-86c2-0053e234c07f"],
Cell[CellGroupData[{
Cell[128721, 3056, 144, 3, 70, "Item",ExpressionUUID->"b51fd359-3ea7-47d2-800e-b7d4042739dc",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[128868, 3061, 7422, 182, 70, "Code",ExpressionUUID->"3e18ad99-1641-474b-97a6-0867e1a0fef5",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[136327, 3248, 150, 2, 70, "Code",ExpressionUUID->"ebae75c6-4f41-47e5-becf-e25128966df6"],
Cell[136480, 3252, 3065, 73, 70, "Output",ExpressionUUID->"8ff97dab-878b-47ff-a9a1-c039a88c5c17"]
}, Open  ]]
}, Closed]],
Cell[139572, 3329, 166, 3, 70, "Subsection",ExpressionUUID->"122395f9-47bd-4179-9ad3-7b54a7bbddc0"],
Cell[CellGroupData[{
Cell[139763, 3336, 1292, 51, 70, "Subsection",ExpressionUUID->"5c7808b2-a1c0-4739-9d78-17faf0196493"],
Cell[141058, 3389, 978, 24, 70, "Text",ExpressionUUID->"cfde15d6-f14b-4b8e-a5aa-13c39e7957e7"],
Cell[CellGroupData[{
Cell[142061, 3417, 144, 3, 70, "Item",ExpressionUUID->"e951db11-7668-438f-9057-49875dca60d9",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[142208, 3422, 7713, 188, 70, "Code",ExpressionUUID->"8ea46284-dd23-496d-9adb-029f0fb1fdb7",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[149958, 3615, 331, 7, 70, "Code",ExpressionUUID->"36f5efe7-6612-446d-ad35-58c7131e2f04"],
Cell[150292, 3624, 3204, 76, 70, "Output",ExpressionUUID->"db2c819d-2b6a-4d30-9407-d8f85037a846"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[153545, 3706, 1092, 41, 70, "Subsection",ExpressionUUID->"a616a0b7-19a9-4a5f-b9d1-98d047d7ae6c"],
Cell[154640, 3749, 562, 9, 70, "Text",ExpressionUUID->"348cdca4-fa7c-41df-a498-68c5efd3fcca"],
Cell[CellGroupData[{
Cell[155227, 3762, 144, 3, 70, "Item",ExpressionUUID->"7313e692-8c38-479a-94f1-9bb7c1c970eb",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[155374, 3767, 7422, 182, 70, "Code",ExpressionUUID->"ca2e68de-1a80-42b0-8fe1-6210d4c64c81",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[162833, 3954, 150, 2, 70, "Code",ExpressionUUID->"540e17f1-00d9-4355-99f3-c01e16f9d6ce"],
Cell[162986, 3958, 3063, 73, 70, "Output",ExpressionUUID->"d28cc2a7-d350-4a9e-ad99-887df416e7f0"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[166098, 4037, 1092, 41, 70, "Subsection",ExpressionUUID->"f6a7f695-398c-4321-a27d-f31456119102"],
Cell[167193, 4080, 562, 9, 70, "Text",ExpressionUUID->"6af7b426-01bf-4007-8e29-ce98f353c223"],
Cell[CellGroupData[{
Cell[167780, 4093, 144, 3, 70, "Item",ExpressionUUID->"5ae5fae0-f033-48de-b855-8a9e3f6932ad",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[167927, 4098, 7422, 182, 70, "Code",ExpressionUUID->"e3f4e271-809c-4609-af54-863737a5a6bb",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[175386, 4285, 150, 2, 70, "Code",ExpressionUUID->"e7ee90a9-398a-4443-99ec-2ac86175fdc9"],
Cell[175539, 4289, 3063, 73, 70, "Output",ExpressionUUID->"eaa88366-cb5f-4f90-bc3d-71e092a3d0f0"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[178663, 4369, 117, 0, 70, "Section",ExpressionUUID->"63761701-b68f-4d1f-80bf-2ededdd80764"],
Cell[CellGroupData[{
Cell[178805, 4373, 93, 0, 70, "Subsection",ExpressionUUID->"353bdab7-ad52-4bb1-82dc-879a71734a9c"],
Cell[178901, 4375, 164, 3, 70, "Text",ExpressionUUID->"d7777d2c-22fb-4062-aef6-d02747b4b8cc"],
Cell[CellGroupData[{
Cell[179090, 4382, 794, 19, 70, "Code",ExpressionUUID->"46335cb3-a334-4a5b-a3be-d87cb3596242"],
Cell[179887, 4403, 545, 12, 70, "Output",ExpressionUUID->"9a6a73ce-55ef-4a73-b0a2-2686602a90b2"]
}, Open  ]],
Cell[180447, 4418, 242, 6, 70, "Input",ExpressionUUID->"b28a1e94-05aa-4a0d-97a6-3dcdb54ffa87"]
}, Open  ]],
Cell[CellGroupData[{
Cell[180726, 4429, 106, 0, 70, "Subsection",ExpressionUUID->"93953d40-4750-442e-9d8c-013bbc0629d8"],
Cell[CellGroupData[{
Cell[180857, 4433, 144, 3, 70, "Item",ExpressionUUID->"b3d74d09-2c4d-4106-bcbb-d80d6a179f4f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[181004, 4438, 14694, 363, 70, "Code",ExpressionUUID->"8205ed6c-d8ab-4ac2-ac61-d99a89ae4592",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[195735, 4806, 144, 2, 70, "Code",ExpressionUUID->"3c7883a8-0279-40db-bb13-80580be9e3ec"],
Cell[195882, 4810, 36585, 783, 70, "Print",ExpressionUUID->"31bb60b9-6dbe-4f92-8f28-da1d2f78189a"],
Cell[232470, 5595, 500, 10, 70, "Output",ExpressionUUID->"c7e66c2b-2aff-4212-a921-eb99d9a4c5d0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[233019, 5611, 1163, 45, 70, "Subsection",ExpressionUUID->"34e5a7eb-27ea-495a-bbae-d993e75da88d"],
Cell[234185, 5658, 552, 9, 70, "Text",ExpressionUUID->"ec36052f-d702-49e5-8998-67e7b005d0ab"],
Cell[CellGroupData[{
Cell[234762, 5671, 144, 3, 70, "Item",ExpressionUUID->"402fb62c-db64-4284-a255-26a4cbbf0160",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[234909, 5676, 5863, 141, 70, "Code",ExpressionUUID->"e413d0dc-2947-46e8-b553-51f65aeef9fa",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[240809, 5822, 144, 2, 70, "Code",ExpressionUUID->"31bf1b21-1f8e-43b1-98bf-f66e218f16ed"],
Cell[240956, 5826, 2888, 70, 70, "Output",ExpressionUUID->"6094b81e-f76f-43e4-88fd-67935b3a4eae"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[243893, 5902, 1205, 46, 70, "Subsection",ExpressionUUID->"f6cb5052-fc39-4c60-bad2-57da0152b573"],
Cell[245101, 5950, 557, 9, 70, "Text",ExpressionUUID->"8a788864-3971-4051-a5ea-808f6540f735"],
Cell[CellGroupData[{
Cell[245683, 5963, 144, 3, 70, "Item",ExpressionUUID->"45858f5f-2652-4baa-bb90-5c4369ee8d08",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[245830, 5968, 7417, 182, 70, "Code",ExpressionUUID->"8a0e54aa-aaae-4fc8-ab6a-6aab4dfa4354",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[253284, 6155, 145, 2, 70, "Code",ExpressionUUID->"218c26ba-f8ff-48ec-8f70-859b57f57850"],
Cell[253432, 6159, 3064, 73, 70, "Output",ExpressionUUID->"a659a6d1-9bfa-4c41-b8fa-440a53908704"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[256569, 6240, 113, 0, 44, "Chapter",ExpressionUUID->"eba7a218-e177-4f7a-8a5e-c94894d154f9"],
Cell[CellGroupData[{
Cell[256707, 6244, 89, 0, 70, "Section",ExpressionUUID->"6e389be1-8fa2-4cf3-a3a5-384f79966850"],
Cell[256799, 6246, 241, 5, 70, "Text",ExpressionUUID->"21899dcf-dfbb-42b1-bcc8-bc74ea721907"],
Cell[CellGroupData[{
Cell[257065, 6255, 147, 3, 70, "Item",ExpressionUUID->"65fdc864-f2fe-456c-95dc-129e832e4d69",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[257215, 6260, 1101, 29, 70, "Code",ExpressionUUID->"9a9dafbc-7045-4710-b449-959e31276562",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[258353, 6294, 353, 9, 70, "Input",ExpressionUUID->"f97dd372-995a-4dc0-a2c0-6b8d72d5dfa4"],
Cell[258709, 6305, 192, 4, 70, "Print",ExpressionUUID->"c2df9085-dfc8-4699-ae6d-aafb216ca237"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[258950, 6315, 113, 0, 70, "Section",ExpressionUUID->"1e9b91ec-cf0e-4088-8e99-a524b01c68a2"],
Cell[259066, 6317, 148, 2, 70, "Text",ExpressionUUID->"299f7de7-067a-4036-85e1-a31661ba8494"],
Cell[CellGroupData[{
Cell[259239, 6323, 96, 0, 70, "Subsection",ExpressionUUID->"68435494-34fb-47e6-b523-60c4912005e6"],
Cell[CellGroupData[{
Cell[259360, 6327, 97, 0, 70, "Subsubsection",ExpressionUUID->"2c17d576-9f8c-4694-a32a-81b98c972023"],
Cell[259460, 6329, 303, 5, 70, "Text",ExpressionUUID->"5e1d73a6-60c7-4810-ab7c-c25f617cf5b5"],
Cell[259766, 6336, 2505, 69, 70, "Code",ExpressionUUID->"3fb818fe-58e8-4c23-8aa2-99afd112baab"]
}, Closed]],
Cell[CellGroupData[{
Cell[262308, 6410, 109, 0, 70, "Subsubsection",ExpressionUUID->"9c97ede5-42fd-4f52-b7e4-a0ca76db4b14"],
Cell[262420, 6412, 350, 5, 70, "Text",ExpressionUUID->"0214a6a7-5b2e-494d-8a83-1194127f1b82"],
Cell[CellGroupData[{
Cell[262795, 6421, 2373, 60, 70, "Code",ExpressionUUID->"3fd21aa4-cb9a-4d44-a7a7-e788af70c710"],
Cell[265171, 6483, 587, 13, 70, "Output",ExpressionUUID->"261d3208-d821-4a9d-a2d0-38545d4b0b6c"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[265807, 6502, 118, 0, 70, "Subsubsection",ExpressionUUID->"5cec5e44-7bdc-44c9-9373-bc1bd6e1f57c"],
Cell[CellGroupData[{
Cell[265950, 6506, 3656, 86, 70, "Code",ExpressionUUID->"b7a3b516-3e1f-4418-a7e3-d05070db39a3"],
Cell[269609, 6594, 40455, 841, 70, "Output",ExpressionUUID->"41273caf-5469-40a4-9abc-ef7d52b26df7"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[310125, 7442, 89, 0, 70, "Subsection",ExpressionUUID->"4f7865c8-6999-473b-821e-b8ba542d9a81"],
Cell[CellGroupData[{
Cell[310239, 7446, 97, 0, 70, "Subsubsection",ExpressionUUID->"7a60eb14-1be6-43f0-b671-eb05df8ad379"],
Cell[310339, 7448, 1283, 30, 70, "Text",ExpressionUUID->"0b4e9244-61fb-478a-a269-cd86d06dee43"],
Cell[311625, 7480, 4650, 110, 70, "Code",ExpressionUUID->"d33b982f-504c-4de1-945d-c9d214489362"]
}, Closed]],
Cell[CellGroupData[{
Cell[316312, 7595, 154, 2, 70, "Subsubsection",ExpressionUUID->"bfd812f3-3ba7-4b26-89a2-445a2bdae723"],
Cell[CellGroupData[{
Cell[316491, 7601, 5652, 147, 70, "Code",ExpressionUUID->"441fea66-3851-4b21-83df-c714694c42bb"],
Cell[322146, 7750, 22875, 494, 70, "Output",ExpressionUUID->"e84fa9e8-d7e4-454a-893a-39939dd7df36"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[345094, 8252, 123, 0, 70, "Section",ExpressionUUID->"1c394f19-5fd6-4253-8a80-0acb1e7234b1"],
Cell[CellGroupData[{
Cell[345242, 8256, 93, 0, 70, "Subsection",ExpressionUUID->"b5b9711f-8eea-4ea9-85af-69c61ddb1a5d"],
Cell[CellGroupData[{
Cell[345360, 8260, 155, 2, 70, "Subsubsection",ExpressionUUID->"26e4ceee-3c14-402d-9283-4c5b0ed59c3f"],
Cell[CellGroupData[{
Cell[345540, 8266, 821, 25, 70, "Code",ExpressionUUID->"838c990a-610d-4f98-9eca-1f22d1b3fb7c"],
Cell[346364, 8293, 516, 12, 70, "Output",ExpressionUUID->"794cd2d4-ec7d-4325-bc26-083543000235"]
}, Open  ]],
Cell[346895, 8308, 278, 9, 70, "Input",ExpressionUUID->"002a8d37-0b7a-40ac-bdbc-602292333e35"]
}, Open  ]],
Cell[CellGroupData[{
Cell[347210, 8322, 151, 2, 70, "Subsubsection",ExpressionUUID->"6d7c4005-149a-4d9e-a157-472a397b5f52"],
Cell[CellGroupData[{
Cell[347386, 8328, 1486, 41, 70, "Code",ExpressionUUID->"6de0b637-3fe8-4a78-8755-38d9cef70c99"],
Cell[348875, 8371, 546, 13, 70, "Output",ExpressionUUID->"23122e2d-c2ab-46af-98d8-975a94919feb"]
}, Open  ]],
Cell[349436, 8387, 242, 7, 70, "Input",ExpressionUUID->"94f20215-249c-4ca5-ba4d-cdcdb82118a3"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[349727, 8400, 106, 0, 70, "Subsection",ExpressionUUID->"18a6ee31-10ea-4f70-a2e8-8c1bb9ebb96a"],
Cell[CellGroupData[{
Cell[349858, 8404, 144, 3, 70, "Item",ExpressionUUID->"6bb93a86-fb70-475f-82a0-a27fddb7b8e6",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[350005, 8409, 6437, 174, 70, "Code",ExpressionUUID->"90ea53ab-9d8d-42df-944e-93122fb0608e",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[356479, 8588, 159, 3, 70, "Code",ExpressionUUID->"de9045ea-adc9-483c-9f24-4dfaffba72fe"],
Cell[356641, 8593, 17605, 376, 70, "Print",ExpressionUUID->"dd864177-cc12-474c-8247-3a03be36d7d4"],
Cell[374249, 8971, 489, 11, 70, "Output",ExpressionUUID->"629fae46-a311-4ae4-8523-7e1eed8bd95f"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[374799, 8989, 112, 0, 70, "Section",ExpressionUUID->"8aded346-527a-4fce-963c-2dc473164b81"],
Cell[CellGroupData[{
Cell[374936, 8993, 93, 0, 70, "Subsection",ExpressionUUID->"98410589-0b15-47be-ab8d-ce57619f14e3"],
Cell[CellGroupData[{
Cell[375054, 8997, 109, 0, 70, "Subsubsection",ExpressionUUID->"dcfcc158-eaf0-40a4-a4c8-b0b78e1245af"],
Cell[CellGroupData[{
Cell[375188, 9001, 817, 24, 70, "Code",ExpressionUUID->"3b98a83d-41ad-4784-816f-2795bff97ea3"],
Cell[376008, 9027, 512, 11, 70, "Output",ExpressionUUID->"e9fab56c-3584-4a83-bd5a-e4de25cc99a9"]
}, Open  ]],
Cell[376535, 9041, 274, 8, 70, "Input",ExpressionUUID->"50c51e13-d54a-4ddc-aec8-f2de40a76f34"]
}, Open  ]],
Cell[CellGroupData[{
Cell[376846, 9054, 106, 0, 70, "Subsubsection",ExpressionUUID->"e68a9a39-ca7a-4996-a231-da33d5482906"],
Cell[CellGroupData[{
Cell[376977, 9058, 1482, 40, 70, "Code",ExpressionUUID->"b62dcb59-08b4-4f8b-b7ce-88170ed0bb8d"],
Cell[378462, 9100, 542, 12, 70, "Output",ExpressionUUID->"adc19963-48ca-44b5-8b46-f08a99bc0e33"]
}, Open  ]],
Cell[379019, 9115, 238, 6, 70, "Input",ExpressionUUID->"15014561-ca32-47ef-8ff0-daf1252731b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[379294, 9126, 221, 5, 70, "Subsubsection",ExpressionUUID->"c5922b06-3341-49b4-a8c5-68814ff4e64e"],
Cell[379518, 9133, 182, 4, 70, "Input",ExpressionUUID->"2048b3ed-00a5-4031-b52f-028c3fef24fd"],
Cell[379703, 9139, 646, 18, 70, "Code",ExpressionUUID->"dd7a2ad1-621d-406f-a1d7-c81dfe7118ed"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[380398, 9163, 106, 0, 70, "Subsection",ExpressionUUID->"d926d0b1-0538-47b3-a6a5-c96f49f0d23a"],
Cell[CellGroupData[{
Cell[380529, 9167, 144, 3, 70, "Item",ExpressionUUID->"e62957ea-d4da-43ac-8c01-e630d56b6f57",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[380676, 9172, 10714, 258, 70, "Code",ExpressionUUID->"eec17ab2-b0a2-40d8-b76d-ef581f509909",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->False],
Cell[391393, 9432, 7112, 162, 70, "Code",ExpressionUUID->"2c5037d4-f02d-4124-b230-8226ba7f5125",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[398508, 9596, 2583, 58, 70, "Code",ExpressionUUID->"69d6ef33-e9cb-4731-a11c-124b42a58b8b",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[401128, 9659, 146, 2, 70, "Code",ExpressionUUID->"b9be64ad-53e9-4154-8931-dcd88a14a927"],
Cell[401277, 9663, 37908, 792, 70, "Output",ExpressionUUID->"1ddd62c8-6d09-4fde-a3f6-c7ab3bac5fe0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[439222, 10460, 146, 2, 70, "Code",ExpressionUUID->"69a84c80-cc20-4c6e-b58e-af1305b79537"],
Cell[439371, 10464, 1265, 24, 70, "Output",ExpressionUUID->"f2a534e0-15a7-41f8-953a-7b65bf6bc2cf"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[440709, 10496, 101, 0, 44, "Chapter",ExpressionUUID->"f6555796-ca6b-4427-b340-72bff96257f4"],
Cell[440813, 10498, 380, 6, 70, "Text",ExpressionUUID->"803da5f2-3a52-4303-9dd0-b928dff7c475"],
Cell[441196, 10506, 945, 30, 70, "Item",ExpressionUUID->"ee51da28-d115-4b58-8a23-21d253d2e876"],
Cell[442144, 10538, 274, 5, 70, "Text",ExpressionUUID->"fa50cb18-46bc-4f4f-9c01-86d18de1da9b"],
Cell[442421, 10545, 438, 12, 70, "Item",ExpressionUUID->"7695f2e9-aa3f-4867-9bf5-965317208156"],
Cell[CellGroupData[{
Cell[442884, 10561, 93, 0, 70, "Section",ExpressionUUID->"846a700c-360c-49a5-b3e8-2808ff05d1f3"],
Cell[442980, 10563, 239, 4, 70, "Text",ExpressionUUID->"f820cd9a-ff92-4cb9-91d6-8bca18fa6140"],
Cell[443222, 10569, 258, 6, 70, "Input",ExpressionUUID->"08a462d7-1df6-4044-a7f4-ba005ee72194"],
Cell[CellGroupData[{
Cell[443505, 10579, 96, 0, 70, "Subsubsection",ExpressionUUID->"fe2b3837-1f69-4104-9cff-df9c2506a109"],
Cell[CellGroupData[{
Cell[443626, 10583, 112, 0, 70, "Subsubsubsection",ExpressionUUID->"3c831cb5-b66a-4055-9b1b-75425bac7343"],
Cell[443741, 10585, 1404, 40, 70, "Code",ExpressionUUID->"86585789-d5f1-43f6-8087-5fb8bdb9e7f8",
 InitializationCell->False],
Cell[445148, 10627, 1325, 32, 70, "Code",ExpressionUUID->"a7be0586-5a58-46b2-8782-5575fa339b2c"]
}, Closed]],
Cell[CellGroupData[{
Cell[446510, 10664, 93, 0, 70, "Subsubsubsection",ExpressionUUID->"1e8e4d15-c8ed-4ed4-8da6-6d37481a9ed8"],
Cell[446606, 10666, 6530, 171, 70, "Code",ExpressionUUID->"a550cae3-780f-4ace-834c-a6aba032a645"]
}, Closed]],
Cell[CellGroupData[{
Cell[453173, 10842, 94, 0, 70, "Subsubsubsection",ExpressionUUID->"8fe31597-8531-4b57-93df-408c0adf4276"],
Cell[453270, 10844, 1998, 52, 70, "Code",ExpressionUUID->"78380468-4253-41ad-aa67-d0a82c68a918"],
Cell[455271, 10898, 2237, 57, 70, "Code",ExpressionUUID->"91dd0c73-ab18-4357-bd61-5d97c9925cc8"],
Cell[457511, 10957, 6812, 158, 70, "Code",ExpressionUUID->"bfa76649-9c52-4a42-ba50-962a4cba592e"]
}, Closed]],
Cell[CellGroupData[{
Cell[464360, 11120, 115, 0, 70, "Subsubsubsection",ExpressionUUID->"19ca15be-3c66-4f86-8506-3b5ebc6c80f9"],
Cell[464478, 11122, 11242, 263, 70, "Code",ExpressionUUID->"746c72d9-502f-455e-b7e7-54cd50e23139"]
}, Closed]],
Cell[CellGroupData[{
Cell[475757, 11390, 110, 0, 70, "Subsubsubsection",ExpressionUUID->"4b912b8f-47cb-48d0-8af8-cb37ea1d95c3"],
Cell[475870, 11392, 292, 4, 70, "Affiliation",ExpressionUUID->"210def0b-eb5f-4c6d-b789-259dc3acb8e6"],
Cell[476165, 11398, 3556, 93, 70, "Code",ExpressionUUID->"3c52eacc-bb7c-45d5-b165-bad9a91645b3"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[479770, 11497, 109, 0, 70, "Subsubsection",ExpressionUUID->"a6d2da7d-5a38-4f27-b5d5-ace56d84e065"],
Cell[CellGroupData[{
Cell[479904, 11501, 5479, 141, 70, "Code",ExpressionUUID->"814c49a5-6a51-4615-82de-62d43df9668d"],
Cell[485386, 11644, 3942, 103, 70, "Output",ExpressionUUID->"a8e243f3-3b68-4892-99e8-66df9e21808e"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[489389, 11754, 113, 0, 70, "Section",ExpressionUUID->"6361cf02-790f-48f5-89c8-e7317aea2a0e"],
Cell[CellGroupData[{
Cell[489527, 11758, 97, 0, 70, "Subsubsection",ExpressionUUID->"c9327891-80e0-491f-a0a3-eb7bcebd8e9c"],
Cell[489627, 11760, 546, 12, 70, "Text",ExpressionUUID->"fd113abe-9e83-49dc-acb2-4f22d18541c9"],
Cell[490176, 11774, 3749, 104, 70, "Code",ExpressionUUID->"fe828d43-f0d7-47cd-8cdd-a8d8694f0d0a"]
}, Closed]],
Cell[CellGroupData[{
Cell[493962, 11883, 93, 0, 70, "Subsubsection",ExpressionUUID->"ed946af3-a5e9-4c23-9256-ac074a8e17e8"],
Cell[494058, 11885, 268, 4, 70, "Text",ExpressionUUID->"04590034-7c2d-4bd7-83cb-1d8a43858c2a"],
Cell[CellGroupData[{
Cell[494351, 11893, 4078, 94, 70, "Code",ExpressionUUID->"e6304f55-8b96-463b-a2c5-aa9c7d51bcd9"],
Cell[498432, 11989, 37253, 791, 70, "Output",ExpressionUUID->"d245f750-c10c-43f6-b19b-12dfaab3a689"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[535746, 12787, 90, 0, 70, "Section",ExpressionUUID->"59eb7bb5-0e65-4667-80be-c5bfd686a8a6"],
Cell[CellGroupData[{
Cell[535861, 12791, 99, 0, 70, "Subsection",ExpressionUUID->"8046a70d-719f-4065-b5de-306485a649bd"],
Cell[CellGroupData[{
Cell[535985, 12795, 106, 0, 70, "Subsubsection",ExpressionUUID->"e33793c7-072f-4af9-993c-603c55a73411"],
Cell[536094, 12797, 519, 14, 70, "Text",ExpressionUUID->"35f95a9c-f9a0-4512-8140-806e6733878d"],
Cell[CellGroupData[{
Cell[536638, 12815, 1190, 32, 70, "Code",ExpressionUUID->"fb8be027-a311-411f-939c-88e1c493c1d9"],
Cell[537831, 12849, 1016, 25, 70, "Output",ExpressionUUID->"d44d4a41-c7ea-4b93-a149-9b92f3708d33"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[538896, 12880, 118, 0, 70, "Subsubsection",ExpressionUUID->"4cce4dfc-f1ee-4112-9b38-1f83abddcde6"],
Cell[539017, 12882, 301, 8, 70, "Input",ExpressionUUID->"f4970a45-6cd4-4d3b-b256-f83a315483db"],
Cell[539321, 12892, 501, 13, 70, "Code",ExpressionUUID->"7daf9ede-01b5-4474-9977-477c006d1e1d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[539859, 12910, 134, 0, 70, "Subsubsection",ExpressionUUID->"71764eec-15bf-4c28-bff3-0c8bf6b6b70d"],
Cell[539996, 12912, 149, 2, 70, "Text",ExpressionUUID->"e34dd273-3e43-41e6-b562-125917123bb2"],
Cell[540148, 12916, 230, 6, 70, "Code",ExpressionUUID->"f3dd02ce-2ee5-4034-bb93-3ac0970f138a"],
Cell[540381, 12924, 607, 18, 70, "Code",ExpressionUUID->"af9f69ca-f2c5-4a3f-ac12-5abf59dd0b49"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[541037, 12948, 96, 0, 70, "Subsection",ExpressionUUID->"97574ac2-997a-45d1-a2b2-6da0b07aa78b"],
Cell[CellGroupData[{
Cell[541158, 12952, 125, 0, 70, "Subsubsection",ExpressionUUID->"11179285-7135-416c-8a31-8d6c37b6f29c"],
Cell[541286, 12954, 403, 10, 70, "Text",ExpressionUUID->"dba1cf52-1d91-4e26-9d36-94bcab3ed342"],
Cell[CellGroupData[{
Cell[541714, 12968, 651, 18, 70, "Code",ExpressionUUID->"35d5b3cb-c4c0-4e7d-9f00-3e3c9b97900d"],
Cell[542368, 12988, 1026, 25, 70, "Output",ExpressionUUID->"9a0df94b-d33b-46fd-82d7-7dce07fc32ac"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[543443, 13019, 115, 0, 70, "Subsubsection",ExpressionUUID->"ec9b8309-84c6-4b45-98e9-08f52a8cce91"],
Cell[543561, 13021, 520, 15, 70, "Input",ExpressionUUID->"aa9cd368-5104-4825-ab43-a3c94e721439"],
Cell[544084, 13038, 609, 16, 70, "Code",ExpressionUUID->"3c63443a-d112-415f-afee-5444bec0327d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[544730, 13059, 131, 0, 70, "Subsubsection",ExpressionUUID->"ae7778d3-4afb-4dda-aa92-125e4c15a921"],
Cell[544864, 13061, 149, 2, 70, "Text",ExpressionUUID->"460a9236-60f9-4370-8902-c3760f756fc1"],
Cell[545016, 13065, 282, 8, 70, "Code",ExpressionUUID->"365da29f-99f8-47a3-bef9-7b6857794877"],
Cell[545301, 13075, 857, 25, 70, "Code",ExpressionUUID->"e2a76c7e-3b38-4024-8dd9-3907e6c1f1b1"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[546207, 13106, 84, 0, 70, "Subsection",ExpressionUUID->"74d5afbb-8993-42bf-a337-8c9ff3eacc9c"],
Cell[546294, 13108, 204, 3, 70, "Text",ExpressionUUID->"d587ee67-2fa4-4cef-8224-f4dfafcd6b6a"],
Cell[CellGroupData[{
Cell[546523, 13115, 142, 2, 70, "Code",ExpressionUUID->"642bfd0f-f336-4d41-ae0e-a306ab212c4c"],
Cell[546668, 13119, 4102, 102, 70, "Output",ExpressionUUID->"4b23c464-2669-4f41-a71e-76c0ba6d0096"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[550831, 13228, 129, 0, 70, "Section",ExpressionUUID->"231750c2-17fb-447a-b50a-8257a3826e66"],
Cell[550963, 13230, 465, 8, 70, "Text",ExpressionUUID->"04258fe4-8655-4a52-80c1-53569f3fa983"],
Cell[CellGroupData[{
Cell[551453, 13242, 102, 0, 70, "Subsection",ExpressionUUID->"a0b0b673-2f8d-4e73-8ee4-e86bbb2d1ddf"],
Cell[551558, 13244, 347, 5, 70, "Text",ExpressionUUID->"8c0283b3-ada5-49ba-9d29-95c5f00a6071"],
Cell[CellGroupData[{
Cell[551930, 13253, 144, 3, 70, "Item",ExpressionUUID->"6870c652-16e9-4999-b73b-d786b347fc0d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[552077, 13258, 3513, 93, 70, "Code",ExpressionUUID->"6727b581-8a6c-4cc9-ba31-2e0787570caf",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[555627, 13356, 1726, 44, 70, "Code",ExpressionUUID->"3c1fe33f-82d6-4728-8270-73bf7b5feb50"],
Cell[557356, 13402, 5562, 110, 70, "Output",ExpressionUUID->"ede6bd33-74d4-46f4-91ef-c0723fd2db94"]
}, Open  ]],
Cell[CellGroupData[{
Cell[562955, 13517, 93, 0, 70, "Subsubsection",ExpressionUUID->"2781829d-a551-49ab-9c53-8be85b8e94e5"],
Cell[CellGroupData[{
Cell[563073, 13521, 144, 3, 70, "Item",ExpressionUUID->"0ae3b953-f150-43d8-a458-072bc0c4fe1c",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[563220, 13526, 14255, 326, 70, "Code",ExpressionUUID->"b527dc57-a9d5-4ce1-a8ae-3b3faa124ba9",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[577512, 13857, 214, 4, 70, "Code",ExpressionUUID->"efd6f633-fb4a-41f4-9507-5b0d867a7d95"],
Cell[577729, 13863, 32259, 713, 70, "Output",ExpressionUUID->"6561af8e-3d09-45f6-9c46-927e41a0254b"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[610049, 14583, 249, 6, 70, "Subsection",ExpressionUUID->"a089c35d-7d12-4d96-89e6-8e6b0c4296a6"],
Cell[610301, 14591, 262, 4, 70, "Affiliation",ExpressionUUID->"2c7547cd-1ca6-4ce3-84ee-7910545e88df"],
Cell[610566, 14597, 646, 15, 70, "Text",ExpressionUUID->"973bbdc6-3e6b-46ee-a7af-0c4cee2bbe4f"],
Cell[CellGroupData[{
Cell[611237, 14616, 144, 3, 70, "Item",ExpressionUUID->"a179c0fc-548d-48fa-9b0b-bc735f6c8f2f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[611384, 14621, 2154, 55, 70, "Code",ExpressionUUID->"736be2d2-450d-4908-b5fc-b6d475c19353",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[613575, 14681, 1640, 42, 70, "Code",ExpressionUUID->"5845acbe-6def-4b34-a287-1ec4d5600f3e"],
Cell[615218, 14725, 5438, 103, 70, "Output",ExpressionUUID->"778e7c8b-766f-4319-be07-c402ae6c4bb1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[620693, 14833, 93, 0, 70, "Subsubsection",ExpressionUUID->"16b68c92-a700-4d7e-9d8e-4fc30c47dab5"],
Cell[CellGroupData[{
Cell[620811, 14837, 144, 3, 70, "Item",ExpressionUUID->"53ee0fb8-68f5-4f84-8b5b-ca1027837da0",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[620958, 14842, 8021, 188, 70, "Code",ExpressionUUID->"9193b947-07df-49b0-804a-30fa21379db7",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[629016, 15035, 158, 3, 70, "Code",ExpressionUUID->"74051573-5a4c-4709-a05f-ff89433b3118"],
Cell[629177, 15040, 24659, 558, 70, "Print",ExpressionUUID->"7d197a63-d445-458b-b313-a37560f1a9c2"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[653897, 15605, 108, 0, 70, "Subsection",ExpressionUUID->"221439da-fc2b-4864-8cfb-34833b458e4a"],
Cell[654008, 15607, 262, 4, 70, "Affiliation",ExpressionUUID->"558f195f-1633-4e1c-8e31-96f1ee344a63"],
Cell[654273, 15613, 413, 8, 70, "Text",ExpressionUUID->"9ad14459-726f-44b0-8b18-96a9a20a70e8"],
Cell[CellGroupData[{
Cell[654711, 15625, 144, 3, 70, "Item",ExpressionUUID->"72b454e1-2cea-4b9c-a1cc-60116dc95e46",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[654858, 15630, 10093, 242, 70, "Code",ExpressionUUID->"89b91d50-91de-4b26-9ea7-1da7f4dd6380",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[664954, 15874, 10919, 271, 70, "Code",ExpressionUUID->"7ab670cc-ffae-44a5-bc16-e17b89639e49",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[675876, 16147, 1007, 26, 70, "Code",ExpressionUUID->"3ece98c0-f253-4444-8301-a8492b6a0e2e",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[676920, 16178, 2194, 59, 70, "Code",ExpressionUUID->"c0fb8953-a3eb-4d72-97f4-e298c03cb041"],
Cell[679117, 16239, 5606, 110, 70, "Output",ExpressionUUID->"d7542c9f-82e1-4b83-a6a8-785d89b04744"]
}, Open  ]],
Cell[CellGroupData[{
Cell[684760, 16354, 93, 0, 70, "Subsubsection",ExpressionUUID->"6f1f60d9-6a1a-4ab9-8d22-1780e368a6a9"],
Cell[CellGroupData[{
Cell[684878, 16358, 144, 3, 70, "Item",ExpressionUUID->"1f44ebea-aba0-4003-a329-2c55d11983ce",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[685025, 16363, 10394, 254, 70, "Code",ExpressionUUID->"49083bda-3869-4926-a6fd-d1d5ed7b95ea",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[695422, 16619, 9795, 218, 70, "Code",ExpressionUUID->"993accd7-401a-4dd0-bb64-b48d0e7e70e7",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[705220, 16839, 9172, 197, 70, "Code",ExpressionUUID->"d006dadd-5194-45ff-a960-2badb30fbdfb",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[714429, 17041, 504, 14, 70, "Code",ExpressionUUID->"e013f686-c7ad-4ad2-b45d-d82078a7c270"],
Cell[714936, 17057, 62179, 1338, 70, "Output",ExpressionUUID->"a18a7143-90d3-430c-a313-7ab9dd01b1ec"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[777176, 18402, 88, 0, 70, "Subsection",ExpressionUUID->"e291a0db-cdf2-42ca-9071-6065dedb99d3"],
Cell[777267, 18404, 292, 4, 70, "Affiliation",ExpressionUUID->"ff98e3fa-582c-49f5-bc99-0718c8d71ff4"],
Cell[777562, 18410, 391, 7, 70, "Text",ExpressionUUID->"1ce56e81-f746-4d97-8998-743c55ff37b2"],
Cell[CellGroupData[{
Cell[777978, 18421, 144, 3, 70, "Item",ExpressionUUID->"f8c5e4a5-6102-4aaf-9f2b-04222db672fc",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[778125, 18426, 13677, 350, 70, "Code",ExpressionUUID->"e8b95a48-5971-40bf-9bcb-a1cb3ec23bf3",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[791805, 18778, 1008, 26, 70, "Code",ExpressionUUID->"1c111a40-e40d-4c19-8ec6-dc70d87c8ac5",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[792850, 18809, 2206, 59, 70, "Code",ExpressionUUID->"492e11d1-8caa-4133-8836-cc05689b564c"],
Cell[795059, 18870, 5730, 113, 70, "Output",ExpressionUUID->"699b66b3-6c1f-44bb-99ca-c64be9553ae1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[800826, 18988, 93, 0, 70, "Subsubsection",ExpressionUUID->"2dcaf874-88b9-437b-a713-8bfe82f9aeee"],
Cell[CellGroupData[{
Cell[800944, 18992, 144, 3, 70, "Item",ExpressionUUID->"a1b7d1c8-9866-41e7-9d3f-b6eb124725af",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[801091, 18997, 13393, 338, 70, "Code",ExpressionUUID->"06a0856d-153b-494e-8589-bba4ef3a46b4",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[814487, 19337, 9904, 219, 70, "Code",ExpressionUUID->"18f6f0e3-2d01-4059-8363-832212c57bb9",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[824394, 19558, 9192, 197, 70, "Code",ExpressionUUID->"f3b3730c-cb35-4e3b-bb88-223cb2c719b6",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[833623, 19760, 513, 14, 70, "Code",ExpressionUUID->"edab9c17-e948-47c9-b502-e1558228df95"],
Cell[834139, 19776, 66111, 1429, 70, "Output",ExpressionUUID->"e4e31d2f-4b5a-46cd-9c34-cecaf0468ce6"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[900311, 21212, 93, 0, 70, "Subsection",ExpressionUUID->"338f6e86-27a4-499c-ae22-f337ee2889c4"],
Cell[900407, 21214, 189, 3, 70, "Affiliation",ExpressionUUID->"ec90f239-9400-467f-b577-4f289521d7db"],
Cell[900599, 21219, 861, 22, 70, "Text",ExpressionUUID->"34f436f7-59f5-4aef-9d16-c5bb91ebc393"],
Cell[CellGroupData[{
Cell[901485, 21245, 144, 3, 70, "Item",ExpressionUUID->"7a09e19f-b122-4ef1-bc2c-161bf35f3839",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[901632, 21250, 3969, 97, 70, "Code",ExpressionUUID->"344b5cb8-1f1c-45b7-b3a8-f4a4d3251c7f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[905638, 21352, 1688, 45, 70, "Code",ExpressionUUID->"f9d3bc76-f4f0-4992-a27a-5942ed8acb1d"],
Cell[907329, 21399, 5637, 107, 70, "Output",ExpressionUUID->"069af358-861b-41b8-ade4-de1f953eb405"]
}, Open  ]],
Cell[CellGroupData[{
Cell[913003, 21511, 93, 0, 70, "Subsubsection",ExpressionUUID->"1a338604-519b-44dc-bd7d-063a556d4f8b"],
Cell[CellGroupData[{
Cell[913121, 21515, 144, 3, 70, "Item",ExpressionUUID->"d5dad47f-fea8-4245-a626-96028687ec80",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[913268, 21520, 11470, 253, 70, "Code",ExpressionUUID->"c84e1b41-e553-40e2-87a8-d25be295c263",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[924775, 21778, 149, 3, 70, "Code",ExpressionUUID->"8c4c0d8a-0713-4a12-957f-0a9865ecf1fd"],
Cell[924927, 21783, 31201, 686, 70, "Output",ExpressionUUID->"5a44bc01-a425-4b7b-84d8-a8e6cd7f7f2c"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[956189, 22476, 85, 0, 70, "Subsection",ExpressionUUID->"91921058-e3ec-418d-a87a-aaa324608622"],
Cell[956277, 22478, 204, 3, 70, "Affiliation",ExpressionUUID->"027bc494-d58f-4129-b49c-62d1f50b8b81"],
Cell[956484, 22483, 241, 4, 70, "Text",ExpressionUUID->"a7a90047-53a2-4348-9179-637bc8636ac8"],
Cell[CellGroupData[{
Cell[956750, 22491, 144, 3, 70, "Item",ExpressionUUID->"efa527fd-0cd7-4696-9c80-440389682b7d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[956897, 22496, 4464, 110, 70, "Code",ExpressionUUID->"0b29e4ac-3912-48aa-ab69-798a2c897a94",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[961398, 22611, 1646, 45, 70, "Code",ExpressionUUID->"31b1c85a-6202-4b7b-8754-e1b6db312ab3"],
Cell[963047, 22658, 5624, 108, 70, "Output",ExpressionUUID->"2eba4408-b84d-47f4-a12a-77df012a007e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[968708, 22771, 93, 0, 70, "Subsubsection",ExpressionUUID->"d5e524f2-1444-48c2-9e7a-69443ba9c8ad"],
Cell[CellGroupData[{
Cell[968826, 22775, 144, 3, 70, "Item",ExpressionUUID->"af3b4e5e-f94a-4e3d-bf9f-5c567fdb3c38",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[968973, 22780, 12235, 270, 70, "Code",ExpressionUUID->"3c9cbecf-daa1-4985-81a4-199af66a24d9",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[981245, 23055, 146, 3, 70, "Code",ExpressionUUID->"dcb8ff77-1554-4dbc-bf18-bd3cab53732f"],
Cell[981394, 23060, 31441, 690, 70, "Output",ExpressionUUID->"2af760a3-5867-4607-8431-75e180fd1e6d"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1012896, 23757, 84, 0, 70, "Subsection",ExpressionUUID->"407bd18e-3850-463d-9493-911b98cc2784"],
Cell[CellGroupData[{
Cell[1013005, 23761, 356, 10, 70, "Code",ExpressionUUID->"b4848c7d-5ca7-41b6-b6d9-63f7c6fd43b1"],
Cell[1013364, 23773, 10641, 208, 70, "Output",ExpressionUUID->"ac9008f0-8603-4dcb-991a-ea68594e52a2"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1024078, 23989, 81, 0, 44, "Chapter",ExpressionUUID->"44aeabb7-6bad-4729-8a60-f1d2e55dc1e9"],
Cell[1024162, 23991, 95, 0, 25, "Item",ExpressionUUID->"f8912e85-3b28-41c8-9b03-f9e6574d8594"],
Cell[1024260, 23993, 98, 0, 25, "Item",ExpressionUUID->"17d1e8e6-1f88-45d8-b10c-a4834de63a76"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

