(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     19444,        492]
NotebookOptionsPosition[     14729,        403]
NotebookOutlinePosition[     15403,        425]
CellTagsIndexPosition[     15360,        422]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Gibbs Ensemble Monte Carlo Simulations for Fluid Phase Equilibria\
\>", "Title",ExpressionUUID->"9a74398d-b74b-4298-89bb-ce623b836e4c"],

Cell["\<\
Michael Haring
Niklas Mayr
Sebastian Thaler
Thomas Steiner
Thomas Wallek\
\>", "Author",
 CellChangeTimes->{{3.876926652686494*^9, 3.876926659166274*^9}, {
  3.8899732158710155`*^9, 3.8899732404430375`*^9}, {3.9138826662266955`*^9, 
  3.913882676377806*^9}, {3.9138827464578767`*^9, 
  3.913882756097313*^9}},ExpressionUUID->"8d442e59-ec0b-4a99-85ac-\
1c5c8f642534"],

Cell["\<\
Graz University of Technology
Institute of Chemical Engineering and Environmental Technology\
\>", "Affiliation",ExpressionUUID->"e81efadf-8348-44e2-9274-85cf9dcfa1c0"],

Cell[TextData[{
 "This is the Notebook Archive version of the GEMC_-_Algorithm software \
package that is hosted at the GIT-Lab server of TU Graz: \n",
 Cell[BoxData[
  TemplateBox[{
   "\"https://gitlab.tugraz.at/thd/gemc\"", 
    "https://gitlab.tugraz.at/thd/gemc"},
   "HyperlinkURL"]],
  CellChangeTimes->{3.8899735516329384`*^9},ExpressionUUID->
  "9c7910f8-83ec-4fe3-adf8-af7d31327e06"]
}], "Text",
 CellChangeTimes->{{3.889973554926577*^9, 
  3.889973576655821*^9}},ExpressionUUID->"4f3734ad-7829-4b09-8e14-\
4387fd7ae934"],

Cell[TextData[{
 "Here is the link to download 2022-11-6ger7tx_Supplements.zip from Notebook \
Archives: \n",
 Cell[BoxData[
  TemplateBox[{
   "\"https://notebookarchive.org/2022-11-6ger7tx/2022-11-6ger7tx_Supplements.\
zip\"", "https://notebookarchive.org/2022-11-6ger7tx/2022-11-6ger7tx_\
Supplements.zip"},
   "HyperlinkURL"]],
  CellChangeTimes->{{3.88997334060189*^9, 3.8899733547849874`*^9}},
  ExpressionUUID->"1bea6b57-b2e8-42b4-ad2c-215c77668a49"]
}], "Text",
 CellChangeTimes->{{3.8806198149521*^9, 3.8806198303659086`*^9}, {
  3.880620300521414*^9, 3.8806203041972303`*^9}, {3.8899733595290036`*^9, 
  3.8899733648966007`*^9}, {3.889973569604248*^9, 
  3.889973572528554*^9}},ExpressionUUID->"44963e61-f83f-43cb-b5ef-\
66b06a1f2df0"],

Cell["\<\
After unpacking the zip archive see Documentation - v3.1.0.pdf for complete \
information about Gibbs Ensemble Monte Carlo Simulations for Fluid Phase \
Equilibria and instructions for the included Wolfram Language code.\
\>", "Text",
 CellChangeTimes->{
  3.889973589303505*^9, {3.9138828004893093`*^9, 
   3.9138828025122766`*^9}},ExpressionUUID->"62774644-e2f5-4a34-bb73-\
01b6f0749441"],

Cell[CellGroupData[{

Cell["About the Algorithm", "Subsection",
 CellChangeTimes->{{3.8769290706671424`*^9, 
  3.876929100858895*^9}},ExpressionUUID->"111ab41e-fe29-46af-a73d-\
a79d1f7d3ec2"],

Cell["\<\
Molecular dynamics simulations (MD) and Monte Carlo simulations (MC) are the \
two dominant ways to simulate molecular systems in chemical thermodynamics. \
This software package contains the execuable algorithm for a Monte Carlo \
simulation in the Gibbs ensemble (GEMC).
More information about the background, structure and use of the algorthm can \
be found in the documentation (see \[OpenCurlyQuote]Documentation - \
v2.4.0.pdf\[CloseCurlyQuote])\
\>", "Text",
 CellChangeTimes->{
  3.8769291672126107`*^9, {3.8769294990750985`*^9, 3.8769295003624477`*^9}, {
   3.876929572299808*^9, 3.876929956751582*^9}, {3.8899736460887084`*^9, 
   3.889973681409155*^9}},ExpressionUUID->"384c64b6-ee72-4e10-b068-\
657d6608e433"],

Cell["\<\
The following list states the main concepts implemented in the present GEMC \
package:\
\>", "Text",
 CellChangeTimes->{
  3.8769298136896753`*^9},ExpressionUUID->"72d2fdfd-b42e-4fe9-9520-\
3c9c3cad22ca"],

Cell[CellGroupData[{

Cell["Project Structure", "Item",
 CellChangeTimes->{
  3.876929176975461*^9, {3.876929208659067*^9, 3.8769292396423407`*^9}, 
   3.8769293280340843`*^9, 3.8769294794576807`*^9, 
   3.8899737274047594`*^9},ExpressionUUID->"edb500b2-f111-47c4-96a8-\
dc3c631e0de2"],

Cell["\<\
As proposed by Allen and Tildesley, the simulation consists of three phases, \
namely the warm-up, equilibration and production phase.\
\>", "ItemParagraph",
 CellChangeTimes->{{3.876929190027787*^9, 3.876929212948683*^9}, 
   3.876929252723609*^9, {3.876929483752366*^9, 3.876929485571995*^9}, 
   3.8899738083223734`*^9},ExpressionUUID->"5d487aa0-cac9-43a0-a854-\
d88486e5d7e6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gibbs Ensemble Monte Carlo Algorithm", "Item",
 CellChangeTimes->{
  3.876929176975461*^9, {3.876929208659067*^9, 3.8769292396423407`*^9}, 
   3.8769293280340843`*^9, 3.8769294794576807`*^9, 
   3.8899737312140765`*^9},ExpressionUUID->"6089c7d2-fa58-454e-89b2-\
f933e52a7d58"],

Cell["\<\
The basis of the present software package is the Gibbs ensemble Monte Carlo \
algorithm in the NVT and NPT ensemble.\
\>", "ItemParagraph",
 CellChangeTimes->{{3.876929190027787*^9, 3.876929212948683*^9}, 
   3.876929252723609*^9, {3.876929483752366*^9, 3.876929485571995*^9}, 
   3.8899738204372244`*^9},ExpressionUUID->"bad1e5fc-98d6-4fb2-a6c5-\
6dad1a4a8cee"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OPLS Force Field", "Item",
 CellChangeTimes->{
  3.876929176975461*^9, {3.876929208659067*^9, 3.8769292396423407`*^9}, 
   3.8769293280340843`*^9, 3.8769294794576807`*^9, {3.8899737357419252`*^9, 
   3.8899737360582666`*^9}},ExpressionUUID->"ee00b148-3846-4cf6-9849-\
9f6bf196a6a1"],

Cell["\<\
The OPLS Force Field is used for the calculation of the intermolecular \
interactions.\
\>", "ItemParagraph",
 CellChangeTimes->{{3.876929190027787*^9, 3.876929212948683*^9}, 
   3.876929252723609*^9, {3.876929483752366*^9, 3.876929485571995*^9}, 
   3.889973831603272*^9},ExpressionUUID->"3b6be43d-e501-4dd9-a3b8-\
33d96ac90061"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tail Corrections for Energy and Pressure", "Item",
 CellChangeTimes->{
  3.876929176975461*^9, {3.876929208659067*^9, 3.8769292396423407`*^9}, 
   3.8769293280340843`*^9, 3.8769294794576807`*^9, 
   3.8899737410398207`*^9},ExpressionUUID->"6038321d-1ef1-4c86-828b-\
36311243b166"],

Cell["\<\
Analytical tail corrections are used to account for the truncation of the \
intermolecular interactions of the Lennard-Jones potential.\
\>", "ItemParagraph",
 CellChangeTimes->{{3.876929190027787*^9, 3.876929212948683*^9}, 
   3.876929252723609*^9, {3.876929483752366*^9, 3.876929485571995*^9}, 
   3.8899738416056585`*^9},ExpressionUUID->"81a45b03-d227-4b0d-817c-\
7272be5a61d6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Various Combining Rules", "Item",
 CellChangeTimes->{
  3.876929176975461*^9, {3.876929208659067*^9, 3.8769292396423407`*^9}, 
   3.8769293280340843`*^9, 3.8769294794576807`*^9, 
   3.889973745134847*^9},ExpressionUUID->"e372060b-6762-4de1-bedc-\
830981b94703"],

Cell["\<\
The calculation of cross interactions can be done using the geometric mean or \
the Lorenz-Berthelot combining rules.\
\>", "ItemParagraph",
 CellChangeTimes->{{3.876929190027787*^9, 3.876929212948683*^9}, 
   3.876929252723609*^9, {3.876929483752366*^9, 3.876929485571995*^9}, {
   3.889973856427452*^9, 
   3.8899738629435577`*^9}},ExpressionUUID->"6ec1f4d6-485d-43b7-b062-\
f4b11bf97e00"],

Cell["Other combining rules can be easily implemented.", "ItemParagraph",
 CellChangeTimes->{{3.876929190027787*^9, 3.876929212948683*^9}, 
   3.876929252723609*^9, {3.876929483752366*^9, 3.876929485571995*^9}, {
   3.889973856427452*^9, 
   3.8899738627430105`*^9}},ExpressionUUID->"129b8690-191f-40cf-8e73-\
8a00a33f521e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pressure Calculation", "Item",
 CellChangeTimes->{
  3.876929176975461*^9, {3.876929208659067*^9, 3.8769292396423407`*^9}, 
   3.8769293280340843`*^9, 3.8769294794576807`*^9, {3.8899737494928875`*^9, 
   3.889973751620467*^9}},ExpressionUUID->"5c3aa187-d8c3-44f1-9423-\
af83d581597c"],

Cell["\<\
The pressure is calculated based on the ideal and virial contribution.\
\>", "ItemParagraph",
 CellChangeTimes->{{3.876929190027787*^9, 3.876929212948683*^9}, 
   3.876929252723609*^9, {3.876929483752366*^9, 3.876929485571995*^9}, 
   3.8899738760436597`*^9},ExpressionUUID->"e79e80c7-e405-40b3-9035-\
81cb7d84c93a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Widom Ghost Particle Method", "Item",
 CellChangeTimes->{
  3.876929176975461*^9, {3.876929208659067*^9, 3.8769292396423407`*^9}, 
   3.8769293280340843`*^9, 3.8769294794576807`*^9, 
   3.8899737559155827`*^9},ExpressionUUID->"583dbc8a-9b12-4a58-95d8-\
3ddf70d0eb8f"],

Cell["\<\
The Widom ghost particle method is used to determine the chemical potential.\
\>", "ItemParagraph",
 CellChangeTimes->{{3.876929190027787*^9, 3.876929212948683*^9}, 
   3.876929252723609*^9, {3.876929483752366*^9, 3.876929485571995*^9}, 
   3.889973885437053*^9},ExpressionUUID->"7cf0b4e5-3126-48cf-a2d3-\
52a9021695b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Electrostatic Long-Range Correction", "Item",
 CellChangeTimes->{
  3.876929176975461*^9, {3.876929208659067*^9, 3.8769292396423407`*^9}, 
   3.8769293280340843`*^9, 3.8769294794576807`*^9, 
   3.8899737609216647`*^9},ExpressionUUID->"2cbd4c28-4244-48bd-aa72-\
a5ceb9872fe2"],

Cell["\<\
The electrostatic potential at long distances can be calculated with either \
the Ewald or Wolf summation.\
\>", "ItemParagraph",
 CellChangeTimes->{{3.876929190027787*^9, 3.876929212948683*^9}, 
   3.876929252723609*^9, {3.876929483752366*^9, 3.876929485571995*^9}, {
   3.8899738942397532`*^9, 
   3.8899739005795*^9}},ExpressionUUID->"a8c30907-bb88-4de2-adb4-\
f37a07c71b5e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Improved Insertion Algorithm for Binary Mixtures", "Item",
 CellChangeTimes->{
  3.876929176975461*^9, {3.876929208659067*^9, 3.8769292396423407`*^9}, 
   3.8769293280340843`*^9, 3.8769294794576807`*^9, 
   3.889973769179792*^9},ExpressionUUID->"4268d91a-82d3-449b-9fa2-\
cfd1e663d38a"],

Cell["\<\
An improved insertion algorithm to increase the acceptance rate of molecule \
transfers based on identity changes is implemented for binary mixtures.\
\>", "ItemParagraph",
 CellChangeTimes->{{3.876929190027787*^9, 3.876929212948683*^9}, 
   3.876929252723609*^9, {3.876929483752366*^9, 3.876929485571995*^9}, {
   3.8899739122407837`*^9, 
   3.8899739169847317`*^9}},ExpressionUUID->"8f1deec0-f59c-40bb-a6f5-\
939685cebdf7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constraint-Specific Intramolecular Trial Moves", "Item",
 CellChangeTimes->{
  3.876929176975461*^9, {3.876929208659067*^9, 3.8769292396423407`*^9}, 
   3.8769293280340843`*^9, 3.8769294794576807`*^9, 3.889973769179792*^9, {
   3.9138828407528963`*^9, 
   3.9138828418960056`*^9}},ExpressionUUID->"ede27aed-684e-4726-aa8e-\
42ac3bf0b087"],

Cell["\<\
Additional trial moves to allow for intramolecular bond, angle and dihedral \
angle flexibility.\
\>", "ItemParagraph",
 CellChangeTimes->{{3.876929190027787*^9, 3.876929212948683*^9}, 
   3.876929252723609*^9, {3.876929483752366*^9, 3.876929485571995*^9}, {
   3.8899739122407837`*^9, 3.8899739169847317`*^9}, {3.9138828496761513`*^9, 
   3.91388285865569*^9}},ExpressionUUID->"4df29a7f-0014-40f1-92b5-\
927db032a2d7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Continuous Fractional Component (CFC) Method", "Item",
 CellChangeTimes->{
  3.876929176975461*^9, {3.876929208659067*^9, 3.8769292396423407`*^9}, 
   3.8769293280340843`*^9, 3.8769294794576807`*^9, {3.8899737752639103`*^9, 
   3.889973778518115*^9}},ExpressionUUID->"31c45185-c82c-4139-b52b-\
f801633fff08"],

Cell["\<\
The continuous fractional component method is implemented as suggested by Ali \
Poursaeidesfahani in the working group of Thijs J. H. Vlugt.\
\>", "ItemParagraph",
 CellChangeTimes->{{3.876929190027787*^9, 3.876929212948683*^9}, 
   3.876929252723609*^9, {3.876929483752366*^9, 3.876929485571995*^9}, 
   3.889973929334132*^9},ExpressionUUID->"d828541a-93b4-4802-a408-\
8047cc19b109"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Auto-calibration of Transfers", "Item",
 CellChangeTimes->{
  3.876929176975461*^9, {3.876929208659067*^9, 3.8769292396423407`*^9}, 
   3.8769293280340843`*^9, 3.8769294794576807`*^9, {3.8899737752639103`*^9, 
   3.889973778518115*^9}, 
   3.8899739444890385`*^9},ExpressionUUID->"f9d573de-d25b-4567-a0af-\
4b0a4093e58d"],

Cell["\<\
If activated, the number of attempted transfers per cycle can be \
auto-calibrated to yield a required number of successful trial moves per \
cycle.\
\>", "ItemParagraph",
 CellChangeTimes->{{3.876929190027787*^9, 3.876929212948683*^9}, 
   3.876929252723609*^9, {3.876929483752366*^9, 3.876929485571995*^9}, 
   3.889973929334132*^9, {3.889973971160366*^9, 
   3.889973973203948*^9}},ExpressionUUID->"f181bddb-9d53-4713-a1c5-\
8c17dbef8b62"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Species Choice Probability for Insertions", "Item",
 CellChangeTimes->{
  3.876929176975461*^9, {3.876929208659067*^9, 3.8769292396423407`*^9}, 
   3.8769293280340843`*^9, 3.8769294794576807`*^9, {3.8899737752639103`*^9, 
   3.889973778518115*^9}, 
   3.8899739491543713`*^9},ExpressionUUID->"2c245164-227c-4c2a-b938-\
8fc0d0ff7c03"],

Cell["\<\
The probability to choose a species for an attempted insertion can be tuned \
or autocalibrated to yield an equal number of successful transfers per \
species.\
\>", "ItemParagraph",
 CellChangeTimes->{{3.876929190027787*^9, 3.876929212948683*^9}, 
   3.876929252723609*^9, {3.876929483752366*^9, 3.876929485571995*^9}, 
   3.889973929334132*^9, {3.889973980091509*^9, 
   3.889973981989907*^9}},ExpressionUUID->"2dd50d86-70a4-4aa0-a23a-\
e1c0dbd7e773"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Combined Analysis of Simulations", "Item",
 CellChangeTimes->{
  3.876929176975461*^9, {3.876929208659067*^9, 3.8769292396423407`*^9}, 
   3.8769293280340843`*^9, 3.8769294794576807`*^9, {3.8899737752639103`*^9, 
   3.889973778518115*^9}, 
   3.8899739554245105`*^9},ExpressionUUID->"d4a64324-ae9b-461d-88b1-\
92659f5c1552"],

Cell["\<\
Results of multiple continuous simulations and extensions can be summarized \
and displayed in a single file.\
\>", "ItemParagraph",
 CellChangeTimes->{{3.876929190027787*^9, 3.876929212948683*^9}, 
   3.876929252723609*^9, {3.876929483752366*^9, 3.876929485571995*^9}, 
   3.889973929334132*^9, {3.88997399950445*^9, 
   3.889974008381526*^9}},ExpressionUUID->"b32e38cc-f39f-4a4e-9613-\
2193230aae46"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{789, 642},
WindowMargins->{{Automatic, 310.5}, {Automatic, 45.75}},
FrontEndVersion->"13.1 for Microsoft Windows (64-bit) (August 22, 2022)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Item"], FontWeight -> "Bold"]}, Visible -> False, 
  FrontEndVersion -> "13.1 for Microsoft Windows (64-bit) (August 22, 2022)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"05fe1fb1-a499-4d0e-b0fa-2e710d625a4c"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 145, 2, 121, "Title",ExpressionUUID->"9a74398d-b74b-4298-89bb-ce623b836e4c"],
Cell[728, 26, 376, 11, 105, "Author",ExpressionUUID->"8d442e59-ec0b-4a99-85ac-1c5c8f642534"],
Cell[1107, 39, 178, 3, 41, "Affiliation",ExpressionUUID->"e81efadf-8348-44e2-9274-85cf9dcfa1c0"],
Cell[1288, 44, 531, 13, 43, "Text",ExpressionUUID->"4f3734ad-7829-4b09-8e14-4387fd7ae934"],
Cell[1822, 59, 745, 16, 43, "Text",ExpressionUUID->"44963e61-f83f-43cb-b5ef-66b06a1f2df0"],
Cell[2570, 77, 400, 8, 45, "Text",ExpressionUUID->"62774644-e2f5-4a34-bb73-01b6f0749441"],
Cell[CellGroupData[{
Cell[2995, 89, 169, 3, 41, "Subsection",ExpressionUUID->"111ab41e-fe29-46af-a73d-a79d1f7d3ec2"],
Cell[3167, 94, 731, 13, 63, "Text",ExpressionUUID->"384c64b6-ee72-4e10-b068-657d6608e433"],
Cell[3901, 109, 214, 6, 27, "Text",ExpressionUUID->"72d2fdfd-b42e-4fe9-9520-3c9c3cad22ca"],
Cell[CellGroupData[{
Cell[4140, 119, 263, 5, 25, "Item",ExpressionUUID->"edb500b2-f111-47c4-96a8-dc3c631e0de2"],
Cell[4406, 126, 390, 7, 19, "ItemParagraph",ExpressionUUID->"5d487aa0-cac9-43a0-a854-d88486e5d7e6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4833, 138, 282, 5, 25, "Item",ExpressionUUID->"6089c7d2-fa58-454e-89b2-f933e52a7d58"],
Cell[5118, 145, 372, 7, 19, "ItemParagraph",ExpressionUUID->"bad1e5fc-98d6-4fb2-a6c5-6dad1a4a8cee"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5527, 157, 288, 5, 25, "Item",ExpressionUUID->"ee00b148-3846-4cf6-9849-9f6bf196a6a1"],
Cell[5818, 164, 340, 7, 19, "ItemParagraph",ExpressionUUID->"3b6be43d-e501-4dd9-a3b8-33d96ac90061"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6195, 176, 286, 5, 25, "Item",ExpressionUUID->"6038321d-1ef1-4c86-828b-36311243b166"],
Cell[6484, 183, 391, 7, 19, "ItemParagraph",ExpressionUUID->"81a45b03-d227-4b0d-817c-7272be5a61d6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6912, 195, 267, 5, 25, "Item",ExpressionUUID->"e372060b-6762-4de1-bedc-830981b94703"],
Cell[7182, 202, 401, 8, 19, "ItemParagraph",ExpressionUUID->"6ec1f4d6-485d-43b7-b062-f4b11bf97e00"],
Cell[7586, 212, 324, 5, 19, "ItemParagraph",ExpressionUUID->"129b8690-191f-40cf-8e73-8a00a33f521e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7947, 222, 290, 5, 25, "Item",ExpressionUUID->"5c3aa187-d8c3-44f1-9423-af83d581597c"],
Cell[8240, 229, 326, 6, 19, "ItemParagraph",ExpressionUUID->"e79e80c7-e405-40b3-9035-81cb7d84c93a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8603, 240, 273, 5, 25, "Item",ExpressionUUID->"583dbc8a-9b12-4a58-95d8-3ddf70d0eb8f"],
Cell[8879, 247, 330, 6, 19, "ItemParagraph",ExpressionUUID->"7cf0b4e5-3126-48cf-a2d3-52a9021695b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9246, 258, 281, 5, 25, "Item",ExpressionUUID->"2cbd4c28-4244-48bd-aa72-a5ceb9872fe2"],
Cell[9530, 265, 388, 8, 19, "ItemParagraph",ExpressionUUID->"a8c30907-bb88-4de2-adb4-f37a07c71b5e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9955, 278, 292, 5, 25, "Item",ExpressionUUID->"4268d91a-82d3-449b-9fa2-cfd1e663d38a"],
Cell[10250, 285, 435, 8, 36, "ItemParagraph",ExpressionUUID->"8f1deec0-f59c-40bb-a6f5-939685cebdf7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10722, 298, 344, 6, 25, "Item",ExpressionUUID->"ede27aed-684e-4726-aa8e-42ac3bf0b087"],
Cell[11069, 306, 429, 8, 19, "ItemParagraph",ExpressionUUID->"4df29a7f-0014-40f1-92b5-927db032a2d7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11535, 319, 314, 5, 25, "Item",ExpressionUUID->"31c45185-c82c-4139-b52b-f801633fff08"],
Cell[11852, 326, 394, 7, 19, "ItemParagraph",ExpressionUUID->"d828541a-93b4-4802-a408-8047cc19b109"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12283, 338, 327, 6, 25, "Item",ExpressionUUID->"f9d573de-d25b-4567-a0af-4b0a4093e58d"],
Cell[12613, 346, 452, 9, 19, "ItemParagraph",ExpressionUUID->"f181bddb-9d53-4713-a1c5-8c17dbef8b62"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13102, 360, 339, 6, 25, "Item",ExpressionUUID->"2c245164-227c-4c2a-b938-8fc0d0ff7c03"],
Cell[13444, 368, 463, 9, 36, "ItemParagraph",ExpressionUUID->"2dd50d86-70a4-4aa0-a23a-e1c0dbd7e773"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13944, 382, 330, 6, 25, "Item",ExpressionUUID->"d4a64324-ae9b-461d-88b1-92659f5c1552"],
Cell[14277, 390, 412, 8, 19, "ItemParagraph",ExpressionUUID->"b32e38cc-f39f-4a4e-9613-2193230aae46"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

